@@ -1,5 +1,5 @@
 /*
- * Copyright 2019-2022 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2019-2020 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -8,16 +8,21 @@
  */
 
 #ifndef OSSL_APPS_FUNCTION_H
-# define OSSL_APPS_FUNCTION_H
+#define OSSL_APPS_FUNCTION_H
 
-# include <openssl/lhash.h>
-# include "opt.h"
+#include <openssl/lhash.h>
+#include "opt.h"
 
-#define DEPRECATED_NO_ALTERNATIVE   "unknown"
+#define DEPRECATED_NO_ALTERNATIVE "unknown"
 
 typedef enum FUNC_TYPE {
-    FT_none, FT_general, FT_md, FT_cipher, FT_pkey,
-    FT_md_alg, FT_cipher_alg
+    FT_none,
+    FT_general,
+    FT_md,
+    FT_cipher,
+    FT_pkey,
+    FT_md_alg,
+    FT_cipher_alg
 } FUNC_TYPE;
 
 typedef struct function_st {
