@@ -15,7 +15,11 @@
 
 typedef enum OPTION_choice {
     OPT_COMMON,
-    OPT_HEX, OPT_GENERATE, OPT_BITS, OPT_SAFE, OPT_CHECKS,
+    OPT_HEX,
+    OPT_GENERATE,
+    OPT_BITS,
+    OPT_SAFE,
+    OPT_CHECKS,
     OPT_PROV_ENUM
 } OPTION_CHOICE;
 
@@ -28,33 +32,36 @@ static int check_num(const char *s, const int is_hex)
      */
     if (is_hex) {
         for (i = 0; ('0' <= s[i] && s[i] <= '9')
-                    || ('A' <= s[i] && s[i] <= 'F')
-                    || ('a' <= s[i] && s[i] <= 'f'); i++);
+            || ('A' <= s[i] && s[i] <= 'F')
+            || ('a' <= s[i] && s[i] <= 'f');
+            i++)
+            ;
     } else {
-        for (i = 0;  '0' <= s[i] && s[i] <= '9'; i++);
+        for (i = 0; '0' <= s[i] && s[i] <= '9'; i++)
+            ;
     }
     return s[i] == 0;
 }
 
 const OPTIONS prime_options[] = {
-    {OPT_HELP_STR, 1, '-', "Usage: %s [options] [number...]\n"},
+    { OPT_HELP_STR, 1, '-', "Usage: %s [options] [number...]\n" },
 
     OPT_SECTION("General"),
-    {"help", OPT_HELP, '-', "Display this summary"},
-    {"bits", OPT_BITS, 'p', "Size of number in bits"},
-    {"checks", OPT_CHECKS, 'p', "Number of checks"},
+    { "help", OPT_HELP, '-', "Display this summary" },
+    { "bits", OPT_BITS, 'p', "Size of number in bits" },
+    { "checks", OPT_CHECKS, 'p', "Number of checks" },
 
     OPT_SECTION("Output"),
-    {"hex", OPT_HEX, '-', "Hex output"},
-    {"generate", OPT_GENERATE, '-', "Generate a prime"},
-    {"safe", OPT_SAFE, '-',
-     "When used with -generate, generate a safe prime"},
+    { "hex", OPT_HEX, '-', "Hex output" },
+    { "generate", OPT_GENERATE, '-', "Generate a prime" },
+    { "safe", OPT_SAFE, '-',
+        "When used with -generate, generate a safe prime" },
 
     OPT_PROV_OPTIONS,
 
     OPT_PARAMETERS(),
-    {"number", 0, 0, "Number(s) to check for primality if not generating"},
-    {NULL}
+    { "number", 0, 0, "Number(s) to check for primality if not generating" },
+    { NULL }
 };
 
 int prime_main(int argc, char **argv)
@@ -69,7 +76,7 @@ int prime_main(int argc, char **argv)
         switch (o) {
         case OPT_EOF:
         case OPT_ERR:
-opthelp:
+        opthelp:
             BIO_printf(bio_err, "%s: Use -help for summary.\n", prog);
             goto end;
         case OPT_HELP:
@@ -133,7 +140,7 @@ opthelp:
         BIO_printf(bio_out, "%s\n", s);
         OPENSSL_free(s);
     } else {
-        for ( ; *argv; argv++) {
+        for (; *argv; argv++) {
             int r = check_num(argv[0], hex);
 
             if (r)
@@ -151,13 +158,13 @@ opthelp:
                 goto end;
             }
             BIO_printf(bio_out, " (%s) %s prime\n",
-                       argv[0],
-                       r == 1 ? "is" : "is not");
+                argv[0],
+                r == 1 ? "is" : "is not");
         }
     }
 
     ret = 0;
- end:
+end:
     BN_free(bn);
     return ret;
 }
