@@ -19,9 +19,9 @@
 #include <openssl/encoder.h>
 #include <openssl/buffer.h>
 #include <openssl/x509.h>
-#include <openssl/rsa.h>         /* For i2d_RSAPublicKey */
-#include <openssl/dsa.h>         /* For i2d_DSAPublicKey */
-#include <openssl/ec.h>          /* For i2o_ECPublicKey */
+#include <openssl/rsa.h> /* For i2d_RSAPublicKey */
+#include <openssl/dsa.h> /* For i2d_DSAPublicKey */
+#include <openssl/ec.h> /* For i2o_ECPublicKey */
 #include "crypto/asn1.h"
 #include "crypto/evp.h"
 
@@ -31,14 +31,14 @@ struct type_and_structure_st {
 };
 
 static int i2d_provided(const EVP_PKEY *a, int selection,
-                        const struct type_and_structure_st *output_info,
-                        unsigned char **pp)
+    const struct type_and_structure_st *output_info,
+    unsigned char **pp)
 {
     int ret;
 
     for (ret = -1;
-         ret == -1 && output_info->output_type != NULL;
-         output_info++) {
+        ret == -1 && output_info->output_type != NULL;
+        output_info++) {
         /*
          * The i2d_ calls don't take a boundary length for *pp.  However,
          * OSSL_ENCODER_to_data() needs one, so we make one up.  Because
@@ -51,9 +51,9 @@ static int i2d_provided(const EVP_PKEY *a, int selection,
         OSSL_ENCODER_CTX *ctx;
 
         ctx = OSSL_ENCODER_CTX_new_for_pkey(a, selection,
-                                            output_info->output_type,
-                                            output_info->output_structure,
-                                            NULL);
+            output_info->output_type,
+            output_info->output_structure,
+            NULL);
         if (ctx == NULL)
             return -1;
         if (OSSL_ENCODER_to_data(ctx, pp, &len)) {
@@ -75,7 +75,9 @@ int i2d_KeyParams(const EVP_PKEY *a, unsigned char **pp)
     if (evp_pkey_is_provided(a)) {
         static const struct type_and_structure_st output_info[] = {
             { "DER", "type-specific" },
-            { NULL, }
+            {
+                NULL,
+            }
         };
 
         return i2d_provided(a, EVP_PKEY_KEY_PARAMETERS, output_info, pp);
@@ -97,7 +99,9 @@ int i2d_PrivateKey(const EVP_PKEY *a, unsigned char **pp)
         static const struct type_and_structure_st output_info[] = {
             { "DER", "type-specific" },
             { "DER", "PrivateKeyInfo" },
-            { NULL, }
+            {
+                NULL,
+            }
         };
 
         return i2d_provided(a, EVP_PKEY_KEYPAIR, output_info, pp);
@@ -124,8 +128,10 @@ int i2d_PublicKey(const EVP_PKEY *a, unsigned char **pp)
     if (evp_pkey_is_provided(a)) {
         static const struct type_and_structure_st output_info[] = {
             { "DER", "type-specific" },
-            { "blob", NULL },    /* for EC */
-            { NULL, }
+            { "blob", NULL }, /* for EC */
+            {
+                NULL,
+            }
         };
 
         return i2d_provided(a, EVP_PKEY_PUBLIC_KEY, output_info, pp);
