@@ -1,5 +1,5 @@
 /*
- * Copyright 2000-2021 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2000-2024 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -14,6 +14,7 @@
 #include <openssl/objects.h>
 #include <openssl/buffer.h>
 #include <openssl/err.h>
+#include "crypto/asn1.h"
 #include "internal/numbers.h"
 #include "asn1_local.h"
 
@@ -25,63 +26,80 @@
  */
 #define ASN1_MAX_CONSTRUCTED_NEST 30
 
-static int asn1_item_embed_d2i(ASN1_VALUE **pval, const unsigned char **in,
-                               long len, const ASN1_ITEM *it,
-                               int tag, int aclass, char opt, ASN1_TLC *ctx,
-                               int depth, OSSL_LIB_CTX *libctx,
-                               const char *propq);
-
 static int asn1_check_eoc(const unsigned char **in, long len);
 static int asn1_find_end(const unsigned char **in, long len, char inf);
 
 static int asn1_collect(BUF_MEM *buf, const unsigned char **in, long len,
-                        char inf, int tag, int aclass, int depth);
+    char inf, int tag, int aclass, int depth);
 
 static int collect_data(BUF_MEM *buf, const unsigned char **p, long plen);
 
 static int asn1_check_tlen(long *olen, int *otag, unsigned char *oclass,
-                           char *inf, char *cst,
-                           const unsigned char **in, long len,
-                           int exptag, int expclass, char opt, ASN1_TLC *ctx);
+    char *inf, char *cst,
+    const unsigned char **in, long len,
+    int exptag, int expclass, char opt, ASN1_TLC *ctx);
 
 static int asn1_template_ex_d2i(ASN1_VALUE **pval,
-                                const unsigned char **in, long len,
-                                const ASN1_TEMPLATE *tt, char opt,
-                                ASN1_TLC *ctx, int depth, OSSL_LIB_CTX *libctx,
-                                const char *propq);
+    const unsigned char **in, long len,
+    const ASN1_TEMPLATE *tt, char opt,
+    ASN1_TLC *ctx, int depth, OSSL_LIB_CTX *libctx,
+    const char *propq);
 static int asn1_template_noexp_d2i(ASN1_VALUE **val,
-                                   const unsigned char **in, long len,
-                                   const ASN1_TEMPLATE *tt, char opt,
-                                   ASN1_TLC *ctx, int depth,
-                                   OSSL_LIB_CTX *libctx, const char *propq);
+    const unsigned char **in, long len,
+    const ASN1_TEMPLATE *tt, char opt,
+    ASN1_TLC *ctx, int depth,
+    OSSL_LIB_CTX *libctx, const char *propq);
 static int asn1_d2i_ex_primitive(ASN1_VALUE **pval,
-                                 const unsigned char **in, long len,
-                                 const ASN1_ITEM *it,
-                                 int tag, int aclass, char opt,
-                                 ASN1_TLC *ctx);
+    const unsigned char **in, long len,
+    const ASN1_ITEM *it,
+    int tag, int aclass, char opt,
+    ASN1_TLC *ctx);
 static int asn1_ex_c2i(ASN1_VALUE **pval, const unsigned char *cont, int len,
-                       int utype, char *free_cont, const ASN1_ITEM *it);
+    int utype, char *free_cont, const ASN1_ITEM *it);
 
 /* Table to convert tags to bit values, used for MSTRING type */
 static const unsigned long tag2bit[32] = {
     /* tags  0 -  3 */
-    0, 0, 0, B_ASN1_BIT_STRING,
+    0,
+    0,
+    0,
+    B_ASN1_BIT_STRING,
     /* tags  4- 7 */
-    B_ASN1_OCTET_STRING, 0, 0, B_ASN1_UNKNOWN,
+    B_ASN1_OCTET_STRING,
+    0,
+    0,
+    B_ASN1_UNKNOWN,
     /* tags  8-11 */
-    B_ASN1_UNKNOWN, B_ASN1_UNKNOWN, 0, B_ASN1_UNKNOWN,
+    B_ASN1_UNKNOWN,
+    B_ASN1_UNKNOWN,
+    0,
+    B_ASN1_UNKNOWN,
     /* tags 12-15 */
-    B_ASN1_UTF8STRING, B_ASN1_UNKNOWN, B_ASN1_UNKNOWN, B_ASN1_UNKNOWN,
+    B_ASN1_UTF8STRING,
+    B_ASN1_UNKNOWN,
+    B_ASN1_UNKNOWN,
+    B_ASN1_UNKNOWN,
     /* tags 16-19 */
-    B_ASN1_SEQUENCE, 0, B_ASN1_NUMERICSTRING, B_ASN1_PRINTABLESTRING,
+    B_ASN1_SEQUENCE,
+    0,
+    B_ASN1_NUMERICSTRING,
+    B_ASN1_PRINTABLESTRING,
     /* tags 20-22 */
-    B_ASN1_T61STRING, B_ASN1_VIDEOTEXSTRING, B_ASN1_IA5STRING,
+    B_ASN1_T61STRING,
+    B_ASN1_VIDEOTEXSTRING,
+    B_ASN1_IA5STRING,
     /* tags 23-24 */
-    B_ASN1_UTCTIME, B_ASN1_GENERALIZEDTIME,
+    B_ASN1_UTCTIME,
+    B_ASN1_GENERALIZEDTIME,
     /* tags 25-27 */
-    B_ASN1_GRAPHICSTRING, B_ASN1_ISO64STRING, B_ASN1_GENERALSTRING,
+    B_ASN1_GRAPHICSTRING,
+    B_ASN1_ISO64STRING,
+    B_ASN1_GENERALSTRING,
     /* tags 28-31 */
-    B_ASN1_UNIVERSALSTRING, B_ASN1_UNKNOWN, B_ASN1_BMPSTRING, B_ASN1_UNKNOWN,
+    B_ASN1_UNIVERSALSTRING,
+    B_ASN1_UNKNOWN,
+    B_ASN1_BMPSTRING,
+    B_ASN1_UNKNOWN,
 };
 
 unsigned long ASN1_tag2bit(int tag)
@@ -93,9 +111,16 @@ unsigned long ASN1_tag2bit(int tag)
 
 /* Macro to initialize and invalidate the cache */
 
-#define asn1_tlc_clear(c)       do { if ((c) != NULL) (c)->valid = 0; } while (0)
+#define asn1_tlc_clear(c)   \
+    do {                    \
+        if ((c) != NULL)    \
+            (c)->valid = 0; \
+    } while (0)
 /* Version to avoid compiler warning about 'c' always non-NULL */
-#define asn1_tlc_clear_nc(c)    do {(c)->valid = 0; } while (0)
+#define asn1_tlc_clear_nc(c) \
+    do {                     \
+        (c)->valid = 0;      \
+    } while (0)
 
 /*
  * Decode an ASN1 item, this currently behaves just like a standard 'd2i'
@@ -105,9 +130,9 @@ unsigned long ASN1_tag2bit(int tag)
  */
 
 static int asn1_item_ex_d2i_intern(ASN1_VALUE **pval, const unsigned char **in,
-                                   long len, const ASN1_ITEM *it, int tag,
-                                   int aclass, char opt, ASN1_TLC *ctx,
-                                   OSSL_LIB_CTX *libctx, const char *propq)
+    long len, const ASN1_ITEM *it, int tag,
+    int aclass, char opt, ASN1_TLC *ctx,
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     int rv;
 
@@ -116,24 +141,24 @@ static int asn1_item_ex_d2i_intern(ASN1_VALUE **pval, const unsigned char **in,
         return 0;
     }
     rv = asn1_item_embed_d2i(pval, in, len, it, tag, aclass, opt, ctx, 0,
-                             libctx, propq);
+        libctx, propq);
     if (rv <= 0)
         ASN1_item_ex_free(pval, it);
     return rv;
 }
 
 int ASN1_item_ex_d2i(ASN1_VALUE **pval, const unsigned char **in, long len,
-                     const ASN1_ITEM *it,
-                     int tag, int aclass, char opt, ASN1_TLC *ctx)
+    const ASN1_ITEM *it,
+    int tag, int aclass, char opt, ASN1_TLC *ctx)
 {
     return asn1_item_ex_d2i_intern(pval, in, len, it, tag, aclass, opt, ctx,
-                                   NULL, NULL);
+        NULL, NULL);
 }
 
 ASN1_VALUE *ASN1_item_d2i_ex(ASN1_VALUE **pval,
-                             const unsigned char **in, long len,
-                             const ASN1_ITEM *it, OSSL_LIB_CTX *libctx,
-                             const char *propq)
+    const unsigned char **in, long len,
+    const ASN1_ITEM *it, OSSL_LIB_CTX *libctx,
+    const char *propq)
 {
     ASN1_TLC c;
     ASN1_VALUE *ptmpval = NULL;
@@ -142,14 +167,15 @@ ASN1_VALUE *ASN1_item_d2i_ex(ASN1_VALUE **pval,
         pval = &ptmpval;
     asn1_tlc_clear_nc(&c);
     if (asn1_item_ex_d2i_intern(pval, in, len, it, -1, 0, 0, &c, libctx,
-                                propq) > 0)
+            propq)
+        > 0)
         return *pval;
     return NULL;
 }
 
 ASN1_VALUE *ASN1_item_d2i(ASN1_VALUE **pval,
-                          const unsigned char **in, long len,
-                          const ASN1_ITEM *it)
+    const unsigned char **in, long len,
+    const ASN1_ITEM *it)
 {
     return ASN1_item_d2i_ex(pval, in, len, it, NULL, NULL);
 }
@@ -159,11 +185,11 @@ ASN1_VALUE *ASN1_item_d2i(ASN1_VALUE **pval,
  * tag mismatch return -1 to handle OPTIONAL
  */
 
-static int asn1_item_embed_d2i(ASN1_VALUE **pval, const unsigned char **in,
-                               long len, const ASN1_ITEM *it,
-                               int tag, int aclass, char opt, ASN1_TLC *ctx,
-                               int depth, OSSL_LIB_CTX *libctx,
-                               const char *propq)
+int asn1_item_embed_d2i(ASN1_VALUE **pval, const unsigned char **in,
+    long len, const ASN1_ITEM *it,
+    int tag, int aclass, char opt, ASN1_TLC *ctx,
+    int depth, OSSL_LIB_CTX *libctx,
+    const char *propq)
 {
     const ASN1_TEMPLATE *tt, *errtt = NULL;
     const ASN1_EXTERN_FUNCS *ef;
@@ -208,14 +234,14 @@ static int asn1_item_embed_d2i(ASN1_VALUE **pval, const unsigned char **in,
              */
             if ((tag != -1) || opt) {
                 ERR_raise(ERR_LIB_ASN1,
-                          ASN1_R_ILLEGAL_OPTIONS_ON_ITEM_TEMPLATE);
+                    ASN1_R_ILLEGAL_OPTIONS_ON_ITEM_TEMPLATE);
                 goto err;
             }
             return asn1_template_ex_d2i(pval, in, len, it->templates, opt, ctx,
-                                        depth, libctx, propq);
+                depth, libctx, propq);
         }
         return asn1_d2i_ex_primitive(pval, in, len, it,
-                                     tag, aclass, opt, ctx);
+            tag, aclass, opt, ctx);
 
     case ASN1_ITYPE_MSTRING:
         /*
@@ -230,7 +256,7 @@ static int asn1_item_embed_d2i(ASN1_VALUE **pval, const unsigned char **in,
         p = *in;
         /* Just read in tag and class */
         ret = asn1_check_tlen(NULL, &otag, &oclass, NULL, NULL,
-                              &p, len, -1, 0, 1, ctx);
+            &p, len, -1, 0, 1, ctx);
         if (!ret) {
             ERR_raise(ERR_LIB_ASN1, ERR_R_NESTED_ASN1_ERROR);
             goto err;
@@ -260,7 +286,7 @@ static int asn1_item_embed_d2i(ASN1_VALUE **pval, const unsigned char **in,
         ef = it->funcs;
         if (ef->asn1_ex_d2i_ex != NULL)
             return ef->asn1_ex_d2i_ex(pval, in, len, it, tag, aclass, opt, ctx,
-                                      libctx, propq);
+                libctx, propq);
         return ef->asn1_ex_d2i(pval, in, len, it, tag, aclass, opt, ctx);
 
     case ASN1_ITYPE_CHOICE:
@@ -296,7 +322,7 @@ static int asn1_item_embed_d2i(ASN1_VALUE **pval, const unsigned char **in,
              * We mark field as OPTIONAL so its absence can be recognised.
              */
             ret = asn1_template_ex_d2i(pchptr, &p, len, tt, 1, ctx, depth,
-                                       libctx, propq);
+                libctx, propq);
             /* If field not present, try the next one */
             if (ret == -1)
                 continue;
@@ -344,7 +370,7 @@ static int asn1_item_embed_d2i(ASN1_VALUE **pval, const unsigned char **in,
         }
         /* Get SEQUENCE length and update len, p */
         ret = asn1_check_tlen(&len, NULL, NULL, &seq_eoc, &cst,
-                              &p, len, tag, aclass, opt, ctx);
+            &p, len, tag, aclass, opt, ctx);
         if (!ret) {
             ERR_raise(ERR_LIB_ASN1, ERR_R_NESTED_ASN1_ERROR);
             goto err;
@@ -363,7 +389,7 @@ static int asn1_item_embed_d2i(ASN1_VALUE **pval, const unsigned char **in,
         }
 
         if (*pval == NULL
-                && !ossl_asn1_item_ex_new_intern(pval, it, libctx, propq)) {
+            && !ossl_asn1_item_ex_new_intern(pval, it, libctx, propq)) {
             ERR_raise(ERR_LIB_ASN1, ERR_R_NESTED_ASN1_ERROR);
             goto err;
         }
@@ -420,7 +446,7 @@ static int asn1_item_embed_d2i(ASN1_VALUE **pval, const unsigned char **in,
              */
 
             ret = asn1_template_ex_d2i(pseqval, &p, len, seqtt, isopt, ctx,
-                                       depth, libctx, propq);
+                depth, libctx, propq);
             if (!ret) {
                 errtt = seqtt;
                 goto err;
@@ -477,12 +503,12 @@ static int asn1_item_embed_d2i(ASN1_VALUE **pval, const unsigned char **in,
     default:
         return 0;
     }
- auxerr:
+auxerr:
     ERR_raise(ERR_LIB_ASN1, ASN1_R_AUX_ERROR);
- err:
+err:
     if (errtt)
         ERR_add_error_data(4, "Field=", errtt->field_name,
-                           ", Type=", it->sname);
+            ", Type=", it->sname);
     else
         ERR_add_error_data(2, "Type=", it->sname);
     return 0;
@@ -494,10 +520,10 @@ static int asn1_item_embed_d2i(ASN1_VALUE **pval, const unsigned char **in,
  */
 
 static int asn1_template_ex_d2i(ASN1_VALUE **val,
-                                const unsigned char **in, long inlen,
-                                const ASN1_TEMPLATE *tt, char opt,
-                                ASN1_TLC *ctx, int depth,
-                                OSSL_LIB_CTX *libctx, const char *propq)
+    const unsigned char **in, long inlen,
+    const ASN1_TEMPLATE *tt, char opt,
+    ASN1_TLC *ctx, int depth,
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     int flags, aclass;
     int ret;
@@ -519,7 +545,7 @@ static int asn1_template_ex_d2i(ASN1_VALUE **val,
          * where it starts: so read in EXPLICIT header to get the info.
          */
         ret = asn1_check_tlen(&len, NULL, NULL, &exp_eoc, &cst,
-                              &p, inlen, tt->tag, aclass, opt, ctx);
+            &p, inlen, tt->tag, aclass, opt, ctx);
         q = p;
         if (!ret) {
             ERR_raise(ERR_LIB_ASN1, ERR_R_NESTED_ASN1_ERROR);
@@ -532,7 +558,7 @@ static int asn1_template_ex_d2i(ASN1_VALUE **val,
         }
         /* We've found the field so it can't be OPTIONAL now */
         ret = asn1_template_noexp_d2i(val, &p, len, tt, 0, ctx, depth, libctx,
-                                      propq);
+            propq);
         if (!ret) {
             ERR_raise(ERR_LIB_ASN1, ERR_R_NESTED_ASN1_ERROR);
             return 0;
@@ -556,20 +582,20 @@ static int asn1_template_ex_d2i(ASN1_VALUE **val,
         }
     } else
         return asn1_template_noexp_d2i(val, in, inlen, tt, opt, ctx, depth,
-                                       libctx, propq);
+            libctx, propq);
 
     *in = p;
     return 1;
 
- err:
+err:
     return 0;
 }
 
 static int asn1_template_noexp_d2i(ASN1_VALUE **val,
-                                   const unsigned char **in, long len,
-                                   const ASN1_TEMPLATE *tt, char opt,
-                                   ASN1_TLC *ctx, int depth,
-                                   OSSL_LIB_CTX *libctx, const char *propq)
+    const unsigned char **in, long len,
+    const ASN1_TEMPLATE *tt, char opt,
+    ASN1_TLC *ctx, int depth,
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     int flags, aclass;
     int ret;
@@ -608,7 +634,7 @@ static int asn1_template_noexp_d2i(ASN1_VALUE **val,
         }
         /* Get the tag */
         ret = asn1_check_tlen(&len, NULL, NULL, &sk_eoc, NULL,
-                              &p, len, sktag, skaclass, opt, ctx);
+            &p, len, sktag, skaclass, opt, ctx);
         if (!ret) {
             ERR_raise(ERR_LIB_ASN1, ERR_R_NESTED_ASN1_ERROR);
             return 0;
@@ -649,8 +675,9 @@ static int asn1_template_noexp_d2i(ASN1_VALUE **val,
             }
             skfield = NULL;
             if (asn1_item_embed_d2i(&skfield, &p, len,
-                                     ASN1_ITEM_ptr(tt->item), -1, 0, 0, ctx,
-                                     depth, libctx, propq) <= 0) {
+                    ASN1_ITEM_ptr(tt->item), -1, 0, 0, ctx,
+                    depth, libctx, propq)
+                <= 0) {
                 ERR_raise(ERR_LIB_ASN1, ERR_R_NESTED_ASN1_ERROR);
                 /* |skfield| may be partially allocated despite failure. */
                 ASN1_item_free(skfield, ASN1_ITEM_ptr(tt->item));
@@ -670,8 +697,8 @@ static int asn1_template_noexp_d2i(ASN1_VALUE **val,
     } else if (flags & ASN1_TFLG_IMPTAG) {
         /* IMPLICIT tagging */
         ret = asn1_item_embed_d2i(val, &p, len,
-                                  ASN1_ITEM_ptr(tt->item), tt->tag, aclass, opt,
-                                  ctx, depth, libctx, propq);
+            ASN1_ITEM_ptr(tt->item), tt->tag, aclass, opt,
+            ctx, depth, libctx, propq);
         if (!ret) {
             ERR_raise(ERR_LIB_ASN1, ERR_R_NESTED_ASN1_ERROR);
             goto err;
@@ -680,7 +707,7 @@ static int asn1_template_noexp_d2i(ASN1_VALUE **val,
     } else {
         /* Nothing special */
         ret = asn1_item_embed_d2i(val, &p, len, ASN1_ITEM_ptr(tt->item),
-                                  -1, 0, opt, ctx, depth, libctx, propq);
+            -1, 0, opt, ctx, depth, libctx, propq);
         if (!ret) {
             ERR_raise(ERR_LIB_ASN1, ERR_R_NESTED_ASN1_ERROR);
             goto err;
@@ -691,14 +718,14 @@ static int asn1_template_noexp_d2i(ASN1_VALUE **val,
     *in = p;
     return 1;
 
- err:
+err:
     return 0;
 }
 
 static int asn1_d2i_ex_primitive(ASN1_VALUE **pval,
-                                 const unsigned char **in, long inlen,
-                                 const ASN1_ITEM *it,
-                                 int tag, int aclass, char opt, ASN1_TLC *ctx)
+    const unsigned char **in, long inlen,
+    const ASN1_ITEM *it,
+    int tag, int aclass, char opt, ASN1_TLC *ctx)
 {
     int ret = 0, utype;
     long plen;
@@ -710,7 +737,7 @@ static int asn1_d2i_ex_primitive(ASN1_VALUE **pval,
 
     if (pval == NULL) {
         ERR_raise(ERR_LIB_ASN1, ASN1_R_ILLEGAL_NULL);
-        return 0;               /* Should never happen */
+        return 0; /* Should never happen */
     }
 
     if (it->itype == ASN1_ITYPE_MSTRING) {
@@ -732,7 +759,7 @@ static int asn1_d2i_ex_primitive(ASN1_VALUE **pval,
         }
         p = *in;
         ret = asn1_check_tlen(NULL, &utype, &oclass, NULL, NULL,
-                              &p, inlen, -1, 0, 0, ctx);
+            &p, inlen, -1, 0, 0, ctx);
         if (!ret) {
             ERR_raise(ERR_LIB_ASN1, ERR_R_NESTED_ASN1_ERROR);
             return 0;
@@ -747,7 +774,7 @@ static int asn1_d2i_ex_primitive(ASN1_VALUE **pval,
     p = *in;
     /* Check header */
     ret = asn1_check_tlen(&plen, NULL, NULL, &inf, &cst,
-                          &p, inlen, tag, aclass, opt, ctx);
+        &p, inlen, tag, aclass, opt, ctx);
     if (!ret) {
         ERR_raise(ERR_LIB_ASN1, ERR_R_NESTED_ASN1_ERROR);
         return 0;
@@ -820,7 +847,7 @@ static int asn1_d2i_ex_primitive(ASN1_VALUE **pval,
 
     *in = p;
     ret = 1;
- err:
+err:
     if (free_cont)
         OPENSSL_free(buf.data);
     return ret;
@@ -829,7 +856,7 @@ static int asn1_d2i_ex_primitive(ASN1_VALUE **pval,
 /* Translate ASN1 content octets into a structure */
 
 static int asn1_ex_c2i(ASN1_VALUE **pval, const unsigned char *cont, int len,
-                       int utype, char *free_cont, const ASN1_ITEM *it)
+    int utype, char *free_cont, const ASN1_ITEM *it)
 {
     ASN1_VALUE **opval = NULL;
     ASN1_STRING *stmp;
@@ -921,6 +948,14 @@ static int asn1_ex_c2i(ASN1_VALUE **pval, const unsigned char *cont, int len,
             ERR_raise(ERR_LIB_ASN1, ASN1_R_UNIVERSALSTRING_IS_WRONG_LENGTH);
             goto err;
         }
+        if (utype == V_ASN1_GENERALIZEDTIME && (len < 15)) {
+            ERR_raise(ERR_LIB_ASN1, ASN1_R_GENERALIZEDTIME_IS_TOO_SHORT);
+            goto err;
+        }
+        if (utype == V_ASN1_UTCTIME && (len < 13)) {
+            ERR_raise(ERR_LIB_ASN1, ASN1_R_UTCTIME_IS_TOO_SHORT);
+            goto err;
+        }
         /* All based on ASN1_STRING and handled the same */
         if (*pval == NULL) {
             stmp = ASN1_STRING_type_new(utype);
@@ -952,7 +987,7 @@ static int asn1_ex_c2i(ASN1_VALUE **pval, const unsigned char *cont, int len,
         typ->value.ptr = NULL;
 
     ret = 1;
- err:
+err:
     if (!ret) {
         ASN1_TYPE_free(typ);
         if (opval)
@@ -996,7 +1031,7 @@ static int asn1_find_end(const unsigned char **in, long len, char inf)
         q = p;
         /* Just read in a header: only care about the length */
         if (!asn1_check_tlen(&plen, NULL, NULL, &inf, NULL, &p, len,
-                             -1, 0, 0, NULL)) {
+                -1, 0, 0, NULL)) {
             ERR_raise(ERR_LIB_ASN1, ERR_R_NESTED_ASN1_ERROR);
             return 0;
         }
@@ -1032,11 +1067,11 @@ static int asn1_find_end(const unsigned char **in, long len, char inf)
  * recursion is allowed at all. Although zero should be adequate examples
  * exist that require a value of 1. So 5 should be more than enough.
  */
-# define ASN1_MAX_STRING_NEST 5
+#define ASN1_MAX_STRING_NEST 5
 #endif
 
 static int asn1_collect(BUF_MEM *buf, const unsigned char **in, long len,
-                        char inf, int tag, int aclass, int depth)
+    char inf, int tag, int aclass, int depth)
 {
     const unsigned char *p, *q;
     long plen;
@@ -1067,7 +1102,7 @@ static int asn1_collect(BUF_MEM *buf, const unsigned char **in, long len,
         }
 
         if (!asn1_check_tlen(&plen, NULL, NULL, &ininf, &cst, &p,
-                             len, tag, aclass, 0, NULL)) {
+                len, tag, aclass, 0, NULL)) {
             ERR_raise(ERR_LIB_ASN1, ERR_R_NESTED_ASN1_ERROR);
             return 0;
         }
@@ -1131,9 +1166,9 @@ static int asn1_check_eoc(const unsigned char **in, long len)
  */
 
 static int asn1_check_tlen(long *olen, int *otag, unsigned char *oclass,
-                           char *inf, char *cst,
-                           const unsigned char **in, long len,
-                           int exptag, int expclass, char opt, ASN1_TLC *ctx)
+    char *inf, char *cst,
+    const unsigned char **in, long len,
+    int exptag, int expclass, char opt, ASN1_TLC *ctx)
 {
     int i;
     int ptag, pclass;
@@ -1214,7 +1249,7 @@ static int asn1_check_tlen(long *olen, int *otag, unsigned char *oclass,
     *in = p;
     return 1;
 
- err:
+err:
     asn1_tlc_clear(ctx);
     return 0;
 }
