@@ -17,17 +17,17 @@
 #include "asn1_local.h"
 
 static int asn1_i2d_ex_primitive(const ASN1_VALUE **pval, unsigned char **out,
-                                 const ASN1_ITEM *it, int tag, int aclass);
+    const ASN1_ITEM *it, int tag, int aclass);
 static int asn1_set_seq_out(STACK_OF(const_ASN1_VALUE) *sk,
-                            unsigned char **out,
-                            int skcontlen, const ASN1_ITEM *item,
-                            int do_sort, int iclass);
+    unsigned char **out,
+    int skcontlen, const ASN1_ITEM *item,
+    int do_sort, int iclass);
 static int asn1_template_ex_i2d(const ASN1_VALUE **pval, unsigned char **out,
-                                const ASN1_TEMPLATE *tt, int tag, int aclass);
+    const ASN1_TEMPLATE *tt, int tag, int aclass);
 static int asn1_item_flags_i2d(const ASN1_VALUE *val, unsigned char **out,
-                               const ASN1_ITEM *it, int flags);
+    const ASN1_ITEM *it, int flags);
 static int asn1_ex_i2c(const ASN1_VALUE **pval, unsigned char *cout, int *putype,
-                       const ASN1_ITEM *it);
+    const ASN1_ITEM *it);
 
 /*
  * Top level i2d equivalents: the 'ndef' variant instructs the encoder to use
@@ -35,7 +35,7 @@ static int asn1_ex_i2c(const ASN1_VALUE **pval, unsigned char *cout, int *putype
  */
 
 int ASN1_item_ndef_i2d(const ASN1_VALUE *val, unsigned char **out,
-                       const ASN1_ITEM *it)
+    const ASN1_ITEM *it)
 {
     return asn1_item_flags_i2d(val, out, it, ASN1_TFLG_NDEF);
 }
@@ -53,7 +53,7 @@ int ASN1_item_i2d(const ASN1_VALUE *val, unsigned char **out, const ASN1_ITEM *i
  */
 
 static int asn1_item_flags_i2d(const ASN1_VALUE *val, unsigned char **out,
-                               const ASN1_ITEM *it, int flags)
+    const ASN1_ITEM *it, int flags)
 {
     if (out != NULL && *out == NULL) {
         unsigned char *p, *buf;
@@ -79,7 +79,7 @@ static int asn1_item_flags_i2d(const ASN1_VALUE *val, unsigned char **out,
  */
 
 int ASN1_item_ex_i2d(const ASN1_VALUE **pval, unsigned char **out,
-                     const ASN1_ITEM *it, int tag, int aclass)
+    const ASN1_ITEM *it, int tag, int aclass)
 {
     const ASN1_TEMPLATE *tt = NULL;
     int i, seqcontlen, seqlen, ndef = 1;
@@ -92,7 +92,7 @@ int ASN1_item_ex_i2d(const ASN1_VALUE **pval, unsigned char **out,
 
     if (aux != NULL) {
         asn1_cb = ((aux->flags & ASN1_AFLG_CONST_CB) != 0) ? aux->asn1_const_cb
-            : (ASN1_aux_const_cb *)aux->asn1_cb; /* backward compatibility */
+                                                           : (ASN1_aux_const_cb *)aux->asn1_cb; /* backward compatibility */
     }
 
     switch (it->itype) {
@@ -100,7 +100,7 @@ int ASN1_item_ex_i2d(const ASN1_VALUE **pval, unsigned char **out,
     case ASN1_ITYPE_PRIMITIVE:
         if (it->templates)
             return asn1_template_ex_i2d(pval, out, it->templates,
-                                        tag, aclass);
+                tag, aclass);
         return asn1_i2d_ex_primitive(pval, out, it, tag, aclass);
 
     case ASN1_ITYPE_MSTRING:
@@ -206,13 +206,12 @@ int ASN1_item_ex_i2d(const ASN1_VALUE **pval, unsigned char **out,
 
     default:
         return 0;
-
     }
     return 0;
 }
 
 static int asn1_template_ex_i2d(const ASN1_VALUE **pval, unsigned char **out,
-                                const ASN1_TEMPLATE *tt, int tag, int iclass)
+    const ASN1_TEMPLATE *tt, int tag, int iclass)
 {
     const int flags = tt->flags;
     int i, ret, ttag, tclass, ndef, len;
@@ -303,7 +302,7 @@ static int asn1_template_ex_i2d(const ASN1_VALUE **pval, unsigned char **out,
         for (i = 0; i < sk_const_ASN1_VALUE_num(sk); i++) {
             skitem = sk_const_ASN1_VALUE_value(sk, i);
             len = ASN1_item_ex_i2d(&skitem, NULL, ASN1_ITEM_ptr(tt->item),
-                                   -1, iclass);
+                -1, iclass);
             if (len == -1 || (skcontlen > INT_MAX - len))
                 return -1;
             if (len == 0 && (tt->flags & ASN1_TFLG_OPTIONAL) == 0) {
@@ -332,7 +331,7 @@ static int asn1_template_ex_i2d(const ASN1_VALUE **pval, unsigned char **out,
         ASN1_put_object(out, ndef, skcontlen, sktag, skaclass);
         /* And the stuff itself */
         asn1_set_seq_out(sk, out, skcontlen, ASN1_ITEM_ptr(tt->item),
-                         isset, iclass);
+            isset, iclass);
         if (ndef == 2) {
             ASN1_put_eoc(out);
             if (flags & ASN1_TFLG_EXPTAG)
@@ -367,7 +366,7 @@ static int asn1_template_ex_i2d(const ASN1_VALUE **pval, unsigned char **out,
 
     /* Either normal or IMPLICIT tagging: combine class and flags */
     len = ASN1_item_ex_i2d(pval, out, ASN1_ITEM_ptr(tt->item),
-                              ttag, tclass | iclass);
+        ttag, tclass | iclass);
     if (len == 0 && (tt->flags & ASN1_TFLG_OPTIONAL) == 0) {
         ERR_raise(ERR_LIB_ASN1, ASN1_R_ILLEGAL_ZERO_CONTENT);
         return -1;
@@ -397,9 +396,9 @@ static int der_cmp(const void *a, const void *b)
 /* Output the content octets of SET OF or SEQUENCE OF */
 
 static int asn1_set_seq_out(STACK_OF(const_ASN1_VALUE) *sk,
-                            unsigned char **out,
-                            int skcontlen, const ASN1_ITEM *item,
-                            int do_sort, int iclass)
+    unsigned char **out,
+    int skcontlen, const ASN1_ITEM *item,
+    int do_sort, int iclass)
 {
     int i, ret = 0;
     const ASN1_VALUE *skitem;
@@ -412,7 +411,7 @@ static int asn1_set_seq_out(STACK_OF(const_ASN1_VALUE) *sk,
             do_sort = 0;
         else {
             derlst = OPENSSL_malloc(sk_const_ASN1_VALUE_num(sk)
-                                    * sizeof(*derlst));
+                * sizeof(*derlst));
             if (derlst == NULL)
                 return 0;
             tmpdat = OPENSSL_malloc(skcontlen);
@@ -460,7 +459,7 @@ err:
 }
 
 static int asn1_i2d_ex_primitive(const ASN1_VALUE **pval, unsigned char **out,
-                                 const ASN1_ITEM *it, int tag, int aclass)
+    const ASN1_ITEM *it, int tag, int aclass)
 {
     int len;
     int utype;
@@ -480,8 +479,7 @@ static int asn1_i2d_ex_primitive(const ASN1_VALUE **pval, unsigned char **out,
      * octets so don't include tag+length. We need to check here because the
      * call to asn1_ex_i2c() could change utype.
      */
-    if ((utype == V_ASN1_SEQUENCE) || (utype == V_ASN1_SET) ||
-        (utype == V_ASN1_OTHER))
+    if ((utype == V_ASN1_SEQUENCE) || (utype == V_ASN1_SET) || (utype == V_ASN1_OTHER))
         usetag = 0;
     else
         usetag = 1;
@@ -520,7 +518,7 @@ static int asn1_i2d_ex_primitive(const ASN1_VALUE **pval, unsigned char **out,
 /* Produce content octets from a structure */
 
 static int asn1_ex_i2c(const ASN1_VALUE **pval, unsigned char *cout, int *putype,
-                       const ASN1_ITEM *it)
+    const ASN1_ITEM *it)
 {
     ASN1_BOOLEAN *tbool = NULL;
     ASN1_STRING *strtmp;
@@ -593,7 +591,7 @@ static int asn1_ex_i2c(const ASN1_VALUE **pval, unsigned char *cout, int *putype
 
     case V_ASN1_BIT_STRING:
         return ossl_i2c_ASN1_BIT_STRING((ASN1_BIT_STRING *)*pval,
-                                        cout ? &cout : NULL);
+            cout ? &cout : NULL);
 
     case V_ASN1_INTEGER:
     case V_ASN1_ENUMERATED:
@@ -635,7 +633,6 @@ static int asn1_ex_i2c(const ASN1_VALUE **pval, unsigned char *cout, int *putype
         len = strtmp->length;
 
         break;
-
     }
     if (cout && len)
         memcpy(cout, cont, len);
