@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2016 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2015-2022 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -25,5 +25,7 @@ typedef struct async_fibre_st {
 #define async_fibre_makecontext(c) 0
 #define async_fibre_free(f)
 #define async_fibre_init_dispatcher(f)
+#define async_local_init() 1
+#define async_local_deinit()
 
 #endif
