@@ -46,9 +46,9 @@ static int ring_buf_init(struct ring_buf *r, size_t nbytes)
 static void ring_buf_destroy(struct ring_buf *r)
 {
     OPENSSL_free(r->start);
-    r->start    = NULL;
-    r->len      = 0;
-    r->count    = 0;
+    r->start = NULL;
+    r->len = 0;
+    r->count = 0;
 }
 
 /*
@@ -141,7 +141,7 @@ static int ring_buf_resize(struct ring_buf *r, size_t nbytes)
             size_t offset = nbytes - r->len;
 
             memmove(new_start + r->idx[1] + offset, new_start + r->idx[1],
-                    r->len - r->idx[1]);
+                r->len - r->idx[1]);
             r->idx[1] += offset;
         }
     } else {
@@ -184,17 +184,17 @@ static int dgram_pair_init(BIO *bio);
 static int dgram_mem_init(BIO *bio);
 static int dgram_pair_free(BIO *bio);
 static int dgram_pair_sendmmsg(BIO *b, BIO_MSG *msg, size_t stride,
-                               size_t num_msg, uint64_t flags,
-                               size_t *num_processed);
+    size_t num_msg, uint64_t flags,
+    size_t *num_processed);
 static int dgram_pair_recvmmsg(BIO *b, BIO_MSG *msg, size_t stride,
-                               size_t num_msg, uint64_t flags,
-                               size_t *num_processed);
+    size_t num_msg, uint64_t flags,
+    size_t *num_processed);
 
 static int dgram_pair_ctrl_destroy_bio_pair(BIO *bio1);
 static size_t dgram_pair_read_inner(struct bio_dgram_pair_st *b, uint8_t *buf,
-                                    size_t sz);
+    size_t sz);
 
-#define BIO_MSG_N(array, n) (*(BIO_MSG *)((char *)(array) + (n)*stride))
+#define BIO_MSG_N(array, n) (*(BIO_MSG *)((char *)(array) + (n) * stride))
 
 static const BIO_METHOD dgram_pair_method = {
     BIO_TYPE_DGRAM_PAIR,
@@ -264,10 +264,10 @@ struct bio_dgram_pair_st {
      * reads.
      */
     CRYPTO_RWLOCK *lock;
-    unsigned int no_trunc          : 1; /* Reads fail if they would truncate */
+    unsigned int no_trunc : 1; /* Reads fail if they would truncate */
     unsigned int local_addr_enable : 1; /* Can use BIO_MSG->local? */
-    unsigned int role              : 1; /* Determines lock order */
-    unsigned int grows_on_write    : 1; /* Set for BIO_s_dgram_mem only */
+    unsigned int role : 1; /* Determines lock order */
+    unsigned int grows_on_write : 1; /* Set for BIO_s_dgram_mem only */
 };
 
 #define MIN_BUF_LEN (1024)
@@ -281,7 +281,7 @@ static int dgram_pair_init(BIO *bio)
     if (b == NULL)
         return 0;
 
-    b->mtu         = 1472;    /* conservative default MTU */
+    b->mtu = 1472; /* conservative default MTU */
     /* default buffer size */
     b->req_buf_len = 9 * (sizeof(struct dgram_hdr) + b->mtu);
 
@@ -348,7 +348,7 @@ static int dgram_pair_ctrl_make_bio_pair(BIO *bio1, BIO *bio2)
     /* Ensure the BIO we have been passed is actually a dgram pair BIO. */
     if (bio1->method != &dgram_pair_method || bio2->method != &dgram_pair_method) {
         ERR_raise_data(ERR_LIB_BIO, BIO_R_INVALID_ARGUMENT,
-                       "both BIOs must be BIO_dgram_pair");
+            "both BIOs must be BIO_dgram_pair");
         return 0;
     }
 
@@ -366,12 +366,12 @@ static int dgram_pair_ctrl_make_bio_pair(BIO *bio1, BIO *bio2)
      */
     if (b1->peer != NULL || b2->peer != NULL) {
         ERR_raise_data(ERR_LIB_BIO, BIO_R_IN_USE,
-                       "cannot associate a BIO_dgram_pair which is already in use");
+            "cannot associate a BIO_dgram_pair which is already in use");
         return 0;
     }
 
     if (!ossl_assert(b1->req_buf_len >= MIN_BUF_LEN
-                        && b2->req_buf_len >= MIN_BUF_LEN)) {
+            && b2->req_buf_len >= MIN_BUF_LEN)) {
         ERR_raise(ERR_LIB_BIO, BIO_R_UNINITIALIZED);
         return 0;
     }
@@ -389,12 +389,12 @@ static int dgram_pair_ctrl_make_bio_pair(BIO *bio1, BIO *bio2)
             return 0;
         }
 
-    b1->peer    = bio2;
-    b2->peer    = bio1;
-    b1->role    = 0;
-    b2->role    = 1;
-    bio1->init  = 1;
-    bio2->init  = 1;
+    b1->peer = bio2;
+    b2->peer = bio1;
+    b1->role = 0;
+    b2->role = 1;
+    bio1->init = 1;
+    bio2->init = 1;
     return 1;
 }
 
@@ -443,7 +443,6 @@ static int dgram_pair_ctrl_eof(BIO *bio)
     if (!is_dgram_pair(b))
         return 0;
 
-
     peerb = b->peer->ptr;
     if (!ossl_assert(peerb != NULL))
         return -1;
@@ -508,13 +507,13 @@ static size_t dgram_pair_ctrl_pending(BIO *bio)
     if (CRYPTO_THREAD_write_lock(readb->lock) == 0)
         return 0;
 
-    saved_idx   = readb->rbuf.idx[1];
+    saved_idx = readb->rbuf.idx[1];
     saved_count = readb->rbuf.count;
 
     l = dgram_pair_read_inner(readb, (uint8_t *)&hdr, sizeof(hdr));
 
     readb->rbuf.idx[1] = saved_idx;
-    readb->rbuf.count  = saved_count;
+    readb->rbuf.count = saved_count;
 
     CRYPTO_THREAD_unlock(readb->lock);
 
@@ -561,8 +560,7 @@ static int dgram_pair_ctrl_get_local_addr_cap(BIO *bio)
     else
         readb = b;
 
-    return (~readb->cap & (BIO_DGRAM_CAP_HANDLES_SRC_ADDR
-                           | BIO_DGRAM_CAP_PROVIDES_DST_ADDR)) == 0;
+    return (~readb->cap & (BIO_DGRAM_CAP_HANDLES_SRC_ADDR | BIO_DGRAM_CAP_PROVIDES_DST_ADDR)) == 0;
 }
 
 /* BIO_dgram_get_effective_caps (BIO_CTRL_DGRAM_GET_EFFECTIVE_CAPS) */
@@ -801,7 +799,7 @@ static long dgram_pair_ctrl(BIO *bio, int cmd, long num, void *ptr)
 }
 
 int BIO_new_bio_dgram_pair(BIO **pbio1, size_t writebuf1,
-                           BIO **pbio2, size_t writebuf2)
+    BIO **pbio2, size_t writebuf2)
 {
     int ret = 0;
     long r;
@@ -878,8 +876,8 @@ static size_t dgram_pair_read_inner(struct bio_dgram_pair_st *b, uint8_t *buf, s
 
         if (buf != NULL)
             buf += src_len;
-        total_read  += src_len;
-        sz          -= src_len;
+        total_read += src_len;
+        sz -= src_len;
     }
 
     return total_read;
@@ -890,8 +888,8 @@ static size_t dgram_pair_read_inner(struct bio_dgram_pair_st *b, uint8_t *buf, s
  * response code.
  */
 static ossl_ssize_t dgram_pair_read_actual(BIO *bio, char *buf, size_t sz,
-                                           BIO_ADDR *local, BIO_ADDR *peer,
-                                           int is_multi)
+    BIO_ADDR *local, BIO_ADDR *peer,
+    int is_multi)
 {
     size_t l, trunc = 0, saved_idx, saved_count;
     struct bio_dgram_pair_st *b = bio->ptr, *readb;
@@ -921,7 +919,7 @@ static ossl_ssize_t dgram_pair_read_actual(BIO *bio, char *buf, size_t sz,
         return -BIO_R_LOCAL_ADDR_NOT_AVAILABLE;
 
     /* Read the header. */
-    saved_idx   = readb->rbuf.idx[1];
+    saved_idx = readb->rbuf.idx[1];
     saved_count = readb->rbuf.count;
     l = dgram_pair_read_inner(readb, (uint8_t *)&hdr, sizeof(hdr));
     if (l == 0) {
@@ -946,7 +944,7 @@ static ossl_ssize_t dgram_pair_read_actual(BIO *bio, char *buf, size_t sz,
         if (b->no_trunc) {
             /* Restore original state. */
             readb->rbuf.idx[1] = saved_idx;
-            readb->rbuf.count  = saved_count;
+            readb->rbuf.count = saved_count;
             return -BIO_R_NON_FATAL;
         }
     }
@@ -967,14 +965,14 @@ static ossl_ssize_t dgram_pair_read_actual(BIO *bio, char *buf, size_t sz,
     if (local != NULL)
         *local = hdr.dst_addr;
     if (peer != NULL)
-        *peer  = hdr.src_addr;
+        *peer = hdr.src_addr;
 
     return (ossl_ssize_t)l;
 }
 
 /* Threadsafe */
 static int dgram_pair_lock_both_write(struct bio_dgram_pair_st *a,
-                                      struct bio_dgram_pair_st *b)
+    struct bio_dgram_pair_st *b)
 {
     struct bio_dgram_pair_st *x, *y;
 
@@ -999,7 +997,7 @@ static int dgram_pair_lock_both_write(struct bio_dgram_pair_st *a,
 }
 
 static void dgram_pair_unlock_both(struct bio_dgram_pair_st *a,
-                                   struct bio_dgram_pair_st *b)
+    struct bio_dgram_pair_st *b)
 {
     CRYPTO_THREAD_unlock(a->lock);
     CRYPTO_THREAD_unlock(b->lock);
@@ -1049,9 +1047,9 @@ static int dgram_pair_read(BIO *bio, char *buf, int sz_)
 
 /* Threadsafe */
 static int dgram_pair_recvmmsg(BIO *bio, BIO_MSG *msg,
-                               size_t stride, size_t num_msg,
-                               uint64_t flags,
-                               size_t *num_processed)
+    size_t stride, size_t num_msg,
+    uint64_t flags,
+    size_t *num_processed)
 {
     int ret;
     ossl_ssize_t l;
@@ -1084,7 +1082,7 @@ static int dgram_pair_recvmmsg(BIO *bio, BIO_MSG *msg,
     for (i = 0; i < num_msg; ++i) {
         m = &BIO_MSG_N(msg, i);
         l = dgram_pair_read_actual(bio, m->data, m->data_len,
-                                   m->local, m->peer, 1);
+            m->local, m->peer, 1);
         if (l < 0) {
             *num_processed = i;
             if (i > 0) {
@@ -1097,7 +1095,7 @@ static int dgram_pair_recvmmsg(BIO *bio, BIO_MSG *msg,
         }
 
         m->data_len = l;
-        m->flags    = 0;
+        m->flags = 0;
     }
 
     *num_processed = i;
@@ -1167,7 +1165,7 @@ static ossl_inline size_t compute_rbuf_growth(size_t target, size_t current)
 
 /* Must hold local write lock */
 static size_t dgram_pair_write_inner(struct bio_dgram_pair_st *b,
-                                     const uint8_t *buf, size_t sz)
+    const uint8_t *buf, size_t sz)
 {
     size_t total_written = 0;
 
@@ -1203,9 +1201,9 @@ static size_t dgram_pair_write_inner(struct bio_dgram_pair_st *b,
         memcpy(dst_buf, buf, dst_len);
         ring_buf_push(&b->rbuf, dst_len);
 
-        buf             += dst_len;
-        sz              -= dst_len;
-        total_written   += dst_len;
+        buf += dst_len;
+        sz -= dst_len;
+        total_written += dst_len;
     }
 
     return total_written;
@@ -1216,13 +1214,13 @@ static size_t dgram_pair_write_inner(struct bio_dgram_pair_st *b,
  * response code.
  */
 static ossl_ssize_t dgram_pair_write_actual(BIO *bio, const char *buf, size_t sz,
-                                            const BIO_ADDR *local, const BIO_ADDR *peer,
-                                            int is_multi)
+    const BIO_ADDR *local, const BIO_ADDR *peer,
+    int is_multi)
 {
     static const BIO_ADDR zero_addr;
     size_t saved_idx, saved_count;
     struct bio_dgram_pair_st *b = bio->ptr, *readb;
-    struct dgram_hdr hdr = {0};
+    struct dgram_hdr hdr = { 0 };
 
     if (!is_multi)
         BIO_clear_retry_flags(bio);
@@ -1252,16 +1250,16 @@ static ossl_ssize_t dgram_pair_write_actual(BIO *bio, const char *buf, size_t sz
         local = b->local_addr;
     hdr.src_addr = (local != NULL ? *local : zero_addr);
 
-    saved_idx   = b->rbuf.idx[0];
+    saved_idx = b->rbuf.idx[0];
     saved_count = b->rbuf.count;
     if (dgram_pair_write_inner(b, (const uint8_t *)&hdr, sizeof(hdr)) != sizeof(hdr)
-            || dgram_pair_write_inner(b, (const uint8_t *)buf, sz) != sz) {
+        || dgram_pair_write_inner(b, (const uint8_t *)buf, sz) != sz) {
         /*
          * We were not able to push the header and the entirety of the payload
          * onto the ring buffer, so abort and roll back the ring buffer state.
          */
         b->rbuf.idx[0] = saved_idx;
-        b->rbuf.count  = saved_count;
+        b->rbuf.count = saved_count;
         if (!is_multi)
             BIO_set_retry_write(bio);
         return -BIO_R_NON_FATAL;
@@ -1301,8 +1299,8 @@ static int dgram_pair_write(BIO *bio, const char *buf, int sz_)
 
 /* Threadsafe */
 static int dgram_pair_sendmmsg(BIO *bio, BIO_MSG *msg,
-                               size_t stride, size_t num_msg,
-                               uint64_t flags, size_t *num_processed)
+    size_t stride, size_t num_msg,
+    uint64_t flags, size_t *num_processed)
 {
     ossl_ssize_t ret, l;
     BIO_MSG *m;
@@ -1323,7 +1321,7 @@ static int dgram_pair_sendmmsg(BIO *bio, BIO_MSG *msg,
     for (i = 0; i < num_msg; ++i) {
         m = &BIO_MSG_N(msg, i);
         l = dgram_pair_write_actual(bio, m->data, m->data_len,
-                                    m->local, m->peer, 1);
+            m->local, m->peer, 1);
         if (l < 0) {
             *num_processed = i;
             if (i > 0) {
