@@ -8,8 +8,10 @@
  */
 
 #include "../bn_local.h"
-#if !(defined(__GNUC__) && __GNUC__>=2)
+#if !(defined(__GNUC__) && __GNUC__ >= 2)
+/* clang-format off */
 # include "../bn_asm.c"         /* kind of dirty hack for Sun Studio */
+/* clang-format on */
 #else
 /*-
  * x86_64 BIGNUM accelerator version 0.1, December 2002.
@@ -63,52 +65,54 @@
  *    machine.
  */
 
-# undef mul
-# undef mul_add
+#undef mul
+#undef mul_add
 
 /*-
  * "m"(a), "+m"(r)      is the way to favor DirectPath µ-code;
  * "g"(0)               let the compiler to decide where does it
  *                      want to keep the value of zero;
  */
-# define mul_add(r,a,word,carry) do {   \
-        register BN_ULONG high,low;     \
-        asm ("mulq %3"                  \
-                : "=a"(low),"=d"(high)  \
-                : "a"(word),"m"(a)      \
-                : "cc");                \
-        asm ("addq %2,%0; adcq %3,%1"   \
-                : "+r"(carry),"+d"(high)\
-                : "a"(low),"g"(0)       \
-                : "cc");                \
-        asm ("addq %2,%0; adcq %3,%1"   \
-                : "+m"(r),"+d"(high)    \
-                : "r"(carry),"g"(0)     \
-                : "cc");                \
-        carry=high;                     \
-        } while (0)
+#define mul_add(r, a, word, carry)    \
+    do {                              \
+        register BN_ULONG high, low;  \
+        asm("mulq %3"                 \
+            : "=a"(low), "=d"(high)   \
+            : "a"(word), "m"(a)       \
+            : "cc");                  \
+        asm("addq %2,%0; adcq %3,%1"  \
+            : "+r"(carry), "+d"(high) \
+            : "a"(low), "g"(0)        \
+            : "cc");                  \
+        asm("addq %2,%0; adcq %3,%1"  \
+            : "+m"(r), "+d"(high)     \
+            : "r"(carry), "g"(0)      \
+            : "cc");                  \
+        carry = high;                 \
+    } while (0)
 
-# define mul(r,a,word,carry) do {       \
-        register BN_ULONG high,low;     \
-        asm ("mulq %3"                  \
-                : "=a"(low),"=d"(high)  \
-                : "a"(word),"g"(a)      \
-                : "cc");                \
-        asm ("addq %2,%0; adcq %3,%1"   \
-                : "+r"(carry),"+d"(high)\
-                : "a"(low),"g"(0)       \
-                : "cc");                \
-        (r)=carry, carry=high;          \
-        } while (0)
-# undef sqr
-# define sqr(r0,r1,a)                   \
-        asm ("mulq %2"                  \
-                : "=a"(r0),"=d"(r1)     \
-                : "a"(a)                \
-                : "cc");
+#define mul(r, a, word, carry)        \
+    do {                              \
+        register BN_ULONG high, low;  \
+        asm("mulq %3"                 \
+            : "=a"(low), "=d"(high)   \
+            : "a"(word), "g"(a)       \
+            : "cc");                  \
+        asm("addq %2,%0; adcq %3,%1"  \
+            : "+r"(carry), "+d"(high) \
+            : "a"(low), "g"(0)        \
+            : "cc");                  \
+        (r) = carry, carry = high;    \
+    } while (0)
+#undef sqr
+#define sqr(r0, r1, a)       \
+    asm("mulq %2"            \
+        : "=a"(r0), "=d"(r1) \
+        : "a"(a)             \
+        : "cc");
 
 BN_ULONG bn_mul_add_words(BN_ULONG *rp, const BN_ULONG *ap, int num,
-                          BN_ULONG w)
+    BN_ULONG w)
 {
     BN_ULONG c1 = 0;
 
@@ -195,15 +199,15 @@ BN_ULONG bn_div_words(BN_ULONG h, BN_ULONG l, BN_ULONG d)
 {
     BN_ULONG ret, waste;
 
- asm("divq      %4":"=a"(ret), "=d"(waste)
- :     "a"(l), "d"(h), "r"(d)
- :     "cc");
+    asm("divq      %4" : "=a"(ret), "=d"(waste)
+        : "a"(l), "d"(h), "r"(d)
+        : "cc");
 
     return ret;
 }
 
 BN_ULONG bn_add_words(BN_ULONG *rp, const BN_ULONG *ap, const BN_ULONG *bp,
-                      int n)
+    int n)
 {
     BN_ULONG ret;
     size_t i = 0;
@@ -211,26 +215,26 @@ BN_ULONG bn_add_words(BN_ULONG *rp, const BN_ULONG *ap, const BN_ULONG *bp,
     if (n <= 0)
         return 0;
 
-    asm volatile ("       subq    %0,%0           \n" /* clear carry */
-                  "       jmp     1f              \n"
-                  ".p2align 4                     \n"
-                  "1:     movq    (%4,%2,8),%0    \n"
-                  "       adcq    (%5,%2,8),%0    \n"
-                  "       movq    %0,(%3,%2,8)    \n"
-                  "       lea     1(%2),%2        \n"
-                  "       dec     %1              \n"
-                  "       jnz     1b              \n"
-                  "       sbbq    %0,%0           \n"
-                  :"=&r" (ret), "+c"(n), "+r"(i)
-                  :"r"(rp), "r"(ap), "r"(bp)
-                  :"cc", "memory");
+    asm volatile("       subq    %0,%0           \n" /* clear carry */
+                 "       jmp     1f              \n"
+                 ".p2align 4                     \n"
+                 "1:     movq    (%4,%2,8),%0    \n"
+                 "       adcq    (%5,%2,8),%0    \n"
+                 "       movq    %0,(%3,%2,8)    \n"
+                 "       lea     1(%2),%2        \n"
+                 "       dec     %1              \n"
+                 "       jnz     1b              \n"
+                 "       sbbq    %0,%0           \n"
+        : "=&r"(ret), "+c"(n), "+r"(i)
+        : "r"(rp), "r"(ap), "r"(bp)
+        : "cc", "memory");
 
     return ret & 1;
 }
 
-# ifndef SIMICS
+#ifndef SIMICS
 BN_ULONG bn_sub_words(BN_ULONG *rp, const BN_ULONG *ap, const BN_ULONG *bp,
-                      int n)
+    int n)
 {
     BN_ULONG ret;
     size_t i = 0;
@@ -238,25 +242,25 @@ BN_ULONG bn_sub_words(BN_ULONG *rp, const BN_ULONG *ap, const BN_ULONG *bp,
     if (n <= 0)
         return 0;
 
-    asm volatile ("       subq    %0,%0           \n" /* clear borrow */
-                  "       jmp     1f              \n"
-                  ".p2align 4                     \n"
-                  "1:     movq    (%4,%2,8),%0    \n"
-                  "       sbbq    (%5,%2,8),%0    \n"
-                  "       movq    %0,(%3,%2,8)    \n"
-                  "       lea     1(%2),%2        \n"
-                  "       dec     %1              \n"
-                  "       jnz     1b              \n"
-                  "       sbbq    %0,%0           \n"
-                  :"=&r" (ret), "+c"(n), "+r"(i)
-                  :"r"(rp), "r"(ap), "r"(bp)
-                  :"cc", "memory");
+    asm volatile("       subq    %0,%0           \n" /* clear borrow */
+                 "       jmp     1f              \n"
+                 ".p2align 4                     \n"
+                 "1:     movq    (%4,%2,8),%0    \n"
+                 "       sbbq    (%5,%2,8),%0    \n"
+                 "       movq    %0,(%3,%2,8)    \n"
+                 "       lea     1(%2),%2        \n"
+                 "       dec     %1              \n"
+                 "       jnz     1b              \n"
+                 "       sbbq    %0,%0           \n"
+        : "=&r"(ret), "+c"(n), "+r"(i)
+        : "r"(rp), "r"(ap), "r"(bp)
+        : "cc", "memory");
 
     return ret & 1;
 }
-# else
+#else
 /* Simics 1.4<7 has buggy sbbq:-( */
-#  define BN_MASK2 0xffffffffffffffffL
+#define BN_MASK2 0xffffffffffffffffL
 BN_ULONG bn_sub_words(BN_ULONG *r, BN_ULONG *a, BN_ULONG *b, int n)
 {
     BN_ULONG t1, t2;
@@ -304,7 +308,7 @@ BN_ULONG bn_sub_words(BN_ULONG *r, BN_ULONG *a, BN_ULONG *b, int n)
     }
     return c;
 }
-# endif
+#endif
 
 /* mul_add_c(a,b,c0,c1,c2)  -- c+=a*b for three word number c=(c2,c1,c0) */
 /* mul_add_c2(a,b,c0,c1,c2) -- c+=2*a*b for three word number c=(c2,c1,c0) */
@@ -318,77 +322,91 @@ BN_ULONG bn_sub_words(BN_ULONG *r, BN_ULONG *a, BN_ULONG *b, int n)
  * Keep in mind that carrying into high part of multiplication result
  * can not overflow, because it cannot be all-ones.
  */
-# if 0
+#if 0
 /* original macros are kept for reference purposes */
-#  define mul_add_c(a,b,c0,c1,c2)       do {    \
-        BN_ULONG ta = (a), tb = (b);            \
-        BN_ULONG lo, hi;                        \
-        BN_UMULT_LOHI(lo,hi,ta,tb);             \
-        c0 += lo; hi += (c0<lo)?1:0;            \
-        c1 += hi; c2 += (c1<hi)?1:0;            \
-        } while(0)
+#define mul_add_c(a, b, c0, c1, c2)    \
+    do {                               \
+        BN_ULONG ta = (a), tb = (b);   \
+        BN_ULONG lo, hi;               \
+        BN_UMULT_LOHI(lo, hi, ta, tb); \
+        c0 += lo;                      \
+        hi += (c0 < lo) ? 1 : 0;       \
+        c1 += hi;                      \
+        c2 += (c1 < hi) ? 1 : 0;       \
+    } while (0)
 
-#  define mul_add_c2(a,b,c0,c1,c2)      do {    \
-        BN_ULONG ta = (a), tb = (b);            \
-        BN_ULONG lo, hi, tt;                    \
-        BN_UMULT_LOHI(lo,hi,ta,tb);             \
-        c0 += lo; tt = hi+((c0<lo)?1:0);        \
-        c1 += tt; c2 += (c1<tt)?1:0;            \
-        c0 += lo; hi += (c0<lo)?1:0;            \
-        c1 += hi; c2 += (c1<hi)?1:0;            \
-        } while(0)
+#define mul_add_c2(a, b, c0, c1, c2)   \
+    do {                               \
+        BN_ULONG ta = (a), tb = (b);   \
+        BN_ULONG lo, hi, tt;           \
+        BN_UMULT_LOHI(lo, hi, ta, tb); \
+        c0 += lo;                      \
+        tt = hi + ((c0 < lo) ? 1 : 0); \
+        c1 += tt;                      \
+        c2 += (c1 < tt) ? 1 : 0;       \
+        c0 += lo;                      \
+        hi += (c0 < lo) ? 1 : 0;       \
+        c1 += hi;                      \
+        c2 += (c1 < hi) ? 1 : 0;       \
+    } while (0)
 
-#  define sqr_add_c(a,i,c0,c1,c2)       do {    \
-        BN_ULONG ta = (a)[i];                   \
-        BN_ULONG lo, hi;                        \
-        BN_UMULT_LOHI(lo,hi,ta,ta);             \
-        c0 += lo; hi += (c0<lo)?1:0;            \
-        c1 += hi; c2 += (c1<hi)?1:0;            \
-        } while(0)
-# else
-#  define mul_add_c(a,b,c0,c1,c2) do {  \
-        BN_ULONG t1,t2;                 \
-        asm ("mulq %3"                  \
-                : "=a"(t1),"=d"(t2)     \
-                : "a"(a),"m"(b)         \
-                : "cc");                \
-        asm ("addq %3,%0; adcq %4,%1; adcq %5,%2"       \
-                : "+r"(c0),"+r"(c1),"+r"(c2)            \
-                : "r"(t1),"r"(t2),"g"(0)                \
-                : "cc");                                \
-        } while (0)
+#define sqr_add_c(a, i, c0, c1, c2)    \
+    do {                               \
+        BN_ULONG ta = (a)[i];          \
+        BN_ULONG lo, hi;               \
+        BN_UMULT_LOHI(lo, hi, ta, ta); \
+        c0 += lo;                      \
+        hi += (c0 < lo) ? 1 : 0;       \
+        c1 += hi;                      \
+        c2 += (c1 < hi) ? 1 : 0;       \
+    } while (0)
+#else
+#define mul_add_c(a, b, c0, c1, c2)              \
+    do {                                         \
+        BN_ULONG t1, t2;                         \
+        asm("mulq %3"                            \
+            : "=a"(t1), "=d"(t2)                 \
+            : "a"(a), "m"(b)                     \
+            : "cc");                             \
+        asm("addq %3,%0; adcq %4,%1; adcq %5,%2" \
+            : "+r"(c0), "+r"(c1), "+r"(c2)       \
+            : "r"(t1), "r"(t2), "g"(0)           \
+            : "cc");                             \
+    } while (0)
 
-#  define sqr_add_c(a,i,c0,c1,c2) do {  \
-        BN_ULONG t1,t2;                 \
-        asm ("mulq %2"                  \
-                : "=a"(t1),"=d"(t2)     \
-                : "a"(a[i])             \
-                : "cc");                \
-        asm ("addq %3,%0; adcq %4,%1; adcq %5,%2"       \
-                : "+r"(c0),"+r"(c1),"+r"(c2)            \
-                : "r"(t1),"r"(t2),"g"(0)                \
-                : "cc");                                \
-        } while (0)
+#define sqr_add_c(a, i, c0, c1, c2)              \
+    do {                                         \
+        BN_ULONG t1, t2;                         \
+        asm("mulq %2"                            \
+            : "=a"(t1), "=d"(t2)                 \
+            : "a"(a[i])                          \
+            : "cc");                             \
+        asm("addq %3,%0; adcq %4,%1; adcq %5,%2" \
+            : "+r"(c0), "+r"(c1), "+r"(c2)       \
+            : "r"(t1), "r"(t2), "g"(0)           \
+            : "cc");                             \
+    } while (0)
 
-#  define mul_add_c2(a,b,c0,c1,c2) do { \
-        BN_ULONG t1,t2;                 \
-        asm ("mulq %3"                  \
-                : "=a"(t1),"=d"(t2)     \
-                : "a"(a),"m"(b)         \
-                : "cc");                \
-        asm ("addq %3,%0; adcq %4,%1; adcq %5,%2"       \
-                : "+r"(c0),"+r"(c1),"+r"(c2)            \
-                : "r"(t1),"r"(t2),"g"(0)                \
-                : "cc");                                \
-        asm ("addq %3,%0; adcq %4,%1; adcq %5,%2"       \
-                : "+r"(c0),"+r"(c1),"+r"(c2)            \
-                : "r"(t1),"r"(t2),"g"(0)                \
-                : "cc");                                \
-        } while (0)
-# endif
+#define mul_add_c2(a, b, c0, c1, c2)             \
+    do {                                         \
+        BN_ULONG t1, t2;                         \
+        asm("mulq %3"                            \
+            : "=a"(t1), "=d"(t2)                 \
+            : "a"(a), "m"(b)                     \
+            : "cc");                             \
+        asm("addq %3,%0; adcq %4,%1; adcq %5,%2" \
+            : "+r"(c0), "+r"(c1), "+r"(c2)       \
+            : "r"(t1), "r"(t2), "g"(0)           \
+            : "cc");                             \
+        asm("addq %3,%0; adcq %4,%1; adcq %5,%2" \
+            : "+r"(c0), "+r"(c1), "+r"(c2)       \
+            : "r"(t1), "r"(t2), "g"(0)           \
+            : "cc");                             \
+    } while (0)
+#endif
 
-# define sqr_add_c2(a,i,j,c0,c1,c2)      \
-        mul_add_c2((a)[i],(a)[j],c0,c1,c2)
+#define sqr_add_c2(a, i, j, c0, c1, c2) \
+    mul_add_c2((a)[i], (a)[j], c0, c1, c2)
 
 void bn_mul_comba8(BN_ULONG *r, BN_ULONG *a, BN_ULONG *b)
 {
