@@ -22,15 +22,15 @@
 
 #define DEFINE_OSSL_CMP_CTX_get0(FIELD, TYPE) \
     DEFINE_OSSL_CMP_CTX_get0_NAME(FIELD, FIELD, TYPE)
-#define DEFINE_OSSL_CMP_CTX_get0_NAME(NAME, FIELD, TYPE) \
-TYPE *OSSL_CMP_CTX_get0_##NAME(const OSSL_CMP_CTX *ctx) \
-{ \
-    if (ctx == NULL) { \
-        ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT); \
-        return NULL; \
-    } \
-    return ctx->FIELD; \
-}
+#define DEFINE_OSSL_CMP_CTX_get0_NAME(NAME, FIELD, TYPE)    \
+    TYPE *OSSL_CMP_CTX_get0_##NAME(const OSSL_CMP_CTX *ctx) \
+    {                                                       \
+        if (ctx == NULL) {                                  \
+            ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT);    \
+            return NULL;                                    \
+        }                                                   \
+        return ctx->FIELD;                                  \
+    }
 
 /*
  * Get current certificate store containing trusted root CA certs
@@ -39,36 +39,36 @@ DEFINE_OSSL_CMP_CTX_get0_NAME(trusted, trusted, X509_STORE)
 
 #define DEFINE_OSSL_set0(PREFIX, FIELD, TYPE) \
     DEFINE_OSSL_set0_NAME(PREFIX, FIELD, FIELD, TYPE)
-#define DEFINE_OSSL_set0_NAME(PREFIX, NAME, FIELD, TYPE) \
-int PREFIX##_set0##_##NAME(OSSL_CMP_CTX *ctx, TYPE *val) \
-{ \
-    if (ctx == NULL) { \
-        ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT); \
-        return 0; \
-    } \
-    TYPE##_free(ctx->FIELD); \
-    ctx->FIELD = val; \
-    return 1; \
-}
+#define DEFINE_OSSL_set0_NAME(PREFIX, NAME, FIELD, TYPE)     \
+    int PREFIX##_set0##_##NAME(OSSL_CMP_CTX *ctx, TYPE *val) \
+    {                                                        \
+        if (ctx == NULL) {                                   \
+            ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT);     \
+            return 0;                                        \
+        }                                                    \
+        TYPE##_free(ctx->FIELD);                             \
+        ctx->FIELD = val;                                    \
+        return 1;                                            \
+    }
 
-/*
- * Set certificate store containing trusted (root) CA certs and possibly CRLs
- * and a cert verification callback function used for CMP server authentication.
- * Any already existing store entry is freed. Given NULL, the entry is reset.
- */
-DEFINE_OSSL_set0_NAME(OSSL_CMP_CTX, trusted, trusted, X509_STORE)
+    /*
+     * Set certificate store containing trusted (root) CA certs and possibly CRLs
+     * and a cert verification callback function used for CMP server authentication.
+     * Any already existing store entry is freed. Given NULL, the entry is reset.
+     */
+    DEFINE_OSSL_set0_NAME(OSSL_CMP_CTX, trusted, trusted, X509_STORE)
 
-DEFINE_OSSL_CMP_CTX_get0(libctx, OSSL_LIB_CTX)
-DEFINE_OSSL_CMP_CTX_get0(propq, const char)
+        DEFINE_OSSL_CMP_CTX_get0(libctx, OSSL_LIB_CTX)
+            DEFINE_OSSL_CMP_CTX_get0(propq, const char)
 
-/* Get current list of non-trusted intermediate certs */
-DEFINE_OSSL_CMP_CTX_get0(untrusted, STACK_OF(X509))
+    /* Get current list of non-trusted intermediate certs */
+    DEFINE_OSSL_CMP_CTX_get0(untrusted, STACK_OF(X509))
 
-/*
- * Set untrusted certificates for path construction in authentication of
- * the CMP server and potentially others (TLS server, newly enrolled cert).
- */
-int OSSL_CMP_CTX_set1_untrusted(OSSL_CMP_CTX *ctx, STACK_OF(X509) *certs)
+    /*
+     * Set untrusted certificates for path construction in authentication of
+     * the CMP server and potentially others (TLS server, newly enrolled cert).
+     */
+    int OSSL_CMP_CTX_set1_untrusted(OSSL_CMP_CTX *ctx, STACK_OF(X509) *certs)
 {
     STACK_OF(X509) *untrusted = NULL;
 
@@ -77,12 +77,12 @@ int OSSL_CMP_CTX_set1_untrusted(OSSL_CMP_CTX *ctx, STACK_OF(X509) *certs)
         return 0;
     }
     if (!ossl_x509_add_certs_new(&untrusted, certs,
-                                 X509_ADD_FLAG_UP_REF | X509_ADD_FLAG_NO_DUP))
+            X509_ADD_FLAG_UP_REF | X509_ADD_FLAG_NO_DUP))
         goto err;
     OSSL_STACK_OF_X509_free(ctx->untrusted);
     ctx->untrusted = untrusted;
     return 1;
- err:
+err:
     OSSL_STACK_OF_X509_free(untrusted);
     return 0;
 }
@@ -144,7 +144,7 @@ OSSL_CMP_CTX *OSSL_CMP_CTX_new(OSSL_LIB_CTX *libctx, const char *propq)
     /* all other elements are initialized to 0 or NULL, respectively */
     return ctx;
 
- err:
+err:
     OSSL_CMP_CTX_free(ctx);
     return NULL;
 }
@@ -252,62 +252,62 @@ void OSSL_CMP_CTX_free(OSSL_CMP_CTX *ctx)
     OPENSSL_free(ctx);
 }
 
-#define DEFINE_OSSL_set(PREFIX, FIELD, TYPE) \
-int PREFIX##_set_##FIELD(OSSL_CMP_CTX *ctx, TYPE val) \
-{ \
-    if (ctx == NULL) { \
-        ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT); \
-        return 0; \
-    } \
-    ctx->FIELD = val; \
-    return 1; \
-}
+#define DEFINE_OSSL_set(PREFIX, FIELD, TYPE)              \
+    int PREFIX##_set_##FIELD(OSSL_CMP_CTX *ctx, TYPE val) \
+    {                                                     \
+        if (ctx == NULL) {                                \
+            ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT);  \
+            return 0;                                     \
+        }                                                 \
+        ctx->FIELD = val;                                 \
+        return 1;                                         \
+    }
 
 DEFINE_OSSL_set(ossl_cmp_ctx, status, int)
 
-#define DEFINE_OSSL_get(PREFIX, FIELD, TYPE, ERR_RET) \
-TYPE PREFIX##_get_##FIELD(const OSSL_CMP_CTX *ctx) \
-{ \
-    if (ctx == NULL) { \
-        ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT); \
-        return ERR_RET; \
-    } \
-    return ctx->FIELD; \
-}
+#define DEFINE_OSSL_get(PREFIX, FIELD, TYPE, ERR_RET)    \
+    TYPE PREFIX##_get_##FIELD(const OSSL_CMP_CTX *ctx)   \
+    {                                                    \
+        if (ctx == NULL) {                               \
+            ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT); \
+            return ERR_RET;                              \
+        }                                                \
+        return ctx->FIELD;                               \
+    }
 
-/*
- * Returns the PKIStatus from the last CertRepMessage
- * or Revocation Response or error message, -1 on error
- */
-DEFINE_OSSL_get(OSSL_CMP_CTX, status, int, -1)
+    /*
+     * Returns the PKIStatus from the last CertRepMessage
+     * or Revocation Response or error message, -1 on error
+     */
+    DEFINE_OSSL_get(OSSL_CMP_CTX, status, int, -1)
 
-/*
- * Returns the statusString from the last CertRepMessage
- * or Revocation Response or error message, NULL on error
- */
-DEFINE_OSSL_CMP_CTX_get0(statusString, OSSL_CMP_PKIFREETEXT)
+    /*
+     * Returns the statusString from the last CertRepMessage
+     * or Revocation Response or error message, NULL on error
+     */
+    DEFINE_OSSL_CMP_CTX_get0(statusString, OSSL_CMP_PKIFREETEXT)
 
-DEFINE_OSSL_set0(ossl_cmp_ctx, statusString, OSSL_CMP_PKIFREETEXT)
+        DEFINE_OSSL_set0(ossl_cmp_ctx, statusString, OSSL_CMP_PKIFREETEXT)
 
-/* Set callback function for checking if the cert is ok or should be rejected */
-DEFINE_OSSL_set(OSSL_CMP_CTX, certConf_cb, OSSL_CMP_certConf_cb_t)
+    /* Set callback function for checking if the cert is ok or should be rejected */
+    DEFINE_OSSL_set(OSSL_CMP_CTX, certConf_cb, OSSL_CMP_certConf_cb_t)
 
-/*
- * Set argument, respectively a pointer to a structure containing arguments,
- * optionally to be used by the certConf callback.
- */
-DEFINE_OSSL_set(OSSL_CMP_CTX, certConf_cb_arg, void *)
+    /*
+     * Set argument, respectively a pointer to a structure containing arguments,
+     * optionally to be used by the certConf callback.
+     */
+    DEFINE_OSSL_set(OSSL_CMP_CTX, certConf_cb_arg, void *)
 
-/*
- * Get argument, respectively the pointer to a structure containing arguments,
- * optionally to be used by certConf callback.
- * Returns callback argument set previously (NULL if not set or on error)
- */
-DEFINE_OSSL_get(OSSL_CMP_CTX, certConf_cb_arg, void *, NULL)
+    /*
+     * Get argument, respectively the pointer to a structure containing arguments,
+     * optionally to be used by certConf callback.
+     * Returns callback argument set previously (NULL if not set or on error)
+     */
+    DEFINE_OSSL_get(OSSL_CMP_CTX, certConf_cb_arg, void *, NULL)
 
 #ifndef OPENSSL_NO_TRACE
-static size_t ossl_cmp_log_trace_cb(const char *buf, size_t cnt,
-                                    int category, int cmd, void *vdata)
+        static size_t ossl_cmp_log_trace_cb(const char *buf, size_t cnt,
+            int category, int cmd, void *vdata)
 {
     OSSL_CMP_CTX *ctx = vdata;
     const char *msg;
@@ -327,11 +327,11 @@ static size_t ossl_cmp_log_trace_cb(const char *buf, size_t cnt,
         goto end; /* suppress output since severity is not sufficient */
 
     if (!ctx->log_cb(func != NULL ? func : "(no func)",
-                     file != NULL ? file : "(no file)",
-                     line, level, msg))
+            file != NULL ? file : "(no file)",
+            line, level, msg))
         cnt = 0;
 
- end:
+end:
     OPENSSL_free(func);
     OPENSSL_free(file);
     return cnt;
@@ -340,8 +340,8 @@ static size_t ossl_cmp_log_trace_cb(const char *buf, size_t cnt,
 
 /* Print CMP log messages (i.e., diagnostic info) via the log cb of the ctx */
 int ossl_cmp_print_log(OSSL_CMP_severity level, const OSSL_CMP_CTX *ctx,
-                       const char *func, const char *file, int line,
-                       const char *level_str, const char *format, ...)
+    const char *func, const char *file, int line,
+    const char *level_str, const char *format, ...)
 {
     va_list args;
     char hugebuf[1024 * 2];
@@ -367,17 +367,19 @@ int ossl_cmp_print_log(OSSL_CMP_severity level, const OSSL_CMP_CTX *ctx,
 
 #ifndef OPENSSL_NO_TRACE
     if (OSSL_TRACE_ENABLED(CMP)) {
-        OSSL_TRACE_BEGIN(CMP) {
-            int printed =
-                BIO_snprintf(hugebuf, sizeof(hugebuf),
-                             "%s:%s:%d:" OSSL_CMP_LOG_PREFIX "%s: ",
-                             func, file, line, level_str);
+        OSSL_TRACE_BEGIN(CMP)
+        {
+            int printed = BIO_snprintf(hugebuf, sizeof(hugebuf),
+                "%s:%s:%d:" OSSL_CMP_LOG_PREFIX "%s: ",
+                func, file, line, level_str);
             if (printed > 0 && (size_t)printed < sizeof(hugebuf)) {
                 if (BIO_vsnprintf(hugebuf + printed,
-                                  sizeof(hugebuf) - printed, format, args) > 0)
+                        sizeof(hugebuf) - printed, format, args)
+                    > 0)
                     res = BIO_puts(trc_out, hugebuf) > 0;
             }
-        } OSSL_TRACE_END(CMP);
+        }
+        OSSL_TRACE_END(CMP);
     }
 #else /* compensate for disabled trace API */
     {
@@ -401,7 +403,7 @@ int OSSL_CMP_CTX_set_log_cb(OSSL_CMP_CTX *ctx, OSSL_CMP_log_cb_t cb)
 #ifndef OPENSSL_NO_TRACE
     /* do also in case cb == NULL, to switch off logging output: */
     if (!OSSL_trace_set_callback(OSSL_TRACE_CATEGORY_CMP,
-                                 ossl_cmp_log_trace_cb, ctx))
+            ossl_cmp_log_trace_cb, ctx))
         return 0;
 #endif
 
@@ -421,19 +423,18 @@ void OSSL_CMP_CTX_print_errors(const OSSL_CMP_CTX *ctx)
  * (i.e., the user name) when using PBMAC.
  */
 int OSSL_CMP_CTX_set1_referenceValue(OSSL_CMP_CTX *ctx,
-                                     const unsigned char *ref, int len)
+    const unsigned char *ref, int len)
 {
     if (ctx == NULL) {
         ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT);
         return 0;
     }
-    return
-        ossl_cmp_asn1_octet_string_set1_bytes(&ctx->referenceValue, ref, len);
+    return ossl_cmp_asn1_octet_string_set1_bytes(&ctx->referenceValue, ref, len);
 }
 
 /* Set or clear the password to be used for protecting messages with PBMAC */
 int OSSL_CMP_CTX_set1_secretValue(OSSL_CMP_CTX *ctx,
-                                  const unsigned char *sec, int len)
+    const unsigned char *sec, int len)
 {
     ASN1_OCTET_STRING *secretValue = NULL;
 
@@ -451,57 +452,57 @@ int OSSL_CMP_CTX_set1_secretValue(OSSL_CMP_CTX *ctx,
     return 1;
 }
 
-#define DEFINE_OSSL_CMP_CTX_get1_certs(FIELD) \
-STACK_OF(X509) *OSSL_CMP_CTX_get1_##FIELD(const OSSL_CMP_CTX *ctx) \
-{ \
-    if (ctx == NULL) { \
-        ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT); \
-        return NULL; \
-    } \
-    return X509_chain_up_ref(ctx->FIELD); \
-}
+#define DEFINE_OSSL_CMP_CTX_get1_certs(FIELD)                          \
+    STACK_OF(X509) *OSSL_CMP_CTX_get1_##FIELD(const OSSL_CMP_CTX *ctx) \
+    {                                                                  \
+        if (ctx == NULL) {                                             \
+            ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT);               \
+            return NULL;                                               \
+        }                                                              \
+        return X509_chain_up_ref(ctx->FIELD);                          \
+    }
 
 /* Returns the cert chain computed by OSSL_CMP_certConf_cb(), NULL on error */
 DEFINE_OSSL_CMP_CTX_get1_certs(newChain)
 
-#define DEFINE_OSSL_set1_certs(PREFIX, FIELD) \
-int PREFIX##_set1_##FIELD(OSSL_CMP_CTX *ctx, STACK_OF(X509) *certs) \
-{ \
-    if (ctx == NULL) { \
-        ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT); \
-        return 0; \
-    } \
-    OSSL_STACK_OF_X509_free(ctx->FIELD); \
-    ctx->FIELD = NULL; \
-    return certs == NULL || (ctx->FIELD = X509_chain_up_ref(certs)) != NULL; \
-}
+#define DEFINE_OSSL_set1_certs(PREFIX, FIELD)                                    \
+    int PREFIX##_set1_##FIELD(OSSL_CMP_CTX *ctx, STACK_OF(X509) *certs)          \
+    {                                                                            \
+        if (ctx == NULL) {                                                       \
+            ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT);                         \
+            return 0;                                                            \
+        }                                                                        \
+        OSSL_STACK_OF_X509_free(ctx->FIELD);                                     \
+        ctx->FIELD = NULL;                                                       \
+        return certs == NULL || (ctx->FIELD = X509_chain_up_ref(certs)) != NULL; \
+    }
 
-/*
- * Copies any given stack of inbound X509 certificates to newChain
- * of the OSSL_CMP_CTX structure so that they may be retrieved later.
- */
-DEFINE_OSSL_set1_certs(ossl_cmp_ctx, newChain)
+    /*
+     * Copies any given stack of inbound X509 certificates to newChain
+     * of the OSSL_CMP_CTX structure so that they may be retrieved later.
+     */
+    DEFINE_OSSL_set1_certs(ossl_cmp_ctx, newChain)
 
-/* Returns the stack of extraCerts received in CertRepMessage, NULL on error */
-DEFINE_OSSL_CMP_CTX_get1_certs(extraCertsIn)
+    /* Returns the stack of extraCerts received in CertRepMessage, NULL on error */
+    DEFINE_OSSL_CMP_CTX_get1_certs(extraCertsIn)
 
-/*
- * Copies any given stack of inbound X509 certificates to extraCertsIn
- * of the OSSL_CMP_CTX structure so that they may be retrieved later.
- */
-DEFINE_OSSL_set1_certs(ossl_cmp_ctx, extraCertsIn)
+    /*
+     * Copies any given stack of inbound X509 certificates to extraCertsIn
+     * of the OSSL_CMP_CTX structure so that they may be retrieved later.
+     */
+    DEFINE_OSSL_set1_certs(ossl_cmp_ctx, extraCertsIn)
 
-/*
- * Copies any given stack as the new stack of X509
- * certificates to send out in the extraCerts field.
- */
-DEFINE_OSSL_set1_certs(OSSL_CMP_CTX, extraCertsOut)
+    /*
+     * Copies any given stack as the new stack of X509
+     * certificates to send out in the extraCerts field.
+     */
+    DEFINE_OSSL_set1_certs(OSSL_CMP_CTX, extraCertsOut)
 
-/*
- * Add the given policy info object
- * to the X509_EXTENSIONS of the requested certificate template.
- */
-int OSSL_CMP_CTX_push0_policy(OSSL_CMP_CTX *ctx, POLICYINFO *pinfo)
+    /*
+     * Add the given policy info object
+     * to the X509_EXTENSIONS of the requested certificate template.
+     */
+    int OSSL_CMP_CTX_push0_policy(OSSL_CMP_CTX *ctx, POLICYINFO *pinfo)
 {
     if (ctx == NULL || pinfo == NULL) {
         ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT);
@@ -509,7 +510,7 @@ int OSSL_CMP_CTX_push0_policy(OSSL_CMP_CTX *ctx, POLICYINFO *pinfo)
     }
 
     if (ctx->policies == NULL
-            && (ctx->policies = CERTIFICATEPOLICIES_new()) == NULL)
+        && (ctx->policies = CERTIFICATEPOLICIES_new()) == NULL)
         return 0;
 
     return sk_POLICYINFO_push(ctx->policies, pinfo);
@@ -538,8 +539,8 @@ int OSSL_CMP_CTX_reset_geninfo_ITAVs(OSSL_CMP_CTX *ctx)
 
 DEFINE_OSSL_CMP_CTX_get0(geninfo_ITAVs, STACK_OF(OSSL_CMP_ITAV))
 
-/* Add an itav for the body of outgoing general messages */
-int OSSL_CMP_CTX_push0_genm_ITAV(OSSL_CMP_CTX *ctx, OSSL_CMP_ITAV *itav)
+    /* Add an itav for the body of outgoing general messages */
+    int OSSL_CMP_CTX_push0_genm_ITAV(OSSL_CMP_CTX *ctx, OSSL_CMP_ITAV *itav)
 {
     if (ctx == NULL) {
         ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT);
@@ -555,82 +556,82 @@ int OSSL_CMP_CTX_push0_genm_ITAV(OSSL_CMP_CTX *ctx, OSSL_CMP_ITAV *itav)
  */
 DEFINE_OSSL_CMP_CTX_get1_certs(caPubs)
 
-/*
- * Copies any given stack of certificates to the given
- * OSSL_CMP_CTX structure so that they may be retrieved later.
- */
-DEFINE_OSSL_set1_certs(ossl_cmp_ctx, caPubs)
+    /*
+     * Copies any given stack of certificates to the given
+     * OSSL_CMP_CTX structure so that they may be retrieved later.
+     */
+    DEFINE_OSSL_set1_certs(ossl_cmp_ctx, caPubs)
 
 #define char_dup OPENSSL_strdup
 #define char_free OPENSSL_free
-#define DEFINE_OSSL_CMP_CTX_set1(FIELD, TYPE) /* this uses _dup */ \
-int OSSL_CMP_CTX_set1_##FIELD(OSSL_CMP_CTX *ctx, const TYPE *val) \
-{ \
-    TYPE *val_dup = NULL; \
-    \
-    if (ctx == NULL) { \
-        ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT); \
-        return 0; \
-    } \
-    \
-    if (val != NULL && (val_dup = TYPE##_dup(val)) == NULL) \
-        return 0; \
-    TYPE##_free(ctx->FIELD); \
-    ctx->FIELD = val_dup; \
-    return 1; \
-}
+#define DEFINE_OSSL_CMP_CTX_set1(FIELD, TYPE) /* this uses _dup */    \
+    int OSSL_CMP_CTX_set1_##FIELD(OSSL_CMP_CTX *ctx, const TYPE *val) \
+    {                                                                 \
+        TYPE *val_dup = NULL;                                         \
+                                                                      \
+        if (ctx == NULL) {                                            \
+            ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT);              \
+            return 0;                                                 \
+        }                                                             \
+                                                                      \
+        if (val != NULL && (val_dup = TYPE##_dup(val)) == NULL)       \
+            return 0;                                                 \
+        TYPE##_free(ctx->FIELD);                                      \
+        ctx->FIELD = val_dup;                                         \
+        return 1;                                                     \
+    }
 
 #define X509_invalid(cert) (!ossl_x509v3_cache_extensions(cert))
 #define EVP_PKEY_invalid(key) 0
 
-#define DEFINE_OSSL_set1_up_ref(PREFIX, FIELD, TYPE) \
-int PREFIX##_set1_##FIELD(OSSL_CMP_CTX *ctx, TYPE *val) \
-{ \
-    if (ctx == NULL) { \
-        ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT); \
-        return 0; \
-    } \
-    \
-    /* prevent misleading error later on malformed cert or provider issue */ \
-    if (val != NULL && TYPE##_invalid(val)) { \
-        ERR_raise(ERR_LIB_CMP, CMP_R_POTENTIALLY_INVALID_CERTIFICATE); \
-        return 0; \
-    } \
-    if (val != NULL && !TYPE##_up_ref(val)) \
-        return 0; \
-    TYPE##_free(ctx->FIELD); \
-    ctx->FIELD = val; \
-    return 1; \
-}
+#define DEFINE_OSSL_set1_up_ref(PREFIX, FIELD, TYPE)                             \
+    int PREFIX##_set1_##FIELD(OSSL_CMP_CTX *ctx, TYPE *val)                      \
+    {                                                                            \
+        if (ctx == NULL) {                                                       \
+            ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT);                         \
+            return 0;                                                            \
+        }                                                                        \
+                                                                                 \
+        /* prevent misleading error later on malformed cert or provider issue */ \
+        if (val != NULL && TYPE##_invalid(val)) {                                \
+            ERR_raise(ERR_LIB_CMP, CMP_R_POTENTIALLY_INVALID_CERTIFICATE);       \
+            return 0;                                                            \
+        }                                                                        \
+        if (val != NULL && !TYPE##_up_ref(val))                                  \
+            return 0;                                                            \
+        TYPE##_free(ctx->FIELD);                                                 \
+        ctx->FIELD = val;                                                        \
+        return 1;                                                                \
+    }
 
-DEFINE_OSSL_set1_up_ref(ossl_cmp_ctx, validatedSrvCert, X509)
+        DEFINE_OSSL_set1_up_ref(ossl_cmp_ctx, validatedSrvCert, X509)
 
-/*
- * Pins the server certificate to be directly trusted (even if it is expired)
- * for verifying response messages.
- * Cert pointer is not consumed. It may be NULL to clear the entry.
- */
-DEFINE_OSSL_set1_up_ref(OSSL_CMP_CTX, srvCert, X509)
+    /*
+     * Pins the server certificate to be directly trusted (even if it is expired)
+     * for verifying response messages.
+     * Cert pointer is not consumed. It may be NULL to clear the entry.
+     */
+    DEFINE_OSSL_set1_up_ref(OSSL_CMP_CTX, srvCert, X509)
 
-/* Set the X509 name of the recipient to be placed in the PKIHeader */
-DEFINE_OSSL_CMP_CTX_set1(recipient, X509_NAME)
+    /* Set the X509 name of the recipient to be placed in the PKIHeader */
+    DEFINE_OSSL_CMP_CTX_set1(recipient, X509_NAME)
 
-/* Store the X509 name of the expected sender in the PKIHeader of responses */
-DEFINE_OSSL_CMP_CTX_set1(expected_sender, X509_NAME)
+    /* Store the X509 name of the expected sender in the PKIHeader of responses */
+    DEFINE_OSSL_CMP_CTX_set1(expected_sender, X509_NAME)
 
-/* Set the X509 name of the issuer to be placed in the certTemplate */
-DEFINE_OSSL_CMP_CTX_set1(issuer, X509_NAME)
+    /* Set the X509 name of the issuer to be placed in the certTemplate */
+    DEFINE_OSSL_CMP_CTX_set1(issuer, X509_NAME)
 
-/* Set the ASN1_INTEGER serial to be placed in the certTemplate for rr */
-DEFINE_OSSL_CMP_CTX_set1(serialNumber, ASN1_INTEGER)
-/*
- * Set the subject name that will be placed in the certificate
- * request. This will be the subject name on the received certificate.
- */
-DEFINE_OSSL_CMP_CTX_set1(subjectName, X509_NAME)
+    /* Set the ASN1_INTEGER serial to be placed in the certTemplate for rr */
+    DEFINE_OSSL_CMP_CTX_set1(serialNumber, ASN1_INTEGER)
+    /*
+     * Set the subject name that will be placed in the certificate
+     * request. This will be the subject name on the received certificate.
+     */
+    DEFINE_OSSL_CMP_CTX_set1(subjectName, X509_NAME)
 
-/* Set the X.509v3 certificate request extensions to be used in IR/CR/KUR */
-int OSSL_CMP_CTX_set0_reqExtensions(OSSL_CMP_CTX *ctx, X509_EXTENSIONS *exts)
+    /* Set the X.509v3 certificate request extensions to be used in IR/CR/KUR */
+    int OSSL_CMP_CTX_set0_reqExtensions(OSSL_CMP_CTX *ctx, X509_EXTENSIONS *exts)
 {
     if (ctx == NULL) {
         ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT);
@@ -638,7 +639,7 @@ int OSSL_CMP_CTX_set0_reqExtensions(OSSL_CMP_CTX *ctx, X509_EXTENSIONS *exts)
     }
 
     if (sk_GENERAL_NAME_num(ctx->subjectAltNames) > 0 && exts != NULL
-            && X509v3_get_ext_by_NID(exts, NID_subject_alt_name, -1) >= 0) {
+        && X509v3_get_ext_by_NID(exts, NID_subject_alt_name, -1) >= 0) {
         ERR_raise(ERR_LIB_CMP, CMP_R_MULTIPLE_SAN_SOURCES);
         return 0;
     }
@@ -657,7 +658,8 @@ int OSSL_CMP_CTX_reqExtensions_have_SAN(OSSL_CMP_CTX *ctx)
     /* if one of the following conditions 'fail' this is not an error */
     return ctx->reqExtensions != NULL
         && X509v3_get_ext_by_NID(ctx->reqExtensions,
-                                 NID_subject_alt_name, -1) >= 0;
+               NID_subject_alt_name, -1)
+        >= 0;
 }
 
 /*
@@ -665,7 +667,7 @@ int OSSL_CMP_CTX_reqExtensions_have_SAN(OSSL_CMP_CTX *ctx)
  * request's extensions field to request subject alternative names.
  */
 int OSSL_CMP_CTX_push1_subjectAltName(OSSL_CMP_CTX *ctx,
-                                      const GENERAL_NAME *name)
+    const GENERAL_NAME *name)
 {
     GENERAL_NAME *name_dup;
 
@@ -680,7 +682,7 @@ int OSSL_CMP_CTX_push1_subjectAltName(OSSL_CMP_CTX *ctx,
     }
 
     if (ctx->subjectAltNames == NULL
-            && (ctx->subjectAltNames = sk_GENERAL_NAME_new_null()) == NULL)
+        && (ctx->subjectAltNames = sk_GENERAL_NAME_new_null()) == NULL)
         return 0;
     if ((name_dup = GENERAL_NAME_dup(name)) == NULL)
         return 0;
@@ -697,8 +699,8 @@ int OSSL_CMP_CTX_push1_subjectAltName(OSSL_CMP_CTX *ctx,
  */
 DEFINE_OSSL_set1_up_ref(OSSL_CMP_CTX, cert, X509)
 
-int OSSL_CMP_CTX_build_cert_chain(OSSL_CMP_CTX *ctx, X509_STORE *own_trusted,
-                                  STACK_OF(X509) *candidates)
+    int OSSL_CMP_CTX_build_cert_chain(OSSL_CMP_CTX *ctx, X509_STORE *own_trusted,
+        STACK_OF(X509) *candidates)
 {
     STACK_OF(X509) *chain;
 
@@ -708,12 +710,12 @@ int OSSL_CMP_CTX_build_cert_chain(OSSL_CMP_CTX *ctx, X509_STORE *own_trusted,
     }
 
     if (!ossl_x509_add_certs_new(&ctx->untrusted, candidates,
-                                 X509_ADD_FLAG_UP_REF | X509_ADD_FLAG_NO_DUP))
+            X509_ADD_FLAG_UP_REF | X509_ADD_FLAG_NO_DUP))
         return 0;
 
     ossl_cmp_debug(ctx, "trying to build chain for own CMP signer cert");
     chain = X509_build_chain(ctx->cert, ctx->untrusted, own_trusted, 0,
-                             ctx->libctx, ctx->propq);
+        ctx->libctx, ctx->propq);
     if (chain == NULL) {
         ERR_raise(ERR_LIB_CMP, CMP_R_FAILED_BUILDING_OWN_CHAIN);
         return 0;
@@ -731,29 +733,29 @@ int OSSL_CMP_CTX_build_cert_chain(OSSL_CMP_CTX *ctx, X509_STORE *own_trusted,
  */
 DEFINE_OSSL_set1_up_ref(OSSL_CMP_CTX, oldCert, X509)
 
-/* Set the PKCS#10 CSR to be sent in P10CR */
-DEFINE_OSSL_CMP_CTX_set1(p10CSR, X509_REQ)
+    /* Set the PKCS#10 CSR to be sent in P10CR */
+    DEFINE_OSSL_CMP_CTX_set1(p10CSR, X509_REQ)
 
-/*
- * Set the (newly received in IP/KUP/CP) certificate in the context.
- * This only permits for one cert to be enrolled at a time.
- */
-DEFINE_OSSL_set0(ossl_cmp_ctx, newCert, X509)
+    /*
+     * Set the (newly received in IP/KUP/CP) certificate in the context.
+     * This only permits for one cert to be enrolled at a time.
+     */
+    DEFINE_OSSL_set0(ossl_cmp_ctx, newCert, X509)
 
-/* Get successfully validated server cert, if any, of current transaction */
-DEFINE_OSSL_CMP_CTX_get0(validatedSrvCert, X509)
+    /* Get successfully validated server cert, if any, of current transaction */
+    DEFINE_OSSL_CMP_CTX_get0(validatedSrvCert, X509)
 
-/*
- * Get the (newly received in IP/KUP/CP) client certificate from the context
- * This only permits for one client cert to be received...
- */
-DEFINE_OSSL_CMP_CTX_get0(newCert, X509)
+    /*
+     * Get the (newly received in IP/KUP/CP) client certificate from the context
+     * This only permits for one client cert to be received...
+     */
+    DEFINE_OSSL_CMP_CTX_get0(newCert, X509)
 
-/* Set the client's current private key */
-DEFINE_OSSL_set1_up_ref(OSSL_CMP_CTX, pkey, EVP_PKEY)
+    /* Set the client's current private key */
+    DEFINE_OSSL_set1_up_ref(OSSL_CMP_CTX, pkey, EVP_PKEY)
 
-/* Set new key pair. Used e.g. when doing Key Update */
-int OSSL_CMP_CTX_set0_newPkey(OSSL_CMP_CTX *ctx, int priv, EVP_PKEY *pkey)
+    /* Set new key pair. Used e.g. when doing Key Update */
+    int OSSL_CMP_CTX_set0_newPkey(OSSL_CMP_CTX *ctx, int priv, EVP_PKEY *pkey)
 {
     if (ctx == NULL) {
         ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT);
@@ -797,80 +799,80 @@ EVP_PKEY *ossl_cmp_ctx_get0_newPubkey(const OSSL_CMP_CTX *ctx)
     return ctx->pkey;
 }
 
-#define DEFINE_set1_ASN1_OCTET_STRING(PREFIX, FIELD) \
-int PREFIX##_set1_##FIELD(OSSL_CMP_CTX *ctx, const ASN1_OCTET_STRING *id) \
-{ \
-    if (ctx == NULL) { \
-        ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT); \
-        return 0; \
-    } \
-    return ossl_cmp_asn1_octet_string_set1(&ctx->FIELD, id); \
-}
+#define DEFINE_set1_ASN1_OCTET_STRING(PREFIX, FIELD)                          \
+    int PREFIX##_set1_##FIELD(OSSL_CMP_CTX *ctx, const ASN1_OCTET_STRING *id) \
+    {                                                                         \
+        if (ctx == NULL) {                                                    \
+            ERR_raise(ERR_LIB_CMP, CMP_R_NULL_ARGUMENT);                      \
+            return 0;                                                         \
+        }                                                                     \
+        return ossl_cmp_asn1_octet_string_set1(&ctx->FIELD, id);              \
+    }
 
 /* Set the given transactionID to the context */
 DEFINE_set1_ASN1_OCTET_STRING(OSSL_CMP_CTX, transactionID)
 
-/* Set the nonce to be used for the recipNonce in the message created next */
-DEFINE_set1_ASN1_OCTET_STRING(ossl_cmp_ctx, recipNonce)
+    /* Set the nonce to be used for the recipNonce in the message created next */
+    DEFINE_set1_ASN1_OCTET_STRING(ossl_cmp_ctx, recipNonce)
 
-/* Stores the given nonce as the last senderNonce sent out */
-DEFINE_set1_ASN1_OCTET_STRING(OSSL_CMP_CTX, senderNonce)
+    /* Stores the given nonce as the last senderNonce sent out */
+    DEFINE_set1_ASN1_OCTET_STRING(OSSL_CMP_CTX, senderNonce)
 
-/* store the first req sender nonce for verifying delayed delivery */
-DEFINE_set1_ASN1_OCTET_STRING(ossl_cmp_ctx, first_senderNonce)
+    /* store the first req sender nonce for verifying delayed delivery */
+    DEFINE_set1_ASN1_OCTET_STRING(ossl_cmp_ctx, first_senderNonce)
 
-/* Set the proxy server to use for HTTP(S) connections */
-DEFINE_OSSL_CMP_CTX_set1(proxy, char)
+    /* Set the proxy server to use for HTTP(S) connections */
+    DEFINE_OSSL_CMP_CTX_set1(proxy, char)
 
-/* Set the (HTTP) hostname of the CMP server */
-DEFINE_OSSL_CMP_CTX_set1(server, char)
+    /* Set the (HTTP) hostname of the CMP server */
+    DEFINE_OSSL_CMP_CTX_set1(server, char)
 
-/* Set the server exclusion list of the HTTP proxy server */
-DEFINE_OSSL_CMP_CTX_set1(no_proxy, char)
+    /* Set the server exclusion list of the HTTP proxy server */
+    DEFINE_OSSL_CMP_CTX_set1(no_proxy, char)
 
 #ifndef OPENSSL_NO_HTTP
-/* Set the http connect/disconnect callback function to be used for HTTP(S) */
-DEFINE_OSSL_set(OSSL_CMP_CTX, http_cb, OSSL_HTTP_bio_cb_t)
+    /* Set the http connect/disconnect callback function to be used for HTTP(S) */
+    DEFINE_OSSL_set(OSSL_CMP_CTX, http_cb, OSSL_HTTP_bio_cb_t)
 
-/* Set argument optionally to be used by the http connect/disconnect callback */
-DEFINE_OSSL_set(OSSL_CMP_CTX, http_cb_arg, void *)
+    /* Set argument optionally to be used by the http connect/disconnect callback */
+    DEFINE_OSSL_set(OSSL_CMP_CTX, http_cb_arg, void *)
 
-/*
- * Get argument optionally to be used by the http connect/disconnect callback
- * Returns callback argument set previously (NULL if not set or on error)
- */
-DEFINE_OSSL_get(OSSL_CMP_CTX, http_cb_arg, void *, NULL)
+    /*
+     * Get argument optionally to be used by the http connect/disconnect callback
+     * Returns callback argument set previously (NULL if not set or on error)
+     */
+    DEFINE_OSSL_get(OSSL_CMP_CTX, http_cb_arg, void *, NULL)
 #endif
 
-/* Set callback function for sending CMP request and receiving response */
-DEFINE_OSSL_set(OSSL_CMP_CTX, transfer_cb, OSSL_CMP_transfer_cb_t)
+    /* Set callback function for sending CMP request and receiving response */
+    DEFINE_OSSL_set(OSSL_CMP_CTX, transfer_cb, OSSL_CMP_transfer_cb_t)
 
-/* Set argument optionally to be used by the transfer callback */
-DEFINE_OSSL_set(OSSL_CMP_CTX, transfer_cb_arg, void *)
+    /* Set argument optionally to be used by the transfer callback */
+    DEFINE_OSSL_set(OSSL_CMP_CTX, transfer_cb_arg, void *)
 
-/*
- * Get argument optionally to be used by the transfer callback.
- * Returns callback argument set previously (NULL if not set or on error)
- */
-DEFINE_OSSL_get(OSSL_CMP_CTX, transfer_cb_arg, void *, NULL)
+    /*
+     * Get argument optionally to be used by the transfer callback.
+     * Returns callback argument set previously (NULL if not set or on error)
+     */
+    DEFINE_OSSL_get(OSSL_CMP_CTX, transfer_cb_arg, void *, NULL)
 
-/** Set the HTTP server port to be used */
-DEFINE_OSSL_set(OSSL_CMP_CTX, serverPort, int)
+    /** Set the HTTP server port to be used */
+    DEFINE_OSSL_set(OSSL_CMP_CTX, serverPort, int)
 
-/* Set the HTTP path to be used on the server (e.g "pkix/") */
-DEFINE_OSSL_CMP_CTX_set1(serverPath, char)
+    /* Set the HTTP path to be used on the server (e.g "pkix/") */
+    DEFINE_OSSL_CMP_CTX_set1(serverPath, char)
 
-/* Set the failInfo error code as bit encoding in OSSL_CMP_CTX */
-DEFINE_OSSL_set(ossl_cmp_ctx, failInfoCode, int)
+    /* Set the failInfo error code as bit encoding in OSSL_CMP_CTX */
+    DEFINE_OSSL_set(ossl_cmp_ctx, failInfoCode, int)
 
-/*
- * Get the failInfo error code in OSSL_CMP_CTX as bit encoding.
- * Returns bit string as integer on success, -1 on error
- */
-DEFINE_OSSL_get(OSSL_CMP_CTX, failInfoCode, int, -1)
+    /*
+     * Get the failInfo error code in OSSL_CMP_CTX as bit encoding.
+     * Returns bit string as integer on success, -1 on error
+     */
+    DEFINE_OSSL_get(OSSL_CMP_CTX, failInfoCode, int, -1)
 
-/* Set a Boolean or integer option of the context to the "val" arg */
-int OSSL_CMP_CTX_set_option(OSSL_CMP_CTX *ctx, int opt, int val)
+    /* Set a Boolean or integer option of the context to the "val" arg */
+    int OSSL_CMP_CTX_set_option(OSSL_CMP_CTX *ctx, int opt, int val)
 {
     int min_val;
 
