@@ -39,8 +39,8 @@ COMP_METHOD *COMP_zstd(void);
 #error Wrong (i.e. linux) zstd.h included.
 #endif
 
-#if ZSTD_VERSION_MAJOR != 1 && ZSTD_VERSION_MINOR < 4
-#error Expecting version 1.4 or greater of ZSTD
+#if ZSTD_VERSION_MAJOR != 1 || ZSTD_VERSION_MINOR < 4
+#error Expecting version 1.4 or greater of ZSTD 1.x
 #endif
 
 #ifndef ZSTD_SHARED
@@ -735,7 +735,7 @@ static int bio_zstd_flush(BIO *b)
         /* Compress some more */
         zret = ZSTD_flushStream(ctx->compress.state, &ctx->compress.outbuf);
         if (ZSTD_isError(zret)) {
-            ERR_raise(ERR_LIB_COMP, COMP_R_ZSTD_DECODE_ERROR);
+            ERR_raise(ERR_LIB_COMP, COMP_R_ZSTD_COMPRESS_ERROR);
             ERR_add_error_data(1, ZSTD_getErrorName(zret));
             return 0;
         }
