@@ -13,28 +13,28 @@
 #include <openssl/safestack.h>
 
 #if defined(_WIN32) && !defined(OPENSSL_SYS_UEFI)
-# include <tchar.h>
-# include <signal.h>
-# ifdef __WATCOMC__
-#  if defined(_UNICODE) || defined(__UNICODE__)
-#   define _vsntprintf _vsnwprintf
-#  else
-#   define _vsntprintf _vsnprintf
-#  endif
-# endif
-# ifdef _MSC_VER
-#  define alloca _alloca
-# endif
+#include <tchar.h>
+#include <signal.h>
+#ifdef __WATCOMC__
+#if defined(_UNICODE) || defined(__UNICODE__)
+#define _vsntprintf _vsnwprintf
+#else
+#define _vsntprintf _vsnprintf
+#endif
+#endif
+#ifdef _MSC_VER
+#define alloca _alloca
+#endif
 
-# if defined(_WIN32_WINNT) && _WIN32_WINNT>=0x0333
-#  ifdef OPENSSL_SYS_WIN_CORE
+#if defined(_WIN32_WINNT) && _WIN32_WINNT >= 0x0333
+#ifdef OPENSSL_SYS_WIN_CORE
 
 int OPENSSL_isservice(void)
 {
     /* OneCore API cannot interact with GUI */
     return 1;
 }
-#  else
+#else
 int OPENSSL_isservice(void)
 {
     HWINSTA h;
@@ -60,26 +60,25 @@ int OPENSSL_isservice(void)
     }
 
     if (_OPENSSL_isservice.p != (void *)-1)
-        return (*_OPENSSL_isservice.f) ();
+        return (*_OPENSSL_isservice.f)();
 
     h = GetProcessWindowStation();
     if (h == NULL)
         return -1;
 
-    if (GetUserObjectInformationW(h, UOI_NAME, NULL, 0, &len) ||
-        GetLastError() != ERROR_INSUFFICIENT_BUFFER)
+    if (GetUserObjectInformationW(h, UOI_NAME, NULL, 0, &len) || GetLastError() != ERROR_INSUFFICIENT_BUFFER)
         return -1;
 
     if (len > 512)
-        return -1;              /* paranoia */
-    len++, len &= ~1;           /* paranoia */
+        return -1; /* paranoia */
+    len++, len &= ~1; /* paranoia */
     name = (WCHAR *)alloca(len + sizeof(WCHAR));
     if (!GetUserObjectInformationW(h, UOI_NAME, name, len, &len))
         return -1;
 
-    len++, len &= ~1;           /* paranoia */
+    len++, len &= ~1; /* paranoia */
     name[len / sizeof(WCHAR)] = L'\0'; /* paranoia */
-#   if 1
+#if 1
     /*
      * This doesn't cover "interactive" services [working with real
      * WinSta0's] nor programs started non-interactively by Task Scheduler
@@ -87,21 +86,21 @@ int OPENSSL_isservice(void)
      */
     if (wcsstr(name, L"Service-0x"))
         return 1;
-#   else
+#else
     /* This covers all non-interactive programs such as services. */
     if (!wcsstr(name, L"WinSta0"))
         return 1;
-#   endif
+#endif
     else
         return 0;
 }
-#  endif
-# else
+#endif
+#else
 int OPENSSL_isservice(void)
 {
     return 0;
 }
-# endif
+#endif
 
 void OPENSSL_showfatal(const char *fmta, ...)
 {
@@ -114,22 +113,21 @@ void OPENSSL_showfatal(const char *fmta, ...)
      * Windows CE does not have a concept of a console application,
      * so we need to guard the check.
      */
-# ifdef STD_ERROR_HANDLE
+#ifdef STD_ERROR_HANDLE
     HANDLE h;
 
-    if ((h = GetStdHandle(STD_ERROR_HANDLE)) != NULL &&
-        GetFileType(h) != FILE_TYPE_UNKNOWN) {
+    if ((h = GetStdHandle(STD_ERROR_HANDLE)) != NULL && GetFileType(h) != FILE_TYPE_UNKNOWN) {
         /* must be console application */
         int len;
         DWORD out;
 
         va_start(ap, fmta);
         len = _vsnprintf((char *)buf, sizeof(buf), fmta, ap);
-        WriteFile(h, buf, len < 0 ? sizeof(buf) : (DWORD) len, &out, NULL);
+        WriteFile(h, buf, len < 0 ? sizeof(buf) : (DWORD)len, &out, NULL);
         va_end(ap);
         return;
     }
-# endif
+#endif
 
     if (sizeof(TCHAR) == sizeof(char))
         fmt = (const TCHAR *)fmta;
@@ -191,19 +189,19 @@ void OPENSSL_showfatal(const char *fmta, ...)
     buf[OSSL_NELEM(buf) - 1] = _T('\0');
     va_end(ap);
 
-# if defined(_WIN32_WINNT) && _WIN32_WINNT>=0x0333
-#  ifdef OPENSSL_SYS_WIN_CORE
+#if defined(_WIN32_WINNT) && _WIN32_WINNT >= 0x0333
+#ifdef OPENSSL_SYS_WIN_CORE
     /* ONECORE is always NONGUI and NT >= 0x0601 */
-#   if !defined(NDEBUG)
-        /*
-        * We are in a situation where we tried to report a critical
-        * error and this failed for some reason. As a last resort,
-        * in debug builds, send output to the debugger or any other
-        * tool like DebugView which can monitor the output.
-        */
-        OutputDebugString(buf);
-#   endif
-#  else
+#if !defined(NDEBUG)
+    /*
+     * We are in a situation where we tried to report a critical
+     * error and this failed for some reason. As a last resort,
+     * in debug builds, send output to the debugger or any other
+     * tool like DebugView which can monitor the output.
+     */
+    OutputDebugString(buf);
+#endif
+#else
     /* this -------------v--- guards NT-specific calls */
     if (check_winnt() && OPENSSL_isservice() > 0) {
         HANDLE hEventLog = RegisterEventSource(NULL, _T("OpenSSL"));
@@ -212,8 +210,8 @@ void OPENSSL_showfatal(const char *fmta, ...)
             const TCHAR *pmsg = buf;
 
             if (!ReportEvent(hEventLog, EVENTLOG_ERROR_TYPE, 0, 0, NULL,
-                             1, 0, &pmsg, NULL)) {
-#   if !defined(NDEBUG)
+                    1, 0, &pmsg, NULL)) {
+#if !defined(NDEBUG)
                 /*
                  * We are in a situation where we tried to report a critical
                  * error and this failed for some reason. As a last resort,
@@ -221,7 +219,7 @@ void OPENSSL_showfatal(const char *fmta, ...)
                  * tool like DebugView which can monitor the output.
                  */
                 OutputDebugString(pmsg);
-#   endif
+#endif
             }
 
             (void)DeregisterEventSource(hEventLog);
@@ -229,10 +227,10 @@ void OPENSSL_showfatal(const char *fmta, ...)
     } else {
         MessageBox(NULL, buf, _T("OpenSSL: FATAL"), MB_OK | MB_ICONERROR);
     }
-#  endif
-# else
+#endif
+#else
     MessageBox(NULL, buf, _T("OpenSSL: FATAL"), MB_OK | MB_ICONERROR);
-# endif
+#endif
 }
 #else
 void OPENSSL_showfatal(const char *fmta, ...)
@@ -255,16 +253,16 @@ int OPENSSL_isservice(void)
 void OPENSSL_die(const char *message, const char *file, int line)
 {
     OPENSSL_showfatal("%s:%d: OpenSSL internal error: %s\n",
-                      file, line, message);
+        file, line, message);
 #if !defined(_WIN32) || defined(OPENSSL_SYS_UEFI)
     abort();
 #else
     /*
      * Win32 abort() customarily shows a dialog, but we just did that...
      */
-# if !defined(_WIN32_WCE)
+#if !defined(_WIN32_WCE)
     raise(SIGABRT);
-# endif
+#endif
     _exit(3);
 #endif
 }
@@ -275,8 +273,8 @@ void OPENSSL_die(const char *message, const char *file, int line)
  * This is used by platform version identification tools.
  * Do not inline this procedure or make it static.
  */
-# define OPENSSL_VPROC_STRING_(x)    x##_CRYPTO
-# define OPENSSL_VPROC_STRING(x)     OPENSSL_VPROC_STRING_(x)
-# define OPENSSL_VPROC_FUNC          OPENSSL_VPROC_STRING(OPENSSL_VPROC)
-void OPENSSL_VPROC_FUNC(void) {}
+#define OPENSSL_VPROC_STRING_(x) x##_CRYPTO
+#define OPENSSL_VPROC_STRING(x) OPENSSL_VPROC_STRING_(x)
+#define OPENSSL_VPROC_FUNC OPENSSL_VPROC_STRING(OPENSSL_VPROC)
+void OPENSSL_VPROC_FUNC(void) { }
 #endif /* __TANDEM */
