@@ -33,24 +33,24 @@
 
 #ifndef FIPS_MODULE
 static int dh_builtin_genparams(DH *ret, int prime_len, int generator,
-                                BN_GENCB *cb);
+    BN_GENCB *cb);
 #endif /* FIPS_MODULE */
 
 int ossl_dh_generate_ffc_parameters(DH *dh, int type, int pbits, int qbits,
-                                    BN_GENCB *cb)
+    BN_GENCB *cb)
 {
     int ret, res;
 
 #ifndef FIPS_MODULE
     if (type == DH_PARAMGEN_TYPE_FIPS_186_2)
         ret = ossl_ffc_params_FIPS186_2_generate(dh->libctx, &dh->params,
-                                                 FFC_PARAM_TYPE_DH,
-                                                 pbits, qbits, &res, cb);
+            FFC_PARAM_TYPE_DH,
+            pbits, qbits, &res, cb);
     else
 #endif
         ret = ossl_ffc_params_FIPS186_4_generate(dh->libctx, &dh->params,
-                                                 FFC_PARAM_TYPE_DH,
-                                                 pbits, qbits, &res, cb);
+            FFC_PARAM_TYPE_DH,
+            pbits, qbits, &res, cb);
     if (ret > 0)
         dh->dirty_cnt++;
     return ret;
@@ -113,7 +113,7 @@ static int dh_gen_named_group(OSSL_LIB_CTX *libctx, DH *ret, int prime_len)
 #endif /* FIPS_MODULE */
 
 int DH_generate_parameters_ex(DH *ret, int prime_len, int generator,
-                              BN_GENCB *cb)
+    BN_GENCB *cb)
 {
 #ifdef FIPS_MODULE
     if (generator != 2)
@@ -154,7 +154,7 @@ int DH_generate_parameters_ex(DH *ret, int prime_len, int generator,
  * for 5, p mod 60 == 59
  */
 static int dh_builtin_genparams(DH *ret, int prime_len, int generator,
-                                BN_GENCB *cb)
+    BN_GENCB *cb)
 {
     BIGNUM *t1, *t2;
     int g, ok = -1;
@@ -222,10 +222,11 @@ static int dh_builtin_genparams(DH *ret, int prime_len, int generator,
         goto err;
     /* We are using safe prime p, set key length equivalent to RFC 7919 */
     ret->length = (2 * ossl_ifc_ffc_compute_security_bits(prime_len)
-                   + 24) / 25 * 25;
+                      + 24)
+        / 25 * 25;
     ret->dirty_cnt++;
     ok = 1;
- err:
+err:
     if (ok == -1) {
         ERR_raise(ERR_LIB_DH, ERR_R_BN_LIB);
         ok = 0;
