@@ -77,11 +77,10 @@ static int dsa_pub_decode(EVP_PKEY *pkey, const X509_PUBKEY *pubkey)
     EVP_PKEY_assign_DSA(pkey, dsa);
     return 1;
 
- err:
+err:
     ASN1_INTEGER_free(public_key);
     DSA_free(dsa);
     return 0;
-
 }
 
 static int dsa_pub_encode(X509_PUBKEY *pk, const EVP_PKEY *pkey)
@@ -135,7 +134,7 @@ static int dsa_pub_encode(X509_PUBKEY *pk, const EVP_PKEY *pkey)
     if (X509_PUBKEY_set0_param(pk, aobj, ptype, str, penc, penclen))
         return 1;
 
- err:
+err:
     OPENSSL_free(penc);
     ASN1_STRING_free(str);
 
@@ -167,7 +166,7 @@ static int dsa_priv_encode(PKCS8_PRIV_KEY_INFO *p8, const EVP_PKEY *pkey)
     unsigned char *dp = NULL;
     int dplen;
 
-    if (pkey->pkey.dsa  == NULL|| pkey->pkey.dsa->priv_key == NULL) {
+    if (pkey->pkey.dsa == NULL || pkey->pkey.dsa->priv_key == NULL) {
         ERR_raise(ERR_LIB_DSA, DSA_R_MISSING_PARAMETERS);
         goto err;
     }
@@ -204,13 +203,13 @@ static int dsa_priv_encode(PKCS8_PRIV_KEY_INFO *p8, const EVP_PKEY *pkey)
     }
 
     if (!PKCS8_pkey_set0(p8, OBJ_nid2obj(NID_dsa), 0,
-                         V_ASN1_SEQUENCE, params, dp, dplen)) {
+            V_ASN1_SEQUENCE, params, dp, dplen)) {
         OPENSSL_clear_free(dp, dplen);
         goto err;
     }
     return 1;
 
- err:
+err:
     ASN1_STRING_free(params);
     return 0;
 }
@@ -313,12 +312,12 @@ static int do_dsa_print(BIO *bp, const DSA *x, int off, int ptype)
     if (!ossl_ffc_params_print(bp, &x->params, off))
         goto err;
     ret = 1;
- err:
+err:
     return ret;
 }
 
 static int dsa_param_decode(EVP_PKEY *pkey,
-                            const unsigned char **pder, int derlen)
+    const unsigned char **pder, int derlen)
 {
     DSA *dsa;
 
@@ -336,25 +335,25 @@ static int dsa_param_encode(const EVP_PKEY *pkey, unsigned char **pder)
 }
 
 static int dsa_param_print(BIO *bp, const EVP_PKEY *pkey, int indent,
-                           ASN1_PCTX *ctx)
+    ASN1_PCTX *ctx)
 {
     return do_dsa_print(bp, pkey->pkey.dsa, indent, 0);
 }
 
 static int dsa_pub_print(BIO *bp, const EVP_PKEY *pkey, int indent,
-                         ASN1_PCTX *ctx)
+    ASN1_PCTX *ctx)
 {
     return do_dsa_print(bp, pkey->pkey.dsa, indent, 1);
 }
 
 static int dsa_priv_print(BIO *bp, const EVP_PKEY *pkey, int indent,
-                          ASN1_PCTX *ctx)
+    ASN1_PCTX *ctx)
 {
     return do_dsa_print(bp, pkey->pkey.dsa, indent, 2);
 }
 
 static int old_dsa_priv_decode(EVP_PKEY *pkey,
-                               const unsigned char **pder, int derlen)
+    const unsigned char **pder, int derlen)
 {
     DSA *dsa;
 
@@ -373,7 +372,7 @@ static int old_dsa_priv_encode(const EVP_PKEY *pkey, unsigned char **pder)
 }
 
 static int dsa_sig_print(BIO *bp, const X509_ALGOR *sigalg,
-                         const ASN1_STRING *sig, int indent, ASN1_PCTX *pctx)
+    const ASN1_STRING *sig, int indent, ASN1_PCTX *pctx)
 {
     DSA_SIG *dsa_sig;
     const unsigned char *p;
@@ -400,7 +399,7 @@ static int dsa_sig_print(BIO *bp, const X509_ALGOR *sigalg,
         if (!ASN1_bn_print(bp, "s:   ", s, NULL, indent))
             goto err;
         rv = 1;
- err:
+    err:
         DSA_SIG_free(dsa_sig);
         return rv;
     }
@@ -427,8 +426,8 @@ static size_t dsa_pkey_dirty_cnt(const EVP_PKEY *pkey)
 }
 
 static int dsa_pkey_export_to(const EVP_PKEY *from, void *to_keydata,
-                              OSSL_FUNC_keymgmt_import_fn *importer,
-                              OSSL_LIB_CTX *libctx, const char *propq)
+    OSSL_FUNC_keymgmt_import_fn *importer,
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     DSA *dsa = from->pkey.dsa;
     OSSL_PARAM_BLD *tmpl;
@@ -453,13 +452,13 @@ static int dsa_pkey_export_to(const EVP_PKEY *from, void *to_keydata,
     selection |= OSSL_KEYMGMT_SELECT_DOMAIN_PARAMETERS;
     if (pub_key != NULL) {
         if (!OSSL_PARAM_BLD_push_BN(tmpl, OSSL_PKEY_PARAM_PUB_KEY,
-                                    pub_key))
+                pub_key))
             goto err;
         selection |= OSSL_KEYMGMT_SELECT_PUBLIC_KEY;
     }
     if (priv_key != NULL) {
         if (!OSSL_PARAM_BLD_push_BN(tmpl, OSSL_PKEY_PARAM_PRIV_KEY,
-                                    priv_key))
+                priv_key))
             goto err;
         selection |= OSSL_KEYMGMT_SELECT_PRIVATE_KEY;
     }
@@ -471,7 +470,7 @@ static int dsa_pkey_export_to(const EVP_PKEY *from, void *to_keydata,
     rv = importer(to_keydata, selection, params);
 
     OSSL_PARAM_free(params);
- err:
+err:
     OSSL_PARAM_BLD_free(tmpl);
     return rv;
 }
@@ -520,63 +519,61 @@ const EVP_PKEY_ASN1_METHOD ossl_dsa_asn1_meths[4] = {
 
     /* This aliases NID_dsa with NID_dsa_2 */
     {
-     EVP_PKEY_DSA1,
-     EVP_PKEY_DSA,
-     ASN1_PKEY_ALIAS},
+        EVP_PKEY_DSA1,
+        EVP_PKEY_DSA,
+        ASN1_PKEY_ALIAS },
 
     /* This aliases NID_dsaWithSHA with NID_dsaWithSHA_2 */
     {
-     EVP_PKEY_DSA4,
-     EVP_PKEY_DSA2,
-     ASN1_PKEY_ALIAS},
+        EVP_PKEY_DSA4,
+        EVP_PKEY_DSA2,
+        ASN1_PKEY_ALIAS },
 
     /* This aliases NID_dsaWithSHA with NID_dsaWithSHA1 */
     {
-     EVP_PKEY_DSA3,
-     EVP_PKEY_DSA2,
-     ASN1_PKEY_ALIAS},
+        EVP_PKEY_DSA3,
+        EVP_PKEY_DSA2,
+        ASN1_PKEY_ALIAS },
 
-    {
-     EVP_PKEY_DSA,
-     EVP_PKEY_DSA,
-     0,
+    { EVP_PKEY_DSA,
+        EVP_PKEY_DSA,
+        0,
 
-     "DSA",
-     "OpenSSL DSA method",
+        "DSA",
+        "OpenSSL DSA method",
 
-     dsa_pub_decode,
-     dsa_pub_encode,
-     dsa_pub_cmp,
-     dsa_pub_print,
+        dsa_pub_decode,
+        dsa_pub_encode,
+        dsa_pub_cmp,
+        dsa_pub_print,
 
-     dsa_priv_decode,
-     dsa_priv_encode,
-     dsa_priv_print,
+        dsa_priv_decode,
+        dsa_priv_encode,
+        dsa_priv_print,
 
-     int_dsa_size,
-     dsa_bits,
-     dsa_security_bits,
+        int_dsa_size,
+        dsa_bits,
+        dsa_security_bits,
 
-     dsa_param_decode,
-     dsa_param_encode,
-     dsa_missing_parameters,
-     dsa_copy_parameters,
-     dsa_cmp_parameters,
-     dsa_param_print,
-     dsa_sig_print,
+        dsa_param_decode,
+        dsa_param_encode,
+        dsa_missing_parameters,
+        dsa_copy_parameters,
+        dsa_cmp_parameters,
+        dsa_param_print,
+        dsa_sig_print,
 
-     int_dsa_free,
-     dsa_pkey_ctrl,
-     old_dsa_priv_decode,
-     old_dsa_priv_encode,
+        int_dsa_free,
+        dsa_pkey_ctrl,
+        old_dsa_priv_decode,
+        old_dsa_priv_encode,
 
-     NULL, NULL, NULL,
-     NULL, NULL, NULL,
-     NULL, NULL, NULL, NULL,
+        NULL, NULL, NULL,
+        NULL, NULL, NULL,
+        NULL, NULL, NULL, NULL,
 
-     dsa_pkey_dirty_cnt,
-     dsa_pkey_export_to,
-     dsa_pkey_import_from,
-     dsa_pkey_copy
-    }
+        dsa_pkey_dirty_cnt,
+        dsa_pkey_export_to,
+        dsa_pkey_import_from,
+        dsa_pkey_copy }
 };
