@@ -46,8 +46,10 @@ ALIGN32 static const BN_ULONG def_xG[P256_LIMBS] = {
 };
 
 ALIGN32 static const BN_ULONG def_yG[P256_LIMBS] = {
-    0x02df32e52139f0a0, 0xd0a9877cc62a4740,
-    0x59bdcee36b692153, 0xbc3736a2f4f6779c,
+    0x02df32e52139f0a0,
+    0xd0a9877cc62a4740,
+    0x59bdcee36b692153,
+    0xbc3736a2f4f6779c,
 };
 #endif
 
@@ -57,7 +59,7 @@ ALIGN32 static const BN_ULONG def_p[P256_LIMBS] = {
     0xffffffffffffffff, 0xfffffffeffffffff
 };
 
-ALIGN32 static const BN_ULONG ONE[P256_LIMBS] = {1, 0, 0, 0};
+ALIGN32 static const BN_ULONG ONE[P256_LIMBS] = { 1, 0, 0, 0 };
 
 /* Functions implemented in assembly */
 /*
@@ -123,10 +125,8 @@ static ossl_inline int is_greater(const BN_ULONG *a, const BN_ULONG *b)
 
 #define is_one(a) is_equal(a, ONE)
 #define is_even(a) !(a[0] & 1)
-#define is_point_equal(a, b)     \
-    is_equal(a->X, b->X) &&      \
-    is_equal(a->Y, b->Y) &&      \
-    is_equal(a->Z, b->Z)
+#define is_point_equal(a, b) \
+    is_equal(a->X, b->X) && is_equal(a->Y, b->Y) && is_equal(a->Z, b->Z)
 
 /* Bignum and field elements conversion */
 #define ecp_sm2p256_bignum_field_elem(out, in) \
@@ -137,8 +137,8 @@ static ossl_inline int is_greater(const BN_ULONG *a, const BN_ULONG *b)
     do {                                           \
         ALIGN32 BN_ULONG u[4];                     \
         ALIGN32 BN_ULONG v[4];                     \
-        ALIGN32 BN_ULONG x1[4] = {1, 0, 0, 0};     \
-        ALIGN32 BN_ULONG x2[4] = {0};              \
+        ALIGN32 BN_ULONG x1[4] = { 1, 0, 0, 0 };   \
+        ALIGN32 BN_ULONG x2[4] = { 0 };            \
                                                    \
         if (is_zeros(in))                          \
             return;                                \
@@ -168,8 +168,9 @@ static ossl_inline int is_greater(const BN_ULONG *a, const BN_ULONG *b)
     } while (0)
 
 /* Modular inverse |out| = |in|^(-1) mod |p|. */
-static ossl_inline void ecp_sm2p256_mod_inverse(BN_ULONG* out,
-                                                const BN_ULONG* in) {
+static ossl_inline void ecp_sm2p256_mod_inverse(BN_ULONG *out,
+    const BN_ULONG *in)
+{
     BN_MOD_INV(out, in, ecp_sm2p256_div_by_2, ecp_sm2p256_sub, def_p);
 }
 
@@ -211,13 +212,13 @@ static void ecp_sm2p256_point_double(P256_POINT *R, const P256_POINT *P)
 
 /* Point add affine: R <- P + Q */
 static void ecp_sm2p256_point_add_affine(P256_POINT *R, const P256_POINT *P,
-                                         const P256_POINT_AFFINE *Q)
+    const P256_POINT_AFFINE *Q)
 {
     unsigned int i;
-    ALIGN32 BN_ULONG tmp0[P256_LIMBS] = {0};
-    ALIGN32 BN_ULONG tmp1[P256_LIMBS] = {0};
-    ALIGN32 BN_ULONG tmp2[P256_LIMBS] = {0};
-    ALIGN32 BN_ULONG tmp3[P256_LIMBS] = {0};
+    ALIGN32 BN_ULONG tmp0[P256_LIMBS] = { 0 };
+    ALIGN32 BN_ULONG tmp1[P256_LIMBS] = { 0 };
+    ALIGN32 BN_ULONG tmp2[P256_LIMBS] = { 0 };
+    ALIGN32 BN_ULONG tmp3[P256_LIMBS] = { 0 };
 
     /* zero-check P->Z */
     if (is_zeros(P->Z)) {
@@ -274,12 +275,12 @@ static void ecp_sm2p256_point_add_affine(P256_POINT *R, const P256_POINT *P,
 
 /* Point add: R <- P + Q */
 static void ecp_sm2p256_point_add(P256_POINT *R, const P256_POINT *P,
-                                  const P256_POINT *Q)
+    const P256_POINT *Q)
 {
     unsigned int i;
-    ALIGN32 BN_ULONG tmp0[P256_LIMBS] = {0};
-    ALIGN32 BN_ULONG tmp1[P256_LIMBS] = {0};
-    ALIGN32 BN_ULONG tmp2[P256_LIMBS] = {0};
+    ALIGN32 BN_ULONG tmp0[P256_LIMBS] = { 0 };
+    ALIGN32 BN_ULONG tmp1[P256_LIMBS] = { 0 };
+    ALIGN32 BN_ULONG tmp2[P256_LIMBS] = { 0 };
 
     /* zero-check P | Q ->Z */
     if (is_zeros(P->Z)) {
@@ -367,7 +368,7 @@ static void ecp_sm2p256_point_G_mul_by_scalar(P256_POINT *R, const BN_ULONG *k)
  * Affine point mul by scalar: k - scalar, P - affine point
  */
 static void ecp_sm2p256_point_P_mul_by_scalar(P256_POINT *R, const BN_ULONG *k,
-                                              P256_POINT_AFFINE P)
+    P256_POINT_AFFINE P)
 {
     int i, init = 0;
     unsigned int index, mask = 0x0f;
@@ -414,10 +415,10 @@ static void ecp_sm2p256_point_P_mul_by_scalar(P256_POINT *R, const BN_ULONG *k,
 
 /* Get affine point */
 static void ecp_sm2p256_point_get_affine(P256_POINT_AFFINE *R,
-                                         const P256_POINT *P)
+    const P256_POINT *P)
 {
-    ALIGN32 BN_ULONG z_inv3[P256_LIMBS] = {0};
-    ALIGN32 BN_ULONG z_inv2[P256_LIMBS] = {0};
+    ALIGN32 BN_ULONG z_inv3[P256_LIMBS] = { 0 };
+    ALIGN32 BN_ULONG z_inv2[P256_LIMBS] = { 0 };
 
     if (is_one(P->Z)) {
         memcpy(R->X, P->X, 32);
@@ -436,24 +437,24 @@ static void ecp_sm2p256_point_get_affine(P256_POINT_AFFINE *R,
 static int ecp_sm2p256_is_affine_G(const EC_POINT *generator)
 {
     return (bn_get_top(generator->X) == P256_LIMBS)
-            && (bn_get_top(generator->Y) == P256_LIMBS)
-            && is_equal(bn_get_words(generator->X), def_xG)
-            && is_equal(bn_get_words(generator->Y), def_yG)
-            && (generator->Z_is_one == 1);
+        && (bn_get_top(generator->Y) == P256_LIMBS)
+        && is_equal(bn_get_words(generator->X), def_xG)
+        && is_equal(bn_get_words(generator->Y), def_yG)
+        && (generator->Z_is_one == 1);
 }
 #endif
 
 /* r = sum(scalar[i]*point[i]) */
 static int ecp_sm2p256_windowed_mul(const EC_GROUP *group,
-                                    P256_POINT *r,
-                                    const BIGNUM **scalar,
-                                    const EC_POINT **point,
-                                    size_t num, BN_CTX *ctx)
+    P256_POINT *r,
+    const BIGNUM **scalar,
+    const EC_POINT **point,
+    size_t num, BN_CTX *ctx)
 {
     unsigned int i;
     int ret = 0;
     const BIGNUM **scalars = NULL;
-    ALIGN32 BN_ULONG k[P256_LIMBS] = {0};
+    ALIGN32 BN_ULONG k[P256_LIMBS] = { 0 };
     P256_POINT kP;
     ALIGN32 union {
         P256_POINT p;
@@ -507,15 +508,15 @@ err:
 
 /* r = scalar*G + sum(scalars[i]*points[i]) */
 static int ecp_sm2p256_points_mul(const EC_GROUP *group,
-                                  EC_POINT *r,
-                                  const BIGNUM *scalar,
-                                  size_t num,
-                                  const EC_POINT *points[],
-                                  const BIGNUM *scalars[], BN_CTX *ctx)
+    EC_POINT *r,
+    const BIGNUM *scalar,
+    size_t num,
+    const EC_POINT *points[],
+    const BIGNUM *scalars[], BN_CTX *ctx)
 {
     int ret = 0, p_is_infinity = 0;
     const EC_POINT *generator = NULL;
-    ALIGN32 BN_ULONG k[P256_LIMBS] = {0};
+    ALIGN32 BN_ULONG k[P256_LIMBS] = { 0 };
     ALIGN32 union {
         P256_POINT p;
         P256_POINT_AFFINE a;
@@ -553,8 +554,9 @@ static int ecp_sm2p256_points_mul(const EC_GROUP *group,
             g_scalars[0] = scalar;
 
             if (!ecp_sm2p256_windowed_mul(group, &p.p, g_scalars, new_generator,
-                                          (new_generator[0] != NULL
-                                           && g_scalars[0] != NULL), ctx))
+                    (new_generator[0] != NULL
+                        && g_scalars[0] != NULL),
+                    ctx))
                 goto err;
         }
     } else {
@@ -587,11 +589,11 @@ err:
 }
 
 static int ecp_sm2p256_field_mul(const EC_GROUP *group, BIGNUM *r,
-                                 const BIGNUM *a, const BIGNUM *b, BN_CTX *ctx)
+    const BIGNUM *a, const BIGNUM *b, BN_CTX *ctx)
 {
-    ALIGN32 BN_ULONG a_fe[P256_LIMBS] = {0};
-    ALIGN32 BN_ULONG b_fe[P256_LIMBS] = {0};
-    ALIGN32 BN_ULONG r_fe[P256_LIMBS] = {0};
+    ALIGN32 BN_ULONG a_fe[P256_LIMBS] = { 0 };
+    ALIGN32 BN_ULONG b_fe[P256_LIMBS] = { 0 };
+    ALIGN32 BN_ULONG r_fe[P256_LIMBS] = { 0 };
 
     if (a == NULL || b == NULL || r == NULL)
         return 0;
@@ -611,10 +613,10 @@ static int ecp_sm2p256_field_mul(const EC_GROUP *group, BIGNUM *r,
 }
 
 static int ecp_sm2p256_field_sqr(const EC_GROUP *group, BIGNUM *r,
-                                 const BIGNUM *a, BN_CTX *ctx)
+    const BIGNUM *a, BN_CTX *ctx)
 {
-    ALIGN32 BN_ULONG a_fe[P256_LIMBS] = {0};
-    ALIGN32 BN_ULONG r_fe[P256_LIMBS] = {0};
+    ALIGN32 BN_ULONG a_fe[P256_LIMBS] = { 0 };
+    ALIGN32 BN_ULONG r_fe[P256_LIMBS] = { 0 };
 
     if (a == NULL || r == NULL)
         return 0;
@@ -688,7 +690,7 @@ const EC_METHOD *EC_GFp_sm2p256_method(void)
         0, /* blind_coordinates */
         0, /* ladder_pre */
         0, /* ladder_step */
-        0  /* ladder_post */
+        0 /* ladder_post */
     };
 
     return &ret;
