@@ -24,28 +24,28 @@
 #include "internal/sizes.h"
 
 int OSSL_DECODER_CTX_set_passphrase(OSSL_DECODER_CTX *ctx,
-                                    const unsigned char *kstr,
-                                    size_t klen)
+    const unsigned char *kstr,
+    size_t klen)
 {
     return ossl_pw_set_passphrase(&ctx->pwdata, kstr, klen);
 }
 
 int OSSL_DECODER_CTX_set_passphrase_ui(OSSL_DECODER_CTX *ctx,
-                                       const UI_METHOD *ui_method,
-                                       void *ui_data)
+    const UI_METHOD *ui_method,
+    void *ui_data)
 {
     return ossl_pw_set_ui_method(&ctx->pwdata, ui_method, ui_data);
 }
 
 int OSSL_DECODER_CTX_set_pem_password_cb(OSSL_DECODER_CTX *ctx,
-                                         pem_password_cb *cb, void *cbarg)
+    pem_password_cb *cb, void *cbarg)
 {
     return ossl_pw_set_pem_password_cb(&ctx->pwdata, cb, cbarg);
 }
 
 int OSSL_DECODER_CTX_set_passphrase_cb(OSSL_DECODER_CTX *ctx,
-                                       OSSL_PASSPHRASE_CALLBACK *cb,
-                                       void *cbarg)
+    OSSL_PASSPHRASE_CALLBACK *cb,
+    void *cbarg)
 {
     return ossl_pw_set_ossl_passphrase_cb(&ctx->pwdata, cb, cbarg);
 }
@@ -63,14 +63,14 @@ struct decoder_pkey_data_st {
     int selection;
 
     STACK_OF(EVP_KEYMGMT) *keymgmts;
-    char *object_type;           /* recorded object data type, may be NULL */
-    void **object;               /* Where the result should end up */
-    OSSL_DECODER_CTX *ctx;       /* The parent decoder context */
+    char *object_type; /* recorded object data type, may be NULL */
+    void **object; /* Where the result should end up */
+    OSSL_DECODER_CTX *ctx; /* The parent decoder context */
 };
 
 static int decoder_construct_pkey(OSSL_DECODER_INSTANCE *decoder_inst,
-                                  const OSSL_PARAM *params,
-                                  void *construct_data)
+    const OSSL_PARAM *params,
+    void *construct_data)
 {
     struct decoder_pkey_data_st *data = construct_data;
     OSSL_DECODER *decoder = OSSL_DECODER_INSTANCE_get_decoder(decoder_inst);
@@ -131,8 +131,9 @@ static int decoder_construct_pkey(OSSL_DECODER_INSTANCE *decoder_inst,
         if (!EVP_KEYMGMT_up_ref(keymgmt))
             return 0;
     } else if ((keymgmt = EVP_KEYMGMT_fetch(data->libctx,
-                                            data->object_type,
-                                            data->propq)) != NULL) {
+                    data->object_type,
+                    data->propq))
+        != NULL) {
         keymgmt_prov = EVP_KEYMGMT_get0_provider(keymgmt);
     }
 
@@ -166,9 +167,9 @@ static int decoder_construct_pkey(OSSL_DECODER_INSTANCE *decoder_inst,
              * |import_data.keydata| is as much an indicator.
              */
             (void)decoder->export_object(decoderctx,
-                                         object_ref, object_ref_sz,
-                                         &evp_keymgmt_util_try_import,
-                                         &import_data);
+                object_ref, object_ref_sz,
+                &evp_keymgmt_util_try_import,
+                &import_data);
             keydata = import_data.keydata;
             import_data.keydata = NULL;
         }
@@ -218,19 +219,25 @@ struct collect_data_st {
 
     const char *keytype; /* the keytype requested, if any */
     int keytype_id; /* if keytype_resolved is set, keymgmt name_id; else 0 */
-    int sm2_id;     /* if keytype_resolved is set and EC, SM2 name_id; else 0 */
-    int total;      /* number of matching results */
+    int sm2_id; /* if keytype_resolved is set and EC, SM2 name_id; else 0 */
+    int total; /* number of matching results */
     char error_occurred;
     char keytype_resolved;
+    OSSL_PROPERTY_LIST *pq;
 
     STACK_OF(EVP_KEYMGMT) *keymgmts;
 };
 
-static void collect_decoder_keymgmt(EVP_KEYMGMT *keymgmt, OSSL_DECODER *decoder,
-                                    void *provctx, struct collect_data_st *data)
+/*
+ * Add decoder instance to the decoder context if it is compatible. Returns 1
+ * if a decoder was added, 0 otherwise.
+ */
+static int collect_decoder_keymgmt(EVP_KEYMGMT *keymgmt, OSSL_DECODER *decoder,
+    void *provctx, struct collect_data_st *data)
 {
     void *decoderctx = NULL;
     OSSL_DECODER_INSTANCE *di = NULL;
+    const OSSL_PROPERTY_LIST *props;
 
     /*
      * We already checked the EVP_KEYMGMT is applicable in check_keymgmt so we
@@ -239,17 +246,17 @@ static void collect_decoder_keymgmt(EVP_KEYMGMT *keymgmt, OSSL_DECODER *decoder,
 
     if (keymgmt->name_id != decoder->base.id)
         /* Mismatch is not an error, continue. */
-        return;
+        return 0;
 
     if ((decoderctx = decoder->newctx(provctx)) == NULL) {
         data->error_occurred = 1;
-        return;
+        return 0;
     }
 
     if ((di = ossl_decoder_instance_new(decoder, decoderctx)) == NULL) {
         decoder->freectx(decoderctx);
         data->error_occurred = 1;
-        return;
+        return 0;
     }
 
     /*
@@ -263,25 +270,44 @@ static void collect_decoder_keymgmt(EVP_KEYMGMT *keymgmt, OSSL_DECODER *decoder,
             || OPENSSL_strcasecmp(data->ctx->start_input_type, "PEM") != 0)) {
         /* Mismatch is not an error, continue. */
         ossl_decoder_instance_free(di);
-        return;
+        return 0;
     }
 
-    OSSL_TRACE_BEGIN(DECODER) {
+    OSSL_TRACE_BEGIN(DECODER)
+    {
         BIO_printf(trc_out,
-                   "(ctx %p) Checking out decoder %p:\n"
-                   "    %s with %s\n",
-                   (void *)data->ctx, (void *)decoder,
-                   OSSL_DECODER_get0_name(decoder),
-                   OSSL_DECODER_get0_properties(decoder));
-    } OSSL_TRACE_END(DECODER);
+            "(ctx %p) Checking out decoder %p:\n"
+            "    %s with %s\n",
+            (void *)data->ctx, (void *)decoder,
+            OSSL_DECODER_get0_name(decoder),
+            OSSL_DECODER_get0_properties(decoder));
+    }
+    OSSL_TRACE_END(DECODER);
+
+    /*
+     * Get the property match score so the decoders can be prioritized later.
+     */
+    props = ossl_decoder_parsed_properties(decoder);
+    if (data->pq != NULL && props != NULL) {
+        di->score = ossl_property_match_count(data->pq, props);
+        /*
+         * Mismatch of mandatory properties is not an error, the decoder is just
+         * ignored, continue.
+         */
+        if (di->score < 0) {
+            ossl_decoder_instance_free(di);
+            return 0;
+        }
+    }
 
     if (!ossl_decoder_ctx_add_decoder_inst(data->ctx, di)) {
         ossl_decoder_instance_free(di);
         data->error_occurred = 1;
-        return;
+        return 0;
     }
 
     ++data->total;
+    return 1;
 }
 
 static void collect_decoder(OSSL_DECODER *decoder, void *arg)
@@ -305,23 +331,27 @@ static void collect_decoder(OSSL_DECODER *decoder, void *arg)
      * doesn't have |does_selection|, it's seen as taking anything.
      */
     if (decoder->does_selection != NULL
-            && !decoder->does_selection(provctx, data->ctx->selection))
+        && !decoder->does_selection(provctx, data->ctx->selection))
         return;
 
-    OSSL_TRACE_BEGIN(DECODER) {
+    OSSL_TRACE_BEGIN(DECODER)
+    {
         BIO_printf(trc_out,
-                   "(ctx %p) Checking out decoder %p:\n"
-                   "    %s with %s\n",
-                   (void *)data->ctx, (void *)decoder,
-                   OSSL_DECODER_get0_name(decoder),
-                   OSSL_DECODER_get0_properties(decoder));
-    } OSSL_TRACE_END(DECODER);
+            "(ctx %p) Checking out decoder %p:\n"
+            "    %s with %s\n",
+            (void *)data->ctx, (void *)decoder,
+            OSSL_DECODER_get0_name(decoder),
+            OSSL_DECODER_get0_properties(decoder));
+    }
+    OSSL_TRACE_END(DECODER);
 
     end_i = sk_EVP_KEYMGMT_num(keymgmts);
     for (i = 0; i < end_i; ++i) {
         keymgmt = sk_EVP_KEYMGMT_value(keymgmts, i);
 
-        collect_decoder_keymgmt(keymgmt, decoder, provctx, data);
+        /* Only add this decoder once */
+        if (collect_decoder_keymgmt(keymgmt, decoder, provctx, data))
+            break;
         if (data->error_occurred)
             return;
     }
@@ -399,29 +429,33 @@ static void collect_keymgmt(EVP_KEYMGMT *keymgmt, void *arg)
  * etc. If 'keytype' is NULL, decoders for all keytypes are bound.
  */
 static int ossl_decoder_ctx_setup_for_pkey(OSSL_DECODER_CTX *ctx,
-                                           const char *keytype,
-                                           OSSL_LIB_CTX *libctx,
-                                           const char *propquery)
+    const char *keytype,
+    OSSL_LIB_CTX *libctx,
+    const char *propquery)
 {
     int ok = 0;
     struct decoder_pkey_data_st *process_data = NULL;
     struct collect_data_st collect_data = { NULL };
     STACK_OF(EVP_KEYMGMT) *keymgmts = NULL;
+    OSSL_PROPERTY_LIST **plp;
+    OSSL_PROPERTY_LIST *pq = NULL, *p2 = NULL;
 
-    OSSL_TRACE_BEGIN(DECODER) {
+    OSSL_TRACE_BEGIN(DECODER)
+    {
         const char *input_type = ctx->start_input_type;
         const char *input_structure = ctx->input_structure;
 
         BIO_printf(trc_out,
-                   "(ctx %p) Looking for decoders producing %s%s%s%s%s%s\n",
-                   (void *)ctx,
-                   keytype != NULL ? keytype : "",
-                   keytype != NULL ? " keys" : "keys of any type",
-                   input_type != NULL ? " from " : "",
-                   input_type != NULL ? input_type : "",
-                   input_structure != NULL ? " with " : "",
-                   input_structure != NULL ? input_structure : "");
-    } OSSL_TRACE_END(DECODER);
+            "(ctx %p) Looking for decoders producing %s%s%s%s%s%s\n",
+            (void *)ctx,
+            keytype != NULL ? keytype : "",
+            keytype != NULL ? " keys" : "keys of any type",
+            input_type != NULL ? " from " : "",
+            input_type != NULL ? input_type : "",
+            input_structure != NULL ? " with " : "",
+            input_structure != NULL ? input_structure : "");
+    }
+    OSSL_TRACE_END(DECODER);
 
     /* Allocate data. */
     if ((process_data = OPENSSL_zalloc(sizeof(*process_data))) == NULL)
@@ -437,10 +471,29 @@ static int ossl_decoder_ctx_setup_for_pkey(OSSL_DECODER_CTX *ctx,
         goto err;
     }
 
-    process_data->object    = NULL;
-    process_data->libctx    = libctx;
+    process_data->object = NULL;
+    process_data->libctx = libctx;
     process_data->selection = ctx->selection;
-    process_data->keymgmts  = keymgmts;
+    process_data->keymgmts = keymgmts;
+
+    /*
+     * Collect passed and default properties to prioritize the decoders.
+     */
+    if (propquery != NULL)
+        p2 = pq = ossl_parse_query(libctx, propquery, 1);
+
+    plp = ossl_ctx_global_properties(libctx, 0);
+    if (plp != NULL && *plp != NULL) {
+        if (pq == NULL) {
+            pq = *plp;
+        } else {
+            p2 = ossl_property_merge(pq, *plp);
+            ossl_property_free(pq);
+            if (p2 == NULL)
+                goto err;
+            pq = p2;
+        }
+    }
 
     /*
      * Enumerate all keymgmts into a stack.
@@ -457,10 +510,11 @@ static int ossl_decoder_ctx_setup_for_pkey(OSSL_DECODER_CTX *ctx,
      * upfront, as this ensures that the names for all loaded providers have
      * been registered by the time we try to resolve the keytype string.
      */
-    collect_data.ctx        = ctx;
-    collect_data.libctx     = libctx;
-    collect_data.keymgmts   = keymgmts;
-    collect_data.keytype    = keytype;
+    collect_data.ctx = ctx;
+    collect_data.libctx = libctx;
+    collect_data.keymgmts = keymgmts;
+    collect_data.keytype = keytype;
+    collect_data.pq = pq;
     EVP_KEYMGMT_do_all_provided(libctx, collect_keymgmt, &collect_data);
 
     if (collect_data.error_occurred)
@@ -472,11 +526,13 @@ static int ossl_decoder_ctx_setup_for_pkey(OSSL_DECODER_CTX *ctx,
     if (collect_data.error_occurred)
         goto err;
 
-    OSSL_TRACE_BEGIN(DECODER) {
+    OSSL_TRACE_BEGIN(DECODER)
+    {
         BIO_printf(trc_out,
-                   "(ctx %p) Got %d decoders producing keys\n",
-                   (void *)ctx, collect_data.total);
-    } OSSL_TRACE_END(DECODER);
+            "(ctx %p) Got %d decoders producing keys\n",
+            (void *)ctx, collect_data.total);
+    }
+    OSSL_TRACE_END(DECODER);
 
     /*
      * Finish initializing the decoder context. If one or more decoders matched
@@ -487,15 +543,16 @@ static int ossl_decoder_ctx_setup_for_pkey(OSSL_DECODER_CTX *ctx,
         if (!OSSL_DECODER_CTX_set_construct(ctx, decoder_construct_pkey)
             || !OSSL_DECODER_CTX_set_construct_data(ctx, process_data)
             || !OSSL_DECODER_CTX_set_cleanup(ctx,
-                                             decoder_clean_pkey_construct_arg))
+                decoder_clean_pkey_construct_arg))
             goto err;
 
         process_data = NULL; /* Avoid it being freed */
     }
 
     ok = 1;
- err:
+err:
     decoder_clean_pkey_construct_arg(process_data);
+    ossl_property_free(p2);
     return ok;
 }
 
@@ -516,9 +573,9 @@ static EVP_KEYMGMT *keymgmt_dup(const EVP_KEYMGMT *keymgmt)
  */
 static OSSL_DECODER_CTX *
 ossl_decoder_ctx_for_pkey_dup(OSSL_DECODER_CTX *src,
-                              EVP_PKEY **pkey,
-                              const char *input_type,
-                              const char *input_structure)
+    EVP_PKEY **pkey,
+    const char *input_type,
+    const char *input_structure)
 {
     OSSL_DECODER_CTX *dest;
     struct decoder_pkey_data_st *process_data_src, *process_data_dest = NULL;
@@ -532,7 +589,7 @@ ossl_decoder_ctx_for_pkey_dup(OSSL_DECODER_CTX *src,
     }
 
     if (!OSSL_DECODER_CTX_set_input_type(dest, input_type)
-            || !OSSL_DECODER_CTX_set_input_structure(dest, input_structure)) {
+        || !OSSL_DECODER_CTX_set_input_structure(dest, input_structure)) {
         ERR_raise(ERR_LIB_OSSL_DECODER, ERR_R_OSSL_DECODER_LIB);
         goto err;
     }
@@ -541,8 +598,8 @@ ossl_decoder_ctx_for_pkey_dup(OSSL_DECODER_CTX *src,
     if (src->decoder_insts != NULL) {
         dest->decoder_insts
             = sk_OSSL_DECODER_INSTANCE_deep_copy(src->decoder_insts,
-                                                 ossl_decoder_instance_dup,
-                                                 ossl_decoder_instance_free);
+                ossl_decoder_instance_dup,
+                ossl_decoder_instance_free);
         if (dest->decoder_insts == NULL) {
             ERR_raise(ERR_LIB_OSSL_DECODER, ERR_R_OSSL_DECODER_LIB);
             goto err;
@@ -550,7 +607,7 @@ ossl_decoder_ctx_for_pkey_dup(OSSL_DECODER_CTX *src,
     }
 
     if (!OSSL_DECODER_CTX_set_construct(dest,
-                                        OSSL_DECODER_CTX_get_construct(src))) {
+            OSSL_DECODER_CTX_get_construct(src))) {
         ERR_raise(ERR_LIB_OSSL_DECODER, ERR_R_OSSL_DECODER_LIB);
         goto err;
     }
@@ -573,18 +630,18 @@ ossl_decoder_ctx_for_pkey_dup(OSSL_DECODER_CTX *src,
         if (process_data_src->keymgmts != NULL) {
             process_data_dest->keymgmts
                 = sk_EVP_KEYMGMT_deep_copy(process_data_src->keymgmts,
-                                           keymgmt_dup,
-                                           EVP_KEYMGMT_free);
+                    keymgmt_dup,
+                    EVP_KEYMGMT_free);
             if (process_data_dest->keymgmts == NULL) {
                 ERR_raise(ERR_LIB_OSSL_DECODER, ERR_R_EVP_LIB);
                 goto err;
             }
         }
 
-        process_data_dest->object    = (void **)pkey;
-        process_data_dest->libctx    = process_data_src->libctx;
+        process_data_dest->object = (void **)pkey;
+        process_data_dest->libctx = process_data_src->libctx;
         process_data_dest->selection = process_data_src->selection;
-        process_data_dest->ctx       = dest;
+        process_data_dest->ctx = dest;
         if (!OSSL_DECODER_CTX_set_construct_data(dest, process_data_dest)) {
             ERR_raise(ERR_LIB_OSSL_DECODER, ERR_R_OSSL_DECODER_LIB);
             goto err;
@@ -593,13 +650,13 @@ ossl_decoder_ctx_for_pkey_dup(OSSL_DECODER_CTX *src,
     }
 
     if (!OSSL_DECODER_CTX_set_cleanup(dest,
-                                      OSSL_DECODER_CTX_get_cleanup(src))) {
+            OSSL_DECODER_CTX_get_cleanup(src))) {
         ERR_raise(ERR_LIB_OSSL_DECODER, ERR_R_OSSL_DECODER_LIB);
         goto err;
     }
 
     return dest;
- err:
+err:
     decoder_clean_pkey_construct_arg(process_data_dest);
     OSSL_DECODER_CTX_free(dest);
     return NULL;
@@ -638,17 +695,21 @@ static unsigned long decoder_cache_entry_hash(const DECODER_CACHE_ENTRY *cache)
     unsigned long hash = 17;
 
     hash = (hash * 23)
-           + (cache->propquery == NULL
-              ? 0 : ossl_lh_strcasehash(cache->propquery));
+        + (cache->propquery == NULL
+                ? 0
+                : ossl_lh_strcasehash(cache->propquery));
     hash = (hash * 23)
-           + (cache->input_structure == NULL
-              ? 0  : ossl_lh_strcasehash(cache->input_structure));
+        + (cache->input_structure == NULL
+                ? 0
+                : ossl_lh_strcasehash(cache->input_structure));
     hash = (hash * 23)
-           + (cache->input_type == NULL
-              ? 0  : ossl_lh_strcasehash(cache->input_type));
+        + (cache->input_type == NULL
+                ? 0
+                : ossl_lh_strcasehash(cache->input_type));
     hash = (hash * 23)
-           + (cache->keytype == NULL
-              ? 0  : ossl_lh_strcasehash(cache->keytype));
+        + (cache->keytype == NULL
+                ? 0
+                : ossl_lh_strcasehash(cache->keytype));
 
     hash ^= cache->selection;
 
@@ -675,7 +736,7 @@ static ossl_inline int nullstrcmp(const char *a, const char *b, int casecmp)
 }
 
 static int decoder_cache_entry_cmp(const DECODER_CACHE_ENTRY *a,
-                                   const DECODER_CACHE_ENTRY *b)
+    const DECODER_CACHE_ENTRY *b)
 {
     int cmp;
 
@@ -712,7 +773,7 @@ void *ossl_decoder_cache_new(OSSL_LIB_CTX *ctx)
         return NULL;
     }
     cache->hashtable = lh_DECODER_CACHE_ENTRY_new(decoder_cache_entry_hash,
-                                                  decoder_cache_entry_cmp);
+        decoder_cache_entry_cmp);
     if (cache->hashtable == NULL) {
         CRYPTO_THREAD_lock_free(cache->lock);
         OPENSSL_free(cache);
@@ -744,7 +805,6 @@ int ossl_decoder_cache_flush(OSSL_LIB_CTX *libctx)
     if (cache == NULL)
         return 0;
 
-
     if (!CRYPTO_THREAD_write_lock(cache->lock)) {
         ERR_raise(ERR_LIB_OSSL_DECODER, ERR_R_OSSL_DECODER_LIB);
         return 0;
@@ -759,10 +819,10 @@ int ossl_decoder_cache_flush(OSSL_LIB_CTX *libctx)
 
 OSSL_DECODER_CTX *
 OSSL_DECODER_CTX_new_for_pkey(EVP_PKEY **pkey,
-                              const char *input_type,
-                              const char *input_structure,
-                              const char *keytype, int selection,
-                              OSSL_LIB_CTX *libctx, const char *propquery)
+    const char *input_type,
+    const char *input_structure,
+    const char *keytype, int selection,
+    OSSL_LIB_CTX *libctx, const char *propquery)
 {
     OSSL_DECODER_CTX *ctx = NULL;
     OSSL_PARAM decoder_params[] = {
@@ -780,13 +840,11 @@ OSSL_DECODER_CTX_new_for_pkey(EVP_PKEY **pkey,
         return NULL;
     }
     if (input_structure != NULL)
-        decoder_params[i++] =
-            OSSL_PARAM_construct_utf8_string(OSSL_OBJECT_PARAM_DATA_STRUCTURE,
-                                             (char *)input_structure, 0);
+        decoder_params[i++] = OSSL_PARAM_construct_utf8_string(OSSL_OBJECT_PARAM_DATA_STRUCTURE,
+            (char *)input_structure, 0);
     if (propquery != NULL)
-        decoder_params[i++] =
-            OSSL_PARAM_construct_utf8_string(OSSL_DECODER_PARAM_PROPERTIES,
-                                             (char *)propquery, 0);
+        decoder_params[i++] = OSSL_PARAM_construct_utf8_string(OSSL_DECODER_PARAM_PROPERTIES,
+            (char *)propquery, 0);
 
     /* It is safe to cast away the const here */
     cacheent.input_type = (char *)input_type;
@@ -816,13 +874,15 @@ OSSL_DECODER_CTX_new_for_pkey(EVP_PKEY **pkey,
             return NULL;
         }
 
-        OSSL_TRACE_BEGIN(DECODER) {
+        OSSL_TRACE_BEGIN(DECODER)
+        {
             BIO_printf(trc_out,
-                    "(ctx %p) Looking for %s decoders with selection %d\n",
-                    (void *)ctx, keytype, selection);
+                "(ctx %p) Looking for %s decoders with selection %d\n",
+                (void *)ctx, keytype, selection);
             BIO_printf(trc_out, "    input type: %s, input structure: %s\n",
-                    input_type, input_structure);
-        } OSSL_TRACE_END(DECODER);
+                input_type, input_structure);
+        }
+        OSSL_TRACE_END(DECODER);
 
         if (OSSL_DECODER_CTX_set_input_type(ctx, input_type)
             && OSSL_DECODER_CTX_set_input_structure(ctx, input_structure)
@@ -831,10 +891,12 @@ OSSL_DECODER_CTX_new_for_pkey(EVP_PKEY **pkey,
             && OSSL_DECODER_CTX_add_extra(ctx, libctx, propquery)
             && (propquery == NULL
                 || OSSL_DECODER_CTX_set_params(ctx, decoder_params))) {
-            OSSL_TRACE_BEGIN(DECODER) {
+            OSSL_TRACE_BEGIN(DECODER)
+            {
                 BIO_printf(trc_out, "(ctx %p) Got %d decoders\n",
-                        (void *)ctx, OSSL_DECODER_CTX_get_num_decoders(ctx));
-            } OSSL_TRACE_END(DECODER);
+                    (void *)ctx, OSSL_DECODER_CTX_get_num_decoders(ctx));
+            }
+            OSSL_TRACE_END(DECODER);
         } else {
             ERR_raise(ERR_LIB_OSSL_DECODER, ERR_R_OSSL_DECODER_LIB);
             OSSL_DECODER_CTX_free(ctx);
@@ -899,7 +961,7 @@ OSSL_DECODER_CTX_new_for_pkey(EVP_PKEY **pkey,
     CRYPTO_THREAD_unlock(cache->lock);
 
     return ctx;
- err:
+err:
     decoder_cache_entry_free(newcache);
     OSSL_DECODER_CTX_free(ctx);
     return NULL;
