@@ -1,5 +1,5 @@
 /*
- * Copyright 2020-2023 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2020-2025 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -48,7 +48,7 @@ struct evp_rand_st {
     OSSL_FUNC_rand_verify_zeroization_fn *verify_zeroization;
     OSSL_FUNC_rand_get_seed_fn *get_seed;
     OSSL_FUNC_rand_clear_seed_fn *clear_seed;
-} /* EVP_RAND */ ;
+} /* EVP_RAND */;
 
 static int evp_rand_up_ref(void *vrand)
 {
@@ -115,8 +115,8 @@ static void evp_rand_unlock(EVP_RAND_CTX *rand)
 }
 
 static void *evp_rand_from_algorithm(int name_id,
-                                     const OSSL_ALGORITHM *algodef,
-                                     OSSL_PROVIDER *prov)
+    const OSSL_ALGORITHM *algodef,
+    OSSL_PROVIDER *prov)
 {
     const OSSL_DISPATCH *fns = algodef->implementation;
     EVP_RAND *rand = NULL;
@@ -157,7 +157,7 @@ static void *evp_rand_from_algorithm(int name_id,
             fnrandcnt++;
             break;
         case OSSL_FUNC_RAND_UNINSTANTIATE:
-             if (rand->uninstantiate != NULL)
+            if (rand->uninstantiate != NULL)
                 break;
             rand->uninstantiate = OSSL_FUNC_rand_uninstantiate(fns);
             fnrandcnt++;
@@ -199,20 +199,17 @@ static void *evp_rand_from_algorithm(int name_id,
         case OSSL_FUNC_RAND_GETTABLE_PARAMS:
             if (rand->gettable_params != NULL)
                 break;
-            rand->gettable_params =
-                OSSL_FUNC_rand_gettable_params(fns);
+            rand->gettable_params = OSSL_FUNC_rand_gettable_params(fns);
             break;
         case OSSL_FUNC_RAND_GETTABLE_CTX_PARAMS:
             if (rand->gettable_ctx_params != NULL)
                 break;
-            rand->gettable_ctx_params =
-                OSSL_FUNC_rand_gettable_ctx_params(fns);
+            rand->gettable_ctx_params = OSSL_FUNC_rand_gettable_ctx_params(fns);
             break;
         case OSSL_FUNC_RAND_SETTABLE_CTX_PARAMS:
             if (rand->settable_ctx_params != NULL)
                 break;
-            rand->settable_ctx_params =
-                OSSL_FUNC_rand_settable_ctx_params(fns);
+            rand->settable_ctx_params = OSSL_FUNC_rand_settable_ctx_params(fns);
             break;
         case OSSL_FUNC_RAND_GET_PARAMS:
             if (rand->get_params != NULL)
@@ -260,13 +257,13 @@ static void *evp_rand_from_algorithm(int name_id,
      * locking functions.
      */
     if (fnrandcnt != 3
-            || fnctxcnt != 3
-            || (fnenablelockcnt != 0 && fnenablelockcnt != 1)
-            || (fnlockcnt != 0 && fnlockcnt != 2)
+        || fnctxcnt != 3
+        || (fnenablelockcnt != 0 && fnenablelockcnt != 1)
+        || (fnlockcnt != 0 && fnlockcnt != 2)
 #ifdef FIPS_MODULE
-            || fnzeroizecnt != 1
+        || fnzeroizecnt != 1
 #endif
-       ) {
+    ) {
         evp_rand_free(rand);
         ERR_raise(ERR_LIB_EVP, EVP_R_INVALID_PROVIDER_FUNCTIONS);
         return NULL;
@@ -283,11 +280,11 @@ static void *evp_rand_from_algorithm(int name_id,
 }
 
 EVP_RAND *EVP_RAND_fetch(OSSL_LIB_CTX *libctx, const char *algorithm,
-                         const char *properties)
+    const char *properties)
 {
     return evp_generic_fetch(libctx, OSSL_OP_RAND, algorithm, properties,
-                             evp_rand_from_algorithm, evp_rand_up_ref,
-                             evp_rand_free);
+        evp_rand_from_algorithm, evp_rand_up_ref,
+        evp_rand_free);
 }
 
 int EVP_RAND_up_ref(EVP_RAND *rand)
@@ -368,8 +365,9 @@ EVP_RAND_CTX *EVP_RAND_CTX_new(EVP_RAND *rand, EVP_RAND_CTX *parent)
         parent_dispatch = parent->meth->dispatch;
     }
     if ((ctx->algctx = rand->newctx(ossl_provider_ctx(rand->prov), parent_ctx,
-                                    parent_dispatch)) == NULL
-            || !EVP_RAND_up_ref(rand)) {
+             parent_dispatch))
+            == NULL
+        || !EVP_RAND_up_ref(rand)) {
         ERR_raise(ERR_LIB_EVP, ERR_R_EVP_LIB);
         rand->freectx(ctx->algctx);
         CRYPTO_FREE_REF(&ctx->refcnt);
@@ -408,7 +406,7 @@ EVP_RAND *EVP_RAND_CTX_get0_rand(EVP_RAND_CTX *ctx)
 }
 
 static int evp_rand_get_ctx_params_locked(EVP_RAND_CTX *ctx,
-                                          OSSL_PARAM params[])
+    OSSL_PARAM params[])
 {
     return ctx->meth->get_ctx_params(ctx->algctx, params);
 }
@@ -425,7 +423,7 @@ int EVP_RAND_CTX_get_params(EVP_RAND_CTX *ctx, OSSL_PARAM params[])
 }
 
 static int evp_rand_set_ctx_params_locked(EVP_RAND_CTX *ctx,
-                                          const OSSL_PARAM params[])
+    const OSSL_PARAM params[])
 {
     if (ctx->meth->set_ctx_params != NULL)
         return ctx->meth->set_ctx_params(ctx->algctx, params);
@@ -491,18 +489,18 @@ const OSSL_PARAM *EVP_RAND_CTX_settable_params(EVP_RAND_CTX *ctx)
 }
 
 void EVP_RAND_do_all_provided(OSSL_LIB_CTX *libctx,
-                              void (*fn)(EVP_RAND *rand, void *arg),
-                              void *arg)
+    void (*fn)(EVP_RAND *rand, void *arg),
+    void *arg)
 {
     evp_generic_do_all(libctx, OSSL_OP_RAND,
-                       (void (*)(void *, void *))fn, arg,
-                       evp_rand_from_algorithm, evp_rand_up_ref,
-                       evp_rand_free);
+        (void (*)(void *, void *))fn, arg,
+        evp_rand_from_algorithm, evp_rand_up_ref,
+        evp_rand_free);
 }
 
 int EVP_RAND_names_do_all(const EVP_RAND *rand,
-                          void (*fn)(const char *name, void *data),
-                          void *data)
+    void (*fn)(const char *name, void *data),
+    void *data)
 {
     if (rand->prov != NULL)
         return evp_names_do_all(rand->prov, rand->name_id, fn, data);
@@ -510,25 +508,24 @@ int EVP_RAND_names_do_all(const EVP_RAND *rand,
     return 1;
 }
 
-static int evp_rand_instantiate_locked
-    (EVP_RAND_CTX *ctx, unsigned int strength, int prediction_resistance,
-     const unsigned char *pstr, size_t pstr_len, const OSSL_PARAM params[])
+static int evp_rand_instantiate_locked(EVP_RAND_CTX *ctx, unsigned int strength, int prediction_resistance,
+    const unsigned char *pstr, size_t pstr_len, const OSSL_PARAM params[])
 {
     return ctx->meth->instantiate(ctx->algctx, strength, prediction_resistance,
-                                  pstr, pstr_len, params);
+        pstr, pstr_len, params);
 }
 
 int EVP_RAND_instantiate(EVP_RAND_CTX *ctx, unsigned int strength,
-                         int prediction_resistance,
-                         const unsigned char *pstr, size_t pstr_len,
-                         const OSSL_PARAM params[])
+    int prediction_resistance,
+    const unsigned char *pstr, size_t pstr_len,
+    const OSSL_PARAM params[])
 {
     int res;
 
     if (!evp_rand_lock(ctx))
         return 0;
     res = evp_rand_instantiate_locked(ctx, strength, prediction_resistance,
-                                      pstr, pstr_len, params);
+        pstr, pstr_len, params);
     evp_rand_unlock(ctx);
     return res;
 }
@@ -550,25 +547,25 @@ int EVP_RAND_uninstantiate(EVP_RAND_CTX *ctx)
 }
 
 static int evp_rand_generate_locked(EVP_RAND_CTX *ctx, unsigned char *out,
-                                    size_t outlen, unsigned int strength,
-                                    int prediction_resistance,
-                                    const unsigned char *addin,
-                                    size_t addin_len)
+    size_t outlen, unsigned int strength,
+    int prediction_resistance,
+    const unsigned char *addin,
+    size_t addin_len)
 {
     size_t chunk, max_request = 0;
     OSSL_PARAM params[2] = { OSSL_PARAM_END, OSSL_PARAM_END };
 
     params[0] = OSSL_PARAM_construct_size_t(OSSL_RAND_PARAM_MAX_REQUEST,
-                                            &max_request);
+        &max_request);
     if (!evp_rand_get_ctx_params_locked(ctx, params)
-            || max_request == 0) {
+        || max_request == 0) {
         ERR_raise(ERR_LIB_EVP, EVP_R_UNABLE_TO_GET_MAXIMUM_REQUEST_SIZE);
         return 0;
     }
     for (; outlen > 0; outlen -= chunk, out += chunk) {
         chunk = outlen > max_request ? max_request : outlen;
         if (!ctx->meth->generate(ctx->algctx, out, chunk, strength,
-                                 prediction_resistance, addin, addin_len)) {
+                prediction_resistance, addin, addin_len)) {
             ERR_raise(ERR_LIB_EVP, EVP_R_GENERATE_ERROR);
             return 0;
         }
@@ -582,39 +579,39 @@ static int evp_rand_generate_locked(EVP_RAND_CTX *ctx, unsigned char *out,
 }
 
 int EVP_RAND_generate(EVP_RAND_CTX *ctx, unsigned char *out, size_t outlen,
-                      unsigned int strength, int prediction_resistance,
-                      const unsigned char *addin, size_t addin_len)
+    unsigned int strength, int prediction_resistance,
+    const unsigned char *addin, size_t addin_len)
 {
     int res;
 
     if (!evp_rand_lock(ctx))
         return 0;
     res = evp_rand_generate_locked(ctx, out, outlen, strength,
-                                   prediction_resistance, addin, addin_len);
+        prediction_resistance, addin, addin_len);
     evp_rand_unlock(ctx);
     return res;
 }
 
 static int evp_rand_reseed_locked(EVP_RAND_CTX *ctx, int prediction_resistance,
-                                  const unsigned char *ent, size_t ent_len,
-                                  const unsigned char *addin, size_t addin_len)
+    const unsigned char *ent, size_t ent_len,
+    const unsigned char *addin, size_t addin_len)
 {
     if (ctx->meth->reseed != NULL)
         return ctx->meth->reseed(ctx->algctx, prediction_resistance,
-                                 ent, ent_len, addin, addin_len);
+            ent, ent_len, addin, addin_len);
     return 1;
 }
 
 int EVP_RAND_reseed(EVP_RAND_CTX *ctx, int prediction_resistance,
-                    const unsigned char *ent, size_t ent_len,
-                    const unsigned char *addin, size_t addin_len)
+    const unsigned char *ent, size_t ent_len,
+    const unsigned char *addin, size_t addin_len)
 {
     int res;
 
     if (!evp_rand_lock(ctx))
         return 0;
     res = evp_rand_reseed_locked(ctx, prediction_resistance,
-                                 ent, ent_len, addin, addin_len);
+        ent, ent_len, addin, addin_len);
     evp_rand_unlock(ctx);
     return res;
 }
@@ -642,14 +639,12 @@ unsigned int EVP_RAND_get_strength(EVP_RAND_CTX *ctx)
 }
 
 static int evp_rand_nonce_locked(EVP_RAND_CTX *ctx, unsigned char *out,
-                                 size_t outlen)
+    size_t outlen)
 {
     unsigned int str = evp_rand_strength_locked(ctx);
 
-    if (ctx->meth->nonce == NULL)
-        return 0;
-    if (ctx->meth->nonce(ctx->algctx, out, str, outlen, outlen))
-        return 1;
+    if (ctx->meth->nonce != NULL)
+        return ctx->meth->nonce(ctx->algctx, out, str, outlen, outlen) > 0;
     return evp_rand_generate_locked(ctx, out, outlen, str, 0, NULL, 0);
 }
 
@@ -657,6 +652,11 @@ int EVP_RAND_nonce(EVP_RAND_CTX *ctx, unsigned char *out, size_t outlen)
 {
     int res;
 
+    if (ctx == NULL || out == NULL || outlen == 0) {
+        ERR_raise(ERR_LIB_EVP, ERR_R_PASSED_NULL_PARAMETER);
+        return 0;
+    }
+
     if (!evp_rand_lock(ctx))
         return 0;
     res = evp_rand_nonce_locked(ctx, out, outlen);
@@ -699,49 +699,49 @@ int evp_rand_can_seed(EVP_RAND_CTX *ctx)
 }
 
 static size_t evp_rand_get_seed_locked(EVP_RAND_CTX *ctx,
-                                       unsigned char **buffer,
-                                       int entropy,
-                                       size_t min_len, size_t max_len,
-                                       int prediction_resistance,
-                                       const unsigned char *adin,
-                                       size_t adin_len)
+    unsigned char **buffer,
+    int entropy,
+    size_t min_len, size_t max_len,
+    int prediction_resistance,
+    const unsigned char *adin,
+    size_t adin_len)
 {
     if (ctx->meth->get_seed != NULL)
         return ctx->meth->get_seed(ctx->algctx, buffer,
-                                   entropy, min_len, max_len,
-                                   prediction_resistance,
-                                   adin, adin_len);
+            entropy, min_len, max_len,
+            prediction_resistance,
+            adin, adin_len);
     return 0;
 }
 
 size_t evp_rand_get_seed(EVP_RAND_CTX *ctx,
-                         unsigned char **buffer,
-                         int entropy, size_t min_len, size_t max_len,
-                         int prediction_resistance,
-                         const unsigned char *adin, size_t adin_len)
+    unsigned char **buffer,
+    int entropy, size_t min_len, size_t max_len,
+    int prediction_resistance,
+    const unsigned char *adin, size_t adin_len)
 {
     int res;
 
     if (!evp_rand_lock(ctx))
         return 0;
     res = evp_rand_get_seed_locked(ctx,
-                                   buffer,
-                                   entropy, min_len, max_len,
-                                   prediction_resistance,
-                                   adin, adin_len);
+        buffer,
+        entropy, min_len, max_len,
+        prediction_resistance,
+        adin, adin_len);
     evp_rand_unlock(ctx);
     return res;
 }
 
 static void evp_rand_clear_seed_locked(EVP_RAND_CTX *ctx,
-                                       unsigned char *buffer, size_t b_len)
+    unsigned char *buffer, size_t b_len)
 {
     if (ctx->meth->clear_seed != NULL)
         ctx->meth->clear_seed(ctx->algctx, buffer, b_len);
 }
 
 void evp_rand_clear_seed(EVP_RAND_CTX *ctx,
-                         unsigned char *buffer, size_t b_len)
+    unsigned char *buffer, size_t b_len)
 {
     if (!evp_rand_lock(ctx))
         return;
