@@ -48,7 +48,7 @@ int evp_keymgmt_util_try_import(const OSSL_PARAM params[], void *arg)
         return 1;
 
     if (evp_keymgmt_import(data->keymgmt, data->keydata, data->selection,
-                           params))
+            params))
         return 1;
     if (delete_on_error) {
         evp_keymgmt_freedata(data->keymgmt, data->keydata);
@@ -58,7 +58,7 @@ int evp_keymgmt_util_try_import(const OSSL_PARAM params[], void *arg)
 }
 
 int evp_keymgmt_util_assign_pkey(EVP_PKEY *pkey, EVP_KEYMGMT *keymgmt,
-                                 void *keydata)
+    void *keydata)
 {
     if (pkey == NULL || keymgmt == NULL || keydata == NULL
         || !EVP_PKEY_set_type_by_keymgmt(pkey, keymgmt)) {
@@ -85,16 +85,16 @@ EVP_PKEY *evp_keymgmt_util_make_pkey(EVP_KEYMGMT *keymgmt, void *keydata)
 }
 
 int evp_keymgmt_util_export(const EVP_PKEY *pk, int selection,
-                            OSSL_CALLBACK *export_cb, void *export_cbarg)
+    OSSL_CALLBACK *export_cb, void *export_cbarg)
 {
     if (pk == NULL || export_cb == NULL)
         return 0;
     return evp_keymgmt_export(pk->keymgmt, pk->keydata, selection,
-                              export_cb, export_cbarg);
+        export_cb, export_cbarg);
 }
 
 void *evp_keymgmt_util_export_to_provider(EVP_PKEY *pk, EVP_KEYMGMT *keymgmt,
-                                          int selection)
+    int selection)
 {
     struct evp_keymgmt_util_try_import_data_st import_data;
     OP_CACHE_ELEM *op;
@@ -156,7 +156,7 @@ void *evp_keymgmt_util_export_to_provider(EVP_PKEY *pk, EVP_KEYMGMT *keymgmt,
      */
 
     /* Setup for the export callback */
-    import_data.keydata = NULL;  /* evp_keymgmt_util_try_import will create it */
+    import_data.keydata = NULL; /* evp_keymgmt_util_try_import will create it */
     import_data.keymgmt = keymgmt;
     import_data.selection = selection;
 
@@ -165,7 +165,7 @@ void *evp_keymgmt_util_export_to_provider(EVP_PKEY *pk, EVP_KEYMGMT *keymgmt,
      * which does the import for us.  If successful, we're done.
      */
     if (!evp_keymgmt_util_export(pk, selection,
-                                 &evp_keymgmt_util_try_import, &import_data))
+            &evp_keymgmt_util_try_import, &import_data))
         /* If there was an error, bail out */
         return NULL;
 
@@ -198,7 +198,7 @@ void *evp_keymgmt_util_export_to_provider(EVP_PKEY *pk, EVP_KEYMGMT *keymgmt,
 
     /* Add the new export to the operation cache */
     if (!evp_keymgmt_util_cache_keydata(pk, keymgmt, import_data.keydata,
-                                        selection)) {
+            selection)) {
         CRYPTO_THREAD_unlock(pk->lock);
         evp_keymgmt_freedata(keymgmt, import_data.keydata);
         return NULL;
@@ -230,8 +230,8 @@ int evp_keymgmt_util_clear_operation_cache(EVP_PKEY *pk)
 }
 
 OP_CACHE_ELEM *evp_keymgmt_util_find_operation_cache(EVP_PKEY *pk,
-                                                     EVP_KEYMGMT *keymgmt,
-                                                     int selection)
+    EVP_KEYMGMT *keymgmt,
+    int selection)
 {
     int i, end = sk_OP_CACHE_ELEM_num(pk->operation_cache);
     OP_CACHE_ELEM *p;
@@ -245,16 +245,16 @@ OP_CACHE_ELEM *evp_keymgmt_util_find_operation_cache(EVP_PKEY *pk,
     for (i = 0; i < end; i++) {
         p = sk_OP_CACHE_ELEM_value(pk->operation_cache, i);
         if ((p->selection & selection) == selection
-                && (keymgmt == p->keymgmt
-                    || (keymgmt->name_id == p->keymgmt->name_id
-                        && keymgmt->prov == p->keymgmt->prov)))
+            && (keymgmt == p->keymgmt
+                || (keymgmt->name_id == p->keymgmt->name_id
+                    && keymgmt->prov == p->keymgmt->prov)))
             return p;
     }
     return NULL;
 }
 
 int evp_keymgmt_util_cache_keydata(EVP_PKEY *pk, EVP_KEYMGMT *keymgmt,
-                                   void *keydata, int selection)
+    void *keydata, int selection)
 {
     OP_CACHE_ELEM *p = NULL;
 
@@ -301,7 +301,7 @@ void evp_keymgmt_util_cache_keyinfo(EVP_PKEY *pk)
 
         params[0] = OSSL_PARAM_construct_int(OSSL_PKEY_PARAM_BITS, &bits);
         params[1] = OSSL_PARAM_construct_int(OSSL_PKEY_PARAM_SECURITY_BITS,
-                                             &security_bits);
+            &security_bits);
         params[2] = OSSL_PARAM_construct_int(OSSL_PKEY_PARAM_MAX_SIZE, &size);
         params[3] = OSSL_PARAM_construct_end();
         if (evp_keymgmt_get_params(pk->keymgmt, pk->keydata, params)) {
@@ -313,7 +313,7 @@ void evp_keymgmt_util_cache_keyinfo(EVP_PKEY *pk)
 }
 
 void *evp_keymgmt_util_fromdata(EVP_PKEY *target, EVP_KEYMGMT *keymgmt,
-                                int selection, const OSSL_PARAM params[])
+    int selection, const OSSL_PARAM params[])
 {
     void *keydata = NULL;
 
@@ -382,7 +382,7 @@ int evp_keymgmt_util_match(EVP_PKEY *pk1, EVP_PKEY *pk2, int selection)
             && keymgmt2 != NULL
             && !match_type(keymgmt1, keymgmt2)) {
             ERR_raise(ERR_LIB_EVP, EVP_R_DIFFERENT_KEY_TYPES);
-            return -1;           /* Not the same type */
+            return -1; /* Not the same type */
         }
 
         /*
@@ -395,9 +395,8 @@ int evp_keymgmt_util_match(EVP_PKEY *pk1, EVP_PKEY *pk2, int selection)
 
             ok = 1;
             if (keydata1 != NULL) {
-                tmp_keydata =
-                    evp_keymgmt_util_export_to_provider(pk1, keymgmt2,
-                                                        selection);
+                tmp_keydata = evp_keymgmt_util_export_to_provider(pk1, keymgmt2,
+                    selection);
                 ok = (tmp_keydata != NULL);
             }
             if (ok) {
@@ -416,9 +415,8 @@ int evp_keymgmt_util_match(EVP_PKEY *pk1, EVP_PKEY *pk2, int selection)
 
             ok = 1;
             if (keydata2 != NULL) {
-                tmp_keydata =
-                    evp_keymgmt_util_export_to_provider(pk2, keymgmt1,
-                                                        selection);
+                tmp_keydata = evp_keymgmt_util_export_to_provider(pk2, keymgmt1,
+                    selection);
                 ok = (tmp_keydata != NULL);
             }
             if (ok) {
@@ -463,8 +461,8 @@ int evp_keymgmt_util_copy(EVP_PKEY *to, EVP_PKEY *from, int selection)
     if (to_keymgmt == from->keymgmt && to_keymgmt->dup != NULL
         && to_keydata == NULL) {
         to_keydata = alloc_keydata = evp_keymgmt_dup(to_keymgmt,
-                                                     from->keydata,
-                                                     selection);
+            from->keydata,
+            selection);
         if (to_keydata == NULL)
             return 0;
     } else if (match_type(to_keymgmt, from->keymgmt)) {
@@ -475,8 +473,8 @@ int evp_keymgmt_util_copy(EVP_PKEY *to, EVP_PKEY *from, int selection)
         import_data.selection = selection;
 
         if (!evp_keymgmt_util_export(from, selection,
-                                     &evp_keymgmt_util_try_import,
-                                     &import_data))
+                &evp_keymgmt_util_try_import,
+                &import_data))
             return 0;
 
         /*
@@ -511,7 +509,7 @@ int evp_keymgmt_util_copy(EVP_PKEY *to, EVP_PKEY *from, int selection)
 }
 
 void *evp_keymgmt_util_gen(EVP_PKEY *target, EVP_KEYMGMT *keymgmt,
-                           void *genctx, OSSL_CALLBACK *cb, void *cbarg)
+    void *genctx, OSSL_CALLBACK *cb, void *cbarg)
 {
     void *keydata = NULL;
 
@@ -531,8 +529,8 @@ void *evp_keymgmt_util_gen(EVP_PKEY *target, EVP_KEYMGMT *keymgmt,
  * returns for no digest.
  */
 int evp_keymgmt_util_get_deflt_digest_name(EVP_KEYMGMT *keymgmt,
-                                           void *keydata,
-                                           char *mdname, size_t mdname_sz)
+    void *keydata,
+    char *mdname, size_t mdname_sz)
 {
     OSSL_PARAM params[3];
     char mddefault[100] = "";
@@ -540,13 +538,11 @@ int evp_keymgmt_util_get_deflt_digest_name(EVP_KEYMGMT *keymgmt,
     char *result = NULL;
     int rv = -2;
 
-    params[0] =
-        OSSL_PARAM_construct_utf8_string(OSSL_PKEY_PARAM_DEFAULT_DIGEST,
-                                         mddefault, sizeof(mddefault));
-    params[1] =
-        OSSL_PARAM_construct_utf8_string(OSSL_PKEY_PARAM_MANDATORY_DIGEST,
-                                         mdmandatory,
-                                         sizeof(mdmandatory));
+    params[0] = OSSL_PARAM_construct_utf8_string(OSSL_PKEY_PARAM_DEFAULT_DIGEST,
+        mddefault, sizeof(mddefault));
+    params[1] = OSSL_PARAM_construct_utf8_string(OSSL_PKEY_PARAM_MANDATORY_DIGEST,
+        mdmandatory,
+        sizeof(mdmandatory));
     params[2] = OSSL_PARAM_construct_end();
 
     if (!evp_keymgmt_get_params(keymgmt, keydata, params))
@@ -576,7 +572,7 @@ int evp_keymgmt_util_get_deflt_digest_name(EVP_KEYMGMT *keymgmt,
  * assuming that it works as a default operation name.
  */
 const char *evp_keymgmt_util_query_operation_name(EVP_KEYMGMT *keymgmt,
-                                                  int op_id)
+    int op_id)
 {
     const char *name = NULL;
 
