@@ -45,8 +45,7 @@ static const char OSSL_HPKE_SECRET_LABEL[] = "\x73\x65\x63\x72\x65\x74";
 /**
  * @brief sender or receiver context
  */
-struct ossl_hpke_ctx_st
-{
+struct ossl_hpke_ctx_st {
     OSSL_LIB_CTX *libctx; /* library context */
     char *propq; /* properties */
     int mode; /* HPKE mode */
@@ -101,17 +100,17 @@ static int hpke_kem_id_nist_curve(uint16_t kem_id)
  * future, but would likely require a name change.
  */
 static EVP_PKEY *evp_pkey_new_raw_nist_public_key(OSSL_LIB_CTX *libctx,
-                                                  const char *propq,
-                                                  const char *gname,
-                                                  const unsigned char *buf,
-                                                  size_t buflen)
+    const char *propq,
+    const char *gname,
+    const unsigned char *buf,
+    size_t buflen)
 {
     OSSL_PARAM params[2];
     EVP_PKEY *ret = NULL;
     EVP_PKEY_CTX *cctx = EVP_PKEY_CTX_new_from_name(libctx, "EC", propq);
 
     params[0] = OSSL_PARAM_construct_utf8_string(OSSL_PKEY_PARAM_GROUP_NAME,
-                                                 (char *)gname, 0);
+        (char *)gname, 0);
     params[1] = OSSL_PARAM_construct_end();
     if (cctx == NULL
         || EVP_PKEY_paramgen_init(cctx) <= 0
@@ -140,9 +139,9 @@ static EVP_PKEY *evp_pkey_new_raw_nist_public_key(OSSL_LIB_CTX *libctx,
  * @return 1 on success, 0 otherwise
  */
 static int hpke_aead_dec(OSSL_HPKE_CTX *hctx, const unsigned char *iv,
-                         const unsigned char *aad, size_t aadlen,
-                         const unsigned char *ct, size_t ctlen,
-                         unsigned char *pt, size_t *ptlen)
+    const unsigned char *aad, size_t aadlen,
+    const unsigned char *ct, size_t ctlen,
+    unsigned char *pt, size_t *ptlen)
 {
     int erv = 0;
     EVP_CIPHER_CTX *ctx = NULL;
@@ -163,7 +162,8 @@ static int hpke_aead_dec(OSSL_HPKE_CTX *hctx, const unsigned char *iv,
         goto err;
     }
     if (EVP_CIPHER_CTX_ctrl(ctx, EVP_CTRL_AEAD_SET_IVLEN,
-                            hctx->noncelen, NULL) != 1) {
+            hctx->noncelen, NULL)
+        != 1) {
         ERR_raise(ERR_LIB_CRYPTO, ERR_R_INTERNAL_ERROR);
         goto err;
     }
@@ -185,7 +185,7 @@ static int hpke_aead_dec(OSSL_HPKE_CTX *hctx, const unsigned char *iv,
     }
     *ptlen = len;
     if (!EVP_CIPHER_CTX_ctrl(ctx, EVP_CTRL_AEAD_SET_TAG,
-                             taglen, (void *)(ct + ctlen - taglen))) {
+            taglen, (void *)(ct + ctlen - taglen))) {
         ERR_raise(ERR_LIB_CRYPTO, ERR_R_INTERNAL_ERROR);
         goto err;
     }
@@ -216,9 +216,9 @@ err:
  * @return 1 for success, 0 otherwise
  */
 static int hpke_aead_enc(OSSL_HPKE_CTX *hctx, const unsigned char *iv,
-                         const unsigned char *aad, size_t aadlen,
-                         const unsigned char *pt, size_t ptlen,
-                         unsigned char *ct, size_t *ctlen)
+    const unsigned char *aad, size_t aadlen,
+    const unsigned char *pt, size_t ptlen,
+    unsigned char *ct, size_t *ctlen)
 {
     int erv = 0;
     EVP_CIPHER_CTX *ctx = NULL;
@@ -244,7 +244,8 @@ static int hpke_aead_enc(OSSL_HPKE_CTX *hctx, const unsigned char *iv,
         goto err;
     }
     if (EVP_CIPHER_CTX_ctrl(ctx, EVP_CTRL_AEAD_SET_IVLEN,
-                            hctx->noncelen, NULL) != 1) {
+            hctx->noncelen, NULL)
+        != 1) {
         ERR_raise(ERR_LIB_CRYPTO, ERR_R_INTERNAL_ERROR);
         goto err;
     }
@@ -312,9 +313,9 @@ static int hpke_mode_check(unsigned int mode)
  * @return 1 for good, 0 otherwise
  */
 static int hpke_suite_check(OSSL_HPKE_SUITE suite,
-                            const OSSL_HPKE_KEM_INFO **kem_info,
-                            const OSSL_HPKE_KDF_INFO **kdf_info,
-                            const OSSL_HPKE_AEAD_INFO **aead_info)
+    const OSSL_HPKE_KEM_INFO **kem_info,
+    const OSSL_HPKE_KDF_INFO **kdf_info,
+    const OSSL_HPKE_AEAD_INFO **aead_info)
 {
     const OSSL_HPKE_KEM_INFO *kem_info_;
     const OSSL_HPKE_KDF_INFO *kdf_info_;
@@ -346,8 +347,8 @@ static int hpke_suite_check(OSSL_HPKE_SUITE suite,
  * @return 1 for success, 0 otherwise
  */
 static int hpke_random_suite(OSSL_LIB_CTX *libctx,
-                             const char *propq,
-                             OSSL_HPKE_SUITE *suite)
+    const char *propq,
+    OSSL_HPKE_SUITE *suite)
 {
     const OSSL_HPKE_KEM_INFO *kem_info = NULL;
     const OSSL_HPKE_KDF_INFO *kdf_info = NULL;
@@ -389,9 +390,9 @@ static int hpke_random_suite(OSSL_LIB_CTX *libctx,
  * @return 1 for success, 0 otherwise
  */
 static int hpke_expansion(OSSL_HPKE_SUITE suite,
-                          size_t *enclen,
-                          size_t clearlen,
-                          size_t *cipherlen)
+    size_t *enclen,
+    size_t clearlen,
+    size_t *cipherlen)
 {
     const OSSL_HPKE_AEAD_INFO *aead_info = NULL;
     const OSSL_HPKE_KEM_INFO *kem_info = NULL;
@@ -417,7 +418,7 @@ static int hpke_expansion(OSSL_HPKE_SUITE suite,
  * @return 0 for error, otherwise blen
  */
 static size_t hpke_seqnonce2buf(OSSL_HPKE_CTX *ctx,
-                                unsigned char *buf, size_t blen)
+    unsigned char *buf, size_t blen)
 {
     size_t i;
     uint64_t seq_copy;
@@ -445,7 +446,7 @@ static size_t hpke_seqnonce2buf(OSSL_HPKE_CTX *ctx,
  * @return 1 for success, 0 for error
  */
 static int hpke_encap(OSSL_HPKE_CTX *ctx, unsigned char *enc, size_t *enclen,
-                      const unsigned char *pub, size_t publen)
+    const unsigned char *pub, size_t publen)
 {
     int erv = 0;
     OSSL_PARAM params[3], *p = params;
@@ -471,12 +472,12 @@ static int hpke_encap(OSSL_HPKE_CTX *ctx, unsigned char *enc, size_t *enclen,
     }
     if (hpke_kem_id_nist_curve(ctx->suite.kem_id) == 1) {
         pkR = evp_pkey_new_raw_nist_public_key(ctx->libctx, ctx->propq,
-                                               kem_info->groupname,
-                                               pub, publen);
+            kem_info->groupname,
+            pub, publen);
     } else {
         pkR = EVP_PKEY_new_raw_public_key_ex(ctx->libctx,
-                                             kem_info->keytype,
-                                             ctx->propq, pub, publen);
+            kem_info->keytype,
+            ctx->propq, pub, publen);
     }
     if (pkR == NULL) {
         ERR_raise(ERR_LIB_CRYPTO, ERR_R_INTERNAL_ERROR);
@@ -488,17 +489,18 @@ static int hpke_encap(OSSL_HPKE_CTX *ctx, unsigned char *enc, size_t *enclen,
         goto err;
     }
     *p++ = OSSL_PARAM_construct_utf8_string(OSSL_KEM_PARAM_OPERATION,
-                                            OSSL_KEM_PARAM_OPERATION_DHKEM,
-                                            0);
+        OSSL_KEM_PARAM_OPERATION_DHKEM,
+        0);
     if (ctx->ikme != NULL) {
         *p++ = OSSL_PARAM_construct_octet_string(OSSL_KEM_PARAM_IKME,
-                                                 ctx->ikme, ctx->ikmelen);
+            ctx->ikme, ctx->ikmelen);
     }
     *p = OSSL_PARAM_construct_end();
     if (ctx->mode == OSSL_HPKE_MODE_AUTH
         || ctx->mode == OSSL_HPKE_MODE_PSKAUTH) {
         if (EVP_PKEY_auth_encapsulate_init(pctx, ctx->authpriv,
-                                           params) != 1) {
+                params)
+            != 1) {
             ERR_raise(ERR_LIB_CRYPTO, ERR_R_INTERNAL_ERROR);
             goto err;
         }
@@ -522,7 +524,8 @@ static int hpke_encap(OSSL_HPKE_CTX *ctx, unsigned char *enc, size_t *enclen,
         goto err;
     ctx->shared_secretlen = lsslen;
     if (EVP_PKEY_encapsulate(pctx, enc, enclen, ctx->shared_secret,
-                             &ctx->shared_secretlen) != 1) {
+            &ctx->shared_secretlen)
+        != 1) {
         ctx->shared_secretlen = 0;
         OPENSSL_free(ctx->shared_secret);
         ctx->shared_secret = NULL;
@@ -546,8 +549,8 @@ err:
  * @return 1 for success, 0 for error
  */
 static int hpke_decap(OSSL_HPKE_CTX *ctx,
-                      const unsigned char *enc, size_t enclen,
-                      EVP_PKEY *priv)
+    const unsigned char *enc, size_t enclen,
+    EVP_PKEY *priv)
 {
     int erv = 0;
     EVP_PKEY_CTX *pctx = NULL;
@@ -570,8 +573,8 @@ static int hpke_decap(OSSL_HPKE_CTX *ctx,
         goto err;
     }
     *p++ = OSSL_PARAM_construct_utf8_string(OSSL_KEM_PARAM_OPERATION,
-                                            OSSL_KEM_PARAM_OPERATION_DHKEM,
-                                            0);
+        OSSL_KEM_PARAM_OPERATION_DHKEM,
+        0);
     *p = OSSL_PARAM_construct_end();
     if (ctx->mode == OSSL_HPKE_MODE_AUTH
         || ctx->mode == OSSL_HPKE_MODE_PSKAUTH) {
@@ -584,15 +587,15 @@ static int hpke_decap(OSSL_HPKE_CTX *ctx,
         }
         if (hpke_kem_id_nist_curve(ctx->suite.kem_id) == 1) {
             spub = evp_pkey_new_raw_nist_public_key(ctx->libctx, ctx->propq,
-                                                    kem_info->groupname,
-                                                    ctx->authpub,
-                                                    ctx->authpublen);
+                kem_info->groupname,
+                ctx->authpub,
+                ctx->authpublen);
         } else {
             spub = EVP_PKEY_new_raw_public_key_ex(ctx->libctx,
-                                                  kem_info->keytype,
-                                                  ctx->propq,
-                                                  ctx->authpub,
-                                                  ctx->authpublen);
+                kem_info->keytype,
+                ctx->propq,
+                ctx->authpub,
+                ctx->authpublen);
         }
         if (spub == NULL) {
             ERR_raise(ERR_LIB_CRYPTO, ERR_R_INTERNAL_ERROR);
@@ -616,7 +619,8 @@ static int hpke_decap(OSSL_HPKE_CTX *ctx,
     if (ctx->shared_secret == NULL)
         goto err;
     if (EVP_PKEY_decapsulate(pctx, ctx->shared_secret, &lsslen,
-                             enc, enclen) != 1) {
+            enc, enclen)
+        != 1) {
         ERR_raise(ERR_LIB_CRYPTO, ERR_R_INTERNAL_ERROR);
         goto err;
     }
@@ -646,7 +650,7 @@ err:
  * ctx fields for the shared_secret, nonce, key and exporter_secret
  */
 static int hpke_do_middle(OSSL_HPKE_CTX *ctx,
-                          const unsigned char *info, size_t infolen)
+    const unsigned char *info, size_t infolen)
 {
     int erv = 0;
     size_t ks_contextlen = OSSL_HPKE_MAXSIZE;
@@ -713,18 +717,20 @@ static int hpke_do_middle(OSSL_HPKE_CTX *ctx,
     suitebuf[5] = ctx->suite.aead_id % 256;
     /* Extract and Expand variously... */
     if (ossl_hpke_labeled_extract(kctx, ks_context + 1, halflen,
-                                  NULL, 0, OSSL_HPKE_SEC51LABEL,
-                                  suitebuf, sizeof(suitebuf),
-                                  OSSL_HPKE_PSKIDHASH_LABEL,
-                                  (unsigned char *)ctx->pskid, pskidlen) != 1) {
+            NULL, 0, OSSL_HPKE_SEC51LABEL,
+            suitebuf, sizeof(suitebuf),
+            OSSL_HPKE_PSKIDHASH_LABEL,
+            (unsigned char *)ctx->pskid, pskidlen)
+        != 1) {
         ERR_raise(ERR_LIB_CRYPTO, ERR_R_INTERNAL_ERROR);
         goto err;
     }
     if (ossl_hpke_labeled_extract(kctx, ks_context + 1 + halflen, halflen,
-                                  NULL, 0, OSSL_HPKE_SEC51LABEL,
-                                  suitebuf, sizeof(suitebuf),
-                                  OSSL_HPKE_INFOHASH_LABEL,
-                                  (unsigned char *)info, infolen) != 1) {
+            NULL, 0, OSSL_HPKE_SEC51LABEL,
+            suitebuf, sizeof(suitebuf),
+            OSSL_HPKE_INFOHASH_LABEL,
+            (unsigned char *)info, infolen)
+        != 1) {
         ERR_raise(ERR_LIB_CRYPTO, ERR_R_INTERNAL_ERROR);
         goto err;
     }
@@ -735,11 +741,12 @@ static int hpke_do_middle(OSSL_HPKE_CTX *ctx,
         goto err;
     }
     if (ossl_hpke_labeled_extract(kctx, secret, secretlen,
-                                  ctx->shared_secret, ctx->shared_secretlen,
-                                  OSSL_HPKE_SEC51LABEL,
-                                  suitebuf, sizeof(suitebuf),
-                                  OSSL_HPKE_SECRET_LABEL,
-                                  ctx->psk, ctx->psklen) != 1) {
+            ctx->shared_secret, ctx->shared_secretlen,
+            OSSL_HPKE_SEC51LABEL,
+            suitebuf, sizeof(suitebuf),
+            OSSL_HPKE_SECRET_LABEL,
+            ctx->psk, ctx->psklen)
+        != 1) {
         ERR_raise(ERR_LIB_CRYPTO, ERR_R_INTERNAL_ERROR);
         goto err;
     }
@@ -750,10 +757,11 @@ static int hpke_do_middle(OSSL_HPKE_CTX *ctx,
         if (ctx->nonce == NULL)
             goto err;
         if (ossl_hpke_labeled_expand(kctx, ctx->nonce, ctx->noncelen,
-                                     secret, secretlen, OSSL_HPKE_SEC51LABEL,
-                                     suitebuf, sizeof(suitebuf),
-                                     OSSL_HPKE_NONCE_LABEL,
-                                     ks_context, ks_contextlen) != 1) {
+                secret, secretlen, OSSL_HPKE_SEC51LABEL,
+                suitebuf, sizeof(suitebuf),
+                OSSL_HPKE_NONCE_LABEL,
+                ks_context, ks_contextlen)
+            != 1) {
             ERR_raise(ERR_LIB_CRYPTO, ERR_R_INTERNAL_ERROR);
             goto err;
         }
@@ -762,10 +770,11 @@ static int hpke_do_middle(OSSL_HPKE_CTX *ctx,
         if (ctx->key == NULL)
             goto err;
         if (ossl_hpke_labeled_expand(kctx, ctx->key, ctx->keylen,
-                                     secret, secretlen, OSSL_HPKE_SEC51LABEL,
-                                     suitebuf, sizeof(suitebuf),
-                                     OSSL_HPKE_KEY_LABEL,
-                                     ks_context, ks_contextlen) != 1) {
+                secret, secretlen, OSSL_HPKE_SEC51LABEL,
+                suitebuf, sizeof(suitebuf),
+                OSSL_HPKE_KEY_LABEL,
+                ks_context, ks_contextlen)
+            != 1) {
             ERR_raise(ERR_LIB_CRYPTO, ERR_R_INTERNAL_ERROR);
             goto err;
         }
@@ -775,10 +784,11 @@ static int hpke_do_middle(OSSL_HPKE_CTX *ctx,
     if (ctx->exportersec == NULL)
         goto err;
     if (ossl_hpke_labeled_expand(kctx, ctx->exportersec, ctx->exporterseclen,
-                                 secret, secretlen, OSSL_HPKE_SEC51LABEL,
-                                 suitebuf, sizeof(suitebuf),
-                                 OSSL_HPKE_EXP_LABEL,
-                                 ks_context, ks_contextlen) != 1) {
+            secret, secretlen, OSSL_HPKE_SEC51LABEL,
+            suitebuf, sizeof(suitebuf),
+            OSSL_HPKE_EXP_LABEL,
+            ks_context, ks_contextlen)
+        != 1) {
         ERR_raise(ERR_LIB_CRYPTO, ERR_R_INTERNAL_ERROR);
         goto err;
     }
@@ -797,7 +807,7 @@ err:
  */
 
 OSSL_HPKE_CTX *OSSL_HPKE_CTX_new(int mode, OSSL_HPKE_SUITE suite, int role,
-                                 OSSL_LIB_CTX *libctx, const char *propq)
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     OSSL_HPKE_CTX *ctx = NULL;
     const OSSL_HPKE_KEM_INFO *kem_info;
@@ -840,8 +850,9 @@ OSSL_HPKE_CTX *OSSL_HPKE_CTX_new(int mode, OSSL_HPKE_SUITE suite, int role,
     ctx->aead_info = aead_info;
     return ctx;
 
- err:
+err:
     EVP_CIPHER_free(ctx->aead_ciph);
+    OPENSSL_free(ctx->propq);
     OPENSSL_free(ctx);
     return NULL;
 }
@@ -867,8 +878,8 @@ void OSSL_HPKE_CTX_free(OSSL_HPKE_CTX *ctx)
 }
 
 int OSSL_HPKE_CTX_set1_psk(OSSL_HPKE_CTX *ctx,
-                           const char *pskid,
-                           const unsigned char *psk, size_t psklen)
+    const char *pskid,
+    const unsigned char *psk, size_t psklen)
 {
     if (ctx == NULL || pskid == NULL || psk == NULL || psklen == 0) {
         ERR_raise(ERR_LIB_CRYPTO, ERR_R_PASSED_INVALID_ARGUMENT);
@@ -913,7 +924,7 @@ int OSSL_HPKE_CTX_set1_psk(OSSL_HPKE_CTX *ctx,
 }
 
 int OSSL_HPKE_CTX_set1_ikme(OSSL_HPKE_CTX *ctx,
-                            const unsigned char *ikme, size_t ikmelen)
+    const unsigned char *ikme, size_t ikmelen)
 {
     if (ctx == NULL || ikme == NULL) {
         ERR_raise(ERR_LIB_CRYPTO, ERR_R_PASSED_NULL_PARAMETER);
@@ -958,7 +969,7 @@ int OSSL_HPKE_CTX_set1_authpriv(OSSL_HPKE_CTX *ctx, EVP_PKEY *priv)
 }
 
 int OSSL_HPKE_CTX_set1_authpub(OSSL_HPKE_CTX *ctx,
-                               const unsigned char *pub, size_t publen)
+    const unsigned char *pub, size_t publen)
 {
     int erv = 0;
     EVP_PKEY *pubp = NULL;
@@ -985,13 +996,13 @@ int OSSL_HPKE_CTX_set1_authpub(OSSL_HPKE_CTX *ctx,
         return 0;
     if (hpke_kem_id_nist_curve(ctx->suite.kem_id) == 1) {
         pubp = evp_pkey_new_raw_nist_public_key(ctx->libctx, ctx->propq,
-                                                kem_info->groupname,
-                                                pub, publen);
+            kem_info->groupname,
+            pub, publen);
     } else {
         pubp = EVP_PKEY_new_raw_public_key_ex(ctx->libctx,
-                                              kem_info->keytype,
-                                              ctx->propq,
-                                              pub, publen);
+            kem_info->keytype,
+            ctx->propq,
+            pub, publen);
     }
     if (pubp == NULL) {
         /* can happen based on external input - buffer value may be garbage */
@@ -1006,8 +1017,8 @@ int OSSL_HPKE_CTX_set1_authpub(OSSL_HPKE_CTX *ctx,
     if (lpub == NULL)
         goto err;
     if (EVP_PKEY_get_octet_string_param(pubp,
-                                        OSSL_PKEY_PARAM_ENCODED_PUBLIC_KEY,
-                                        lpub, OSSL_HPKE_MAXSIZE, &lpublen)
+            OSSL_PKEY_PARAM_ENCODED_PUBLIC_KEY,
+            lpub, OSSL_HPKE_MAXSIZE, &lpublen)
         != 1) {
         OPENSSL_free(lpub);
         ERR_raise(ERR_LIB_CRYPTO, ERR_R_INTERNAL_ERROR);
@@ -1054,9 +1065,9 @@ int OSSL_HPKE_CTX_set_seq(OSSL_HPKE_CTX *ctx, uint64_t seq)
 }
 
 int OSSL_HPKE_encap(OSSL_HPKE_CTX *ctx,
-                    unsigned char *enc, size_t *enclen,
-                    const unsigned char *pub, size_t publen,
-                    const unsigned char *info, size_t infolen)
+    unsigned char *enc, size_t *enclen,
+    const unsigned char *pub, size_t publen,
+    const unsigned char *info, size_t infolen)
 {
     int erv = 1;
     size_t minenc = 0;
@@ -1102,9 +1113,9 @@ int OSSL_HPKE_encap(OSSL_HPKE_CTX *ctx,
 }
 
 int OSSL_HPKE_decap(OSSL_HPKE_CTX *ctx,
-                    const unsigned char *enc, size_t enclen,
-                    EVP_PKEY *recippriv,
-                    const unsigned char *info, size_t infolen)
+    const unsigned char *enc, size_t enclen,
+    EVP_PKEY *recippriv,
+    const unsigned char *info, size_t infolen)
 {
     int erv = 1;
     size_t minenc = 0;
@@ -1150,9 +1161,9 @@ int OSSL_HPKE_decap(OSSL_HPKE_CTX *ctx,
 }
 
 int OSSL_HPKE_seal(OSSL_HPKE_CTX *ctx,
-                   unsigned char *ct, size_t *ctlen,
-                   const unsigned char *aad, size_t aadlen,
-                   const unsigned char *pt, size_t ptlen)
+    unsigned char *ct, size_t *ctlen,
+    const unsigned char *aad, size_t aadlen,
+    const unsigned char *pt, size_t ptlen)
 {
     unsigned char seqbuf[OSSL_HPKE_MAX_NONCELEN];
     size_t seqlen = 0;
@@ -1192,9 +1203,9 @@ int OSSL_HPKE_seal(OSSL_HPKE_CTX *ctx,
 }
 
 int OSSL_HPKE_open(OSSL_HPKE_CTX *ctx,
-                   unsigned char *pt, size_t *ptlen,
-                   const unsigned char *aad, size_t aadlen,
-                   const unsigned char *ct, size_t ctlen)
+    unsigned char *pt, size_t *ptlen,
+    const unsigned char *aad, size_t aadlen,
+    const unsigned char *ct, size_t ctlen)
 {
     unsigned char seqbuf[OSSL_HPKE_MAX_NONCELEN];
     size_t seqlen = 0;
@@ -1233,8 +1244,8 @@ int OSSL_HPKE_open(OSSL_HPKE_CTX *ctx,
 }
 
 int OSSL_HPKE_export(OSSL_HPKE_CTX *ctx,
-                     unsigned char *secret, size_t secretlen,
-                     const unsigned char *label, size_t labellen)
+    unsigned char *secret, size_t secretlen,
+    const unsigned char *label, size_t labellen)
 {
     int erv = 0;
     EVP_KDF_CTX *kctx = NULL;
@@ -1277,11 +1288,11 @@ int OSSL_HPKE_export(OSSL_HPKE_CTX *ctx,
     suitebuf[4] = ctx->suite.aead_id / 256;
     suitebuf[5] = ctx->suite.aead_id % 256;
     erv = ossl_hpke_labeled_expand(kctx, secret, secretlen,
-                                   ctx->exportersec, ctx->exporterseclen,
-                                   OSSL_HPKE_SEC51LABEL,
-                                   suitebuf, sizeof(suitebuf),
-                                   OSSL_HPKE_EXP_SEC_LABEL,
-                                   label, labellen);
+        ctx->exportersec, ctx->exporterseclen,
+        OSSL_HPKE_SEC51LABEL,
+        suitebuf, sizeof(suitebuf),
+        OSSL_HPKE_EXP_SEC_LABEL,
+        label, labellen);
     EVP_KDF_CTX_free(kctx);
     if (erv != 1)
         ERR_raise(ERR_LIB_CRYPTO, ERR_R_INTERNAL_ERROR);
@@ -1289,9 +1300,9 @@ int OSSL_HPKE_export(OSSL_HPKE_CTX *ctx,
 }
 
 int OSSL_HPKE_keygen(OSSL_HPKE_SUITE suite,
-                     unsigned char *pub, size_t *publen, EVP_PKEY **priv,
-                     const unsigned char *ikm, size_t ikmlen,
-                     OSSL_LIB_CTX *libctx, const char *propq)
+    unsigned char *pub, size_t *publen, EVP_PKEY **priv,
+    const unsigned char *ikm, size_t ikmlen,
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     int erv = 0; /* Our error return value - 1 is success */
     EVP_PKEY_CTX *pctx = NULL;
@@ -1316,7 +1327,7 @@ int OSSL_HPKE_keygen(OSSL_HPKE_SUITE suite,
 
     if (hpke_kem_id_nist_curve(suite.kem_id) == 1) {
         *p++ = OSSL_PARAM_construct_utf8_string(OSSL_PKEY_PARAM_GROUP_NAME,
-                                                (char *)kem_info->groupname, 0);
+            (char *)kem_info->groupname, 0);
         pctx = EVP_PKEY_CTX_new_from_name(libctx, "EC", propq);
     } else {
         pctx = EVP_PKEY_CTX_new_from_name(libctx, kem_info->keytype, propq);
@@ -1328,7 +1339,7 @@ int OSSL_HPKE_keygen(OSSL_HPKE_SUITE suite,
     }
     if (ikm != NULL)
         *p++ = OSSL_PARAM_construct_octet_string(OSSL_PKEY_PARAM_DHKEM_IKM,
-                                                 (char *)ikm, ikmlen);
+            (char *)ikm, ikmlen);
     *p = OSSL_PARAM_construct_end();
     if (EVP_PKEY_CTX_set_params(pctx, params) <= 0) {
         ERR_raise(ERR_LIB_CRYPTO, ERR_R_INTERNAL_ERROR);
@@ -1341,7 +1352,8 @@ int OSSL_HPKE_keygen(OSSL_HPKE_SUITE suite,
     EVP_PKEY_CTX_free(pctx);
     pctx = NULL;
     if (EVP_PKEY_get_octet_string_param(skR, OSSL_PKEY_PARAM_ENCODED_PUBLIC_KEY,
-                                        pub, *publen, publen) != 1) {
+            pub, *publen, publen)
+        != 1) {
         ERR_raise(ERR_LIB_CRYPTO, ERR_R_INTERNAL_ERROR);
         goto err;
     }
@@ -1361,10 +1373,10 @@ int OSSL_HPKE_suite_check(OSSL_HPKE_SUITE suite)
 }
 
 int OSSL_HPKE_get_grease_value(const OSSL_HPKE_SUITE *suite_in,
-                               OSSL_HPKE_SUITE *suite,
-                               unsigned char *enc, size_t *enclen,
-                               unsigned char *ct, size_t ctlen,
-                               OSSL_LIB_CTX *libctx, const char *propq)
+    OSSL_HPKE_SUITE *suite,
+    unsigned char *enc, size_t *enclen,
+    unsigned char *ct, size_t ctlen,
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     OSSL_HPKE_SUITE chosen;
     size_t plen = 0;
@@ -1410,7 +1422,8 @@ int OSSL_HPKE_get_grease_value(const OSSL_HPKE_SUITE *suite_in,
      * the relevant curve.
      */
     if (OSSL_HPKE_keygen(chosen, enc, enclen, &fakepriv, NULL, 0,
-                         libctx, propq) != 1) {
+            libctx, propq)
+        != 1) {
         ERR_raise(ERR_LIB_CRYPTO, ERR_R_INTERNAL_ERROR);
         goto err;
     }
