@@ -13,8 +13,7 @@
 #include "internal/cryptlib.h"
 #include "crypto/context.h"
 
-typedef struct indicator_cb_st
-{
+typedef struct indicator_cb_st {
     OSSL_INDICATOR_CALLBACK *cb;
 } INDICATOR_CB;
 
@@ -37,7 +36,7 @@ static INDICATOR_CB *get_indicator_callback(OSSL_LIB_CTX *libctx)
 }
 
 void OSSL_INDICATOR_set_callback(OSSL_LIB_CTX *libctx,
-                                 OSSL_INDICATOR_CALLBACK *cb)
+    OSSL_INDICATOR_CALLBACK *cb)
 {
     INDICATOR_CB *icb = get_indicator_callback(libctx);
 
@@ -46,7 +45,7 @@ void OSSL_INDICATOR_set_callback(OSSL_LIB_CTX *libctx,
 }
 
 void OSSL_INDICATOR_get_callback(OSSL_LIB_CTX *libctx,
-                                 OSSL_INDICATOR_CALLBACK **cb)
+    OSSL_INDICATOR_CALLBACK **cb)
 {
     INDICATOR_CB *icb = get_indicator_callback(libctx);
 
