@@ -35,8 +35,8 @@ int ossl_ml_dsa_key_get_prov_flags(const ML_DSA_KEY *key)
 }
 
 int ossl_ml_dsa_set_prekey(ML_DSA_KEY *key, int flags_set, int flags_clr,
-                           const uint8_t *seed, size_t seed_len,
-                           const uint8_t *sk, size_t sk_len)
+    const uint8_t *seed, size_t seed_len,
+    const uint8_t *sk, size_t sk_len)
 {
     int ret = 0;
 
@@ -58,7 +58,7 @@ int ossl_ml_dsa_set_prekey(ML_DSA_KEY *key, int flags_set, int flags_clr,
     key->prov_flags &= ~flags_clr;
     ret = 1;
 
- end:
+end:
     if (!ret) {
         OPENSSL_free(key->priv_encoding);
         OPENSSL_free(key->seed);
@@ -76,7 +76,7 @@ int ossl_ml_dsa_set_prekey(ML_DSA_KEY *key, int flags_set, int flags_clr,
  * @returns The new ML_DSA_KEY object on success, or NULL on malloc failure
  */
 ML_DSA_KEY *ossl_ml_dsa_key_new(OSSL_LIB_CTX *libctx, const char *propq,
-                                int evp_type)
+    int evp_type)
 {
     ML_DSA_KEY *ret;
     const ML_DSA_PARAMS *params = ossl_ml_dsa_params_get(evp_type);
@@ -204,7 +204,8 @@ ML_DSA_KEY *ossl_ml_dsa_key_dup(const ML_DSA_KEY *src, int selection)
                     vector_copy(&ret->t1, &src->t1);
                 }
                 if ((ret->pub_encoding = OPENSSL_memdup(src->pub_encoding,
-                                                        src->params->pk_len)) == NULL)
+                         src->params->pk_len))
+                    == NULL)
                     goto err;
             }
             if ((selection & OSSL_KEYMGMT_SELECT_PRIVATE_KEY) != 0) {
@@ -217,14 +218,15 @@ ML_DSA_KEY *ossl_ml_dsa_key_dup(const ML_DSA_KEY *src, int selection)
                         vector_copy(&ret->s2, &src->s2);
                         vector_copy(&ret->t0, &src->t0);
                     }
-                    if ((ret->priv_encoding =
-                            OPENSSL_memdup(src->priv_encoding,
-                                           src->params->sk_len)) == NULL)
+                    if ((ret->priv_encoding = OPENSSL_memdup(src->priv_encoding,
+                             src->params->sk_len))
+                        == NULL)
                         goto err;
                 }
                 if (src->seed != NULL
                     && (ret->seed = OPENSSL_memdup(src->seed,
-                                                   ML_DSA_SEED_BYTES)) == NULL)
+                            ML_DSA_SEED_BYTES))
+                        == NULL)
                     goto err;
             }
         }
@@ -234,7 +236,7 @@ ML_DSA_KEY *ossl_ml_dsa_key_dup(const ML_DSA_KEY *src, int selection)
         ret->shake256_md = src->shake256_md;
     }
     return ret;
- err:
+err:
     ossl_ml_dsa_key_free(ret);
     return NULL;
 }
@@ -252,7 +254,7 @@ ML_DSA_KEY *ossl_ml_dsa_key_dup(const ML_DSA_KEY *src, int selection)
  * @returns 1 if the keys are equal otherwise it returns 0.
  */
 int ossl_ml_dsa_key_equal(const ML_DSA_KEY *key1, const ML_DSA_KEY *key2,
-                          int selection)
+    int selection)
 {
     int key_checked = 0;
 
@@ -263,16 +265,18 @@ int ossl_ml_dsa_key_equal(const ML_DSA_KEY *key1, const ML_DSA_KEY *key2,
         if ((selection & OSSL_KEYMGMT_SELECT_PUBLIC_KEY) != 0) {
             if (key1->pub_encoding != NULL && key2->pub_encoding != NULL) {
                 if (memcmp(key1->pub_encoding, key2->pub_encoding,
-                                  key1->params->pk_len) != 0)
+                        key1->params->pk_len)
+                    != 0)
                     return 0;
                 key_checked = 1;
             }
         }
         if (!key_checked
-                && (selection & OSSL_KEYMGMT_SELECT_PRIVATE_KEY) != 0) {
+            && (selection & OSSL_KEYMGMT_SELECT_PRIVATE_KEY) != 0) {
             if (key1->priv_encoding != NULL && key2->priv_encoding != NULL) {
                 if (memcmp(key1->priv_encoding, key2->priv_encoding,
-                           key1->params->sk_len) != 0)
+                        key1->params->sk_len)
+                    != 0)
                     return 0;
                 key_checked = 1;
             }
@@ -289,7 +293,7 @@ int ossl_ml_dsa_key_has(const ML_DSA_KEY *key, int selection)
         if (ossl_ml_dsa_key_get_pub(key) == NULL)
             return 0; /* No public key */
         if ((selection & OSSL_KEYMGMT_SELECT_PRIVATE_KEY) != 0
-                && ossl_ml_dsa_key_get_priv(key) == NULL)
+            && ossl_ml_dsa_key_get_priv(key) == NULL)
             return 0; /* No private key */
         return 1;
     }
@@ -309,7 +313,7 @@ int ossl_ml_dsa_key_has(const ML_DSA_KEY *key, int selection)
  * @returns 1 on success, or 0 on failure.
  */
 static int public_from_private(const ML_DSA_KEY *key, EVP_MD_CTX *md_ctx,
-                               VECTOR *t1, VECTOR *t0)
+    VECTOR *t1, VECTOR *t0)
 {
     int ret = 0;
     const ML_DSA_PARAMS *params = key->params;
@@ -358,14 +362,14 @@ int ossl_ml_dsa_key_public_from_private(ML_DSA_KEY *key)
 
     if (!vector_alloc(&t0, key->params->k)) /* t0 is already in the private key */
         return 0;
-    ret = ((md_ctx = EVP_MD_CTX_new())!= NULL)
-        && ossl_ml_dsa_key_pub_alloc(key)  /* allocate space for t1 */
+    ret = ((md_ctx = EVP_MD_CTX_new()) != NULL)
+        && ossl_ml_dsa_key_pub_alloc(key) /* allocate space for t1 */
         && public_from_private(key, md_ctx, &key->t1, &t0)
         && vector_equal(&t0, &key->t0) /* compare the generated t0 to the expected */
         && ossl_ml_dsa_pk_encode(key)
         && shake_xof(md_ctx, key->shake256_md,
-                     key->pub_encoding, key->params->pk_len,
-                     key->tr, sizeof(key->tr));
+            key->pub_encoding, key->params->pk_len,
+            key->tr, sizeof(key->tr));
     vector_free(&t0);
     EVP_MD_CTX_free(md_ctx);
     return ret;
@@ -432,7 +436,7 @@ static int keygen_internal(ML_DSA_KEY *out)
     augmented_seed[ML_DSA_SEED_BYTES + 1] = (uint8_t)params->l;
     /* Expand the seed into p[32], p'[64], K[32] */
     if (!shake_xof(md_ctx, out->shake256_md, augmented_seed, sizeof(augmented_seed),
-                   expanded_seed, sizeof(expanded_seed)))
+            expanded_seed, sizeof(expanded_seed)))
         goto err;
 
     memcpy(out->rho, rho, sizeof(out->rho));
@@ -442,7 +446,7 @@ static int keygen_internal(ML_DSA_KEY *out)
         && public_from_private(out, md_ctx, &out->t1, &out->t0)
         && ossl_ml_dsa_pk_encode(out)
         && shake_xof(md_ctx, out->shake256_md, out->pub_encoding, out->params->pk_len,
-                     out->tr, sizeof(out->tr))
+            out->tr, sizeof(out->tr))
         && ossl_ml_dsa_sk_encode(out);
 
 err:
@@ -482,8 +486,8 @@ int ossl_ml_dsa_generate_key(ML_DSA_KEY *out)
             ret = 0;
             ossl_ml_dsa_key_reset(out);
             ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_KEY,
-                           "explicit %s private key does not match seed",
-                           out->params->alg);
+                "explicit %s private key does not match seed",
+                out->params->alg);
         }
         OPENSSL_free(sk);
     }
