@@ -1,7 +1,7 @@
 /*
- * Copyright 2014-2018 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2014-2026 The OpenSSL Project Authors. All Rights Reserved.
  *
- * Licensed under the OpenSSL license (the "License").  You may not use
+ * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
  * in the file LICENSE in the source distribution or at
  * https://www.openssl.org/source/license.html
@@ -10,7 +10,7 @@
 #include <string.h>
 #include <openssl/crypto.h>
 #include <openssl/err.h>
-#include "modes_lcl.h"
+#include "crypto/modes.h"
 
 #ifndef OPENSSL_NO_OCB
 
@@ -40,7 +40,7 @@ static u32 ocb_ntz(u64 n)
  * Shift a block of 16 bytes left by shift bits
  */
 static void ocb_block_lshift(const unsigned char *in, size_t shift,
-                             unsigned char *out)
+    unsigned char *out)
 {
     int i;
     unsigned char carry = 0, carry_next;
@@ -76,8 +76,8 @@ static void ocb_double(OCB_BLOCK *in, OCB_BLOCK *out)
  * Perform an xor on in1 and in2 - each of len bytes. Store result in out
  */
 static void ocb_block_xor(const unsigned char *in1,
-                          const unsigned char *in2, size_t len,
-                          unsigned char *out)
+    const unsigned char *in2, size_t len,
+    unsigned char *out)
 {
     size_t i;
     for (i = 0; i < len; i++) {
@@ -128,15 +128,15 @@ static OCB_BLOCK *ocb_lookup_l(OCB128_CONTEXT *ctx, size_t idx)
  * Create a new OCB128_CONTEXT
  */
 OCB128_CONTEXT *CRYPTO_ocb128_new(void *keyenc, void *keydec,
-                                  block128_f encrypt, block128_f decrypt,
-                                  ocb128_f stream)
+    block128_f encrypt, block128_f decrypt,
+    ocb128_f stream)
 {
     OCB128_CONTEXT *octx;
     int ret;
 
     if ((octx = OPENSSL_malloc(sizeof(*octx))) != NULL) {
         ret = CRYPTO_ocb128_init(octx, keyenc, keydec, encrypt, decrypt,
-                                 stream);
+            stream);
         if (ret)
             return octx;
         OPENSSL_free(octx);
@@ -149,16 +149,14 @@ OCB128_CONTEXT *CRYPTO_ocb128_new(void *keyenc, void *keydec,
  * Initialise an existing OCB128_CONTEXT
  */
 int CRYPTO_ocb128_init(OCB128_CONTEXT *ctx, void *keyenc, void *keydec,
-                       block128_f encrypt, block128_f decrypt,
-                       ocb128_f stream)
+    block128_f encrypt, block128_f decrypt,
+    ocb128_f stream)
 {
     memset(ctx, 0, sizeof(*ctx));
     ctx->l_index = 0;
     ctx->max_l_index = 5;
-    if ((ctx->l = OPENSSL_malloc(ctx->max_l_index * 16)) == NULL) {
-        CRYPTOerr(CRYPTO_F_CRYPTO_OCB128_INIT, ERR_R_MALLOC_FAILURE);
+    if ((ctx->l = OPENSSL_malloc(ctx->max_l_index * 16)) == NULL)
         return 0;
-    }
 
     /*
      * We set both the encryption and decryption key schedules - decryption
@@ -181,11 +179,11 @@ int CRYPTO_ocb128_init(OCB128_CONTEXT *ctx, void *keyenc, void *keydec,
     ocb_double(&ctx->l_dollar, ctx->l);
 
     /* L_{i} = double(L_{i-1}) */
-    ocb_double(ctx->l, ctx->l+1);
-    ocb_double(ctx->l+1, ctx->l+2);
-    ocb_double(ctx->l+2, ctx->l+3);
-    ocb_double(ctx->l+3, ctx->l+4);
-    ctx->l_index = 4;   /* enough to process up to 496 bytes */
+    ocb_double(ctx->l, ctx->l + 1);
+    ocb_double(ctx->l + 1, ctx->l + 2);
+    ocb_double(ctx->l + 2, ctx->l + 3);
+    ocb_double(ctx->l + 3, ctx->l + 4);
+    ctx->l_index = 4; /* enough to process up to 496 bytes */
 
     return 1;
 }
@@ -194,7 +192,7 @@ int CRYPTO_ocb128_init(OCB128_CONTEXT *ctx, void *keyenc, void *keydec,
  * Copy an OCB128_CONTEXT object
  */
 int CRYPTO_ocb128_copy_ctx(OCB128_CONTEXT *dest, OCB128_CONTEXT *src,
-                           void *keyenc, void *keydec)
+    void *keyenc, void *keydec)
 {
     memcpy(dest, src, sizeof(OCB128_CONTEXT));
     if (keyenc)
@@ -202,10 +200,8 @@ int CRYPTO_ocb128_copy_ctx(OCB128_CONTEXT *dest, OCB128_CONTEXT *src,
     if (keydec)
         dest->keydec = keydec;
     if (src->l) {
-        if ((dest->l = OPENSSL_malloc(src->max_l_index * 16)) == NULL) {
-            CRYPTOerr(CRYPTO_F_CRYPTO_OCB128_COPY_CTX, ERR_R_MALLOC_FAILURE);
+        if ((dest->l = OPENSSL_malloc(src->max_l_index * 16)) == NULL)
             return 0;
-        }
         memcpy(dest->l, src->l, (src->l_index + 1) * 16);
     }
     return 1;
@@ -215,7 +211,7 @@ int CRYPTO_ocb128_copy_ctx(OCB128_CONTEXT *dest, OCB128_CONTEXT *src,
  * Set the IV to be used for this operation. Must be 1 - 15 bytes.
  */
 int CRYPTO_ocb128_setiv(OCB128_CONTEXT *ctx, const unsigned char *iv,
-                        size_t len, size_t taglen)
+    size_t len, size_t taglen)
 {
     unsigned char ktop[16], tmp[16], mask;
     unsigned char stretch[24], nonce[16];
@@ -255,8 +251,7 @@ int CRYPTO_ocb128_setiv(OCB128_CONTEXT *ctx, const unsigned char *iv,
     ocb_block_lshift(stretch + (bottom / 8), shift, ctx->sess.offset.c);
     mask = 0xff;
     mask <<= 8 - shift;
-    ctx->sess.offset.c[15] |=
-        (*(stretch + (bottom / 8) + 16) & mask) >> (8 - shift);
+    ctx->sess.offset.c[15] |= (*(stretch + (bottom / 8) + 16) & mask) >> (8 - shift);
 
     return 1;
 }
@@ -266,7 +261,7 @@ int CRYPTO_ocb128_setiv(OCB128_CONTEXT *ctx, const unsigned char *iv,
  * have a partial block
  */
 int CRYPTO_ocb128_aad(OCB128_CONTEXT *ctx, const unsigned char *aad,
-                      size_t len)
+    size_t len)
 {
     u64 i, all_num_blocks;
     size_t num_blocks, last_len;
@@ -304,7 +299,7 @@ int CRYPTO_ocb128_aad(OCB128_CONTEXT *ctx, const unsigned char *aad,
     if (last_len > 0) {
         /* Offset_* = Offset_m xor L_* */
         ocb_block16_xor(&ctx->sess.offset_aad, &ctx->l_star,
-                        &ctx->sess.offset_aad);
+            &ctx->sess.offset_aad);
 
         /* CipherInput = (A_* || 1 || zeros(127-bitlen(A_*))) xor Offset_* */
         memset(tmp.c, 0, 16);
@@ -327,8 +322,8 @@ int CRYPTO_ocb128_aad(OCB128_CONTEXT *ctx, const unsigned char *aad,
  * the final time can have a partial block
  */
 int CRYPTO_ocb128_encrypt(OCB128_CONTEXT *ctx,
-                          const unsigned char *in, unsigned char *out,
-                          size_t len)
+    const unsigned char *in, unsigned char *out,
+    size_t len)
 {
     u64 i, all_num_blocks;
     size_t num_blocks, last_len;
@@ -342,7 +337,7 @@ int CRYPTO_ocb128_encrypt(OCB128_CONTEXT *ctx,
 
     if (num_blocks && all_num_blocks == (size_t)all_num_blocks
         && ctx->stream != NULL) {
-        size_t max_idx = 0, top = (size_t)all_num_blocks;
+        size_t max_idx = 0, top = (size_t)all_num_blocks, processed_bytes = 0;
 
         /*
          * See how many L_{i} entries we need to process data at hand
@@ -354,8 +349,11 @@ int CRYPTO_ocb128_encrypt(OCB128_CONTEXT *ctx,
             return 0;
 
         ctx->stream(in, out, num_blocks, ctx->keyenc,
-                    (size_t)ctx->sess.blocks_processed + 1, ctx->sess.offset.c,
-                    (const unsigned char (*)[16])ctx->l, ctx->sess.checksum.c);
+            (size_t)ctx->sess.blocks_processed + 1, ctx->sess.offset.c,
+            (const unsigned char (*)[16])ctx->l, ctx->sess.checksum.c);
+        processed_bytes = num_blocks * 16;
+        in += processed_bytes;
+        out += processed_bytes;
     } else {
         /* Loop through all full blocks to be encrypted */
         for (i = ctx->sess.blocks_processed + 1; i <= all_num_blocks; i++) {
@@ -403,7 +401,7 @@ int CRYPTO_ocb128_encrypt(OCB128_CONTEXT *ctx,
         ocb_block_xor(in, pad.c, last_len, out);
 
         /* Checksum_* = Checksum_m xor (P_* || 1 || zeros(127-bitlen(P_*))) */
-        memset(pad.c, 0, 16);           /* borrow pad */
+        memset(pad.c, 0, 16); /* borrow pad */
         memcpy(pad.c, in, last_len);
         pad.c[last_len] = 0x80;
         ocb_block16_xor(&pad, &ctx->sess.checksum, &ctx->sess.checksum);
@@ -419,8 +417,8 @@ int CRYPTO_ocb128_encrypt(OCB128_CONTEXT *ctx,
  * the final time can have a partial block
  */
 int CRYPTO_ocb128_decrypt(OCB128_CONTEXT *ctx,
-                          const unsigned char *in, unsigned char *out,
-                          size_t len)
+    const unsigned char *in, unsigned char *out,
+    size_t len)
 {
     u64 i, all_num_blocks;
     size_t num_blocks, last_len;
@@ -434,7 +432,7 @@ int CRYPTO_ocb128_decrypt(OCB128_CONTEXT *ctx,
 
     if (num_blocks && all_num_blocks == (size_t)all_num_blocks
         && ctx->stream != NULL) {
-        size_t max_idx = 0, top = (size_t)all_num_blocks;
+        size_t max_idx = 0, top = (size_t)all_num_blocks, processed_bytes = 0;
 
         /*
          * See how many L_{i} entries we need to process data at hand
@@ -446,8 +444,11 @@ int CRYPTO_ocb128_decrypt(OCB128_CONTEXT *ctx,
             return 0;
 
         ctx->stream(in, out, num_blocks, ctx->keydec,
-                    (size_t)ctx->sess.blocks_processed + 1, ctx->sess.offset.c,
-                    (const unsigned char (*)[16])ctx->l, ctx->sess.checksum.c);
+            (size_t)ctx->sess.blocks_processed + 1, ctx->sess.offset.c,
+            (const unsigned char (*)[16])ctx->l, ctx->sess.checksum.c);
+        processed_bytes = num_blocks * 16;
+        in += processed_bytes;
+        out += processed_bytes;
     } else {
         OCB_BLOCK tmp;
 
@@ -495,7 +496,7 @@ int CRYPTO_ocb128_decrypt(OCB128_CONTEXT *ctx,
         ocb_block_xor(in, pad.c, last_len, out);
 
         /* Checksum_* = Checksum_m xor (P_* || 1 || zeros(127-bitlen(P_*))) */
-        memset(pad.c, 0, 16);           /* borrow pad */
+        memset(pad.c, 0, 16); /* borrow pad */
         memcpy(pad.c, out, last_len);
         pad.c[last_len] = 0x80;
         ocb_block16_xor(&pad, &ctx->sess.checksum, &ctx->sess.checksum);
@@ -507,7 +508,7 @@ int CRYPTO_ocb128_decrypt(OCB128_CONTEXT *ctx,
 }
 
 static int ocb_finish(OCB128_CONTEXT *ctx, unsigned char *tag, size_t len,
-                      int write)
+    int write)
 {
     OCB_BLOCK tmp;
 
@@ -535,9 +536,9 @@ static int ocb_finish(OCB128_CONTEXT *ctx, unsigned char *tag, size_t len,
  * Calculate the tag and verify it against the supplied tag
  */
 int CRYPTO_ocb128_finish(OCB128_CONTEXT *ctx, const unsigned char *tag,
-                         size_t len)
+    size_t len)
 {
-    return ocb_finish(ctx, (unsigned char*)tag, len, 0);
+    return ocb_finish(ctx, (unsigned char *)tag, len, 0);
 }
 
 /*
@@ -559,4 +560,4 @@ void CRYPTO_ocb128_cleanup(OCB128_CONTEXT *ctx)
     }
 }
 
-#endif                          /* OPENSSL_NO_OCB */
+#endif /* OPENSSL_NO_OCB */
