@@ -27,21 +27,18 @@ int OCSP_REQUEST_get_ext_count(OCSP_REQUEST *x)
 
 int OCSP_REQUEST_get_ext_by_NID(OCSP_REQUEST *x, int nid, int lastpos)
 {
-    return (X509v3_get_ext_by_NID
-            (x->tbsRequest.requestExtensions, nid, lastpos));
+    return (X509v3_get_ext_by_NID(x->tbsRequest.requestExtensions, nid, lastpos));
 }
 
 int OCSP_REQUEST_get_ext_by_OBJ(OCSP_REQUEST *x, const ASN1_OBJECT *obj,
-                                int lastpos)
+    int lastpos)
 {
-    return (X509v3_get_ext_by_OBJ
-            (x->tbsRequest.requestExtensions, obj, lastpos));
+    return (X509v3_get_ext_by_OBJ(x->tbsRequest.requestExtensions, obj, lastpos));
 }
 
 int OCSP_REQUEST_get_ext_by_critical(OCSP_REQUEST *x, int crit, int lastpos)
 {
-    return (X509v3_get_ext_by_critical
-            (x->tbsRequest.requestExtensions, crit, lastpos));
+    return (X509v3_get_ext_by_critical(x->tbsRequest.requestExtensions, crit, lastpos));
 }
 
 X509_EXTENSION *OCSP_REQUEST_get_ext(OCSP_REQUEST *x, int loc)
@@ -60,16 +57,15 @@ void *OCSP_REQUEST_get1_ext_d2i(OCSP_REQUEST *x, int nid, int *crit, int *idx)
 }
 
 int OCSP_REQUEST_add1_ext_i2d(OCSP_REQUEST *x, int nid, void *value, int crit,
-                              unsigned long flags)
+    unsigned long flags)
 {
     return X509V3_add1_i2d(&x->tbsRequest.requestExtensions, nid, value,
-                           crit, flags);
+        crit, flags);
 }
 
 int OCSP_REQUEST_add_ext(OCSP_REQUEST *x, X509_EXTENSION *ex, int loc)
 {
-    return (X509v3_add_ext(&(x->tbsRequest.requestExtensions), ex, loc) !=
-            NULL);
+    return (X509v3_add_ext(&(x->tbsRequest.requestExtensions), ex, loc) != NULL);
 }
 
 /* Single extensions */
@@ -85,15 +81,14 @@ int OCSP_ONEREQ_get_ext_by_NID(OCSP_ONEREQ *x, int nid, int lastpos)
 }
 
 int OCSP_ONEREQ_get_ext_by_OBJ(OCSP_ONEREQ *x, const ASN1_OBJECT *obj,
-                               int lastpos)
+    int lastpos)
 {
     return X509v3_get_ext_by_OBJ(x->singleRequestExtensions, obj, lastpos);
 }
 
 int OCSP_ONEREQ_get_ext_by_critical(OCSP_ONEREQ *x, int crit, int lastpos)
 {
-    return (X509v3_get_ext_by_critical
-            (x->singleRequestExtensions, crit, lastpos));
+    return (X509v3_get_ext_by_critical(x->singleRequestExtensions, crit, lastpos));
 }
 
 X509_EXTENSION *OCSP_ONEREQ_get_ext(OCSP_ONEREQ *x, int loc)
@@ -112,10 +107,10 @@ void *OCSP_ONEREQ_get1_ext_d2i(OCSP_ONEREQ *x, int nid, int *crit, int *idx)
 }
 
 int OCSP_ONEREQ_add1_ext_i2d(OCSP_ONEREQ *x, int nid, void *value, int crit,
-                             unsigned long flags)
+    unsigned long flags)
 {
     return X509V3_add1_i2d(&x->singleRequestExtensions, nid, value, crit,
-                           flags);
+        flags);
 }
 
 int OCSP_ONEREQ_add_ext(OCSP_ONEREQ *x, X509_EXTENSION *ex, int loc)
@@ -132,22 +127,19 @@ int OCSP_BASICRESP_get_ext_count(OCSP_BASICRESP *x)
 
 int OCSP_BASICRESP_get_ext_by_NID(OCSP_BASICRESP *x, int nid, int lastpos)
 {
-    return (X509v3_get_ext_by_NID
-            (x->tbsResponseData.responseExtensions, nid, lastpos));
+    return (X509v3_get_ext_by_NID(x->tbsResponseData.responseExtensions, nid, lastpos));
 }
 
 int OCSP_BASICRESP_get_ext_by_OBJ(OCSP_BASICRESP *x, const ASN1_OBJECT *obj,
-                                  int lastpos)
+    int lastpos)
 {
-    return (X509v3_get_ext_by_OBJ
-            (x->tbsResponseData.responseExtensions, obj, lastpos));
+    return (X509v3_get_ext_by_OBJ(x->tbsResponseData.responseExtensions, obj, lastpos));
 }
 
 int OCSP_BASICRESP_get_ext_by_critical(OCSP_BASICRESP *x, int crit,
-                                       int lastpos)
+    int lastpos)
 {
-    return (X509v3_get_ext_by_critical
-            (x->tbsResponseData.responseExtensions, crit, lastpos));
+    return (X509v3_get_ext_by_critical(x->tbsResponseData.responseExtensions, crit, lastpos));
 }
 
 X509_EXTENSION *OCSP_BASICRESP_get_ext(OCSP_BASICRESP *x, int loc)
@@ -161,23 +153,23 @@ X509_EXTENSION *OCSP_BASICRESP_delete_ext(OCSP_BASICRESP *x, int loc)
 }
 
 void *OCSP_BASICRESP_get1_ext_d2i(OCSP_BASICRESP *x, int nid, int *crit,
-                                  int *idx)
+    int *idx)
 {
     return X509V3_get_d2i(x->tbsResponseData.responseExtensions, nid, crit,
-                          idx);
+        idx);
 }
 
 int OCSP_BASICRESP_add1_ext_i2d(OCSP_BASICRESP *x, int nid, void *value,
-                                int crit, unsigned long flags)
+    int crit, unsigned long flags)
 {
     return X509V3_add1_i2d(&x->tbsResponseData.responseExtensions, nid,
-                           value, crit, flags);
+        value, crit, flags);
 }
 
 int OCSP_BASICRESP_add_ext(OCSP_BASICRESP *x, X509_EXTENSION *ex, int loc)
 {
     return (X509v3_add_ext(&(x->tbsResponseData.responseExtensions), ex, loc)
-            != NULL);
+        != NULL);
 }
 
 /* OCSP single response extensions */
@@ -193,13 +185,13 @@ int OCSP_SINGLERESP_get_ext_by_NID(OCSP_SINGLERESP *x, int nid, int lastpos)
 }
 
 int OCSP_SINGLERESP_get_ext_by_OBJ(OCSP_SINGLERESP *x, const ASN1_OBJECT *obj,
-                                   int lastpos)
+    int lastpos)
 {
     return X509v3_get_ext_by_OBJ(x->singleExtensions, obj, lastpos);
 }
 
 int OCSP_SINGLERESP_get_ext_by_critical(OCSP_SINGLERESP *x, int crit,
-                                        int lastpos)
+    int lastpos)
 {
     return X509v3_get_ext_by_critical(x->singleExtensions, crit, lastpos);
 }
@@ -215,13 +207,13 @@ X509_EXTENSION *OCSP_SINGLERESP_delete_ext(OCSP_SINGLERESP *x, int loc)
 }
 
 void *OCSP_SINGLERESP_get1_ext_d2i(OCSP_SINGLERESP *x, int nid, int *crit,
-                                   int *idx)
+    int *idx)
 {
     return X509V3_get_d2i(x->singleExtensions, nid, crit, idx);
 }
 
 int OCSP_SINGLERESP_add1_ext_i2d(OCSP_SINGLERESP *x, int nid, void *value,
-                                 int crit, unsigned long flags)
+    int crit, unsigned long flags)
 {
     return X509V3_add1_i2d(&x->singleExtensions, nid, value, crit, flags);
 }
@@ -242,7 +234,7 @@ int OCSP_SINGLERESP_add_ext(OCSP_SINGLERESP *x, X509_EXTENSION *ex, int loc)
  */
 
 static int ocsp_add1_nonce(STACK_OF(X509_EXTENSION) **exts,
-                           unsigned char *val, int len)
+    unsigned char *val, int len)
 {
     unsigned char *tmpval;
     ASN1_OCTET_STRING os;
@@ -269,10 +261,11 @@ static int ocsp_add1_nonce(STACK_OF(X509_EXTENSION) **exts,
     else if (RAND_bytes(tmpval, len) <= 0)
         goto err;
     if (X509V3_add1_i2d(exts, NID_id_pkix_OCSP_Nonce,
-                         &os, 0, X509V3_ADD_REPLACE) <= 0)
+            &os, 0, X509V3_ADD_REPLACE)
+        <= 0)
         goto err;
     ret = 1;
- err:
+err:
     OPENSSL_free(os.data);
     return ret;
 }
@@ -289,7 +282,7 @@ int OCSP_request_add1_nonce(OCSP_REQUEST *req, unsigned char *val, int len)
 int OCSP_basic_add1_nonce(OCSP_BASICRESP *resp, unsigned char *val, int len)
 {
     return ocsp_add1_nonce(&resp->tbsResponseData.responseExtensions, val,
-                           len);
+        len);
 }
 
 /*-
@@ -335,7 +328,7 @@ int OCSP_check_nonce(OCSP_REQUEST *req, OCSP_BASICRESP *bs)
     req_ext = OCSP_REQUEST_get_ext(req, req_idx);
     resp_ext = OCSP_BASICRESP_get_ext(bs, resp_idx);
     if (ASN1_OCTET_STRING_cmp(X509_EXTENSION_get_data(req_ext),
-                              X509_EXTENSION_get_data(resp_ext)))
+            X509_EXTENSION_get_data(resp_ext)))
         return 0;
     return 1;
 }
@@ -383,7 +376,7 @@ X509_EXTENSION *OCSP_crlID_new(const char *url, long *n, char *tim)
             goto err;
     }
     x = X509V3_EXT_i2d(NID_id_pkix_OCSP_CrlID, 0, cid);
- err:
+err:
     OCSP_CRLID_free(cid);
     return x;
 }
@@ -405,7 +398,7 @@ X509_EXTENSION *OCSP_accept_responses_new(char **oids)
         oids++;
     }
     x = X509V3_EXT_i2d(NID_id_pkix_OCSP_acceptableResponses, 0, sk);
- err:
+err:
     sk_ASN1_OBJECT_pop_free(sk, ASN1_OBJECT_free);
     return x;
 }
@@ -421,7 +414,7 @@ X509_EXTENSION *OCSP_archive_cutoff_new(char *tim)
     if (!(ASN1_GENERALIZEDTIME_set_string(gt, tim)))
         goto err;
     x = X509V3_EXT_i2d(NID_id_pkix_OCSP_archiveCutoff, 0, gt);
- err:
+err:
     ASN1_GENERALIZEDTIME_free(gt);
     return x;
 }
@@ -465,7 +458,7 @@ X509_EXTENSION *OCSP_url_svcloc_new(const X509_NAME *issuer, const char **urls)
         urls++;
     }
     x = X509V3_EXT_i2d(NID_id_pkix_OCSP_serviceLocator, 0, sloc);
- err:
+err:
     ASN1_IA5STRING_free(ia5);
     ACCESS_DESCRIPTION_free(ad);
     OCSP_SERVICELOC_free(sloc);
