@@ -42,10 +42,8 @@ int ossl_pw_set_passphrase(struct ossl_passphrase_data_st *data,
     data->type = is_expl_passphrase;
     data->_.expl_passphrase.passphrase_copy = passphrase_len != 0 ? OPENSSL_memdup(passphrase, passphrase_len)
                                                                   : OPENSSL_malloc(1);
-    if (data->_.expl_passphrase.passphrase_copy == NULL) {
-        ERR_raise(ERR_LIB_CRYPTO, ERR_R_MALLOC_FAILURE);
+    if (data->_.expl_passphrase.passphrase_copy == NULL)
         return 0;
-    }
     data->_.expl_passphrase.passphrase_len = passphrase_len;
     return 1;
 }
@@ -128,7 +126,7 @@ static int do_ui_passphrase(char *pass, size_t pass_size, size_t *pass_len,
     }
 
     if ((ui = UI_new()) == NULL) {
-        ERR_raise(ERR_LIB_CRYPTO, ERR_R_MALLOC_FAILURE);
+        ERR_raise(ERR_LIB_CRYPTO, ERR_R_UI_LIB);
         return 0;
     }
 
@@ -141,16 +139,14 @@ static int do_ui_passphrase(char *pass, size_t pass_size, size_t *pass_len,
     /* Get an application constructed prompt */
     prompt = UI_construct_prompt(ui, "pass phrase", prompt_info);
     if (prompt == NULL) {
-        ERR_raise(ERR_LIB_CRYPTO, ERR_R_MALLOC_FAILURE);
+        ERR_raise(ERR_LIB_CRYPTO, ERR_R_UI_LIB);
         goto end;
     }
 
     /* Get a buffer for verification prompt */
     ipass = OPENSSL_zalloc(pass_size + 1);
-    if (ipass == NULL) {
-        ERR_raise(ERR_LIB_CRYPTO, ERR_R_MALLOC_FAILURE);
+    if (ipass == NULL)
         goto end;
-    }
 
     prompt_idx = UI_add_input_string(ui, prompt,
                      UI_INPUT_FLAG_DEFAULT_PWD,
@@ -164,10 +160,8 @@ static int do_ui_passphrase(char *pass, size_t pass_size, size_t *pass_len,
     if (verify) {
         /* Get a buffer for verification prompt */
         vpass = OPENSSL_zalloc(pass_size + 1);
-        if (vpass == NULL) {
-            ERR_raise(ERR_LIB_CRYPTO, ERR_R_MALLOC_FAILURE);
+        if (vpass == NULL)
             goto end;
-        }
         verify_idx = UI_add_verify_string(ui, prompt,
                          UI_INPUT_FLAG_DEFAULT_PWD,
                          vpass, 0, pass_size,
@@ -269,7 +263,7 @@ int ossl_pw_get_passphrase(char *pass, size_t pass_size, size_t *pass_len,
         ui_data = data->_.pem_password.password_cbarg;
 
         if (ui_method == NULL) {
-            ERR_raise(ERR_LIB_CRYPTO, ERR_R_MALLOC_FAILURE);
+            ERR_raise(ERR_LIB_CRYPTO, ERR_R_UI_LIB);
             return 0;
         }
     } else if (data->type == is_ui_method) {
@@ -298,7 +292,6 @@ do_cache:
 
             if (new_cache == NULL) {
                 OPENSSL_cleanse(pass, *pass_len);
-                ERR_raise(ERR_LIB_CRYPTO, ERR_R_MALLOC_FAILURE);
                 return 0;
             }
             data->cached_passphrase = new_cache;
