@@ -27,7 +27,7 @@
 #ifndef OPENSSL_NO_STDIO
 STACK_OF(X509_INFO)
 *PEM_X509_INFO_read_ex(FILE *fp, STACK_OF(X509_INFO) *sk, pem_password_cb *cb,
-                       void *u, OSSL_LIB_CTX *libctx, const char *propq)
+    void *u, OSSL_LIB_CTX *libctx, const char *propq)
 {
     BIO *b;
     STACK_OF(X509_INFO) *ret;
@@ -43,16 +43,16 @@ STACK_OF(X509_INFO)
 }
 
 STACK_OF(X509_INFO) *PEM_X509_INFO_read(FILE *fp, STACK_OF(X509_INFO) *sk,
-                                        pem_password_cb *cb, void *u)
+    pem_password_cb *cb, void *u)
 {
     return PEM_X509_INFO_read_ex(fp, sk, cb, u, NULL, NULL);
 }
 #endif
 
 STACK_OF(X509_INFO) *PEM_X509_INFO_read_bio_ex(BIO *bp, STACK_OF(X509_INFO) *sk,
-                                               pem_password_cb *cb, void *u,
-                                               OSSL_LIB_CTX *libctx,
-                                               const char *propq)
+    pem_password_cb *cb, void *u,
+    OSSL_LIB_CTX *libctx,
+    const char *propq)
 {
     X509_INFO *xi = NULL;
     char *name = NULL, *header = NULL, *str;
@@ -67,7 +67,7 @@ STACK_OF(X509_INFO) *PEM_X509_INFO_read_bio_ex(BIO *bp, STACK_OF(X509_INFO) *sk,
 
     if (sk == NULL) {
         if ((ret = sk_X509_INFO_new_null()) == NULL) {
-            ERR_raise(ERR_LIB_PEM, ERR_R_MALLOC_FAILURE);
+            ERR_raise(ERR_LIB_PEM, ERR_R_CRYPTO_LIB);
             goto err;
         }
     } else
@@ -90,10 +90,10 @@ STACK_OF(X509_INFO) *PEM_X509_INFO_read_bio_ex(BIO *bp, STACK_OF(X509_INFO) *sk,
             goto err;
         }
         ERR_clear_last_mark();
- start:
+    start:
         if (strcmp(name, PEM_STRING_X509) == 0
-                || strcmp(name, PEM_STRING_X509_OLD) == 0
-                || strcmp(name, PEM_STRING_X509_TRUSTED) == 0) {
+            || strcmp(name, PEM_STRING_X509_OLD) == 0
+            || strcmp(name, PEM_STRING_X509_TRUSTED) == 0) {
             if (xi->x509 != NULL) {
                 if (!sk_X509_INFO_push(ret, xi))
                     goto err;
@@ -102,15 +102,15 @@ STACK_OF(X509_INFO) *PEM_X509_INFO_read_bio_ex(BIO *bp, STACK_OF(X509_INFO) *sk,
                 goto start;
             }
             if ((strcmp(name, PEM_STRING_X509_TRUSTED) == 0))
-                d2i = (D2I_OF(void)) d2i_X509_AUX;
+                d2i = (D2I_OF(void))d2i_X509_AUX;
             else
-                d2i = (D2I_OF(void)) d2i_X509;
+                d2i = (D2I_OF(void))d2i_X509;
             xi->x509 = X509_new_ex(libctx, propq);
             if (xi->x509 == NULL)
                 goto err;
             pp = &(xi->x509);
         } else if (strcmp(name, PEM_STRING_X509_CRL) == 0) {
-            d2i = (D2I_OF(void)) d2i_X509_CRL;
+            d2i = (D2I_OF(void))d2i_X509_CRL;
             if (xi->crl != NULL) {
                 if (!sk_X509_INFO_push(ret, xi))
                     goto err;
@@ -137,13 +137,13 @@ STACK_OF(X509_INFO) *PEM_X509_INFO_read_bio_ex(BIO *bp, STACK_OF(X509_INFO) *sk,
             xi->enc_data = NULL;
             xi->enc_len = 0;
 
-            d2i = (D2I_OF(void)) d2i_AutoPrivateKey;
+            d2i = (D2I_OF(void))d2i_AutoPrivateKey;
             xi->x_pkey = X509_PKEY_new();
             if (xi->x_pkey == NULL)
                 goto err;
             pp = &xi->x_pkey->dec_pkey;
             if ((int)strlen(header) > 10 /* assume encrypted */
-                   || strcmp(name, PEM_STRING_PKCS8) == 0)
+                || strcmp(name, PEM_STRING_PKCS8) == 0)
                 raw = 1;
         } else { /* unknown */
             d2i = NULL;
@@ -161,7 +161,8 @@ STACK_OF(X509_INFO) *PEM_X509_INFO_read_bio_ex(BIO *bp, STACK_OF(X509_INFO) *sk,
                 p = data;
                 if (ptype) {
                     if (d2i_PrivateKey_ex(ptype, pp, &p, len,
-                                          libctx, propq) == NULL) {
+                            libctx, propq)
+                        == NULL) {
                         ERR_raise(ERR_LIB_PEM, ERR_R_ASN1_LIB);
                         goto err;
                     }
@@ -169,7 +170,7 @@ STACK_OF(X509_INFO) *PEM_X509_INFO_read_bio_ex(BIO *bp, STACK_OF(X509_INFO) *sk,
                     ERR_raise(ERR_LIB_PEM, ERR_R_ASN1_LIB);
                     goto err;
                 }
-            } else {            /* encrypted key data */
+            } else { /* encrypted key data */
                 if (!PEM_get_EVP_CIPHER_INFO(header, &xi->enc_cipher))
                     goto err;
                 xi->enc_data = (char *)data;
@@ -189,14 +190,13 @@ STACK_OF(X509_INFO) *PEM_X509_INFO_read_bio_ex(BIO *bp, STACK_OF(X509_INFO) *sk,
      * if the last one hasn't been pushed yet and there is anything in it
      * then add it to the stack ...
      */
-    if ((xi->x509 != NULL) || (xi->crl != NULL) ||
-        (xi->x_pkey != NULL) || (xi->enc_data != NULL)) {
+    if ((xi->x509 != NULL) || (xi->crl != NULL) || (xi->x_pkey != NULL) || (xi->enc_data != NULL)) {
         if (!sk_X509_INFO_push(ret, xi))
             goto err;
         xi = NULL;
     }
     ok = 1;
- err:
+err:
     X509_INFO_free(xi);
     if (!ok) {
         for (i = 0; ((int)i) < sk_X509_INFO_num(ret); i++) {
@@ -215,15 +215,15 @@ STACK_OF(X509_INFO) *PEM_X509_INFO_read_bio_ex(BIO *bp, STACK_OF(X509_INFO) *sk,
 }
 
 STACK_OF(X509_INFO) *PEM_X509_INFO_read_bio(BIO *bp, STACK_OF(X509_INFO) *sk,
-                                            pem_password_cb *cb, void *u)
+    pem_password_cb *cb, void *u)
 {
     return PEM_X509_INFO_read_bio_ex(bp, sk, cb, u, NULL, NULL);
 }
 
 /* A TJH addition */
 int PEM_X509_INFO_write_bio(BIO *bp, const X509_INFO *xi, EVP_CIPHER *enc,
-                            const unsigned char *kstr, int klen,
-                            pem_password_cb *cb, void *u)
+    const unsigned char *kstr, int klen,
+    pem_password_cb *cb, void *u)
 {
     int i, ret = 0;
     unsigned char *data = NULL;
@@ -234,12 +234,12 @@ int PEM_X509_INFO_write_bio(BIO *bp, const X509_INFO *xi, EVP_CIPHER *enc,
     if (enc != NULL) {
         objstr = EVP_CIPHER_get0_name(enc);
         if (objstr == NULL
-               /*
-                * Check "Proc-Type: 4,Encrypted\nDEK-Info: objstr,hex-iv\n"
-                * fits into buf
-                */
+            /*
+             * Check "Proc-Type: 4,Encrypted\nDEK-Info: objstr,hex-iv\n"
+             * fits into buf
+             */
             || strlen(objstr) + 23 + 2 * EVP_CIPHER_get_iv_length(enc) + 13
-               > sizeof(buf)) {
+                > sizeof(buf)) {
             ERR_raise(ERR_LIB_PEM, PEM_R_UNSUPPORTED_CIPHER);
             goto err;
         }
@@ -277,7 +277,7 @@ int PEM_X509_INFO_write_bio(BIO *bp, const X509_INFO *xi, EVP_CIPHER *enc,
             buf[0] = '\0';
             PEM_proc_type(buf, PEM_TYPE_ENCRYPTED);
             PEM_dek_info(buf, objstr, EVP_CIPHER_get_iv_length(enc),
-                         (const char *)iv);
+                (const char *)iv);
 
             /* use the normal code to write things out */
             i = PEM_write_bio(bp, PEM_STRING_RSA, buf, data, i);
@@ -287,8 +287,9 @@ int PEM_X509_INFO_write_bio(BIO *bp, const X509_INFO *xi, EVP_CIPHER *enc,
             /* Add DSA/DH */
             /* normal optionally encrypted stuff */
             if (PEM_write_bio_RSAPrivateKey(bp,
-                                            EVP_PKEY_get0_RSA(xi->x_pkey->dec_pkey),
-                                            enc, kstr, klen, cb, u) <= 0)
+                    EVP_PKEY_get0_RSA(xi->x_pkey->dec_pkey),
+                    enc, kstr, klen, cb, u)
+                <= 0)
                 goto err;
         }
     }
@@ -305,7 +306,7 @@ int PEM_X509_INFO_write_bio(BIO *bp, const X509_INFO *xi, EVP_CIPHER *enc,
 
     ret = 1;
 
- err:
+err:
     OPENSSL_cleanse(buf, PEM_BUFSIZE);
     return ret;
 }
