@@ -13,15 +13,15 @@
 #include "p12_local.h"
 
 static int pkcs12_add_bag(STACK_OF(PKCS12_SAFEBAG) **pbags,
-                          PKCS12_SAFEBAG *bag);
+    PKCS12_SAFEBAG *bag);
 static int pkcs12_remove_bag(STACK_OF(PKCS12_SAFEBAG) **pbags,
-                             PKCS12_SAFEBAG *bag);
+    PKCS12_SAFEBAG *bag);
 static PKCS12_SAFEBAG *pkcs12_add_cert_bag(STACK_OF(PKCS12_SAFEBAG) **pbags,
-                                           X509 *cert,
-                                           const char *name,
-                                           int namelen,
-                                           unsigned char *keyid,
-                                           int keyidlen);
+    X509 *cert,
+    const char *name,
+    int namelen,
+    unsigned char *keyid,
+    int keyidlen);
 
 static int copy_bag_attr(PKCS12_SAFEBAG *bag, EVP_PKEY *pkey, int nid)
 {
@@ -33,10 +33,10 @@ static int copy_bag_attr(PKCS12_SAFEBAG *bag, EVP_PKEY *pkey, int nid)
 }
 
 PKCS12 *PKCS12_create_ex2(const char *pass, const char *name, EVP_PKEY *pkey,
-                          X509 *cert, STACK_OF(X509) *ca, int nid_key, int nid_cert,
-                          int iter, int mac_iter, int keytype,
-                          OSSL_LIB_CTX *ctx, const char *propq,
-                          PKCS12_create_cb *cb, void *cbarg)
+    X509 *cert, STACK_OF(X509) *ca, int nid_key, int nid_cert,
+    int iter, int mac_iter, int keytype,
+    OSSL_LIB_CTX *ctx, const char *propq,
+    PKCS12_create_cb *cb, void *cbarg)
 {
     PKCS12 *p12 = NULL;
     STACK_OF(PKCS7) *safes = NULL;
@@ -84,7 +84,7 @@ PKCS12 *PKCS12_create_ex2(const char *pass, const char *name, EVP_PKEY *pkey,
         bag = pkcs12_add_cert_bag(&bags, cert, name, namelen, pkeyid, pkeyidlen);
         if (cb != NULL) {
             cbret = cb(bag, cbarg);
-            if (cbret  == -1) {
+            if (cbret == -1) {
                 ERR_raise(ERR_LIB_PKCS12, PKCS12_R_CALLBACK_FAILED);
                 goto err;
             } else if (cbret == 0) {
@@ -99,7 +99,7 @@ PKCS12 *PKCS12_create_ex2(const char *pass, const char *name, EVP_PKEY *pkey,
             goto err;
         if (cb != NULL) {
             cbret = cb(bag, cbarg);
-            if (cbret  == -1) {
+            if (cbret == -1) {
                 ERR_raise(ERR_LIB_PKCS12, PKCS12_R_CALLBACK_FAILED);
                 goto err;
             } else if (cbret == 0) {
@@ -108,8 +108,7 @@ PKCS12 *PKCS12_create_ex2(const char *pass, const char *name, EVP_PKEY *pkey,
         }
     }
 
-    if (bags && !PKCS12_add_safe_ex(&safes, bags, nid_cert, iter, pass,
-                                    ctx, propq))
+    if (bags && !PKCS12_add_safe_ex(&safes, bags, nid_cert, iter, pass, ctx, propq))
         goto err;
 
     sk_PKCS12_SAFEBAG_pop_free(bags, PKCS12_SAFEBAG_free);
@@ -117,7 +116,7 @@ PKCS12 *PKCS12_create_ex2(const char *pass, const char *name, EVP_PKEY *pkey,
 
     if (pkey) {
         bag = PKCS12_add_key_ex(&bags, pkey, keytype, iter, nid_key, pass,
-                                ctx, propq);
+            ctx, propq);
 
         if (!bag)
             goto err;
@@ -133,7 +132,7 @@ PKCS12 *PKCS12_create_ex2(const char *pass, const char *name, EVP_PKEY *pkey,
             goto err;
         if (cb != NULL) {
             cbret = cb(bag, cbarg);
-            if (cbret  == -1) {
+            if (cbret == -1) {
                 ERR_raise(ERR_LIB_PKCS12, PKCS12_R_CALLBACK_FAILED);
                 goto err;
             } else if (cbret == 0) {
@@ -157,44 +156,42 @@ PKCS12 *PKCS12_create_ex2(const char *pass, const char *name, EVP_PKEY *pkey,
 
     safes = NULL;
 
-    if ((mac_iter != -1) &&
-        !PKCS12_set_mac(p12, pass, -1, NULL, 0, mac_iter, NULL))
+    if ((mac_iter != -1) && !PKCS12_set_mac(p12, pass, -1, NULL, 0, mac_iter, NULL))
         goto err;
 
     return p12;
 
- err:
+err:
     PKCS12_free(p12);
     sk_PKCS7_pop_free(safes, PKCS7_free);
     sk_PKCS12_SAFEBAG_pop_free(bags, PKCS12_SAFEBAG_free);
     return NULL;
-
 }
 
 PKCS12 *PKCS12_create_ex(const char *pass, const char *name, EVP_PKEY *pkey, X509 *cert,
-                        STACK_OF(X509) *ca, int nid_key, int nid_cert, int iter,
-                        int mac_iter, int keytype,
-                        OSSL_LIB_CTX *ctx, const char *propq)
+    STACK_OF(X509) *ca, int nid_key, int nid_cert, int iter,
+    int mac_iter, int keytype,
+    OSSL_LIB_CTX *ctx, const char *propq)
 {
     return PKCS12_create_ex2(pass, name, pkey, cert, ca, nid_key, nid_cert,
-                             iter, mac_iter, keytype, ctx, propq,
-                             NULL, NULL);
+        iter, mac_iter, keytype, ctx, propq,
+        NULL, NULL);
 }
 
 PKCS12 *PKCS12_create(const char *pass, const char *name, EVP_PKEY *pkey, X509 *cert,
-                      STACK_OF(X509) *ca, int nid_key, int nid_cert, int iter,
-                      int mac_iter, int keytype)
+    STACK_OF(X509) *ca, int nid_key, int nid_cert, int iter,
+    int mac_iter, int keytype)
 {
     return PKCS12_create_ex(pass, name, pkey, cert, ca, nid_key, nid_cert,
-                            iter, mac_iter, keytype, NULL, NULL);
+        iter, mac_iter, keytype, NULL, NULL);
 }
 
 static PKCS12_SAFEBAG *pkcs12_add_cert_bag(STACK_OF(PKCS12_SAFEBAG) **pbags,
-                                           X509 *cert,
-                                           const char *name,
-                                           int namelen,
-                                           unsigned char *keyid,
-                                           int keyidlen)
+    X509 *cert,
+    const char *name,
+    int namelen,
+    unsigned char *keyid,
+    int keyidlen)
 {
     PKCS12_SAFEBAG *bag = NULL;
 
@@ -213,7 +210,7 @@ static PKCS12_SAFEBAG *pkcs12_add_cert_bag(STACK_OF(PKCS12_SAFEBAG) **pbags,
 
     return bag;
 
- err:
+err:
     PKCS12_SAFEBAG_free(bag);
     return NULL;
 }
@@ -235,9 +232,9 @@ PKCS12_SAFEBAG *PKCS12_add_cert(STACK_OF(PKCS12_SAFEBAG) **pbags, X509 *cert)
 }
 
 PKCS12_SAFEBAG *PKCS12_add_key_ex(STACK_OF(PKCS12_SAFEBAG) **pbags,
-                                  EVP_PKEY *key, int key_usage, int iter,
-                                  int nid_key, const char *pass,
-                                  OSSL_LIB_CTX *ctx, const char *propq)
+    EVP_PKEY *key, int key_usage, int iter,
+    int nid_key, const char *pass,
+    OSSL_LIB_CTX *ctx, const char *propq)
 {
 
     PKCS12_SAFEBAG *bag = NULL;
@@ -253,11 +250,11 @@ PKCS12_SAFEBAG *PKCS12_add_key_ex(STACK_OF(PKCS12_SAFEBAG) **pbags,
     if (nid_key != -1) {
         /* This call does not take ownership of p8 */
         bag = PKCS12_SAFEBAG_create_pkcs8_encrypt_ex(nid_key, pass, -1, NULL, 0,
-                                                     iter, p8, ctx, propq);
+            iter, p8, ctx, propq);
     } else {
         bag = PKCS12_SAFEBAG_create0_p8inf(p8);
         if (bag != NULL)
-           p8 = NULL; /* bag takes ownership of p8 */
+            p8 = NULL; /* bag takes ownership of p8 */
     }
     /* This does not need to be in the error path */
     if (p8 != NULL)
@@ -268,22 +265,21 @@ PKCS12_SAFEBAG *PKCS12_add_key_ex(STACK_OF(PKCS12_SAFEBAG) **pbags,
 
     return bag;
 
- err:
+err:
     PKCS12_SAFEBAG_free(bag);
     return NULL;
-
 }
 
 PKCS12_SAFEBAG *PKCS12_add_key(STACK_OF(PKCS12_SAFEBAG) **pbags,
-                               EVP_PKEY *key, int key_usage, int iter,
-                               int nid_key, const char *pass)
+    EVP_PKEY *key, int key_usage, int iter,
+    int nid_key, const char *pass)
 {
     return PKCS12_add_key_ex(pbags, key, key_usage, iter, nid_key, pass,
-                             NULL, NULL);
+        NULL, NULL);
 }
 
-PKCS12_SAFEBAG *PKCS12_add_secret(STACK_OF(PKCS12_SAFEBAG) **pbags, 
-                                  int nid_type, const unsigned char *value, int len)
+PKCS12_SAFEBAG *PKCS12_add_secret(STACK_OF(PKCS12_SAFEBAG) **pbags,
+    int nid_type, const unsigned char *value, int len)
 {
     PKCS12_SAFEBAG *bag = NULL;
 
@@ -295,14 +291,14 @@ PKCS12_SAFEBAG *PKCS12_add_secret(STACK_OF(PKCS12_SAFEBAG) **pbags,
         goto err;
 
     return bag;
- err:
+err:
     PKCS12_SAFEBAG_free(bag);
     return NULL;
 }
 
 int PKCS12_add_safe_ex(STACK_OF(PKCS7) **psafes, STACK_OF(PKCS12_SAFEBAG) *bags,
-                       int nid_safe, int iter, const char *pass,
-                       OSSL_LIB_CTX *ctx, const char *propq)
+    int nid_safe, int iter, const char *pass,
+    OSSL_LIB_CTX *ctx, const char *propq)
 {
     PKCS7 *p7 = NULL;
     int free_safes = 0;
@@ -333,7 +329,7 @@ int PKCS12_add_safe_ex(STACK_OF(PKCS7) **psafes, STACK_OF(PKCS12_SAFEBAG) *bags,
 
     return 1;
 
- err:
+err:
     if (free_safes) {
         sk_PKCS7_free(*psafes);
         *psafes = NULL;
@@ -343,14 +339,13 @@ int PKCS12_add_safe_ex(STACK_OF(PKCS7) **psafes, STACK_OF(PKCS12_SAFEBAG) *bags,
 }
 
 int PKCS12_add_safe(STACK_OF(PKCS7) **psafes, STACK_OF(PKCS12_SAFEBAG) *bags,
-                    int nid_safe, int iter, const char *pass)
+    int nid_safe, int iter, const char *pass)
 {
     return PKCS12_add_safe_ex(psafes, bags, nid_safe, iter, pass, NULL, NULL);
 }
 
-
 static int pkcs12_remove_bag(STACK_OF(PKCS12_SAFEBAG) **pbags,
-                             PKCS12_SAFEBAG *bag)
+    PKCS12_SAFEBAG *bag)
 {
     PKCS12_SAFEBAG *tmp;
 
@@ -365,7 +360,7 @@ static int pkcs12_remove_bag(STACK_OF(PKCS12_SAFEBAG) **pbags,
 }
 
 static int pkcs12_add_bag(STACK_OF(PKCS12_SAFEBAG) **pbags,
-                          PKCS12_SAFEBAG *bag)
+    PKCS12_SAFEBAG *bag)
 {
     int free_bags = 0;
 
@@ -387,11 +382,10 @@ static int pkcs12_add_bag(STACK_OF(PKCS12_SAFEBAG) **pbags,
     }
 
     return 1;
-
 }
 
 PKCS12 *PKCS12_add_safes_ex(STACK_OF(PKCS7) *safes, int nid_p7,
-                            OSSL_LIB_CTX *ctx, const char *propq)
+    OSSL_LIB_CTX *ctx, const char *propq)
 {
     PKCS12 *p12;
 
@@ -407,7 +401,6 @@ PKCS12 *PKCS12_add_safes_ex(STACK_OF(PKCS7) *safes, int nid_p7,
     }
 
     return p12;
-
 }
 
 PKCS12 *PKCS12_add_safes(STACK_OF(PKCS7) *safes, int nid_p7)
