@@ -1,5 +1,5 @@
 /*
- * Copyright 1999-2024 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 1999-2026 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -23,10 +23,10 @@
 #include "p12_local.h"
 
 static int pkcs12_pbmac1_pbkdf2_key_gen(const char *pass, int passlen,
-                                        unsigned char *salt, int saltlen,
-                                        int id, int iter, int keylen,
-                                        unsigned char *out,
-                                        const EVP_MD *md_type);
+    unsigned char *salt, int saltlen,
+    int id, int iter, int keylen,
+    unsigned char *out,
+    const EVP_MD *md_type);
 
 int PKCS12_mac_present(const PKCS12 *p12)
 {
@@ -34,10 +34,10 @@ int PKCS12_mac_present(const PKCS12 *p12)
 }
 
 void PKCS12_get0_mac(const ASN1_OCTET_STRING **pmac,
-                     const X509_ALGOR **pmacalg,
-                     const ASN1_OCTET_STRING **psalt,
-                     const ASN1_INTEGER **piter,
-                     const PKCS12 *p12)
+    const X509_ALGOR **pmacalg,
+    const ASN1_OCTET_STRING **psalt,
+    const ASN1_INTEGER **piter,
+    const PKCS12 *p12)
 {
     if (p12->mac) {
         X509_SIG_get0(p12->mac->dinfo, pmacalg, pmac);
@@ -60,9 +60,9 @@ void PKCS12_get0_mac(const ASN1_OCTET_STRING **pmac,
 #define TK26_MAC_KEY_LEN 32
 
 static int pkcs12_gen_gost_mac_key(const char *pass, int passlen,
-                                   const unsigned char *salt, int saltlen,
-                                   int iter, int keylen, unsigned char *key,
-                                   const EVP_MD *digest)
+    const unsigned char *salt, int saltlen,
+    int iter, int keylen, unsigned char *key,
+    const EVP_MD *digest)
 {
     unsigned char out[96];
 
@@ -71,7 +71,7 @@ static int pkcs12_gen_gost_mac_key(const char *pass, int passlen,
     }
 
     if (!PKCS5_PBKDF2_HMAC(pass, passlen, salt, saltlen, iter,
-                           digest, sizeof(out), out)) {
+            digest, sizeof(out), out)) {
         return 0;
     }
     memcpy(key, out + sizeof(out) - TK26_MAC_KEY_LEN, TK26_MAC_KEY_LEN);
@@ -99,15 +99,15 @@ PBKDF2PARAM *PBMAC1_get1_pbkdf2_param(const X509_ALGOR *macalg)
     }
 
     pbkdf2_param = ASN1_TYPE_unpack_sequence(ASN1_ITEM_rptr(PBKDF2PARAM),
-                                             param->keyDerivationFunc->parameter);
+        param->keyDerivationFunc->parameter);
     PBMAC1PARAM_free(param);
 
     return pbkdf2_param;
 }
 
 static int PBMAC1_PBKDF2_HMAC(OSSL_LIB_CTX *ctx, const char *propq,
-                              const char *pass, int passlen,
-                              const X509_ALGOR *macalg, unsigned char *key)
+    const char *pass, int passlen,
+    const X509_ALGOR *macalg, unsigned char *key)
 {
     PBKDF2PARAM *pbkdf2_param = NULL;
     const ASN1_OBJECT *kdf_hmac_oid;
@@ -122,8 +122,6 @@ static int PBMAC1_PBKDF2_HMAC(OSSL_LIB_CTX *ctx, const char *propq,
         ERR_raise(ERR_LIB_PKCS12, ERR_R_UNSUPPORTED);
         goto err;
     }
-    keylen = ASN1_INTEGER_get(pbkdf2_param->keylength);
-    pbkdf2_salt = pbkdf2_param->salt->value.octet_string;
 
     if (pbkdf2_param->prf == NULL) {
         kdf_hmac_nid = NID_hmacWithSHA1;
@@ -138,14 +136,31 @@ static int PBMAC1_PBKDF2_HMAC(OSSL_LIB_CTX *ctx, const char *propq,
         goto err;
     }
 
+    /* Validate salt is an OCTET STRING choice */
+    if (pbkdf2_param->salt == NULL
+        || pbkdf2_param->salt->type != V_ASN1_OCTET_STRING) {
+        ERR_raise(ERR_LIB_PKCS12, PKCS12_R_PARSE_ERROR);
+        goto err;
+    }
+    pbkdf2_salt = pbkdf2_param->salt->value.octet_string;
+
+    /* RFC 9579 specifies missing key length as invalid */
+    if (pbkdf2_param->keylength != NULL)
+        keylen = ASN1_INTEGER_get(pbkdf2_param->keylength);
+    if (keylen <= 0 || keylen > EVP_MAX_MD_SIZE) {
+        ERR_raise(ERR_LIB_PKCS12, PKCS12_R_PARSE_ERROR);
+        goto err;
+    }
+
     if (PKCS5_PBKDF2_HMAC(pass, passlen, pbkdf2_salt->data, pbkdf2_salt->length,
-                          ASN1_INTEGER_get(pbkdf2_param->iter), kdf_md, keylen, key) <= 0) {
+            ASN1_INTEGER_get(pbkdf2_param->iter), kdf_md, keylen, key)
+        <= 0) {
         ERR_raise(ERR_LIB_PKCS12, ERR_R_INTERNAL_ERROR);
         goto err;
     }
     ret = keylen;
 
- err:
+err:
     EVP_MD_free(kdf_md);
     PBKDF2PARAM_free(pbkdf2_param);
 
@@ -154,13 +169,13 @@ static int PBMAC1_PBKDF2_HMAC(OSSL_LIB_CTX *ctx, const char *propq,
 
 /* Generate a MAC, also used for verification */
 static int pkcs12_gen_mac(PKCS12 *p12, const char *pass, int passlen,
-                          unsigned char *mac, unsigned int *maclen,
-                          int pbmac1_md_nid, int pbmac1_kdf_nid,
-                          int (*pkcs12_key_gen)(const char *pass, int passlen,
-                                                unsigned char *salt, int slen,
-                                                int id, int iter, int n,
-                                                unsigned char *out,
-                                                const EVP_MD *md_type))
+    unsigned char *mac, unsigned int *maclen,
+    int pbmac1_md_nid, int pbmac1_kdf_nid,
+    int (*pkcs12_key_gen)(const char *pass, int passlen,
+        unsigned char *salt, int slen,
+        int id, int iter, int n,
+        unsigned char *out,
+        const EVP_MD *md_type))
 {
     int ret = 0;
     const EVP_MD *md;
@@ -201,7 +216,7 @@ static int pkcs12_gen_mac(PKCS12 *p12, const char *pass, int passlen,
     }
     (void)ERR_set_mark();
     md = md_fetch = EVP_MD_fetch(p12->authsafes->ctx.libctx, md_name,
-                                 p12->authsafes->ctx.propq);
+        p12->authsafes->ctx.propq);
     if (md == NULL)
         md = EVP_get_digestbynid(OBJ_obj2nid(macoid));
 
@@ -220,16 +235,16 @@ static int pkcs12_gen_mac(PKCS12 *p12, const char *pass, int passlen,
     /* For PBMAC1 we use a special keygen callback if not provided (e.g. on verification) */
     if (pbmac1_md_nid != NID_undef && pkcs12_key_gen == NULL) {
         keylen = PBMAC1_PBKDF2_HMAC(p12->authsafes->ctx.libctx, p12->authsafes->ctx.propq,
-                                    pass, passlen, macalg, key);
+            pass, passlen, macalg, key);
         if (keylen < 0)
             goto err;
     } else if ((md_nid == NID_id_GostR3411_94
-                || md_nid == NID_id_GostR3411_2012_256
-                || md_nid == NID_id_GostR3411_2012_512)
-               && ossl_safe_getenv("LEGACY_GOST_PKCS12") == NULL) {
+                   || md_nid == NID_id_GostR3411_2012_256
+                   || md_nid == NID_id_GostR3411_2012_512)
+        && ossl_safe_getenv("LEGACY_GOST_PKCS12") == NULL) {
         keylen = TK26_MAC_KEY_LEN;
         if (!pkcs12_gen_gost_mac_key(pass, passlen, salt, saltlen, iter,
-                                     keylen, key, md)) {
+                keylen, key, md)) {
             ERR_raise(ERR_LIB_PKCS12, PKCS12_R_KEY_GEN_ERROR);
             goto err;
         }
@@ -249,7 +264,7 @@ static int pkcs12_gen_mac(PKCS12 *p12, const char *pass, int passlen,
         }
         if (pkcs12_key_gen != NULL) {
             int res = (*pkcs12_key_gen)(pass, passlen, salt, saltlen, PKCS12_MAC_ID,
-                                        iter, keylen, key, hmac_md);
+                iter, keylen, key, hmac_md);
 
             if (fetched)
                 EVP_MD_free(hmac_md);
@@ -262,8 +277,8 @@ static int pkcs12_gen_mac(PKCS12 *p12, const char *pass, int passlen,
                 EVP_MD_free(hmac_md);
             /* Default to UTF-8 password */
             if (!PKCS12_key_gen_utf8_ex(pass, passlen, salt, saltlen, PKCS12_MAC_ID,
-                                        iter, keylen, key, md,
-                                        p12->authsafes->ctx.libctx, p12->authsafes->ctx.propq)) {
+                    iter, keylen, key, md,
+                    p12->authsafes->ctx.libctx, p12->authsafes->ctx.propq)) {
                 ERR_raise(ERR_LIB_PKCS12, PKCS12_R_KEY_GEN_ERROR);
                 goto err;
             }
@@ -272,7 +287,7 @@ static int pkcs12_gen_mac(PKCS12 *p12, const char *pass, int passlen,
     if ((hmac = HMAC_CTX_new()) == NULL
         || !HMAC_Init_ex(hmac, key, keylen, md, NULL)
         || !HMAC_Update(hmac, p12->authsafes->d.data->data,
-                        p12->authsafes->d.data->length)
+            p12->authsafes->d.data->length)
         || !HMAC_Final(hmac, mac, maclen)) {
         goto err;
     }
@@ -286,7 +301,7 @@ err:
 }
 
 int PKCS12_gen_mac(PKCS12 *p12, const char *pass, int passlen,
-                   unsigned char *mac, unsigned int *maclen)
+    unsigned char *mac, unsigned int *maclen)
 {
     return pkcs12_gen_mac(p12, pass, passlen, mac, maclen, NID_undef, NID_undef, NULL);
 }
@@ -342,8 +357,8 @@ int PKCS12_verify_mac(PKCS12 *p12, const char *pass, int passlen)
 
 /* Set a mac */
 int PKCS12_set_mac(PKCS12 *p12, const char *pass, int passlen,
-                   unsigned char *salt, int saltlen, int iter,
-                   const EVP_MD *md_type)
+    unsigned char *salt, int saltlen, int iter,
+    const EVP_MD *md_type)
 {
     unsigned char mac[EVP_MAX_MD_SIZE];
     unsigned int maclen;
@@ -374,17 +389,17 @@ int PKCS12_set_mac(PKCS12 *p12, const char *pass, int passlen,
 }
 
 static int pkcs12_pbmac1_pbkdf2_key_gen(const char *pass, int passlen,
-                                        unsigned char *salt, int saltlen,
-                                        int id, int iter, int keylen,
-                                        unsigned char *out,
-                                        const EVP_MD *md_type)
+    unsigned char *salt, int saltlen,
+    int id, int iter, int keylen,
+    unsigned char *out,
+    const EVP_MD *md_type)
 {
     return PKCS5_PBKDF2_HMAC(pass, passlen, salt, saltlen, iter,
-                             md_type, keylen, out);
+        md_type, keylen, out);
 }
 
 static int pkcs12_setup_mac(PKCS12 *p12, int iter, unsigned char *salt, int saltlen,
-                            int nid)
+    int nid)
 {
     X509_ALGOR *macalg;
 
@@ -412,7 +427,8 @@ static int pkcs12_setup_mac(PKCS12 *p12, int iter, unsigned char *salt, int salt
     p12->mac->salt->length = saltlen;
     if (salt == NULL) {
         if (RAND_bytes_ex(p12->authsafes->ctx.libctx, p12->mac->salt->data,
-                          (size_t)saltlen, 0) <= 0)
+                (size_t)saltlen, 0)
+            <= 0)
             return 0;
     } else {
         memcpy(p12->mac->salt->data, salt, saltlen);
@@ -428,14 +444,14 @@ static int pkcs12_setup_mac(PKCS12 *p12, int iter, unsigned char *salt, int salt
 
 /* Set up a mac structure */
 int PKCS12_setup_mac(PKCS12 *p12, int iter, unsigned char *salt, int saltlen,
-                     const EVP_MD *md_type)
+    const EVP_MD *md_type)
 {
     return pkcs12_setup_mac(p12, iter, salt, saltlen, EVP_MD_get_type(md_type));
 }
 
 int PKCS12_set_pbmac1_pbkdf2(PKCS12 *p12, const char *pass, int passlen,
-                             unsigned char *salt, int saltlen, int iter,
-                             const EVP_MD *md_type, const char *prf_md_name)
+    unsigned char *salt, int saltlen, int iter,
+    const EVP_MD *md_type, const char *prf_md_name)
 {
     unsigned char mac[EVP_MAX_MD_SIZE];
     unsigned int maclen;
@@ -446,7 +462,7 @@ int PKCS12_set_pbmac1_pbkdf2(PKCS12 *p12, const char *pass, int passlen,
     unsigned char *known_salt = NULL;
     int keylen = 0;
     PBMAC1PARAM *param = NULL;
-    X509_ALGOR  *hmac_alg = NULL, *macalg = NULL;
+    X509_ALGOR *hmac_alg = NULL, *macalg = NULL;
 
     if (md_type == NULL)
         /* No need to do a fetch as the md_type is used only to get a NID */
@@ -462,7 +478,7 @@ int PKCS12_set_pbmac1_pbkdf2(PKCS12 *p12, const char *pass, int passlen,
 
     keylen = EVP_MD_get_size(md_type);
 
-    prf_nid  = ossl_md2hmacnid(prf_md_nid);
+    prf_nid = ossl_md2hmacnid(prf_md_nid);
     hmac_nid = ossl_md2hmacnid(EVP_MD_get_type(md_type));
 
     if (prf_nid == NID_undef || hmac_nid == NID_undef) {
@@ -488,7 +504,8 @@ int PKCS12_set_pbmac1_pbkdf2(PKCS12 *p12, const char *pass, int passlen,
         goto err;
 
     if (pkcs12_setup_mac(p12, iter, salt ? salt : known_salt, saltlen,
-                         NID_pbmac1) == PKCS12_ERROR) {
+            NID_pbmac1)
+        == PKCS12_ERROR) {
         ERR_raise(ERR_LIB_PKCS12, PKCS12_R_MAC_SETUP_ERROR);
         goto err;
     }
@@ -511,8 +528,8 @@ int PKCS12_set_pbmac1_pbkdf2(PKCS12 *p12, const char *pass, int passlen,
      * Note that output mac is forced to UTF-8...
      */
     if (!pkcs12_gen_mac(p12, pass, passlen, mac, &maclen,
-                        EVP_MD_get_type(md_type), prf_md_nid,
-                        pkcs12_pbmac1_pbkdf2_key_gen)) {
+            EVP_MD_get_type(md_type), prf_md_nid,
+            pkcs12_pbmac1_pbkdf2_key_gen)) {
         ERR_raise(ERR_LIB_PKCS12, PKCS12_R_MAC_GENERATION_ERROR);
         goto err;
     }
@@ -522,7 +539,7 @@ int PKCS12_set_pbmac1_pbkdf2(PKCS12 *p12, const char *pass, int passlen,
     }
     ret = 1;
 
- err:
+err:
     PBMAC1PARAM_free(param);
     OPENSSL_free(known_salt);
     return ret;
