@@ -14,10 +14,10 @@
 #include "crypto/x509.h"
 
 X509_SIG *PKCS8_encrypt_ex(int pbe_nid, const EVP_CIPHER *cipher,
-                           const char *pass, int passlen,
-                           unsigned char *salt, int saltlen, int iter,
-                           PKCS8_PRIV_KEY_INFO *p8inf,
-                           OSSL_LIB_CTX *libctx, const char *propq)
+    const char *pass, int passlen,
+    unsigned char *salt, int saltlen, int iter,
+    PKCS8_PRIV_KEY_INFO *p8inf,
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     X509_SIG *p8 = NULL;
     X509_ALGOR *pbe;
@@ -28,7 +28,7 @@ X509_SIG *PKCS8_encrypt_ex(int pbe_nid, const EVP_CIPHER *cipher,
             return NULL;
         }
         pbe = PKCS5_pbe2_set_iv_ex(cipher, iter, salt, saltlen, NULL, -1,
-                                   libctx);
+            libctx);
     } else {
         ERR_set_mark();
         if (EVP_PBE_find(EVP_PBE_TYPE_PRF, pbe_nid, NULL, NULL, 0)) {
@@ -38,7 +38,7 @@ X509_SIG *PKCS8_encrypt_ex(int pbe_nid, const EVP_CIPHER *cipher,
                 return NULL;
             }
             pbe = PKCS5_pbe2_set_iv_ex(cipher, iter, salt, saltlen, NULL,
-                                       pbe_nid, libctx);
+                pbe_nid, libctx);
         } else {
             ERR_pop_to_mark();
             pbe = PKCS5_pbe_set_ex(pbe_nid, iter, salt, saltlen, libctx);
@@ -58,24 +58,23 @@ X509_SIG *PKCS8_encrypt_ex(int pbe_nid, const EVP_CIPHER *cipher,
 }
 
 X509_SIG *PKCS8_encrypt(int pbe_nid, const EVP_CIPHER *cipher,
-                        const char *pass, int passlen,
-                        unsigned char *salt, int saltlen, int iter,
-                        PKCS8_PRIV_KEY_INFO *p8inf)
+    const char *pass, int passlen,
+    unsigned char *salt, int saltlen, int iter,
+    PKCS8_PRIV_KEY_INFO *p8inf)
 {
     return PKCS8_encrypt_ex(pbe_nid, cipher, pass, passlen, salt, saltlen, iter,
-                            p8inf, NULL, NULL);
+        p8inf, NULL, NULL);
 }
 
 X509_SIG *PKCS8_set0_pbe_ex(const char *pass, int passlen,
-                            PKCS8_PRIV_KEY_INFO *p8inf, X509_ALGOR *pbe,
-                            OSSL_LIB_CTX *ctx, const char *propq)
+    PKCS8_PRIV_KEY_INFO *p8inf, X509_ALGOR *pbe,
+    OSSL_LIB_CTX *ctx, const char *propq)
 {
     X509_SIG *p8;
     ASN1_OCTET_STRING *enckey;
 
-    enckey =
-        PKCS12_item_i2d_encrypt_ex(pbe, ASN1_ITEM_rptr(PKCS8_PRIV_KEY_INFO),
-                                   pass, passlen, p8inf, 1, ctx, propq);
+    enckey = PKCS12_item_i2d_encrypt_ex(pbe, ASN1_ITEM_rptr(PKCS8_PRIV_KEY_INFO),
+        pass, passlen, p8inf, 1, ctx, propq);
     if (!enckey) {
         ERR_raise(ERR_LIB_PKCS12, PKCS12_R_ENCRYPT_ERROR);
         return NULL;
@@ -94,7 +93,7 @@ X509_SIG *PKCS8_set0_pbe_ex(const char *pass, int passlen,
 }
 
 X509_SIG *PKCS8_set0_pbe(const char *pass, int passlen,
-                         PKCS8_PRIV_KEY_INFO *p8inf, X509_ALGOR *pbe)
+    PKCS8_PRIV_KEY_INFO *p8inf, X509_ALGOR *pbe)
 {
     return PKCS8_set0_pbe_ex(pass, passlen, p8inf, pbe, NULL, NULL);
 }
