@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2021 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2015-2024 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -21,10 +21,7 @@ size_t Poly1305_ctx_size(void)
 /* pick 32-bit unsigned integer in little endian order */
 static unsigned int U8TOU32(const unsigned char *p)
 {
-    return (((unsigned int)(p[0] & 0xff)) |
-            ((unsigned int)(p[1] & 0xff) << 8) |
-            ((unsigned int)(p[2] & 0xff) << 16) |
-            ((unsigned int)(p[3] & 0xff) << 24));
+    return (((unsigned int)(p[0] & 0xff)) | ((unsigned int)(p[1] & 0xff) << 8) | ((unsigned int)(p[2] & 0xff) << 16) | ((unsigned int)(p[3] & 0xff) << 24));
 }
 
 /*
@@ -90,11 +87,10 @@ poly1305_blocks(void *ctx, const unsigned char *inp, size_t len, u32 padbit);
 /*
  * Type-agnostic "rip-off" from constant_time.h
  */
-# define CONSTANT_TIME_CARRY(a,b) ( \
-         (a ^ ((a ^ b) | ((a - b) ^ b))) >> (sizeof(a) * 8 - 1) \
-         )
+#define CONSTANT_TIME_CARRY(a, b) ( \
+    (a ^ ((a ^ b) | ((a - b) ^ b))) >> (sizeof(a) * 8 - 1))
 
-# if defined(INT64_MAX) && defined(INT128_MAX)
+#if defined(INT64_MAX) && defined(INT128_MAX)
 
 typedef unsigned long u64;
 typedef uint128_t u128;
@@ -107,14 +103,7 @@ typedef struct {
 /* pick 32-bit unsigned integer in little endian order */
 static u64 U8TOU64(const unsigned char *p)
 {
-    return (((u64)(p[0] & 0xff)) |
-            ((u64)(p[1] & 0xff) << 8) |
-            ((u64)(p[2] & 0xff) << 16) |
-            ((u64)(p[3] & 0xff) << 24) |
-            ((u64)(p[4] & 0xff) << 32) |
-            ((u64)(p[5] & 0xff) << 40) |
-            ((u64)(p[6] & 0xff) << 48) |
-            ((u64)(p[7] & 0xff) << 56));
+    return (((u64)(p[0] & 0xff)) | ((u64)(p[1] & 0xff) << 8) | ((u64)(p[2] & 0xff) << 16) | ((u64)(p[3] & 0xff) << 24) | ((u64)(p[4] & 0xff) << 32) | ((u64)(p[5] & 0xff) << 40) | ((u64)(p[6] & 0xff) << 48) | ((u64)(p[7] & 0xff) << 56));
 }
 
 /* store a 32-bit unsigned integer in little endian */
@@ -132,7 +121,7 @@ static void U64TO8(unsigned char *p, u64 v)
 
 static void poly1305_init(void *ctx, const unsigned char key[16])
 {
-    poly1305_internal *st = (poly1305_internal *) ctx;
+    poly1305_internal *st = (poly1305_internal *)ctx;
 
     /* h = 0 */
     st->h[0] = 0;
@@ -168,16 +157,13 @@ poly1305_blocks(void *ctx, const unsigned char *inp, size_t len, u32 padbit)
         h1 = (u64)(d1 = (u128)h1 + (d0 >> 64) + U8TOU64(inp + 8));
         /*
          * padbit can be zero only when original len was
-         * POLY1306_BLOCK_SIZE, but we don't check
+         * POLY1305_BLOCK_SIZE, but we don't check
          */
         h2 += (u64)(d1 >> 64) + padbit;
 
         /* h *= r "%" p, where "%" stands for "partial remainder" */
-        d0 = ((u128)h0 * r0) +
-             ((u128)h1 * s1);
-        d1 = ((u128)h0 * r1) +
-             ((u128)h1 * r0) +
-             (h2 * s1);
+        d0 = ((u128)h0 * r0) + ((u128)h1 * s1);
+        d1 = ((u128)h0 * r1) + ((u128)h1 * r0) + (h2 * s1);
         h2 = (h2 * r0);
 
         /* last reduction step: */
@@ -189,8 +175,8 @@ poly1305_blocks(void *ctx, const unsigned char *inp, size_t len, u32 padbit)
         c = (h2 >> 2) + (h2 & ~3UL);
         h2 &= 3;
         h0 += c;
-        h1 += (c = CONSTANT_TIME_CARRY(h0,c));
-        h2 += CONSTANT_TIME_CARRY(h1,c);
+        h1 += (c = CONSTANT_TIME_CARRY(h0, c));
+        h2 += CONSTANT_TIME_CARRY(h1, c);
         /*
          * Occasional overflows to 3rd bit of h2 are taken care of
          * "naturally". If after this point we end up at the top of
@@ -211,9 +197,9 @@ poly1305_blocks(void *ctx, const unsigned char *inp, size_t len, u32 padbit)
 }
 
 static void poly1305_emit(void *ctx, unsigned char mac[16],
-                          const u32 nonce[4])
+    const u32 nonce[4])
 {
-    poly1305_internal *st = (poly1305_internal *) ctx;
+    poly1305_internal *st = (poly1305_internal *)ctx;
     u64 h0, h1, h2;
     u64 g0, g1, g2;
     u128 t;
@@ -237,22 +223,22 @@ static void poly1305_emit(void *ctx, unsigned char mac[16],
     h1 = (h1 & mask) | g1;
 
     /* mac = (h + nonce) % (2^128) */
-    h0 = (u64)(t = (u128)h0 + nonce[0] + ((u64)nonce[1]<<32));
-    h1 = (u64)(t = (u128)h1 + nonce[2] + ((u64)nonce[3]<<32) + (t >> 64));
+    h0 = (u64)(t = (u128)h0 + nonce[0] + ((u64)nonce[1] << 32));
+    h1 = (u64)(t = (u128)h1 + nonce[2] + ((u64)nonce[3] << 32) + (t >> 64));
 
     U64TO8(mac + 0, h0);
     U64TO8(mac + 8, h1);
 }
 
-# else
+#else
 
-#  if defined(_WIN32) && !defined(__MINGW32__)
+#if defined(_WIN32) && !defined(__MINGW32__)
 typedef unsigned __int64 u64;
-#  elif defined(__arch64__)
+#elif defined(__arch64__)
 typedef unsigned long u64;
-#  else
+#else
 typedef unsigned long long u64;
-#  endif
+#endif
 
 typedef struct {
     u32 h[5];
@@ -270,7 +256,7 @@ static void U32TO8(unsigned char *p, unsigned int v)
 
 static void poly1305_init(void *ctx, const unsigned char key[16])
 {
-    poly1305_internal *st = (poly1305_internal *) ctx;
+    poly1305_internal *st = (poly1305_internal *)ctx;
 
     /* h = 0 */
     st->h[0] = 0;
@@ -319,25 +305,10 @@ poly1305_blocks(void *ctx, const unsigned char *inp, size_t len, u32 padbit)
         h4 += (u32)(d3 >> 32) + padbit;
 
         /* h *= r "%" p, where "%" stands for "partial remainder" */
-        d0 = ((u64)h0 * r0) +
-             ((u64)h1 * s3) +
-             ((u64)h2 * s2) +
-             ((u64)h3 * s1);
-        d1 = ((u64)h0 * r1) +
-             ((u64)h1 * r0) +
-             ((u64)h2 * s3) +
-             ((u64)h3 * s2) +
-             (h4 * s1);
-        d2 = ((u64)h0 * r2) +
-             ((u64)h1 * r1) +
-             ((u64)h2 * r0) +
-             ((u64)h3 * s3) +
-             (h4 * s2);
-        d3 = ((u64)h0 * r3) +
-             ((u64)h1 * r2) +
-             ((u64)h2 * r1) +
-             ((u64)h3 * r0) +
-             (h4 * s3);
+        d0 = ((u64)h0 * r0) + ((u64)h1 * s3) + ((u64)h2 * s2) + ((u64)h3 * s1);
+        d1 = ((u64)h0 * r1) + ((u64)h1 * r0) + ((u64)h2 * s3) + ((u64)h3 * s2) + (h4 * s1);
+        d2 = ((u64)h0 * r2) + ((u64)h1 * r1) + ((u64)h2 * r0) + ((u64)h3 * s3) + (h4 * s2);
+        d3 = ((u64)h0 * r3) + ((u64)h1 * r2) + ((u64)h2 * r1) + ((u64)h3 * r0) + (h4 * s3);
         h4 = (h4 * r0);
 
         /* last reduction step: */
@@ -351,10 +322,10 @@ poly1305_blocks(void *ctx, const unsigned char *inp, size_t len, u32 padbit)
         c = (h4 >> 2) + (h4 & ~3U);
         h4 &= 3;
         h0 += c;
-        h1 += (c = CONSTANT_TIME_CARRY(h0,c));
-        h2 += (c = CONSTANT_TIME_CARRY(h1,c));
-        h3 += (c = CONSTANT_TIME_CARRY(h2,c));
-        h4 += CONSTANT_TIME_CARRY(h3,c);
+        h1 += (c = CONSTANT_TIME_CARRY(h0, c));
+        h2 += (c = CONSTANT_TIME_CARRY(h1, c));
+        h3 += (c = CONSTANT_TIME_CARRY(h2, c));
+        h4 += CONSTANT_TIME_CARRY(h3, c);
         /*
          * Occasional overflows to 3rd bit of h4 are taken care of
          * "naturally". If after this point we end up at the top of
@@ -377,9 +348,9 @@ poly1305_blocks(void *ctx, const unsigned char *inp, size_t len, u32 padbit)
 }
 
 static void poly1305_emit(void *ctx, unsigned char mac[16],
-                          const u32 nonce[4])
+    const u32 nonce[4])
 {
-    poly1305_internal *st = (poly1305_internal *) ctx;
+    poly1305_internal *st = (poly1305_internal *)ctx;
     u32 h0, h1, h2, h3, h4;
     u32 g0, g1, g2, g3, g4;
     u64 t;
@@ -421,13 +392,13 @@ static void poly1305_emit(void *ctx, unsigned char mac[16],
     U32TO8(mac + 8, h2);
     U32TO8(mac + 12, h3);
 }
-# endif
+#endif
 #else
 int poly1305_init(void *ctx, const unsigned char key[16], void *func);
 void poly1305_blocks(void *ctx, const unsigned char *inp, size_t len,
-                     unsigned int padbit);
+    unsigned int padbit);
 void poly1305_emit(void *ctx, unsigned char mac[16],
-                   const unsigned int nonce[4]);
+    const unsigned int nonce[4]);
 #endif
 
 void Poly1305_Init(POLY1305 *ctx, const unsigned char key[32])
@@ -453,7 +424,6 @@ void Poly1305_Init(POLY1305 *ctx, const unsigned char key[32])
 #endif
 
     ctx->num = 0;
-
 }
 
 #ifdef POLY1305_ASM
@@ -461,8 +431,8 @@ void Poly1305_Init(POLY1305 *ctx, const unsigned char key[32])
  * This "eclipses" poly1305_blocks and poly1305_emit, but it's
  * conscious choice imposed by -Wshadow compiler warnings.
  */
-# define poly1305_blocks (*poly1305_blocks_p)
-# define poly1305_emit   (*poly1305_emit_p)
+#define poly1305_blocks (*poly1305_blocks_p)
+#define poly1305_emit (*poly1305_emit_p)
 #endif
 
 void Poly1305_Update(POLY1305 *ctx, const unsigned char *inp, size_t len)
@@ -516,7 +486,7 @@ void Poly1305_Final(POLY1305 *ctx, unsigned char mac[16])
     size_t num;
 
     if ((num = ctx->num)) {
-        ctx->data[num++] = 1;   /* pad bit */
+        ctx->data[num++] = 1; /* pad bit */
         while (num < POLY1305_BLOCK_SIZE)
             ctx->data[num++] = 0;
         poly1305_blocks(ctx->opaque, ctx->data, POLY1305_BLOCK_SIZE, 0);
