@@ -14,17 +14,17 @@
 #include <signal.h>
 #include <unistd.h>
 #if defined(__linux) || defined(_AIX)
-# include <sys/utsname.h>
+#include <sys/utsname.h>
+#endif
+#if defined(_AIX53) /* defined even on post-5.3 */
+#include <sys/systemcfg.h>
+#if !defined(__power_set)
+#define __power_set(a) (_system_configuration.implementation & (a))
 #endif
-#if defined(_AIX53)     /* defined even on post-5.3 */
-# include <sys/systemcfg.h>
-# if !defined(__power_set)
-#  define __power_set(a) (_system_configuration.implementation & (a))
-# endif
 #endif
 #if defined(__APPLE__) && defined(__MACH__)
-# include <sys/types.h>
-# include <sys/sysctl.h>
+#include <sys/types.h>
+#include <sys/sysctl.h>
 #endif
 #include <openssl/crypto.h>
 #include "internal/cryptlib.h"
@@ -87,57 +87,56 @@ size_t OPENSSL_instrument_bus2(unsigned int *out, size_t cnt, size_t max)
 }
 
 #if defined(__GLIBC__) && defined(__GLIBC_PREREQ)
-# if __GLIBC_PREREQ(2, 16)
-#  include <sys/auxv.h>
-#  define OSSL_IMPLEMENT_GETAUXVAL
-# elif defined(__ANDROID_API__)
+#if __GLIBC_PREREQ(2, 16)
+#include <sys/auxv.h>
+#define OSSL_IMPLEMENT_GETAUXVAL
+#elif defined(__ANDROID_API__)
 /* see https://developer.android.google.cn/ndk/guides/cpu-features */
-#  if __ANDROID_API__ >= 18
-#   include <sys/auxv.h>
-#   define OSSL_IMPLEMENT_GETAUXVAL
-#  endif
-# endif
+#if __ANDROID_API__ >= 18
+#include <sys/auxv.h>
+#define OSSL_IMPLEMENT_GETAUXVAL
+#endif
+#endif
 #endif
 
 #if defined(__FreeBSD__) || defined(__OpenBSD__)
-# include <sys/param.h>
-# if (defined(__FreeBSD__) && __FreeBSD_version >= 1200000) || \
-    (defined(__OpenBSD__) && OpenBSD >= 202409)
-#  include <sys/auxv.h>
-#  define OSSL_IMPLEMENT_GETAUXVAL
+#include <sys/param.h>
+#if (defined(__FreeBSD__) && __FreeBSD_version >= 1200000) || (defined(__OpenBSD__) && OpenBSD >= 202409)
+#include <sys/auxv.h>
+#define OSSL_IMPLEMENT_GETAUXVAL
 
 static unsigned long getauxval(unsigned long key)
 {
-  unsigned long val = 0ul;
+    unsigned long val = 0ul;
 
-  if (elf_aux_info((int)key, &val, sizeof(val)) != 0)
-    return 0ul;
+    if (elf_aux_info((int)key, &val, sizeof(val)) != 0)
+        return 0ul;
 
-  return val;
+    return val;
 }
-# endif
+#endif
 #endif
 
 /* I wish <sys/auxv.h> was universally available */
 #ifndef AT_HWCAP
-# define AT_HWCAP               16      /* AT_HWCAP */
+#define AT_HWCAP 16 /* AT_HWCAP */
 #endif
-#define HWCAP_PPC64             (1U << 30)
-#define HWCAP_ALTIVEC           (1U << 28)
-#define HWCAP_FPU               (1U << 27)
-#define HWCAP_POWER6_EXT        (1U << 9)
-#define HWCAP_VSX               (1U << 7)
+#define HWCAP_PPC64 (1U << 30)
+#define HWCAP_ALTIVEC (1U << 28)
+#define HWCAP_FPU (1U << 27)
+#define HWCAP_POWER6_EXT (1U << 9)
+#define HWCAP_VSX (1U << 7)
 
 #ifndef AT_HWCAP2
-# define AT_HWCAP2              26      /* AT_HWCAP2 */
+#define AT_HWCAP2 26 /* AT_HWCAP2 */
 #endif
-#define HWCAP_VEC_CRYPTO        (1U << 25)
-#define HWCAP_ARCH_3_00         (1U << 23)
-#define HWCAP_ARCH_3_1          (1U << 18)
+#define HWCAP_VEC_CRYPTO (1U << 25)
+#define HWCAP_ARCH_3_00 (1U << 23)
+#define HWCAP_ARCH_3_1 (1U << 18)
 
-# if defined(__GNUC__) && __GNUC__>=2
-__attribute__ ((constructor))
-# endif
+#if defined(__GNUC__) && __GNUC__ >= 2
+__attribute__((constructor))
+#endif
 void OPENSSL_cpuid_setup(void)
 {
     char *e;
@@ -161,15 +160,15 @@ void OPENSSL_cpuid_setup(void)
 
     if (sizeof(size_t) == 4) {
         struct utsname uts;
-# if defined(_SC_AIX_KERNEL_BITMODE)
+#if defined(_SC_AIX_KERNEL_BITMODE)
         if (sysconf(_SC_AIX_KERNEL_BITMODE) != 64)
             return;
-# endif
+#endif
         if (uname(&uts) != 0 || atoi(uts.version) < 6)
             return;
     }
 
-# if defined(__power_set)
+#if defined(__power_set)
     /*
      * Value used in __power_set is a single-bit 1<<n one denoting
      * specific processor class. Incidentally 0xffffffff<<n can be
@@ -177,28 +176,28 @@ void OPENSSL_cpuid_setup(void)
      */
     if (sizeof(size_t) == 4) {
         /* In 32-bit case PPC_FPU64 is always fastest [if option] */
-        if (__power_set(0xffffffffU<<13))       /* POWER5 and later */
+        if (__power_set(0xffffffffU << 13)) /* POWER5 and later */
             OPENSSL_ppccap_P |= PPC_FPU64;
     } else {
         /* In 64-bit case PPC_FPU64 is fastest only on POWER6 */
-        if (__power_set(0x1U<<14))              /* POWER6 */
+        if (__power_set(0x1U << 14)) /* POWER6 */
             OPENSSL_ppccap_P |= PPC_FPU64;
     }
 
-    if (__power_set(0xffffffffU<<14))           /* POWER6 and later */
+    if (__power_set(0xffffffffU << 14)) /* POWER6 and later */
         OPENSSL_ppccap_P |= PPC_ALTIVEC;
 
-    if (__power_set(0xffffffffU<<16))           /* POWER8 and later */
+    if (__power_set(0xffffffffU << 16)) /* POWER8 and later */
         OPENSSL_ppccap_P |= PPC_CRYPTO207;
 
-    if (__power_set(0xffffffffU<<17))           /* POWER9 and later */
+    if (__power_set(0xffffffffU << 17)) /* POWER9 and later */
         OPENSSL_ppccap_P |= PPC_MADD300;
 
-    if (__power_set(0xffffffffU<<18))           /* POWER10 and later */
+    if (__power_set(0xffffffffU << 18)) /* POWER10 and later */
         OPENSSL_ppccap_P |= PPC_BRD31;
 
     return;
-# endif
+#endif
 #endif
 
 #if defined(__APPLE__) && defined(__MACH__)
@@ -282,10 +281,10 @@ void OPENSSL_cpuid_setup(void)
         OPENSSL_ppccap_P |= PPC_FPU;
 
         if (sizeof(size_t) == 4) {
-# ifdef __linux
+#ifdef __linux
             struct utsname uts;
             if (uname(&uts) == 0 && strcmp(uts.machine, "ppc64") == 0)
-# endif
+#endif
                 if (sigsetjmp(ill_jmp, 1) == 0) {
                     OPENSSL_ppc64_probe();
                     OPENSSL_ppccap_P |= PPC_FPU64;
