@@ -50,9 +50,9 @@ void ossl_child_prov_ctx_free(void *vgbl)
 static OSSL_provider_init_fn ossl_child_provider_init;
 
 static int ossl_child_provider_init(const OSSL_CORE_HANDLE *handle,
-                                    const OSSL_DISPATCH *in,
-                                    const OSSL_DISPATCH **out,
-                                    void **provctx)
+    const OSSL_DISPATCH *in,
+    const OSSL_DISPATCH **out,
+    void **provctx)
 {
     OSSL_FUNC_core_get_libctx_fn *c_get_libctx = NULL;
     OSSL_LIB_CTX *ctx;
@@ -132,7 +132,8 @@ static int provider_create_child_cb(const OSSL_CORE_HANDLE *prov, void *cbdata)
          * init children
          */
         if ((cprov = ossl_provider_new(ctx, provname, ossl_child_provider_init,
-                                       NULL, 1)) == NULL)
+                 NULL, 1))
+            == NULL)
             goto err;
 
         if (!ossl_provider_activate(cprov, 0, 0)) {
@@ -149,7 +150,7 @@ static int provider_create_child_cb(const OSSL_CORE_HANDLE *prov, void *cbdata)
     }
 
     ret = 1;
- err:
+err:
     CRYPTO_THREAD_unlock(gbl->lock);
     return ret;
 }
@@ -175,7 +176,7 @@ static int provider_remove_child_cb(const OSSL_CORE_HANDLE *prov, void *cbdata)
      */
     ossl_provider_free(cprov);
     if (ossl_provider_is_child(cprov)
-            && !ossl_provider_deactivate(cprov, 1))
+        && !ossl_provider_deactivate(cprov, 1))
         return 0;
 
     return 1;
@@ -189,8 +190,8 @@ static int provider_global_props_cb(const char *props, void *cbdata)
 }
 
 int ossl_provider_init_as_child(OSSL_LIB_CTX *ctx,
-                                const OSSL_CORE_HANDLE *handle,
-                                const OSSL_DISPATCH *in)
+    const OSSL_CORE_HANDLE *handle,
+    const OSSL_DISPATCH *in)
 {
     struct child_prov_globals *gbl;
 
@@ -239,12 +240,12 @@ int ossl_provider_init_as_child(OSSL_LIB_CTX *ctx,
     }
 
     if (gbl->c_get_libctx == NULL
-            || gbl->c_provider_register_child_cb == NULL
-            || gbl->c_prov_name == NULL
-            || gbl->c_prov_get0_provider_ctx == NULL
-            || gbl->c_prov_get0_dispatch == NULL
-            || gbl->c_prov_up_ref == NULL
-            || gbl->c_prov_free == NULL)
+        || gbl->c_provider_register_child_cb == NULL
+        || gbl->c_prov_name == NULL
+        || gbl->c_prov_get0_provider_ctx == NULL
+        || gbl->c_prov_get0_dispatch == NULL
+        || gbl->c_prov_up_ref == NULL
+        || gbl->c_prov_free == NULL)
         return 0;
 
     gbl->lock = CRYPTO_THREAD_lock_new();
@@ -252,10 +253,10 @@ int ossl_provider_init_as_child(OSSL_LIB_CTX *ctx,
         return 0;
 
     if (!gbl->c_provider_register_child_cb(gbl->handle,
-                                           provider_create_child_cb,
-                                           provider_remove_child_cb,
-                                           provider_global_props_cb,
-                                           ctx))
+            provider_create_child_cb,
+            provider_remove_child_cb,
+            provider_global_props_cb,
+            ctx))
         return 0;
 
     return 1;
@@ -289,7 +290,7 @@ int ossl_provider_up_ref_parent(OSSL_PROVIDER *prov, int activate)
     const OSSL_CORE_HANDLE *parent_handle;
 
     gbl = ossl_lib_ctx_get_data(ossl_provider_libctx(prov),
-                                OSSL_LIB_CTX_CHILD_PROVIDER_INDEX);
+        OSSL_LIB_CTX_CHILD_PROVIDER_INDEX);
     if (gbl == NULL)
         return 0;
 
@@ -305,7 +306,7 @@ int ossl_provider_free_parent(OSSL_PROVIDER *prov, int deactivate)
     const OSSL_CORE_HANDLE *parent_handle;
 
     gbl = ossl_lib_ctx_get_data(ossl_provider_libctx(prov),
-                                OSSL_LIB_CTX_CHILD_PROVIDER_INDEX);
+        OSSL_LIB_CTX_CHILD_PROVIDER_INDEX);
     if (gbl == NULL)
         return 0;
 
