@@ -35,22 +35,22 @@ int RAND_egd_bytes(const char *path, int bytes)
 
 #else
 
-# include <unistd.h>
-# include <stddef.h>
-# include <sys/types.h>
-# include <sys/socket.h>
-# ifndef NO_SYS_UN_H
-#  include <sys/un.h>
-# else
+#include <unistd.h>
+#include <stddef.h>
+#include <sys/types.h>
+#include <sys/socket.h>
+#ifndef NO_SYS_UN_H
+#include <sys/un.h>
+#else
 struct sockaddr_un {
-    short sun_family;           /* AF_UNIX */
-    char sun_path[108];         /* path name (gag) */
+    short sun_family; /* AF_UNIX */
+    char sun_path[108]; /* path name (gag) */
 };
-# endif                         /* NO_SYS_UN_H */
-# include <string.h>
-# include <errno.h>
+#endif /* NO_SYS_UN_H */
+#include <string.h>
+#include <errno.h>
 
-# if defined(OPENSSL_SYS_TANDEM)
+#if defined(OPENSSL_SYS_TANDEM)
 /*
  * HPNS:
  *
@@ -66,17 +66,16 @@ struct sockaddr_un {
  *  the two modes or revise the EGD code to listen on two different sockets
  *  (each in one of the two modes) or use the hardware randomizer.
  */
-_variable
-int hpns_socket(int family,
-                int type,
-                int protocol,
-                char* transport)
+_variable int hpns_socket(int family,
+    int type,
+    int protocol,
+    char *transport)
 {
-    int  socket_rc;
+    int socket_rc;
     char current_transport[20];
 
-#  define AF_UNIX_PORTABILITY    "$ZAFN2"
-#  define AF_UNIX_COMPATIBILITY  "$ZPLS"
+#define AF_UNIX_PORTABILITY "$ZAFN2"
+#define AF_UNIX_COMPATIBILITY "$ZPLS"
 
     if (!_arg_present(transport) || transport == NULL || transport[0] == '\0')
         return socket(family, type, protocol);
@@ -103,8 +102,7 @@ int hpns_socket(int family,
 
 static int hpns_connect_attempt = 0;
 
-# endif /* defined(OPENSSL_SYS_HPNS) */
-
+#endif /* defined(OPENSSL_SYS_HPNS) */
 
 int RAND_query_egd_bytes(const char *path, unsigned char *buf, int bytes)
 {
@@ -136,27 +134,27 @@ int RAND_query_egd_bytes(const char *path, unsigned char *buf, int bytes)
     for (;;) {
         if (connect(fd, (struct sockaddr *)&addr, i) == 0)
             break;
-# ifdef EISCONN
+#ifdef EISCONN
         if (errno == EISCONN)
             break;
-# endif
+#endif
         switch (errno) {
-# ifdef EINTR
+#ifdef EINTR
         case EINTR:
-# endif
-# ifdef EAGAIN
+#endif
+#ifdef EAGAIN
         case EAGAIN:
-# endif
-# ifdef EINPROGRESS
+#endif
+#ifdef EINPROGRESS
         case EINPROGRESS:
-# endif
-# ifdef EALREADY
+#endif
+#ifdef EALREADY
         case EALREADY:
-# endif
+#endif
             /* No error, try again */
             break;
         default:
-# if defined(OPENSSL_SYS_TANDEM)
+#if defined(OPENSSL_SYS_TANDEM)
             if (hpns_connect_attempt == 0) {
                 /* try the other kind of AF_UNIX socket */
                 close(fd);
@@ -164,9 +162,9 @@ int RAND_query_egd_bytes(const char *path, unsigned char *buf, int bytes)
                 if (fd == -1)
                     return -1;
                 ++hpns_connect_attempt;
-                break;  /* try the connect again */
+                break; /* try the connect again */
             }
-# endif
+#endif
 
             ret = -1;
             goto err;
@@ -195,7 +193,7 @@ int RAND_query_egd_bytes(const char *path, unsigned char *buf, int bytes)
     if (mybuffer)
         RAND_add(tempbuf, i, i);
 
- err:
+err:
     if (fp != NULL)
         fclose(fp);
     return ret;
