@@ -13,12 +13,15 @@
 #include <openssl/err.h>
 #include <openssl/opensslconf.h>
 #include <openssl/core_names.h>
+#include <openssl/provider.h>
 #include "internal/cryptlib.h"
+#include "internal/provider.h"
 #include "internal/thread_once.h"
 #include "crypto/rand.h"
 #include "crypto/cryptlib.h"
 #include "rand_local.h"
 #include "crypto/context.h"
+#include "internal/provider.h"
 
 /* clang-format off */
 #ifndef OPENSSL_DEFAULT_SEED_SRC
@@ -26,6 +29,80 @@
 #endif
 /* clang-format on */
 
+typedef struct rand_global_st {
+    /*
+     * The three shared DRBG instances
+     *
+     * There are three shared DRBG instances: <primary>, <public>, and
+     * <private>.  The <public> and <private> DRBGs are secondary ones.
+     * These are used for non-secret (e.g. nonces) and secret
+     * (e.g. private keys) data respectively.
+     */
+    CRYPTO_RWLOCK *lock;
+
+    EVP_RAND_CTX *seed;
+
+    /*
+     * The <primary> DRBG
+     *
+     * Not used directly by the application, only for reseeding the two other
+     * DRBGs. It reseeds itself by pulling either randomness from os entropy
+     * sources or by consuming randomness which was added by RAND_add().
+     *
+     * The <primary> DRBG is a global instance which is accessed concurrently by
+     * all threads. The necessary locking is managed automatically by its child
+     * DRBG instances during reseeding.
+     */
+    EVP_RAND_CTX *primary;
+
+    /*
+     * The provider which we'll use to generate randomness.
+     */
+#ifndef FIPS_MODULE
+    OSSL_PROVIDER *random_provider;
+    char *random_provider_name;
+#endif /* !FIPS_MODULE */
+
+    /*
+     * The <public> DRBG
+     *
+     * Used by default for generating random bytes using RAND_bytes().
+     *
+     * The <public> secondary DRBG is thread-local, i.e., there is one instance
+     * per thread.
+     */
+    CRYPTO_THREAD_LOCAL public;
+
+    /*
+     * The <private> DRBG
+     *
+     * Used by default for generating private keys using RAND_priv_bytes()
+     *
+     * The <private> secondary DRBG is thread-local, i.e., there is one
+     * instance per thread.
+     */
+    CRYPTO_THREAD_LOCAL private;
+
+    /* Which RNG is being used by default and it's configuration settings */
+    char *rng_name;
+    char *rng_cipher;
+    char *rng_digest;
+    char *rng_propq;
+
+    /* Allow the randomness source to be changed */
+    char *seed_name;
+    char *seed_propq;
+} RAND_GLOBAL;
+
+static EVP_RAND_CTX *rand_get0_primary(OSSL_LIB_CTX *ctx, RAND_GLOBAL *dgbl);
+static EVP_RAND_CTX *rand_get0_public(OSSL_LIB_CTX *ctx, RAND_GLOBAL *dgbl);
+static EVP_RAND_CTX *rand_get0_private(OSSL_LIB_CTX *ctx, RAND_GLOBAL *dgbl);
+
+static RAND_GLOBAL *rand_get_global(OSSL_LIB_CTX *libctx)
+{
+    return ossl_lib_ctx_get_data(libctx, OSSL_LIB_CTX_DRBG_INDEX);
+}
+
 #ifndef FIPS_MODULE
 #include <stdio.h>
 #include <time.h>
@@ -38,15 +115,33 @@
 #include "internal/e_os.h"
 #include "internal/property.h"
 
+/*
+ * The default name for the random provider.
+ * This ensures that the FIPS provider will supply libcrypto's random byte
+ * requirements.
+ */
+static const char random_provider_fips_name[] = "fips";
+
+static int set_random_provider_name(RAND_GLOBAL *dgbl, const char *name)
+{
+    if (dgbl->random_provider_name != NULL
+        && OPENSSL_strcasecmp(dgbl->random_provider_name, name) == 0)
+        return 1;
+
+    OPENSSL_free(dgbl->random_provider_name);
+    dgbl->random_provider_name = OPENSSL_strdup(name);
+    return dgbl->random_provider_name != NULL;
+}
+
 #ifndef OPENSSL_NO_ENGINE
 /* non-NULL if default_RAND_meth is ENGINE-provided */
 static ENGINE *funct_ref;
 static CRYPTO_RWLOCK *rand_engine_lock;
-#endif
+#endif /* !OPENSSL_NO_ENGINE */
 #ifndef OPENSSL_NO_DEPRECATED_3_0
 static CRYPTO_RWLOCK *rand_meth_lock;
 static const RAND_METHOD *default_RAND_meth;
-#endif
+#endif /* !OPENSSL_NO_DEPRECATED_3_0 */
 static CRYPTO_ONCE rand_init = CRYPTO_ONCE_STATIC_INIT;
 
 static int rand_inited = 0;
@@ -57,13 +152,13 @@ DEFINE_RUN_ONCE_STATIC(do_rand_init)
     rand_engine_lock = CRYPTO_THREAD_lock_new();
     if (rand_engine_lock == NULL)
         return 0;
-#endif
+#endif /* !OPENSSL_NO_ENGINE */
 
 #ifndef OPENSSL_NO_DEPRECATED_3_0
     rand_meth_lock = CRYPTO_THREAD_lock_new();
     if (rand_meth_lock == NULL)
         goto err;
-#endif
+#endif /* !OPENSSL_NO_DEPRECATED_3_0 */
 
     if (!ossl_rand_pool_init())
         goto err;
@@ -75,11 +170,11 @@ err:
 #ifndef OPENSSL_NO_DEPRECATED_3_0
     CRYPTO_THREAD_lock_free(rand_meth_lock);
     rand_meth_lock = NULL;
-#endif
+#endif /* !OPENSSL_NO_DEPRECATED_3_0 */
 #ifndef OPENSSL_NO_ENGINE
     CRYPTO_THREAD_lock_free(rand_engine_lock);
     rand_engine_lock = NULL;
-#endif
+#endif /* !OPENSSL_NO_ENGINE */
     return 0;
 }
 
@@ -94,16 +189,16 @@ void ossl_rand_cleanup_int(void)
     if (meth != NULL && meth->cleanup != NULL)
         meth->cleanup();
     RAND_set_rand_method(NULL);
-#endif
+#endif /* !OPENSSL_NO_DEPRECATED_3_0 */
     ossl_rand_pool_cleanup();
 #ifndef OPENSSL_NO_ENGINE
     CRYPTO_THREAD_lock_free(rand_engine_lock);
     rand_engine_lock = NULL;
-#endif
+#endif /* !OPENSSL_NO_ENGINE */
 #ifndef OPENSSL_NO_DEPRECATED_3_0
     CRYPTO_THREAD_lock_free(rand_meth_lock);
     rand_meth_lock = NULL;
-#endif
+#endif /* !OPENSSL_NO_DEPRECATED_3_0 */
     ossl_release_default_drbg_ctx();
     rand_inited = 0;
 }
@@ -161,7 +256,7 @@ int RAND_poll(void)
         ossl_rand_pool_free(pool);
         return ret;
     }
-#endif
+#endif /* !OPENSSL_NO_DEPRECATED_3_0 */
 
     RAND_seed(salt, sizeof(salt));
     return 1;
@@ -344,6 +439,7 @@ const RAND_METHOD *RAND_get_rand_method(void)
 int RAND_priv_bytes_ex(OSSL_LIB_CTX *ctx, unsigned char *buf, size_t num,
     unsigned int strength)
 {
+    RAND_GLOBAL *dgbl;
     EVP_RAND_CTX *rand;
 #if !defined(OPENSSL_NO_DEPRECATED_3_0) && !defined(FIPS_MODULE)
     const RAND_METHOD *meth = RAND_get_rand_method();
@@ -356,7 +452,16 @@ int RAND_priv_bytes_ex(OSSL_LIB_CTX *ctx, unsigned char *buf, size_t num,
     }
 #endif
 
-    rand = RAND_get0_private(ctx);
+    dgbl = rand_get_global(ctx);
+    if (dgbl == NULL)
+        return 0;
+#ifndef FIPS_MODULE
+    if (dgbl->random_provider != NULL)
+        return ossl_provider_random_bytes(dgbl->random_provider,
+            OSSL_PROV_RANDOM_PRIVATE,
+            buf, num, strength);
+#endif /* !FIPS_MODULE */
+    rand = rand_get0_private(ctx, dgbl);
     if (rand != NULL)
         return EVP_RAND_generate(rand, buf, num, strength, 0, NULL, 0);
 
@@ -373,6 +478,7 @@ int RAND_priv_bytes(unsigned char *buf, int num)
 int RAND_bytes_ex(OSSL_LIB_CTX *ctx, unsigned char *buf, size_t num,
     unsigned int strength)
 {
+    RAND_GLOBAL *dgbl;
     EVP_RAND_CTX *rand;
 #if !defined(OPENSSL_NO_DEPRECATED_3_0) && !defined(FIPS_MODULE)
     const RAND_METHOD *meth = RAND_get_rand_method();
@@ -385,7 +491,17 @@ int RAND_bytes_ex(OSSL_LIB_CTX *ctx, unsigned char *buf, size_t num,
     }
 #endif
 
-    rand = RAND_get0_public(ctx);
+    dgbl = rand_get_global(ctx);
+    if (dgbl == NULL)
+        return 0;
+#ifndef FIPS_MODULE
+    if (dgbl->random_provider != NULL)
+        return ossl_provider_random_bytes(dgbl->random_provider,
+            OSSL_PROV_RANDOM_PUBLIC,
+            buf, num, strength);
+#endif /* !FIPS_MODULE */
+
+    rand = rand_get0_public(ctx, dgbl);
     if (rand != NULL)
         return EVP_RAND_generate(rand, buf, num, strength, 0, NULL, 0);
 
@@ -399,63 +515,6 @@ int RAND_bytes(unsigned char *buf, int num)
     return RAND_bytes_ex(NULL, buf, (size_t)num, 0);
 }
 
-typedef struct rand_global_st {
-    /*
-     * The three shared DRBG instances
-     *
-     * There are three shared DRBG instances: <primary>, <public>, and
-     * <private>.  The <public> and <private> DRBGs are secondary ones.
-     * These are used for non-secret (e.g. nonces) and secret
-     * (e.g. private keys) data respectively.
-     */
-    CRYPTO_RWLOCK *lock;
-
-    EVP_RAND_CTX *seed;
-
-    /*
-     * The <primary> DRBG
-     *
-     * Not used directly by the application, only for reseeding the two other
-     * DRBGs. It reseeds itself by pulling either randomness from os entropy
-     * sources or by consuming randomness which was added by RAND_add().
-     *
-     * The <primary> DRBG is a global instance which is accessed concurrently by
-     * all threads. The necessary locking is managed automatically by its child
-     * DRBG instances during reseeding.
-     */
-    EVP_RAND_CTX *primary;
-
-    /*
-     * The <public> DRBG
-     *
-     * Used by default for generating random bytes using RAND_bytes().
-     *
-     * The <public> secondary DRBG is thread-local, i.e., there is one instance
-     * per thread.
-     */
-    CRYPTO_THREAD_LOCAL public;
-
-    /*
-     * The <private> DRBG
-     *
-     * Used by default for generating private keys using RAND_priv_bytes()
-     *
-     * The <private> secondary DRBG is thread-local, i.e., there is one
-     * instance per thread.
-     */
-    CRYPTO_THREAD_LOCAL private;
-
-    /* Which RNG is being used by default and it's configuration settings */
-    char *rng_name;
-    char *rng_cipher;
-    char *rng_digest;
-    char *rng_propq;
-
-    /* Allow the randomness source to be changed */
-    char *seed_name;
-    char *seed_propq;
-} RAND_GLOBAL;
-
 /*
  * Initialize the OSSL_LIB_CTX global DRBGs on first use.
  * Returns the allocated global data on success or NULL on failure.
@@ -473,6 +532,11 @@ void *ossl_rand_ctx_new(OSSL_LIB_CTX *libctx)
      * initialised.
      */
     OPENSSL_init_crypto(OPENSSL_INIT_BASE_ONLY, NULL);
+
+    /* Prepopulate the random provider name */
+    dgbl->random_provider_name = OPENSSL_strdup(random_provider_fips_name);
+    if (dgbl->random_provider_name == NULL)
+        goto err0;
 #endif
 
     dgbl->lock = CRYPTO_THREAD_lock_new();
@@ -491,6 +555,10 @@ err2:
     CRYPTO_THREAD_cleanup_local(&dgbl->private);
 err1:
     CRYPTO_THREAD_lock_free(dgbl->lock);
+#ifndef FIPS_MODULE
+err0:
+    OPENSSL_free(dgbl->random_provider_name);
+#endif
     OPENSSL_free(dgbl);
     return NULL;
 }
@@ -507,6 +575,9 @@ void ossl_rand_ctx_free(void *vdgbl)
     CRYPTO_THREAD_cleanup_local(&dgbl->public);
     EVP_RAND_CTX_free(dgbl->primary);
     EVP_RAND_CTX_free(dgbl->seed);
+#ifndef FIPS_MODULE
+    OPENSSL_free(dgbl->random_provider_name);
+#endif /* !FIPS_MODULE */
     OPENSSL_free(dgbl->rng_name);
     OPENSSL_free(dgbl->rng_cipher);
     OPENSSL_free(dgbl->rng_digest);
@@ -517,11 +588,6 @@ void ossl_rand_ctx_free(void *vdgbl)
     OPENSSL_free(dgbl);
 }
 
-static RAND_GLOBAL *rand_get_global(OSSL_LIB_CTX *libctx)
-{
-    return ossl_lib_ctx_get_data(libctx, OSSL_LIB_CTX_DRBG_INDEX);
-}
-
 static void rand_delete_thread_state(void *arg)
 {
     OSSL_LIB_CTX *ctx = arg;
@@ -540,72 +606,25 @@ static void rand_delete_thread_state(void *arg)
     EVP_RAND_CTX_free(rand);
 }
 
-#ifndef FIPS_MODULE
+#if !defined(FIPS_MODULE) || !defined(OPENSSL_NO_FIPS_JITTER)
 static EVP_RAND_CTX *rand_new_seed(OSSL_LIB_CTX *libctx)
 {
     EVP_RAND *rand;
-    RAND_GLOBAL *dgbl = rand_get_global(libctx);
-    EVP_RAND_CTX *ctx = NULL;
     const char *propq;
-    char *name, *props = NULL;
-    size_t props_len;
-    OSSL_PROPERTY_LIST *pl1, *pl2, *pl3 = NULL;
+    char *name;
+    EVP_RAND_CTX *ctx = NULL;
+#ifdef OPENSSL_NO_FIPS_JITTER
+    RAND_GLOBAL *dgbl = rand_get_global(libctx);
 
     if (dgbl == NULL)
         return NULL;
     propq = dgbl->seed_propq;
-    if (dgbl->seed_name != NULL) {
-        name = dgbl->seed_name;
-    } else {
-        /*
-         * Default to our internal seed source.  This isn't part of the FIPS
-         * provider so we need to override any FIPS properties.
-         */
-        if (propq == NULL || *propq == '\0') {
-            propq = "-fips";
-        } else {
-            pl1 = ossl_parse_query(libctx, propq, 1);
-            if (pl1 == NULL) {
-                ERR_raise(ERR_LIB_RAND, RAND_R_INVALID_PROPERTY_QUERY);
-                return NULL;
-            }
-            pl2 = ossl_parse_query(libctx, "-fips", 1);
-            if (pl2 == NULL) {
-                ossl_property_free(pl1);
-                ERR_raise(ERR_LIB_RAND, ERR_R_INTERNAL_ERROR);
-                return NULL;
-            }
-            pl3 = ossl_property_merge(pl2, pl1);
-            ossl_property_free(pl1);
-            ossl_property_free(pl2);
-            if (pl3 == NULL) {
-                ERR_raise(ERR_LIB_RAND, ERR_R_INTERNAL_ERROR);
-                return NULL;
-            }
-            props_len = ossl_property_list_to_string(libctx, pl3, NULL, 0);
-            if (props_len == 0) {
-                /* Shouldn't happen since we added a query element */
-                ERR_raise(ERR_LIB_RAND, ERR_R_INTERNAL_ERROR);
-                goto err;
-            } else {
-                props = OPENSSL_malloc(props_len);
-                if (props == NULL) {
-                    ERR_raise(ERR_LIB_RAND, ERR_R_MALLOC_FAILURE);
-                    goto err;
-                }
-                if (ossl_property_list_to_string(libctx, pl3,
-                        props, props_len)
-                    == 0) {
-                    ERR_raise(ERR_LIB_RAND, ERR_R_INTERNAL_ERROR);
-                    goto err;
-                }
-                ossl_property_free(pl3);
-                pl3 = NULL;
-                propq = props;
-            }
-        }
-        name = OPENSSL_MSTR(OPENSSL_DEFAULT_SEED_SRC);
-    }
+    name = dgbl->seed_name != NULL ? dgbl->seed_name
+                                   : OPENSSL_MSTR(OPENSSL_DEFAULT_SEED_SRC);
+#else /* !OPENSSL_NO_FIPS_JITTER */
+    name = "JITTER";
+    propq = "";
+#endif /* OPENSSL_NO_FIPS_JITTER */
 
     rand = EVP_RAND_fetch(libctx, name, propq);
     if (rand == NULL) {
@@ -622,15 +641,14 @@ static EVP_RAND_CTX *rand_new_seed(OSSL_LIB_CTX *libctx)
         ERR_raise(ERR_LIB_RAND, RAND_R_ERROR_INSTANTIATING_DRBG);
         goto err;
     }
-    OPENSSL_free(props);
     return ctx;
 err:
     EVP_RAND_CTX_free(ctx);
-    ossl_property_free(pl3);
-    OPENSSL_free(props);
     return NULL;
 }
+#endif /* !FIPS_MODULE || !OPENSSL_NO_FIPS_JITTER */
 
+#ifndef FIPS_MODULE
 EVP_RAND_CTX *ossl_rand_get0_seed_noncreating(OSSL_LIB_CTX *ctx)
 {
     RAND_GLOBAL *dgbl = rand_get_global(ctx);
@@ -645,7 +663,7 @@ EVP_RAND_CTX *ossl_rand_get0_seed_noncreating(OSSL_LIB_CTX *ctx)
     CRYPTO_THREAD_unlock(dgbl->lock);
     return ret;
 }
-#endif
+#endif /* !FIPS_MODULE */
 
 static EVP_RAND_CTX *rand_new_drbg(OSSL_LIB_CTX *libctx, EVP_RAND_CTX *parent,
     unsigned int reseed_interval,
@@ -654,8 +672,9 @@ static EVP_RAND_CTX *rand_new_drbg(OSSL_LIB_CTX *libctx, EVP_RAND_CTX *parent,
     EVP_RAND *rand;
     RAND_GLOBAL *dgbl = rand_get_global(libctx);
     EVP_RAND_CTX *ctx;
-    OSSL_PARAM params[8], *p = params;
+    OSSL_PARAM params[9], *p = params;
     const OSSL_PARAM *settables;
+    const char *prov_name;
     char *name, *cipher;
     int use_df = 1;
 
@@ -667,6 +686,7 @@ static EVP_RAND_CTX *rand_new_drbg(OSSL_LIB_CTX *libctx, EVP_RAND_CTX *parent,
         ERR_raise(ERR_LIB_RAND, RAND_R_UNABLE_TO_FETCH_DRBG);
         return NULL;
     }
+    prov_name = ossl_provider_name(EVP_RAND_get0_provider(rand));
     ctx = EVP_RAND_CTX_new(rand, parent);
     EVP_RAND_free(rand);
     if (ctx == NULL) {
@@ -684,6 +704,9 @@ static EVP_RAND_CTX *rand_new_drbg(OSSL_LIB_CTX *libctx, EVP_RAND_CTX *parent,
         && OSSL_PARAM_locate_const(settables, OSSL_DRBG_PARAM_DIGEST))
         *p++ = OSSL_PARAM_construct_utf8_string(OSSL_DRBG_PARAM_DIGEST,
             dgbl->rng_digest, 0);
+    if (prov_name != NULL)
+        *p++ = OSSL_PARAM_construct_utf8_string(OSSL_PROV_PARAM_CORE_PROV_NAME,
+            (char *)prov_name, 0);
     if (dgbl->rng_propq != NULL)
         *p++ = OSSL_PARAM_construct_utf8_string(OSSL_DRBG_PARAM_PROPERTIES,
             dgbl->rng_propq, 0);
@@ -704,13 +727,13 @@ static EVP_RAND_CTX *rand_new_drbg(OSSL_LIB_CTX *libctx, EVP_RAND_CTX *parent,
     return ctx;
 }
 
-#ifdef FIPS_MODULE
+#if defined(FIPS_MODULE)
 static EVP_RAND_CTX *rand_new_crngt(OSSL_LIB_CTX *libctx, EVP_RAND_CTX *parent)
 {
     EVP_RAND *rand;
     EVP_RAND_CTX *ctx;
 
-    rand = EVP_RAND_fetch(libctx, "CRNG-TEST", "fips=no");
+    rand = EVP_RAND_fetch(libctx, "CRNG-TEST", "-fips");
     if (rand == NULL) {
         ERR_raise(ERR_LIB_RAND, RAND_R_UNABLE_TO_FETCH_DRBG);
         return NULL;
@@ -729,7 +752,79 @@ static EVP_RAND_CTX *rand_new_crngt(OSSL_LIB_CTX *libctx, EVP_RAND_CTX *parent)
     }
     return ctx;
 }
-#endif
+#endif /* FIPS_MODULE */
+
+/*
+ * Get the primary random generator.
+ * Returns pointer to its EVP_RAND_CTX on success, NULL on failure.
+ *
+ */
+static EVP_RAND_CTX *rand_get0_primary(OSSL_LIB_CTX *ctx, RAND_GLOBAL *dgbl)
+{
+    EVP_RAND_CTX *ret, *seed, *newseed = NULL, *primary;
+
+    if (dgbl == NULL)
+        return NULL;
+
+    if (!CRYPTO_THREAD_read_lock(dgbl->lock))
+        return NULL;
+
+    ret = dgbl->primary;
+    seed = dgbl->seed;
+    CRYPTO_THREAD_unlock(dgbl->lock);
+
+    if (ret != NULL)
+        return ret;
+
+#if !defined(FIPS_MODULE) || !defined(OPENSSL_NO_FIPS_JITTER)
+    /* Create a seed source for libcrypto or jitter enabled FIPS provider */
+    if (seed == NULL) {
+        ERR_set_mark();
+        seed = newseed = rand_new_seed(ctx);
+        ERR_pop_to_mark();
+    }
+#endif /* !FIPS_MODULE || !OPENSSL_NO_FIPS_JITTER */
+
+#if defined(FIPS_MODULE)
+    /* The FIPS provider has entropy health tests instead of the primary */
+    ret = rand_new_crngt(ctx, seed);
+#else /* FIPS_MODULE */
+    ret = rand_new_drbg(ctx, seed, PRIMARY_RESEED_INTERVAL,
+        PRIMARY_RESEED_TIME_INTERVAL);
+#endif /* FIPS_MODULE */
+
+    /*
+     * The primary DRBG may be shared between multiple threads so we must
+     * enable locking.
+     */
+    if (ret == NULL || !EVP_RAND_enable_locking(ret)) {
+        if (ret != NULL) {
+            ERR_raise(ERR_LIB_EVP, EVP_R_UNABLE_TO_ENABLE_LOCKING);
+            EVP_RAND_CTX_free(ret);
+        }
+        if (newseed == NULL)
+            return NULL;
+        /* else carry on and store seed */
+        ret = NULL;
+    }
+
+    if (!CRYPTO_THREAD_write_lock(dgbl->lock))
+        return NULL;
+
+    primary = dgbl->primary;
+    if (primary != NULL) {
+        CRYPTO_THREAD_unlock(dgbl->lock);
+        EVP_RAND_CTX_free(ret);
+        EVP_RAND_CTX_free(newseed);
+        return primary;
+    }
+    if (newseed != NULL)
+        dgbl->seed = newseed;
+    dgbl->primary = ret;
+    CRYPTO_THREAD_unlock(dgbl->lock);
+
+    return ret;
+}
 
 /*
  * Get the primary random generator.
@@ -739,63 +834,12 @@ static EVP_RAND_CTX *rand_new_crngt(OSSL_LIB_CTX *libctx, EVP_RAND_CTX *parent)
 EVP_RAND_CTX *RAND_get0_primary(OSSL_LIB_CTX *ctx)
 {
     RAND_GLOBAL *dgbl = rand_get_global(ctx);
-    EVP_RAND_CTX *ret;
 
-    if (dgbl == NULL)
-        return NULL;
-
-    if (!CRYPTO_THREAD_read_lock(dgbl->lock))
-        return NULL;
-
-    ret = dgbl->primary;
-    CRYPTO_THREAD_unlock(dgbl->lock);
-
-    if (ret != NULL)
-        return ret;
-
-    if (!CRYPTO_THREAD_write_lock(dgbl->lock))
-        return NULL;
-
-    ret = dgbl->primary;
-    if (ret != NULL) {
-        CRYPTO_THREAD_unlock(dgbl->lock);
-        return ret;
-    }
-
-#ifdef FIPS_MODULE
-    ret = rand_new_crngt(ctx, dgbl->seed);
-#else
-    if (dgbl->seed == NULL) {
-        ERR_set_mark();
-        dgbl->seed = rand_new_seed(ctx);
-        ERR_pop_to_mark();
-    }
-    ret = rand_new_drbg(ctx, dgbl->seed, PRIMARY_RESEED_INTERVAL,
-        PRIMARY_RESEED_TIME_INTERVAL);
-#endif
-
-    /*
-     * The primary DRBG may be shared between multiple threads so we must
-     * enable locking.
-     */
-    dgbl->primary = ret;
-    if (ret != NULL && !EVP_RAND_enable_locking(ret)) {
-        ERR_raise(ERR_LIB_EVP, EVP_R_UNABLE_TO_ENABLE_LOCKING);
-        EVP_RAND_CTX_free(ret);
-        ret = dgbl->primary = NULL;
-    }
-    CRYPTO_THREAD_unlock(dgbl->lock);
-
-    return ret;
+    return dgbl == NULL ? NULL : rand_get0_primary(ctx, dgbl);
 }
 
-/*
- * Get the public random generator.
- * Returns pointer to its EVP_RAND_CTX on success, NULL on failure.
- */
-EVP_RAND_CTX *RAND_get0_public(OSSL_LIB_CTX *ctx)
+static EVP_RAND_CTX *rand_get0_public(OSSL_LIB_CTX *ctx, RAND_GLOBAL *dgbl)
 {
-    RAND_GLOBAL *dgbl = rand_get_global(ctx);
     EVP_RAND_CTX *rand, *primary;
 
     if (dgbl == NULL)
@@ -803,7 +847,7 @@ EVP_RAND_CTX *RAND_get0_public(OSSL_LIB_CTX *ctx)
 
     rand = CRYPTO_THREAD_get_local(&dgbl->public);
     if (rand == NULL) {
-        primary = RAND_get0_primary(ctx);
+        primary = rand_get0_primary(ctx, dgbl);
         if (primary == NULL)
             return NULL;
 
@@ -826,20 +870,23 @@ EVP_RAND_CTX *RAND_get0_public(OSSL_LIB_CTX *ctx)
 }
 
 /*
- * Get the private random generator.
+ * Get the public random generator.
  * Returns pointer to its EVP_RAND_CTX on success, NULL on failure.
  */
-EVP_RAND_CTX *RAND_get0_private(OSSL_LIB_CTX *ctx)
+EVP_RAND_CTX *RAND_get0_public(OSSL_LIB_CTX *ctx)
 {
     RAND_GLOBAL *dgbl = rand_get_global(ctx);
-    EVP_RAND_CTX *rand, *primary;
 
-    if (dgbl == NULL)
-        return NULL;
+    return dgbl == NULL ? NULL : rand_get0_public(ctx, dgbl);
+}
+
+static EVP_RAND_CTX *rand_get0_private(OSSL_LIB_CTX *ctx, RAND_GLOBAL *dgbl)
+{
+    EVP_RAND_CTX *rand, *primary;
 
     rand = CRYPTO_THREAD_get_local(&dgbl->private);
     if (rand == NULL) {
-        primary = RAND_get0_primary(ctx);
+        primary = rand_get0_primary(ctx, dgbl);
         if (primary == NULL)
             return NULL;
 
@@ -861,6 +908,17 @@ EVP_RAND_CTX *RAND_get0_private(OSSL_LIB_CTX *ctx)
     return rand;
 }
 
+/*
+ * Get the private random generator.
+ * Returns pointer to its EVP_RAND_CTX on success, NULL on failure.
+ */
+EVP_RAND_CTX *RAND_get0_private(OSSL_LIB_CTX *ctx)
+{
+    RAND_GLOBAL *dgbl = rand_get_global(ctx);
+
+    return dgbl == NULL ? NULL : rand_get0_private(ctx, dgbl);
+}
+
 #ifdef FIPS_MODULE
 EVP_RAND_CTX *ossl_rand_get0_private_noncreating(OSSL_LIB_CTX *ctx)
 {
@@ -923,7 +981,8 @@ static int random_conf_init(CONF_IMODULE *md, const CONF *cnf)
 {
     STACK_OF(CONF_VALUE) *elist;
     CONF_VALUE *cval;
-    RAND_GLOBAL *dgbl = rand_get_global(NCONF_get0_libctx((CONF *)cnf));
+    OSSL_LIB_CTX *libctx = NCONF_get0_libctx((CONF *)cnf);
+    RAND_GLOBAL *dgbl = rand_get_global(libctx);
     int i, r = 1;
 
     OSSL_TRACE1(CONF, "Loading random module: section %s\n",
@@ -959,6 +1018,31 @@ static int random_conf_init(CONF_IMODULE *md, const CONF *cnf)
         } else if (OPENSSL_strcasecmp(cval->name, "seed_properties") == 0) {
             if (!random_set_string(&dgbl->seed_propq, cval->value))
                 return 0;
+        } else if (OPENSSL_strcasecmp(cval->name, "random_provider") == 0) {
+#ifndef FIPS_MODULE
+            OSSL_PROVIDER *prov = ossl_provider_find(libctx, cval->value, 0);
+
+            if (prov != NULL) {
+                if (!RAND_set1_random_provider(libctx, prov)) {
+                    ERR_raise(ERR_LIB_CRYPTO, ERR_R_INTERNAL_ERROR);
+                    OSSL_PROVIDER_unload(prov);
+                    return 0;
+                }
+                /*
+                 * We need to release the reference from ossl_provider_find because
+                 * we don't want to keep a reference counted handle to the provider.
+                 *
+                 * The provider unload code checks for the random provider and,
+                 * if present, our reference will be NULLed when it is fully freed.
+                 * The provider load code, conversely, checks the provider name
+                 * and re-hooks our reference if required.  This means that a load,
+                 * hook random provider, use, unload, reload, reuse sequence will
+                 * work as expected.
+                 */
+                OSSL_PROVIDER_unload(prov);
+            } else if (!set_random_provider_name(dgbl, cval->value))
+                return 0;
+#endif
         } else {
             ERR_raise_data(ERR_LIB_CRYPTO,
                 CRYPTO_R_UNKNOWN_NAME_IN_RANDOM_SECTION,
@@ -1012,4 +1096,69 @@ int RAND_set_seed_source_type(OSSL_LIB_CTX *ctx, const char *seed,
         && random_set_string(&dgbl->seed_propq, propq);
 }
 
-#endif
+int RAND_set1_random_provider(OSSL_LIB_CTX *ctx, OSSL_PROVIDER *prov)
+{
+    RAND_GLOBAL *dgbl = rand_get_global(ctx);
+
+    if (dgbl == NULL)
+        return 0;
+
+    if (prov == NULL) {
+        OPENSSL_free(dgbl->random_provider_name);
+        dgbl->random_provider_name = NULL;
+        dgbl->random_provider = NULL;
+        return 1;
+    }
+
+    if (dgbl->random_provider == prov)
+        return 1;
+
+    if (!set_random_provider_name(dgbl, OSSL_PROVIDER_get0_name(prov)))
+        return 0;
+
+    dgbl->random_provider = prov;
+    return 1;
+}
+
+/*
+ * When a new provider is loaded, we need to check to see if it is the
+ * designated randomness provider and register it if it is.
+ */
+int ossl_rand_check_random_provider_on_load(OSSL_LIB_CTX *ctx,
+    OSSL_PROVIDER *prov)
+{
+    RAND_GLOBAL *dgbl = rand_get_global(ctx);
+
+    if (dgbl == NULL)
+        return 0;
+
+    /* No random provider name specified, or one is installed already */
+    if (dgbl->random_provider_name == NULL || dgbl->random_provider != NULL)
+        return 1;
+
+    /* Does this provider match the name we're using? */
+    if (strcmp(dgbl->random_provider_name, OSSL_PROVIDER_get0_name(prov)) != 0)
+        return 1;
+
+    dgbl->random_provider = prov;
+    return 1;
+}
+
+/*
+ * When a provider is being unloaded, if it is the randomness provider,
+ * we need to deregister it.
+ */
+int ossl_rand_check_random_provider_on_unload(OSSL_LIB_CTX *ctx,
+    OSSL_PROVIDER *prov)
+{
+    RAND_GLOBAL *dgbl = rand_get_global(ctx);
+
+    if (dgbl == NULL)
+        return 0;
+
+    if (dgbl->random_provider == prov)
+        dgbl->random_provider = NULL;
+    return 1;
+}
+
+#endif /* !FIPS_MODULE */
