@@ -1,5 +1,5 @@
 /*
- * Copyright 2022-2024 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2022-2025 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -21,6 +21,7 @@
 #include <unistd.h>
 #include <sys/syscall.h>
 #include <asm/hwprobe.h>
+#include <sys/auxv.h>
 #endif
 
 extern size_t riscv_vlen_asm(void);
@@ -30,6 +31,10 @@ static void strtoupper(char *str);
 
 static size_t vlen = 0;
 
+#ifdef OSSL_RISCV_HWPROBE
+unsigned int OPENSSL_riscv_hwcap_P = 0;
+#endif
+
 uint32_t OPENSSL_rdtsc(void)
 {
     return 0;
@@ -99,8 +104,9 @@ static void hwprobe_to_cap(void)
                 if (pairs[j].key == RISCV_capabilities[i].hwprobe_key
                     && (pairs[j].value & RISCV_capabilities[i].hwprobe_value)
                         != 0)
-                    /* Match, set relevant bit in OPENSSL_riscvcap_P[] */
-                    OPENSSL_riscvcap_P[RISCV_capabilities[i].index] |= (1 << RISCV_capabilities[i].bit_offset);
+                    if (!IS_IN_DEPEND_VECTOR(RISCV_capabilities[i].bit_offset) || VECTOR_CAPABLE)
+                        /* Match, set relevant bit in OPENSSL_riscvcap_P[] */
+                        OPENSSL_riscvcap_P[RISCV_capabilities[i].index] |= (1 << RISCV_capabilities[i].bit_offset);
             }
         }
     }
@@ -129,6 +135,7 @@ void OPENSSL_cpuid_setup(void)
     }
 #ifdef OSSL_RISCV_HWPROBE
     else {
+        OPENSSL_riscv_hwcap_P = getauxval(AT_HWCAP);
         hwprobe_to_cap();
     }
 #endif
