@@ -15,16 +15,16 @@
 #define OPENSSL_SUPPRESS_DEPRECATED
 
 #ifndef OPENSSL_NO_SRP
-# include "internal/cryptlib.h"
-# include <openssl/sha.h>
-# include <openssl/srp.h>
-# include <openssl/evp.h>
-# include "crypto/bn_srp.h"
+#include "internal/cryptlib.h"
+#include <openssl/sha.h>
+#include <openssl/srp.h>
+#include <openssl/evp.h>
+#include "crypto/bn_srp.h"
 
 /* calculate = SHA1(PAD(x) || PAD(y)) */
 
 static BIGNUM *srp_Calc_xy(const BIGNUM *x, const BIGNUM *y, const BIGNUM *N,
-                           OSSL_LIB_CTX *libctx, const char *propq)
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     unsigned char digest[SHA_DIGEST_LENGTH];
     unsigned char *tmp = NULL;
@@ -46,22 +46,22 @@ static BIGNUM *srp_Calc_xy(const BIGNUM *x, const BIGNUM *y, const BIGNUM *N,
         || !EVP_Digest(tmp, numN * 2, digest, NULL, sha1, NULL))
         goto err;
     res = BN_bin2bn(digest, sizeof(digest), NULL);
- err:
+err:
     EVP_MD_free(sha1);
     OPENSSL_free(tmp);
     return res;
 }
 
 static BIGNUM *srp_Calc_k(const BIGNUM *N, const BIGNUM *g,
-                          OSSL_LIB_CTX *libctx,
-                          const char *propq)
+    OSSL_LIB_CTX *libctx,
+    const char *propq)
 {
     /* k = SHA1(N | PAD(g)) -- tls-srp RFC 5054 */
     return srp_Calc_xy(N, g, N, libctx, propq);
 }
 
 BIGNUM *SRP_Calc_u_ex(const BIGNUM *A, const BIGNUM *B, const BIGNUM *N,
-                      OSSL_LIB_CTX *libctx, const char *propq)
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     /* u = SHA1(PAD(A) || PAD(B) ) -- tls-srp RFC 5054 */
     return srp_Calc_xy(A, B, N, libctx, propq);
@@ -74,7 +74,7 @@ BIGNUM *SRP_Calc_u(const BIGNUM *A, const BIGNUM *B, const BIGNUM *N)
 }
 
 BIGNUM *SRP_Calc_server_key(const BIGNUM *A, const BIGNUM *v, const BIGNUM *u,
-                            const BIGNUM *b, const BIGNUM *N)
+    const BIGNUM *b, const BIGNUM *N)
 {
     BIGNUM *tmp = NULL, *S = NULL;
     BN_CTX *bn_ctx;
@@ -97,25 +97,23 @@ BIGNUM *SRP_Calc_server_key(const BIGNUM *A, const BIGNUM *v, const BIGNUM *u,
         BN_free(S);
         S = NULL;
     }
- err:
+err:
     BN_CTX_free(bn_ctx);
     BN_clear_free(tmp);
     return S;
 }
 
 BIGNUM *SRP_Calc_B_ex(const BIGNUM *b, const BIGNUM *N, const BIGNUM *g,
-                      const BIGNUM *v, OSSL_LIB_CTX *libctx, const char *propq)
+    const BIGNUM *v, OSSL_LIB_CTX *libctx, const char *propq)
 {
     BIGNUM *kv = NULL, *gb = NULL;
     BIGNUM *B = NULL, *k = NULL;
     BN_CTX *bn_ctx;
 
-    if (b == NULL || N == NULL || g == NULL || v == NULL ||
-        (bn_ctx = BN_CTX_new_ex(libctx)) == NULL)
+    if (b == NULL || N == NULL || g == NULL || v == NULL || (bn_ctx = BN_CTX_new_ex(libctx)) == NULL)
         return NULL;
 
-    if ((kv = BN_new()) == NULL ||
-        (gb = BN_new()) == NULL || (B = BN_new()) == NULL)
+    if ((kv = BN_new()) == NULL || (gb = BN_new()) == NULL || (B = BN_new()) == NULL)
         goto err;
 
     /* B = g**b + k*v */
@@ -127,7 +125,7 @@ BIGNUM *SRP_Calc_B_ex(const BIGNUM *b, const BIGNUM *N, const BIGNUM *g,
         BN_free(B);
         B = NULL;
     }
- err:
+err:
     BN_CTX_free(bn_ctx);
     BN_clear_free(kv);
     BN_clear_free(gb);
@@ -136,13 +134,13 @@ BIGNUM *SRP_Calc_B_ex(const BIGNUM *b, const BIGNUM *N, const BIGNUM *g,
 }
 
 BIGNUM *SRP_Calc_B(const BIGNUM *b, const BIGNUM *N, const BIGNUM *g,
-                   const BIGNUM *v)
+    const BIGNUM *v)
 {
     return SRP_Calc_B_ex(b, N, g, v, NULL, NULL);
 }
 
 BIGNUM *SRP_Calc_x_ex(const BIGNUM *s, const char *user, const char *pass,
-                      OSSL_LIB_CTX *libctx, const char *propq)
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     unsigned char dig[SHA_DIGEST_LENGTH];
     EVP_MD_CTX *ctxt;
@@ -181,7 +179,7 @@ BIGNUM *SRP_Calc_x_ex(const BIGNUM *s, const char *user, const char *pass,
 
     res = BN_bin2bn(dig, sizeof(dig), NULL);
 
- err:
+err:
     EVP_MD_free(sha1);
     OPENSSL_free(cs);
     EVP_MD_CTX_free(ctxt);
@@ -210,8 +208,8 @@ BIGNUM *SRP_Calc_A(const BIGNUM *a, const BIGNUM *N, const BIGNUM *g)
 }
 
 BIGNUM *SRP_Calc_client_key_ex(const BIGNUM *N, const BIGNUM *B, const BIGNUM *g,
-                            const BIGNUM *x, const BIGNUM *a, const BIGNUM *u,
-                            OSSL_LIB_CTX *libctx, const char *propq)
+    const BIGNUM *x, const BIGNUM *a, const BIGNUM *u,
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     BIGNUM *tmp = NULL, *tmp2 = NULL, *tmp3 = NULL, *k = NULL, *K = NULL;
     BIGNUM *xtmp = NULL;
@@ -221,10 +219,7 @@ BIGNUM *SRP_Calc_client_key_ex(const BIGNUM *N, const BIGNUM *B, const BIGNUM *g
         || a == NULL || (bn_ctx = BN_CTX_new_ex(libctx)) == NULL)
         return NULL;
 
-    if ((tmp = BN_new()) == NULL ||
-        (tmp2 = BN_new()) == NULL ||
-        (tmp3 = BN_new()) == NULL ||
-        (xtmp = BN_new()) == NULL)
+    if ((tmp = BN_new()) == NULL || (tmp2 = BN_new()) == NULL || (tmp3 = BN_new()) == NULL || (xtmp = BN_new()) == NULL)
         goto err;
 
     BN_with_flags(xtmp, x, BN_FLG_CONSTTIME);
@@ -247,7 +242,7 @@ BIGNUM *SRP_Calc_client_key_ex(const BIGNUM *N, const BIGNUM *B, const BIGNUM *g
         K = NULL;
     }
 
- err:
+err:
     BN_CTX_free(bn_ctx);
     BN_free(xtmp);
     BN_clear_free(tmp);
@@ -258,7 +253,7 @@ BIGNUM *SRP_Calc_client_key_ex(const BIGNUM *N, const BIGNUM *B, const BIGNUM *g
 }
 
 BIGNUM *SRP_Calc_client_key(const BIGNUM *N, const BIGNUM *B, const BIGNUM *g,
-                            const BIGNUM *x, const BIGNUM *a, const BIGNUM *u)
+    const BIGNUM *x, const BIGNUM *a, const BIGNUM *u)
 {
     return SRP_Calc_client_key_ex(N, B, g, x, a, u, NULL, NULL);
 }
@@ -278,7 +273,7 @@ int SRP_Verify_B_mod_N(const BIGNUM *B, const BIGNUM *N)
     if (!BN_nnmod(r, B, N, bn_ctx))
         goto err;
     ret = !BN_is_zero(r);
- err:
+err:
     BN_CTX_free(bn_ctx);
     BN_free(r);
     return ret;
@@ -291,16 +286,16 @@ int SRP_Verify_A_mod_N(const BIGNUM *A, const BIGNUM *N)
 }
 
 static SRP_gN knowngN[] = {
-    {"8192", &ossl_bn_generator_19, &ossl_bn_group_8192},
-    {"6144", &ossl_bn_generator_5, &ossl_bn_group_6144},
-    {"4096", &ossl_bn_generator_5, &ossl_bn_group_4096},
-    {"3072", &ossl_bn_generator_5, &ossl_bn_group_3072},
-    {"2048", &ossl_bn_generator_2, &ossl_bn_group_2048},
-    {"1536", &ossl_bn_generator_2, &ossl_bn_group_1536},
-    {"1024", &ossl_bn_generator_2, &ossl_bn_group_1024},
+    { "8192", &ossl_bn_generator_19, &ossl_bn_group_8192 },
+    { "6144", &ossl_bn_generator_5, &ossl_bn_group_6144 },
+    { "4096", &ossl_bn_generator_5, &ossl_bn_group_4096 },
+    { "3072", &ossl_bn_generator_5, &ossl_bn_group_3072 },
+    { "2048", &ossl_bn_generator_2, &ossl_bn_group_2048 },
+    { "1536", &ossl_bn_generator_2, &ossl_bn_group_1536 },
+    { "1024", &ossl_bn_generator_2, &ossl_bn_group_1024 },
 };
 
-# define KNOWN_GN_NUMBER sizeof(knowngN) / sizeof(SRP_gN)
+#define KNOWN_GN_NUMBER sizeof(knowngN) / sizeof(SRP_gN)
 
 /*
  * Check if G and N are known parameters. The values have been generated
