@@ -15,18 +15,18 @@
 #define OPENSSL_SUPPRESS_DEPRECATED
 
 #ifndef OPENSSL_NO_SRP
-# include "internal/cryptlib.h"
-# include "crypto/evp.h"
-# include <openssl/sha.h>
-# include <openssl/srp.h>
-# include <openssl/evp.h>
-# include <openssl/buffer.h>
-# include <openssl/rand.h>
-# include <openssl/txt_db.h>
-# include <openssl/err.h>
+#include "internal/cryptlib.h"
+#include "crypto/evp.h"
+#include <openssl/sha.h>
+#include <openssl/srp.h>
+#include <openssl/evp.h>
+#include <openssl/buffer.h>
+#include <openssl/rand.h>
+#include <openssl/txt_db.h>
+#include <openssl/err.h>
 
-# define SRP_RANDOM_SALT_LEN 20
-# define MAX_LEN 2500
+#define SRP_RANDOM_SALT_LEN 20
+#define MAX_LEN 2500
 
 /*
  * Note that SRP uses its own variant of base 64 encoding. A different base64
@@ -84,7 +84,7 @@ static int t_fromb64(unsigned char *a, size_t alen, const char *src)
 
     /* Add any encoded padding that is required */
     if (padsize != 0
-            && EVP_DecodeUpdate(ctx, a, &outl, pad, padsize) < 0) {
+        && EVP_DecodeUpdate(ctx, a, &outl, pad, padsize) < 0) {
         outl = -1;
         goto err;
     }
@@ -120,7 +120,7 @@ static int t_fromb64(unsigned char *a, size_t alen, const char *src)
         outl -= padsize;
     }
 
- err:
+err:
     EVP_ENCODE_CTX_free(ctx);
 
     return outl;
@@ -134,15 +134,14 @@ static int t_tob64(char *dst, const unsigned char *src, int size)
 {
     EVP_ENCODE_CTX *ctx = EVP_ENCODE_CTX_new();
     int outl = 0, outl2 = 0;
-    unsigned char pad[2] = {0, 0};
+    unsigned char pad[2] = { 0, 0 };
     size_t leadz = 0;
 
     if (ctx == NULL)
         return 0;
 
     EVP_EncodeInit(ctx);
-    evp_encode_ctx_set_flags(ctx, EVP_ENCODE_CTX_NO_NEWLINES
-                                  | EVP_ENCODE_CTX_USE_SRP_ALPHABET);
+    evp_encode_ctx_set_flags(ctx, EVP_ENCODE_CTX_NO_NEWLINES | EVP_ENCODE_CTX_USE_SRP_ALPHABET);
 
     /*
      * We pad at the front with zero bytes until the length is a multiple of 3
@@ -151,14 +150,14 @@ static int t_tob64(char *dst, const unsigned char *src, int size)
      */
     leadz = 3 - (size % 3);
     if (leadz != 3
-            && !EVP_EncodeUpdate(ctx, (unsigned char *)dst, &outl, pad,
-                                 leadz)) {
+        && !EVP_EncodeUpdate(ctx, (unsigned char *)dst, &outl, pad,
+            leadz)) {
         EVP_ENCODE_CTX_free(ctx);
         return 0;
     }
 
     if (!EVP_EncodeUpdate(ctx, (unsigned char *)dst + outl, &outl2, src,
-                          size)) {
+            size)) {
         EVP_ENCODE_CTX_free(ctx);
         return 0;
     }
@@ -203,14 +202,14 @@ SRP_user_pwd *SRP_user_pwd_new(void)
 }
 
 void SRP_user_pwd_set_gN(SRP_user_pwd *vinfo, const BIGNUM *g,
-                         const BIGNUM *N)
+    const BIGNUM *N)
 {
     vinfo->N = N;
     vinfo->g = g;
 }
 
 int SRP_user_pwd_set1_ids(SRP_user_pwd *vinfo, const char *id,
-                          const char *info)
+    const char *info)
 {
     OPENSSL_free(vinfo->id);
     OPENSSL_free(vinfo->info);
@@ -222,7 +221,7 @@ int SRP_user_pwd_set1_ids(SRP_user_pwd *vinfo, const char *id,
 }
 
 static int SRP_user_pwd_set_sv(SRP_user_pwd *vinfo, const char *s,
-                               const char *v)
+    const char *v)
 {
     unsigned char tmp[MAX_LEN];
     int len;
@@ -242,7 +241,7 @@ static int SRP_user_pwd_set_sv(SRP_user_pwd *vinfo, const char *s,
     if (vinfo->s == NULL)
         goto err;
     return 1;
- err:
+err:
     BN_free(vinfo->v);
     vinfo->v = NULL;
     return 0;
@@ -269,8 +268,8 @@ static SRP_user_pwd *srp_user_pwd_dup(SRP_user_pwd *src)
     SRP_user_pwd_set_gN(ret, src->g, src->N);
     if (!SRP_user_pwd_set1_ids(ret, src->id, src->info)
         || !SRP_user_pwd_set0_sv(ret, BN_dup(src->s), BN_dup(src->v))) {
-            SRP_user_pwd_free(ret);
-            return NULL;
+        SRP_user_pwd_free(ret);
+        return NULL;
     }
     return ret;
 }
@@ -329,7 +328,7 @@ static SRP_gN_cache *SRP_gN_new_init(const char *ch)
         return newgN;
 
     OPENSSL_free(newgN->b64_bn);
- err:
+err:
     OPENSSL_free(newgN);
     return NULL;
 }
@@ -371,7 +370,7 @@ static BIGNUM *SRP_gN_place_bn(STACK_OF(SRP_gN_cache) *gN_cache, char *ch)
         if (strcmp(cache->b64_bn, ch) == 0)
             return cache->bn;
     }
-    {                           /* it is the first time that we find it */
+    { /* it is the first time that we find it */
         SRP_gN_cache *newgN = SRP_gN_new_init(ch);
         if (newgN) {
             if (sk_SRP_gN_cache_insert(gN_cache, newgN, 0) > 0)
@@ -441,9 +440,9 @@ int SRP_VBASE_init(SRP_VBASE *vb, char *verifier_file)
 
             if ((gN->id = OPENSSL_strdup(pp[DB_srpid])) == NULL
                 || (gN->N = SRP_gN_place_bn(vb->gN_cache, pp[DB_srpverifier]))
-                        == NULL
+                    == NULL
                 || (gN->g = SRP_gN_place_bn(vb->gN_cache, pp[DB_srpsalt]))
-                        == NULL
+                    == NULL
                 || sk_SRP_gN_insert(SRP_gN_tab, gN, 0) == 0)
                 goto err;
 
@@ -462,13 +461,11 @@ int SRP_VBASE_init(SRP_VBASE *vb, char *verifier_file)
                     goto err;
 
                 SRP_user_pwd_set_gN(user_pwd, lgN->g, lgN->N);
-                if (!SRP_user_pwd_set1_ids
-                    (user_pwd, pp[DB_srpid], pp[DB_srpinfo]))
+                if (!SRP_user_pwd_set1_ids(user_pwd, pp[DB_srpid], pp[DB_srpinfo]))
                     goto err;
 
                 error_code = SRP_ERR_VBASE_BN_LIB;
-                if (!SRP_user_pwd_set_sv
-                    (user_pwd, pp[DB_srpsalt], pp[DB_srpverifier]))
+                if (!SRP_user_pwd_set_sv(user_pwd, pp[DB_srpsalt], pp[DB_srpverifier]))
                     goto err;
 
                 if (sk_SRP_user_pwd_insert(vb->users_pwd, user_pwd, 0) == 0)
@@ -491,7 +488,7 @@ int SRP_VBASE_init(SRP_VBASE *vb, char *verifier_file)
     }
     error_code = SRP_NO_ERROR;
 
- err:
+err:
     /*
      * there may be still some leaks to fix, if this fails, the application
      * terminates most likely
@@ -510,7 +507,6 @@ int SRP_VBASE_init(SRP_VBASE *vb, char *verifier_file)
     sk_SRP_gN_free(SRP_gN_tab);
 
     return error_code;
-
 }
 
 static SRP_user_pwd *find_user(SRP_VBASE *vb, char *username)
@@ -537,7 +533,7 @@ int SRP_VBASE_add0_user(SRP_VBASE *vb, SRP_user_pwd *user_pwd)
     return 1;
 }
 
-# ifndef OPENSSL_NO_DEPRECATED_1_1_0
+#ifndef OPENSSL_NO_DEPRECATED_1_1_0
 /*
  * DEPRECATED: use SRP_VBASE_get1_by_user instead.
  * This method ignores the configured seed and fails for an unknown user.
@@ -548,7 +544,7 @@ SRP_user_pwd *SRP_VBASE_get_by_user(SRP_VBASE *vb, char *username)
 {
     return find_user(vb, username);
 }
-# endif
+#endif
 
 /*
  * Ownership of the returned pointer is released to the caller.
@@ -568,11 +564,10 @@ SRP_user_pwd *SRP_VBASE_get1_by_user(SRP_VBASE *vb, char *username)
     if ((user = find_user(vb, username)) != NULL)
         return srp_user_pwd_dup(user);
 
-    if ((vb->seed_key == NULL) ||
-        (vb->default_g == NULL) || (vb->default_N == NULL))
+    if ((vb->seed_key == NULL) || (vb->default_g == NULL) || (vb->default_N == NULL))
         return NULL;
 
-/* if the user is unknown we set parameters as well if we have a seed_key */
+    /* if the user is unknown we set parameters as well if we have a seed_key */
 
     if ((user = SRP_user_pwd_new()) == NULL)
         return NULL;
@@ -599,11 +594,11 @@ SRP_user_pwd *SRP_VBASE_get1_by_user(SRP_VBASE *vb, char *username)
     EVP_MD_free(md);
     md = NULL;
     if (SRP_user_pwd_set0_sv(user,
-                             BN_bin2bn(digs, SHA_DIGEST_LENGTH, NULL),
-                             BN_bin2bn(digv, SHA_DIGEST_LENGTH, NULL)))
+            BN_bin2bn(digs, SHA_DIGEST_LENGTH, NULL),
+            BN_bin2bn(digv, SHA_DIGEST_LENGTH, NULL)))
         return user;
 
- err:
+err:
     EVP_MD_free(md);
     EVP_MD_CTX_free(ctxt);
     SRP_user_pwd_free(user);
@@ -614,8 +609,8 @@ SRP_user_pwd *SRP_VBASE_get1_by_user(SRP_VBASE *vb, char *username)
  * create a verifier (*salt,*verifier,g and N are in base64)
  */
 char *SRP_create_verifier_ex(const char *user, const char *pass, char **salt,
-                             char **verifier, const char *N, const char *g,
-                             OSSL_LIB_CTX *libctx, const char *propq)
+    char **verifier, const char *N, const char *g,
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     int len;
     char *result = NULL, *vf = NULL;
@@ -626,8 +621,7 @@ char *SRP_create_verifier_ex(const char *user, const char *pass, char **salt,
     char *defgNid = NULL;
     int vfsize = 0;
 
-    if ((user == NULL) ||
-        (pass == NULL) || (salt == NULL) || (verifier == NULL))
+    if ((user == NULL) || (pass == NULL) || (salt == NULL) || (verifier == NULL))
         goto err;
 
     if (N) {
@@ -667,7 +661,7 @@ char *SRP_create_verifier_ex(const char *user, const char *pass, char **salt,
         goto err;
 
     if (!SRP_create_verifier_BN_ex(user, pass, &s, &v, N_bn, g_bn, libctx,
-                                   propq))
+            propq))
         goto err;
 
     if (BN_bn2bin(v, tmp) < 0)
@@ -695,7 +689,7 @@ char *SRP_create_verifier_ex(const char *user, const char *pass, char **salt,
     vf = NULL;
     result = defgNid;
 
- err:
+err:
     BN_free(N_bn_alloc);
     BN_free(g_bn_alloc);
     OPENSSL_clear_free(vf, vfsize);
@@ -705,7 +699,7 @@ char *SRP_create_verifier_ex(const char *user, const char *pass, char **salt,
 }
 
 char *SRP_create_verifier(const char *user, const char *pass, char **salt,
-                          char **verifier, const char *N, const char *g)
+    char **verifier, const char *N, const char *g)
 {
     return SRP_create_verifier_ex(user, pass, salt, verifier, N, g, NULL, NULL);
 }
@@ -720,9 +714,9 @@ char *SRP_create_verifier(const char *user, const char *pass, char **salt,
  * BIGNUMS.
  */
 int SRP_create_verifier_BN_ex(const char *user, const char *pass, BIGNUM **salt,
-                              BIGNUM **verifier, const BIGNUM *N,
-                              const BIGNUM *g, OSSL_LIB_CTX *libctx,
-                              const char *propq)
+    BIGNUM **verifier, const BIGNUM *N,
+    const BIGNUM *g, OSSL_LIB_CTX *libctx,
+    const char *propq)
 {
     int result = 0;
     BIGNUM *x = NULL;
@@ -730,10 +724,7 @@ int SRP_create_verifier_BN_ex(const char *user, const char *pass, BIGNUM **salt,
     unsigned char tmp2[MAX_LEN];
     BIGNUM *salttmp = NULL, *verif;
 
-    if ((user == NULL) ||
-        (pass == NULL) ||
-        (salt == NULL) ||
-        (verifier == NULL) || (N == NULL) || (g == NULL) || (bn_ctx == NULL))
+    if ((user == NULL) || (pass == NULL) || (salt == NULL) || (verifier == NULL) || (N == NULL) || (g == NULL) || (bn_ctx == NULL))
         goto err;
 
     if (*salt == NULL) {
@@ -764,7 +755,7 @@ int SRP_create_verifier_BN_ex(const char *user, const char *pass, BIGNUM **salt,
     *salt = salttmp;
     *verifier = verif;
 
- err:
+err:
     if (salt != NULL && *salt != salttmp)
         BN_clear_free(salttmp);
     BN_clear_free(x);
@@ -773,10 +764,10 @@ int SRP_create_verifier_BN_ex(const char *user, const char *pass, BIGNUM **salt,
 }
 
 int SRP_create_verifier_BN(const char *user, const char *pass, BIGNUM **salt,
-                           BIGNUM **verifier, const BIGNUM *N,
-                           const BIGNUM *g)
+    BIGNUM **verifier, const BIGNUM *N,
+    const BIGNUM *g)
 {
     return SRP_create_verifier_BN_ex(user, pass, salt, verifier, N, g, NULL,
-                                     NULL);
+        NULL);
 }
 #endif
