@@ -74,9 +74,9 @@ static void free_loader(void *method)
 /* Data to be passed through ossl_method_construct() */
 struct loader_data_st {
     OSSL_LIB_CTX *libctx;
-    int scheme_id;               /* For get_loader_from_store() */
-    const char *scheme;          /* For get_loader_from_store() */
-    const char *propquery;       /* For get_loader_from_store() */
+    int scheme_id; /* For get_loader_from_store() */
+    const char *scheme; /* For get_loader_from_store() */
+    const char *propquery; /* For get_loader_from_store() */
 
     OSSL_METHOD_STORE *tmp_store; /* For get_tmp_loader_store() */
 
@@ -98,7 +98,7 @@ static void *get_tmp_loader_store(void *data)
     return methdata->tmp_store;
 }
 
- static void dealloc_tmp_loader_store(void *store)
+static void dealloc_tmp_loader_store(void *store)
 {
     if (store != NULL)
         ossl_method_store_free(store);
@@ -134,7 +134,7 @@ static int unreserve_loader_store(void *store, void *data)
 
 /* Get loader methods from a store, or put one in */
 static void *get_loader_from_store(void *store, const OSSL_PROVIDER **prov,
-                                   void *data)
+    void *data)
 {
     struct loader_data_st *methdata = data;
     void *method = NULL;
@@ -156,9 +156,9 @@ static void *get_loader_from_store(void *store, const OSSL_PROVIDER **prov,
 }
 
 static int put_loader_in_store(void *store, void *method,
-                               const OSSL_PROVIDER *prov,
-                               const char *scheme, const char *propdef,
-                               void *data)
+    const OSSL_PROVIDER *prov,
+    const char *scheme, const char *propdef,
+    void *data)
 {
     struct loader_data_st *methdata = data;
     OSSL_NAMEMAP *namemap;
@@ -172,11 +172,11 @@ static int put_loader_in_store(void *store, void *method,
         return 0;
 
     return ossl_method_store_add(store, prov, id, propdef, method,
-                                 up_ref_loader, free_loader);
+        up_ref_loader, free_loader);
 }
 
 static void *loader_from_algorithm(int scheme_id, const OSSL_ALGORITHM *algodef,
-                                   OSSL_PROVIDER *prov)
+    OSSL_PROVIDER *prov)
 {
     OSSL_STORE_LOADER *loader = NULL;
     const OSSL_DISPATCH *fns = algodef->implementation;
@@ -199,8 +199,7 @@ static void *loader_from_algorithm(int scheme_id, const OSSL_ALGORITHM *algodef,
             break;
         case OSSL_FUNC_STORE_SETTABLE_CTX_PARAMS:
             if (loader->p_settable_ctx_params == NULL)
-                loader->p_settable_ctx_params =
-                    OSSL_FUNC_store_settable_ctx_params(fns);
+                loader->p_settable_ctx_params = OSSL_FUNC_store_settable_ctx_params(fns);
             break;
         case OSSL_FUNC_STORE_SET_CTX_PARAMS:
             if (loader->p_set_ctx_params == NULL)
@@ -251,7 +250,7 @@ static void *loader_from_algorithm(int scheme_id, const OSSL_ALGORITHM *algodef,
  * then call loader_from_algorithm() with that identity number.
  */
 static void *construct_loader(const OSSL_ALGORITHM *algodef,
-                              OSSL_PROVIDER *prov, void *data)
+    OSSL_PROVIDER *prov, void *data)
 {
     /*
      * This function is only called if get_loader_from_store() returned
@@ -289,7 +288,7 @@ static void destruct_loader(void *method, void *data)
 /* Fetching support.  Can fetch by numeric identity or by scheme */
 static OSSL_STORE_LOADER *
 inner_loader_fetch(struct loader_data_st *methdata,
-                   const char *scheme, const char *properties)
+    const char *scheme, const char *properties)
 {
     OSSL_METHOD_STORE *store = get_loader_store(methdata->libctx);
     OSSL_NAMEMAP *namemap = ossl_namemap_stored(methdata->libctx);
@@ -329,8 +328,9 @@ inner_loader_fetch(struct loader_data_st *methdata,
         methdata->propquery = propq;
         methdata->flag_construct_error_occurred = 0;
         if ((method = ossl_method_construct(methdata->libctx, OSSL_OP_STORE,
-                                            &prov, 0 /* !force_cache */,
-                                            &mcm, methdata)) != NULL) {
+                 &prov, 0 /* !force_cache */,
+                 &mcm, methdata))
+            != NULL) {
             /*
              * If construction did create a method for us, we know that there
              * is a correct scheme_id, since those have already been calculated
@@ -339,7 +339,7 @@ inner_loader_fetch(struct loader_data_st *methdata,
             if (id == 0)
                 id = ossl_namemap_name2num(namemap, scheme);
             ossl_method_store_cache_set(store, prov, id, propq, method,
-                                        up_ref_loader, free_loader);
+                up_ref_loader, free_loader);
         }
 
         /*
@@ -351,29 +351,28 @@ inner_loader_fetch(struct loader_data_st *methdata,
 
     if ((id != 0 || scheme != NULL) && method == NULL) {
         int code = unsupported ? ERR_R_UNSUPPORTED : ERR_R_FETCH_FAILED;
-        const char *helpful_msg =
-            unsupported
-            ? ( "No store loader found. For standard store loaders you need "
-                "at least one of the default or base providers available. "
-                "Did you forget to load them? Info: " )
+        const char *helpful_msg = unsupported
+            ? ("No store loader found. For standard store loaders you need "
+               "at least one of the default or base providers available. "
+               "Did you forget to load them? Info: ")
             : "";
 
         if (scheme == NULL)
             scheme = ossl_namemap_num2name(namemap, id, 0);
         ERR_raise_data(ERR_LIB_OSSL_STORE, code,
-                       "%s%s, Scheme (%s : %d), Properties (%s)",
-                       helpful_msg,
-                       ossl_lib_ctx_get_descriptor(methdata->libctx),
-                       scheme == NULL ? "<null>" : scheme, id,
-                       properties == NULL ? "<null>" : properties);
+            "%s%s, Scheme (%s : %d), Properties (%s)",
+            helpful_msg,
+            ossl_lib_ctx_get_descriptor(methdata->libctx),
+            scheme == NULL ? "<null>" : scheme, id,
+            properties == NULL ? "<null>" : properties);
     }
 
     return method;
 }
 
 OSSL_STORE_LOADER *OSSL_STORE_LOADER_fetch(OSSL_LIB_CTX *libctx,
-                                           const char *scheme,
-                                           const char *properties)
+    const char *scheme,
+    const char *properties)
 {
     struct loader_data_st methdata;
     void *method;
@@ -467,9 +466,9 @@ static void do_one(ossl_unused int id, void *method, void *arg)
 }
 
 void OSSL_STORE_LOADER_do_all_provided(OSSL_LIB_CTX *libctx,
-                                       void (*user_fn)(OSSL_STORE_LOADER *loader,
-                                                       void *arg),
-                                       void *user_arg)
+    void (*user_fn)(OSSL_STORE_LOADER *loader,
+        void *arg),
+    void *user_arg)
 {
     struct loader_data_st methdata;
     struct do_one_data_st data;
@@ -487,8 +486,8 @@ void OSSL_STORE_LOADER_do_all_provided(OSSL_LIB_CTX *libctx,
 }
 
 int OSSL_STORE_LOADER_names_do_all(const OSSL_STORE_LOADER *loader,
-                                   void (*fn)(const char *name, void *data),
-                                   void *data)
+    void (*fn)(const char *name, void *data),
+    void *data)
 {
     if (loader == NULL)
         return 0;
