@@ -40,25 +40,24 @@ ASN1_SEQUENCE(IPAddressRange) = {
 
 ASN1_CHOICE(IPAddressOrRange) = {
     ASN1_SIMPLE(IPAddressOrRange, u.addressPrefix, ASN1_BIT_STRING),
-    ASN1_SIMPLE(IPAddressOrRange, u.addressRange,  IPAddressRange)
+    ASN1_SIMPLE(IPAddressOrRange, u.addressRange, IPAddressRange)
 } ASN1_CHOICE_END(IPAddressOrRange)
 
 ASN1_CHOICE(IPAddressChoice) = {
-    ASN1_SIMPLE(IPAddressChoice,      u.inherit,           ASN1_NULL),
+    ASN1_SIMPLE(IPAddressChoice, u.inherit, ASN1_NULL),
     ASN1_SEQUENCE_OF(IPAddressChoice, u.addressesOrRanges, IPAddressOrRange)
 } ASN1_CHOICE_END(IPAddressChoice)
 
 ASN1_SEQUENCE(IPAddressFamily) = {
-    ASN1_SIMPLE(IPAddressFamily, addressFamily,   ASN1_OCTET_STRING),
+    ASN1_SIMPLE(IPAddressFamily, addressFamily, ASN1_OCTET_STRING),
     ASN1_SIMPLE(IPAddressFamily, ipAddressChoice, IPAddressChoice)
 } ASN1_SEQUENCE_END(IPAddressFamily)
 
-ASN1_ITEM_TEMPLATE(IPAddrBlocks) =
-    ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0,
-                          IPAddrBlocks, IPAddressFamily)
+ASN1_ITEM_TEMPLATE(IPAddrBlocks) = ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0,
+    IPAddrBlocks, IPAddressFamily)
 static_ASN1_ITEM_TEMPLATE_END(IPAddrBlocks)
 
-IMPLEMENT_ASN1_FUNCTIONS(IPAddressRange)
+    IMPLEMENT_ASN1_FUNCTIONS(IPAddressRange)
 IMPLEMENT_ASN1_FUNCTIONS(IPAddressOrRange)
 IMPLEMENT_ASN1_FUNCTIONS(IPAddressChoice)
 IMPLEMENT_ASN1_FUNCTIONS(IPAddressFamily)
@@ -66,7 +65,7 @@ IMPLEMENT_ASN1_FUNCTIONS(IPAddressFamily)
 /*
  * How much buffer space do we need for a raw address?
  */
-# define ADDR_RAW_BUF_LEN 16
+#define ADDR_RAW_BUF_LEN 16
 
 /*
  * What's the address length associated with this AFI?
@@ -89,9 +88,9 @@ static int length_from_afi(const unsigned afi)
 unsigned int X509v3_addr_get_afi(const IPAddressFamily *f)
 {
     if (f == NULL
-            || f->addressFamily == NULL
-            || f->addressFamily->data == NULL
-            || f->addressFamily->length < 2)
+        || f->addressFamily == NULL
+        || f->addressFamily->data == NULL
+        || f->addressFamily->length < 2)
         return 0;
     return (f->addressFamily->data[0] << 8) | f->addressFamily->data[1];
 }
@@ -101,8 +100,8 @@ unsigned int X509v3_addr_get_afi(const IPAddressFamily *f)
  * At the moment this is coded for simplicity, not speed.
  */
 static int addr_expand(unsigned char *addr,
-                       const ASN1_BIT_STRING *bs,
-                       const int length, const unsigned char fill)
+    const ASN1_BIT_STRING *bs,
+    const int length, const unsigned char fill)
 {
     if (bs->length < 0 || bs->length > length)
         return 0;
@@ -124,14 +123,14 @@ static int addr_expand(unsigned char *addr,
 /*
  * Extract the prefix length from a bitstring.
  */
-# define addr_prefixlen(bs) ((int)((bs)->length * 8 - ((bs)->flags & 7)))
+#define addr_prefixlen(bs) ((int)((bs)->length * 8 - ((bs)->flags & 7)))
 
 /*
  * i2r handler for one address bitstring.
  */
 static int i2r_address(BIO *out,
-                       const unsigned afi,
-                       const unsigned char fill, const ASN1_BIT_STRING *bs)
+    const unsigned afi,
+    const unsigned char fill, const ASN1_BIT_STRING *bs)
 {
     unsigned char addr[ADDR_RAW_BUF_LEN];
     int i, n;
@@ -148,10 +147,11 @@ static int i2r_address(BIO *out,
         if (!addr_expand(addr, bs, 16, fill))
             return 0;
         for (n = 16; n > 1 && addr[n - 1] == 0x00 && addr[n - 2] == 0x00;
-             n -= 2) ;
+            n -= 2)
+            ;
         for (i = 0; i < n; i += 2)
             BIO_printf(out, "%x%s", (addr[i] << 8) | addr[i + 1],
-                       (i < 14 ? ":" : ""));
+                (i < 14 ? ":" : ""));
         if (i < 16)
             BIO_puts(out, ":");
         if (i == 0)
@@ -170,9 +170,9 @@ static int i2r_address(BIO *out,
  * i2r handler for a sequence of addresses and ranges.
  */
 static int i2r_IPAddressOrRanges(BIO *out,
-                                 const int indent,
-                                 const IPAddressOrRanges *aors,
-                                 const unsigned afi)
+    const int indent,
+    const IPAddressOrRanges *aors,
+    const unsigned afi)
 {
     int i;
 
@@ -203,7 +203,7 @@ static int i2r_IPAddressOrRanges(BIO *out,
  * i2r handler for an IPAddrBlocks extension.
  */
 static int i2r_IPAddrBlocks(const X509V3_EXT_METHOD *method,
-                            void *ext, BIO *out, int indent)
+    void *ext, BIO *out, int indent)
 {
     const IPAddrBlocks *addr = ext;
     int i;
@@ -251,7 +251,7 @@ static int i2r_IPAddrBlocks(const X509V3_EXT_METHOD *method,
                 break;
             default:
                 BIO_printf(out, " (Unknown SAFI %u)",
-                           (unsigned)f->addressFamily->data[2]);
+                    (unsigned)f->addressFamily->data[2]);
                 break;
             }
         }
@@ -262,9 +262,8 @@ static int i2r_IPAddrBlocks(const X509V3_EXT_METHOD *method,
         case IPAddressChoice_addressesOrRanges:
             BIO_puts(out, ":\n");
             if (!i2r_IPAddressOrRanges(out,
-                                       indent + 2,
-                                       f->ipAddressChoice->
-                                       u.addressesOrRanges, afi))
+                    indent + 2,
+                    f->ipAddressChoice->u.addressesOrRanges, afi))
                 return 0;
             break;
         }
@@ -283,7 +282,7 @@ static int i2r_IPAddrBlocks(const X509V3_EXT_METHOD *method,
  * for garbage input, tough noogies.
  */
 static int IPAddressOrRange_cmp(const IPAddressOrRange *a,
-                                const IPAddressOrRange *b, const int length)
+    const IPAddressOrRange *b, const int length)
 {
     unsigned char addr_a[ADDR_RAW_BUF_LEN], addr_b[ADDR_RAW_BUF_LEN];
     int prefixlen_a = 0, prefixlen_b = 0;
@@ -330,7 +329,7 @@ static int IPAddressOrRange_cmp(const IPAddressOrRange *a,
  * comparison routines are only allowed two arguments.
  */
 static int v4IPAddressOrRange_cmp(const IPAddressOrRange *const *a,
-                                  const IPAddressOrRange *const *b)
+    const IPAddressOrRange *const *b)
 {
     return IPAddressOrRange_cmp(*a, *b, 4);
 }
@@ -340,7 +339,7 @@ static int v4IPAddressOrRange_cmp(const IPAddressOrRange *const *a,
  * comparison routines are only allowed two arguments.
  */
 static int v6IPAddressOrRange_cmp(const IPAddressOrRange *const *a,
-                                  const IPAddressOrRange *const *b)
+    const IPAddressOrRange *const *b)
 {
     return IPAddressOrRange_cmp(*a, *b, 16);
 }
@@ -350,7 +349,7 @@ static int v6IPAddressOrRange_cmp(const IPAddressOrRange *const *a,
  * See last paragraph of RFC 3779 2.2.3.7.
  */
 static int range_should_be_prefix(const unsigned char *min,
-                                  const unsigned char *max, const int length)
+    const unsigned char *max, const int length)
 {
     unsigned char mask;
     int i, j;
@@ -362,8 +361,10 @@ static int range_should_be_prefix(const unsigned char *min,
      */
     assert(memcmp(min, max, length) <= 0);
 
-    for (i = 0; i < length && min[i] == max[i]; i++) ;
-    for (j = length - 1; j >= 0 && min[j] == 0x00 && max[j] == 0xFF; j--) ;
+    for (i = 0; i < length && min[i] == max[i]; i++)
+        ;
+    for (j = length - 1; j >= 0 && min[j] == 0x00 && max[j] == 0xFF; j--)
+        ;
     if (i < j)
         return -1;
     if (i > j)
@@ -404,7 +405,7 @@ static int range_should_be_prefix(const unsigned char *min,
  * Construct a prefix.
  */
 static int make_addressPrefix(IPAddressOrRange **result, unsigned char *addr,
-                              const int prefixlen, const int afilen)
+    const int prefixlen, const int afilen)
 {
     int bytelen = (prefixlen + 7) / 8, bitlen = prefixlen % 8;
     IPAddressOrRange *aor;
@@ -414,8 +415,7 @@ static int make_addressPrefix(IPAddressOrRange **result, unsigned char *addr,
     if ((aor = IPAddressOrRange_new()) == NULL)
         return 0;
     aor->type = IPAddressOrRange_addressPrefix;
-    if (aor->u.addressPrefix == NULL &&
-        (aor->u.addressPrefix = ASN1_BIT_STRING_new()) == NULL)
+    if (aor->u.addressPrefix == NULL && (aor->u.addressPrefix = ASN1_BIT_STRING_new()) == NULL)
         goto err;
     if (!ASN1_BIT_STRING_set(aor->u.addressPrefix, addr, bytelen))
         goto err;
@@ -426,7 +426,7 @@ static int make_addressPrefix(IPAddressOrRange **result, unsigned char *addr,
     *result = aor;
     return 1;
 
- err:
+err:
     IPAddressOrRange_free(aor);
     return 0;
 }
@@ -437,8 +437,8 @@ static int make_addressPrefix(IPAddressOrRange **result, unsigned char *addr,
  * the rest of the code considerably.
  */
 static int make_addressRange(IPAddressOrRange **result,
-                             unsigned char *min,
-                             unsigned char *max, const int length)
+    unsigned char *min,
+    unsigned char *max, const int length)
 {
     IPAddressOrRange *aor;
     int i, prefixlen;
@@ -454,14 +454,13 @@ static int make_addressRange(IPAddressOrRange **result,
     aor->type = IPAddressOrRange_addressRange;
     if ((aor->u.addressRange = IPAddressRange_new()) == NULL)
         goto err;
-    if (aor->u.addressRange->min == NULL &&
-        (aor->u.addressRange->min = ASN1_BIT_STRING_new()) == NULL)
+    if (aor->u.addressRange->min == NULL && (aor->u.addressRange->min = ASN1_BIT_STRING_new()) == NULL)
         goto err;
-    if (aor->u.addressRange->max == NULL &&
-        (aor->u.addressRange->max = ASN1_BIT_STRING_new()) == NULL)
+    if (aor->u.addressRange->max == NULL && (aor->u.addressRange->max = ASN1_BIT_STRING_new()) == NULL)
         goto err;
 
-    for (i = length; i > 0 && min[i - 1] == 0x00; --i) ;
+    for (i = length; i > 0 && min[i - 1] == 0x00; --i)
+        ;
     if (!ASN1_BIT_STRING_set(aor->u.addressRange->min, min, i))
         goto err;
     ossl_asn1_string_set_bits_left(aor->u.addressRange->min, 0);
@@ -474,7 +473,8 @@ static int make_addressRange(IPAddressOrRange **result,
         aor->u.addressRange->min->flags |= 8 - j;
     }
 
-    for (i = length; i > 0 && max[i - 1] == 0xFF; --i) ;
+    for (i = length; i > 0 && max[i - 1] == 0xFF; --i)
+        ;
     if (!ASN1_BIT_STRING_set(aor->u.addressRange->max, max, i))
         goto err;
     ossl_asn1_string_set_bits_left(aor->u.addressRange->max, 0);
@@ -490,7 +490,7 @@ static int make_addressRange(IPAddressOrRange **result,
     *result = aor;
     return 1;
 
- err:
+err:
     IPAddressOrRange_free(aor);
     return 0;
 }
@@ -499,8 +499,8 @@ static int make_addressRange(IPAddressOrRange **result,
  * Construct a new address family or find an existing one.
  */
 static IPAddressFamily *make_IPAddressFamily(IPAddrBlocks *addr,
-                                             const unsigned afi,
-                                             const unsigned *safi)
+    const unsigned afi,
+    const unsigned *safi)
 {
     IPAddressFamily *f;
     unsigned char key[3];
@@ -518,18 +518,15 @@ static IPAddressFamily *make_IPAddressFamily(IPAddrBlocks *addr,
 
     for (i = 0; i < sk_IPAddressFamily_num(addr); i++) {
         f = sk_IPAddressFamily_value(addr, i);
-        if (f->addressFamily->length == keylen &&
-            !memcmp(f->addressFamily->data, key, keylen))
+        if (f->addressFamily->length == keylen && !memcmp(f->addressFamily->data, key, keylen))
             return f;
     }
 
     if ((f = IPAddressFamily_new()) == NULL)
         goto err;
-    if (f->ipAddressChoice == NULL &&
-        (f->ipAddressChoice = IPAddressChoice_new()) == NULL)
+    if (f->ipAddressChoice == NULL && (f->ipAddressChoice = IPAddressChoice_new()) == NULL)
         goto err;
-    if (f->addressFamily == NULL &&
-        (f->addressFamily = ASN1_OCTET_STRING_new()) == NULL)
+    if (f->addressFamily == NULL && (f->addressFamily = ASN1_OCTET_STRING_new()) == NULL)
         goto err;
     if (!ASN1_OCTET_STRING_set(f->addressFamily, key, keylen))
         goto err;
@@ -538,7 +535,7 @@ static IPAddressFamily *make_IPAddressFamily(IPAddrBlocks *addr,
 
     return f;
 
- err:
+err:
     IPAddressFamily_free(f);
     return NULL;
 }
@@ -547,20 +544,15 @@ static IPAddressFamily *make_IPAddressFamily(IPAddrBlocks *addr,
  * Add an inheritance element.
  */
 int X509v3_addr_add_inherit(IPAddrBlocks *addr,
-                            const unsigned afi, const unsigned *safi)
+    const unsigned afi, const unsigned *safi)
 {
     IPAddressFamily *f = make_IPAddressFamily(addr, afi, safi);
 
-    if (f == NULL ||
-        f->ipAddressChoice == NULL ||
-        (f->ipAddressChoice->type == IPAddressChoice_addressesOrRanges &&
-         f->ipAddressChoice->u.addressesOrRanges != NULL))
+    if (f == NULL || f->ipAddressChoice == NULL || (f->ipAddressChoice->type == IPAddressChoice_addressesOrRanges && f->ipAddressChoice->u.addressesOrRanges != NULL))
         return 0;
-    if (f->ipAddressChoice->type == IPAddressChoice_inherit &&
-        f->ipAddressChoice->u.inherit != NULL)
+    if (f->ipAddressChoice->type == IPAddressChoice_inherit && f->ipAddressChoice->u.inherit != NULL)
         return 1;
-    if (f->ipAddressChoice->u.inherit == NULL &&
-        (f->ipAddressChoice->u.inherit = ASN1_NULL_new()) == NULL)
+    if (f->ipAddressChoice->u.inherit == NULL && (f->ipAddressChoice->u.inherit = ASN1_NULL_new()) == NULL)
         return 0;
     f->ipAddressChoice->type = IPAddressChoice_inherit;
     return 1;
@@ -570,16 +562,13 @@ int X509v3_addr_add_inherit(IPAddrBlocks *addr,
  * Construct an IPAddressOrRange sequence, or return an existing one.
  */
 static IPAddressOrRanges *make_prefix_or_range(IPAddrBlocks *addr,
-                                               const unsigned afi,
-                                               const unsigned *safi)
+    const unsigned afi,
+    const unsigned *safi)
 {
     IPAddressFamily *f = make_IPAddressFamily(addr, afi, safi);
     IPAddressOrRanges *aors = NULL;
 
-    if (f == NULL ||
-        f->ipAddressChoice == NULL ||
-        (f->ipAddressChoice->type == IPAddressChoice_inherit &&
-         f->ipAddressChoice->u.inherit != NULL))
+    if (f == NULL || f->ipAddressChoice == NULL || (f->ipAddressChoice->type == IPAddressChoice_inherit && f->ipAddressChoice->u.inherit != NULL))
         return NULL;
     if (f->ipAddressChoice->type == IPAddressChoice_addressesOrRanges)
         aors = f->ipAddressChoice->u.addressesOrRanges;
@@ -604,15 +593,15 @@ static IPAddressOrRanges *make_prefix_or_range(IPAddrBlocks *addr,
  * Add a prefix.
  */
 int X509v3_addr_add_prefix(IPAddrBlocks *addr,
-                           const unsigned afi,
-                           const unsigned *safi,
-                           unsigned char *a, const int prefixlen)
+    const unsigned afi,
+    const unsigned *safi,
+    unsigned char *a, const int prefixlen)
 {
     IPAddressOrRanges *aors = make_prefix_or_range(addr, afi, safi);
     IPAddressOrRange *aor;
 
     if (aors == NULL
-            || !make_addressPrefix(&aor, a, prefixlen, length_from_afi(afi)))
+        || !make_addressPrefix(&aor, a, prefixlen, length_from_afi(afi)))
         return 0;
     if (sk_IPAddressOrRange_push(aors, aor))
         return 1;
@@ -624,9 +613,9 @@ int X509v3_addr_add_prefix(IPAddrBlocks *addr,
  * Add a range.
  */
 int X509v3_addr_add_range(IPAddrBlocks *addr,
-                          const unsigned afi,
-                          const unsigned *safi,
-                          unsigned char *min, unsigned char *max)
+    const unsigned afi,
+    const unsigned *safi,
+    unsigned char *min, unsigned char *max)
 {
     IPAddressOrRanges *aors = make_prefix_or_range(addr, afi, safi);
     IPAddressOrRange *aor;
@@ -646,17 +635,15 @@ int X509v3_addr_add_range(IPAddrBlocks *addr,
  * Extract min and max values from an IPAddressOrRange.
  */
 static int extract_min_max(IPAddressOrRange *aor,
-                           unsigned char *min, unsigned char *max, int length)
+    unsigned char *min, unsigned char *max, int length)
 {
     if (aor == NULL || min == NULL || max == NULL)
         return 0;
     switch (aor->type) {
     case IPAddressOrRange_addressPrefix:
-        return (addr_expand(min, aor->u.addressPrefix, length, 0x00) &&
-                addr_expand(max, aor->u.addressPrefix, length, 0xFF));
+        return (addr_expand(min, aor->u.addressPrefix, length, 0x00) && addr_expand(max, aor->u.addressPrefix, length, 0xFF));
     case IPAddressOrRange_addressRange:
-        return (addr_expand(min, aor->u.addressRange->min, length, 0x00) &&
-                addr_expand(max, aor->u.addressRange->max, length, 0xFF));
+        return (addr_expand(min, aor->u.addressRange->min, length, 0x00) && addr_expand(max, aor->u.addressRange->max, length, 0xFF));
     }
     return 0;
 }
@@ -665,17 +652,13 @@ static int extract_min_max(IPAddressOrRange *aor,
  * Public wrapper for extract_min_max().
  */
 int X509v3_addr_get_range(IPAddressOrRange *aor,
-                          const unsigned afi,
-                          unsigned char *min,
-                          unsigned char *max, const int length)
+    const unsigned afi,
+    unsigned char *min,
+    unsigned char *max, const int length)
 {
     int afi_length = length_from_afi(afi);
 
-    if (aor == NULL || min == NULL || max == NULL ||
-        afi_length == 0 || length < afi_length ||
-        (aor->type != IPAddressOrRange_addressPrefix &&
-         aor->type != IPAddressOrRange_addressRange) ||
-        !extract_min_max(aor, min, max, afi_length))
+    if (aor == NULL || min == NULL || max == NULL || afi_length == 0 || length < afi_length || (aor->type != IPAddressOrRange_addressPrefix && aor->type != IPAddressOrRange_addressRange) || !extract_min_max(aor, min, max, afi_length))
         return 0;
 
     return afi_length;
@@ -692,7 +675,7 @@ int X509v3_addr_get_range(IPAddressOrRange *aor,
  * would have expected and is what the following code implements.
  */
 static int IPAddressFamily_cmp(const IPAddressFamily *const *a_,
-                               const IPAddressFamily *const *b_)
+    const IPAddressFamily *const *b_)
 {
     const ASN1_OCTET_STRING *a = (*a_)->addressFamily;
     const ASN1_OCTET_STRING *b = (*b_)->addressFamily;
@@ -775,31 +758,28 @@ int X509v3_addr_is_canonical(IPAddrBlocks *addr)
             IPAddressOrRange *a = sk_IPAddressOrRange_value(aors, j);
             IPAddressOrRange *b = sk_IPAddressOrRange_value(aors, j + 1);
 
-            if (!extract_min_max(a, a_min, a_max, length) ||
-                !extract_min_max(b, b_min, b_max, length))
+            if (!extract_min_max(a, a_min, a_max, length) || !extract_min_max(b, b_min, b_max, length))
                 return 0;
 
             /*
              * Punt misordered list, overlapping start, or inverted range.
              */
-            if (memcmp(a_min, b_min, length) >= 0 ||
-                memcmp(a_min, a_max, length) > 0 ||
-                memcmp(b_min, b_max, length) > 0)
+            if (memcmp(a_min, b_min, length) >= 0 || memcmp(a_min, a_max, length) > 0 || memcmp(b_min, b_max, length) > 0)
                 return 0;
 
             /*
              * Punt if adjacent or overlapping.  Check for adjacency by
              * subtracting one from b_min first.
              */
-            for (k = length - 1; k >= 0 && b_min[k]-- == 0x00; k--) ;
+            for (k = length - 1; k >= 0 && b_min[k]-- == 0x00; k--)
+                ;
             if (memcmp(a_max, b_min, length) >= 0)
                 return 0;
 
             /*
              * Check for range that should be expressed as a prefix.
              */
-            if (a->type == IPAddressOrRange_addressRange &&
-                range_should_be_prefix(a_min, a_max, length) >= 0)
+            if (a->type == IPAddressOrRange_addressRange && range_should_be_prefix(a_min, a_max, length) >= 0)
                 return 0;
         }
 
@@ -814,8 +794,7 @@ int X509v3_addr_is_canonical(IPAddrBlocks *addr)
             if (a != NULL && a->type == IPAddressOrRange_addressRange) {
                 if (!extract_min_max(a, a_min, a_max, length))
                     return 0;
-                if (memcmp(a_min, a_max, length) > 0 ||
-                    range_should_be_prefix(a_min, a_max, length) >= 0)
+                if (memcmp(a_min, a_max, length) > 0 || range_should_be_prefix(a_min, a_max, length) >= 0)
                     return 0;
             }
         }
@@ -831,7 +810,7 @@ int X509v3_addr_is_canonical(IPAddrBlocks *addr)
  * Whack an IPAddressOrRanges into canonical form.
  */
 static int IPAddressOrRanges_canonize(IPAddressOrRanges *aors,
-                                      const unsigned afi)
+    const unsigned afi)
 {
     int i, j, length = length_from_afi(afi);
 
@@ -849,15 +828,13 @@ static int IPAddressOrRanges_canonize(IPAddressOrRanges *aors,
         unsigned char a_min[ADDR_RAW_BUF_LEN], a_max[ADDR_RAW_BUF_LEN];
         unsigned char b_min[ADDR_RAW_BUF_LEN], b_max[ADDR_RAW_BUF_LEN];
 
-        if (!extract_min_max(a, a_min, a_max, length) ||
-            !extract_min_max(b, b_min, b_max, length))
+        if (!extract_min_max(a, a_min, a_max, length) || !extract_min_max(b, b_min, b_max, length))
             return 0;
 
         /*
          * Punt inverted ranges.
          */
-        if (memcmp(a_min, a_max, length) > 0 ||
-            memcmp(b_min, b_max, length) > 0)
+        if (memcmp(a_min, a_max, length) > 0 || memcmp(b_min, b_max, length) > 0)
             return 0;
 
         /*
@@ -870,7 +847,8 @@ static int IPAddressOrRanges_canonize(IPAddressOrRanges *aors,
          * Merge if a and b are adjacent.  We check for
          * adjacency by subtracting one from b_min first.
          */
-        for (j = length - 1; j >= 0 && b_min[j]-- == 0x00; j--) ;
+        for (j = length - 1; j >= 0 && b_min[j]-- == 0x00; j--)
+            ;
         if (memcmp(a_max, b_min, length) == 0) {
             IPAddressOrRange *merged;
 
@@ -923,10 +901,7 @@ int X509v3_addr_canonize(IPAddrBlocks *addr)
         if (!IPAddressFamily_check_len(f))
             return 0;
 
-        if (f->ipAddressChoice->type == IPAddressChoice_addressesOrRanges &&
-            !IPAddressOrRanges_canonize(f->ipAddressChoice->
-                                        u.addressesOrRanges,
-                                        X509v3_addr_get_afi(f)))
+        if (f->ipAddressChoice->type == IPAddressChoice_addressesOrRanges && !IPAddressOrRanges_canonize(f->ipAddressChoice->u.addressesOrRanges, X509v3_addr_get_afi(f)))
             return 0;
     }
     (void)sk_IPAddressFamily_set_cmp_func(addr, IPAddressFamily_cmp);
@@ -940,8 +915,8 @@ int X509v3_addr_canonize(IPAddrBlocks *addr)
  * v2i handler for the IPAddrBlocks extension.
  */
 static void *v2i_IPAddrBlocks(const struct v3_ext_method *method,
-                              struct v3_ext_ctx *ctx,
-                              STACK_OF(CONF_VALUE) *values)
+    struct v3_ext_ctx *ctx,
+    STACK_OF(CONF_VALUE) *values)
 {
     static const char v4addr_chars[] = "0123456789.";
     static const char v6addr_chars[] = "0123456789.:abcdefABCDEF";
@@ -973,7 +948,7 @@ static void *v2i_IPAddrBlocks(const struct v3_ext_method *method,
             safi = &safi_;
         } else {
             ERR_raise_data(ERR_LIB_X509V3, X509V3_R_EXTENSION_NAME_ERROR,
-                           "%s", val->name);
+                "%s", val->name);
             goto err;
         }
 
@@ -1042,9 +1017,9 @@ static void *v2i_IPAddrBlocks(const struct v3_ext_method *method,
         case '/':
             prefixlen = (int)strtoul(s + i2, &t, 10);
             if (t == s + i2
-                    || *t != '\0'
-                    || prefixlen > (length * 8)
-                    || prefixlen < 0) {
+                || *t != '\0'
+                || prefixlen > (length * 8)
+                || prefixlen < 0) {
                 ERR_raise(ERR_LIB_X509V3, X509V3_R_EXTENSION_VALUE_ERROR);
                 X509V3_conf_add_error_name_value(val);
                 goto err;
@@ -1100,7 +1075,7 @@ static void *v2i_IPAddrBlocks(const struct v3_ext_method *method,
         goto err;
     return addr;
 
- err:
+err:
     OPENSSL_free(s);
     sk_IPAddressFamily_pop_free(addr, IPAddressFamily_free);
     return NULL;
@@ -1110,17 +1085,17 @@ static void *v2i_IPAddrBlocks(const struct v3_ext_method *method,
  * OpenSSL dispatch
  */
 const X509V3_EXT_METHOD ossl_v3_addr = {
-    NID_sbgp_ipAddrBlock,       /* nid */
-    0,                          /* flags */
+    NID_sbgp_ipAddrBlock, /* nid */
+    0, /* flags */
     ASN1_ITEM_ref(IPAddrBlocks), /* template */
-    0, 0, 0, 0,                 /* old functions, ignored */
-    0,                          /* i2s */
-    0,                          /* s2i */
-    0,                          /* i2v */
-    v2i_IPAddrBlocks,           /* v2i */
-    i2r_IPAddrBlocks,           /* i2r */
-    0,                          /* r2i */
-    NULL                        /* extension-specific data */
+    0, 0, 0, 0, /* old functions, ignored */
+    0, /* i2s */
+    0, /* s2i */
+    0, /* i2v */
+    v2i_IPAddrBlocks, /* v2i */
+    i2r_IPAddrBlocks, /* i2r */
+    0, /* r2i */
+    NULL /* extension-specific data */
 };
 
 /*
@@ -1145,7 +1120,7 @@ int X509v3_addr_inherits(IPAddrBlocks *addr)
  * Figure out whether parent contains child.
  */
 static int addr_contains(IPAddressOrRanges *parent,
-                         IPAddressOrRanges *child, int length)
+    IPAddressOrRanges *child, int length)
 {
     unsigned char p_min[ADDR_RAW_BUF_LEN], p_max[ADDR_RAW_BUF_LEN];
     unsigned char c_min[ADDR_RAW_BUF_LEN], c_max[ADDR_RAW_BUF_LEN];
@@ -1159,13 +1134,13 @@ static int addr_contains(IPAddressOrRanges *parent,
     p = 0;
     for (c = 0; c < sk_IPAddressOrRange_num(child); c++) {
         if (!extract_min_max(sk_IPAddressOrRange_value(child, c),
-                             c_min, c_max, length))
+                c_min, c_max, length))
             return 0;
         for (;; p++) {
             if (p >= sk_IPAddressOrRange_num(parent))
                 return 0;
             if (!extract_min_max(sk_IPAddressOrRange_value(parent, p),
-                                 p_min, p_max, length))
+                    p_min, p_max, length))
                 return 0;
             if (memcmp(p_max, c_max, length) < 0)
                 continue;
@@ -1202,8 +1177,8 @@ int X509v3_addr_subset(IPAddrBlocks *a, IPAddrBlocks *b)
         if (!IPAddressFamily_check_len(fa) || !IPAddressFamily_check_len(fb))
             return 0;
         if (!addr_contains(fb->ipAddressChoice->u.addressesOrRanges,
-                           fa->ipAddressChoice->u.addressesOrRanges,
-                           length_from_afi(X509v3_addr_get_afi(fb))))
+                fa->ipAddressChoice->u.addressesOrRanges,
+                length_from_afi(X509v3_addr_get_afi(fb))))
             return 0;
     }
     return 1;
@@ -1212,18 +1187,18 @@ int X509v3_addr_subset(IPAddrBlocks *a, IPAddrBlocks *b)
 /*
  * Validation error handling via callback.
  */
-# define validation_err(_err_)            \
-    do {                                  \
-        if (ctx != NULL) {                \
-            ctx->error = _err_;           \
-            ctx->error_depth = i;         \
-            ctx->current_cert = x;        \
-            rv = ctx->verify_cb(0, ctx);  \
-        } else {                          \
-            rv = 0;                       \
-        }                                 \
-        if (rv == 0)                      \
-            goto done;                    \
+#define validation_err(_err_)            \
+    do {                                 \
+        if (ctx != NULL) {               \
+            ctx->error = _err_;          \
+            ctx->error_depth = i;        \
+            ctx->current_cert = x;       \
+            rv = ctx->verify_cb(0, ctx); \
+        } else {                         \
+            rv = 0;                      \
+        }                                \
+        if (rv == 0)                     \
+            goto done;                   \
     } while (0)
 
 /*
@@ -1235,16 +1210,16 @@ int X509v3_addr_subset(IPAddrBlocks *a, IPAddrBlocks *b)
  * X509_V_OK.
  */
 static int addr_validate_path_internal(X509_STORE_CTX *ctx,
-                                       STACK_OF(X509) *chain,
-                                       IPAddrBlocks *ext)
+    STACK_OF(X509) *chain,
+    IPAddrBlocks *ext)
 {
     IPAddrBlocks *child = NULL;
     int i, j, ret = 0, rv;
     X509 *x;
 
     if (!ossl_assert(chain != NULL && sk_X509_num(chain) > 0)
-            || !ossl_assert(ctx != NULL || ext != NULL)
-            || !ossl_assert(ctx == NULL || ctx->verify_cb != NULL)) {
+        || !ossl_assert(ctx != NULL || ext != NULL)
+        || !ossl_assert(ctx == NULL || ctx->verify_cb != NULL)) {
         if (ctx != NULL)
             ctx->error = X509_V_ERR_UNSPECIFIED;
         return 0;
@@ -1298,17 +1273,15 @@ static int addr_validate_path_internal(X509_STORE_CTX *ctx,
             continue;
         }
         (void)sk_IPAddressFamily_set_cmp_func(x->rfc3779_addr,
-                                              IPAddressFamily_cmp);
+            IPAddressFamily_cmp);
         sk_IPAddressFamily_sort(x->rfc3779_addr);
         for (j = 0; j < sk_IPAddressFamily_num(child); j++) {
             IPAddressFamily *fc = sk_IPAddressFamily_value(child, j);
             int k = sk_IPAddressFamily_find(x->rfc3779_addr, fc);
-            IPAddressFamily *fp =
-                sk_IPAddressFamily_value(x->rfc3779_addr, k);
+            IPAddressFamily *fp = sk_IPAddressFamily_value(x->rfc3779_addr, k);
 
             if (fp == NULL) {
-                if (fc->ipAddressChoice->type ==
-                    IPAddressChoice_addressesOrRanges) {
+                if (fc->ipAddressChoice->type == IPAddressChoice_addressesOrRanges) {
                     validation_err(X509_V_ERR_UNNESTED_RESOURCE);
                     break;
                 }
@@ -1318,12 +1291,11 @@ static int addr_validate_path_internal(X509_STORE_CTX *ctx,
             if (!IPAddressFamily_check_len(fc) || !IPAddressFamily_check_len(fp))
                 goto done;
 
-            if (fp->ipAddressChoice->type ==
-                IPAddressChoice_addressesOrRanges) {
+            if (fp->ipAddressChoice->type == IPAddressChoice_addressesOrRanges) {
                 if (fc->ipAddressChoice->type == IPAddressChoice_inherit
                     || addr_contains(fp->ipAddressChoice->u.addressesOrRanges,
-                                     fc->ipAddressChoice->u.addressesOrRanges,
-                                     length_from_afi(X509v3_addr_get_afi(fc))))
+                        fc->ipAddressChoice->u.addressesOrRanges,
+                        length_from_afi(X509v3_addr_get_afi(fc))))
                     (void)sk_IPAddressFamily_set(child, j, fp);
                 else
                     validation_err(X509_V_ERR_UNNESTED_RESOURCE);
@@ -1347,12 +1319,12 @@ static int addr_validate_path_internal(X509_STORE_CTX *ctx,
         }
     }
     ret = 1;
- done:
+done:
     sk_IPAddressFamily_free(child);
     return ret;
 }
 
-# undef validation_err
+#undef validation_err
 
 /*
  * RFC 3779 2.3 path validation -- called from X509_verify_cert().
@@ -1360,8 +1332,8 @@ static int addr_validate_path_internal(X509_STORE_CTX *ctx,
 int X509v3_addr_validate_path(X509_STORE_CTX *ctx)
 {
     if (ctx->chain == NULL
-            || sk_X509_num(ctx->chain) == 0
-            || ctx->verify_cb == NULL) {
+        || sk_X509_num(ctx->chain) == 0
+        || ctx->verify_cb == NULL) {
         ctx->error = X509_V_ERR_UNSPECIFIED;
         return 0;
     }
@@ -1373,7 +1345,7 @@ int X509v3_addr_validate_path(X509_STORE_CTX *ctx)
  * Test whether chain covers extension.
  */
 int X509v3_addr_validate_resource_set(STACK_OF(X509) *chain,
-                                      IPAddrBlocks *ext, int allow_inheritance)
+    IPAddrBlocks *ext, int allow_inheritance)
 {
     if (ext == NULL)
         return 1;
