@@ -1,5 +1,5 @@
 /*
- * Copyright 2006-2021 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2006-2024 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -32,23 +32,23 @@
  */
 
 ASN1_SEQUENCE(ASRange) = {
-  ASN1_SIMPLE(ASRange, min, ASN1_INTEGER),
-  ASN1_SIMPLE(ASRange, max, ASN1_INTEGER)
+    ASN1_SIMPLE(ASRange, min, ASN1_INTEGER),
+    ASN1_SIMPLE(ASRange, max, ASN1_INTEGER)
 } ASN1_SEQUENCE_END(ASRange)
 
 ASN1_CHOICE(ASIdOrRange) = {
-  ASN1_SIMPLE(ASIdOrRange, u.id,    ASN1_INTEGER),
-  ASN1_SIMPLE(ASIdOrRange, u.range, ASRange)
+    ASN1_SIMPLE(ASIdOrRange, u.id, ASN1_INTEGER),
+    ASN1_SIMPLE(ASIdOrRange, u.range, ASRange)
 } ASN1_CHOICE_END(ASIdOrRange)
 
 ASN1_CHOICE(ASIdentifierChoice) = {
-  ASN1_SIMPLE(ASIdentifierChoice,      u.inherit,       ASN1_NULL),
-  ASN1_SEQUENCE_OF(ASIdentifierChoice, u.asIdsOrRanges, ASIdOrRange)
+    ASN1_SIMPLE(ASIdentifierChoice, u.inherit, ASN1_NULL),
+    ASN1_SEQUENCE_OF(ASIdentifierChoice, u.asIdsOrRanges, ASIdOrRange)
 } ASN1_CHOICE_END(ASIdentifierChoice)
 
 ASN1_SEQUENCE(ASIdentifiers) = {
-  ASN1_EXP_OPT(ASIdentifiers, asnum, ASIdentifierChoice, 0),
-  ASN1_EXP_OPT(ASIdentifiers, rdi,   ASIdentifierChoice, 1)
+    ASN1_EXP_OPT(ASIdentifiers, asnum, ASIdentifierChoice, 0),
+    ASN1_EXP_OPT(ASIdentifiers, rdi, ASIdentifierChoice, 1)
 } ASN1_SEQUENCE_END(ASIdentifiers)
 
 IMPLEMENT_ASN1_FUNCTIONS(ASRange)
@@ -60,8 +60,8 @@ IMPLEMENT_ASN1_FUNCTIONS(ASIdentifiers)
  * i2r method for an ASIdentifierChoice.
  */
 static int i2r_ASIdentifierChoice(BIO *out,
-                                  ASIdentifierChoice *choice,
-                                  int indent, const char *msg)
+    ASIdentifierChoice *choice,
+    int indent, const char *msg)
 {
     int i;
     char *s;
@@ -74,8 +74,7 @@ static int i2r_ASIdentifierChoice(BIO *out,
         break;
     case ASIdentifierChoice_asIdsOrRanges:
         for (i = 0; i < sk_ASIdOrRange_num(choice->u.asIdsOrRanges); i++) {
-            ASIdOrRange *aor =
-                sk_ASIdOrRange_value(choice->u.asIdsOrRanges, i);
+            ASIdOrRange *aor = sk_ASIdOrRange_value(choice->u.asIdsOrRanges, i);
             switch (aor->type) {
             case ASIdOrRange_id:
                 if ((s = i2s_ASN1_INTEGER(NULL, aor->u.id)) == NULL)
@@ -108,38 +107,33 @@ static int i2r_ASIdentifierChoice(BIO *out,
  * i2r method for an ASIdentifier extension.
  */
 static int i2r_ASIdentifiers(const X509V3_EXT_METHOD *method,
-                             void *ext, BIO *out, int indent)
+    void *ext, BIO *out, int indent)
 {
     ASIdentifiers *asid = ext;
     return (i2r_ASIdentifierChoice(out, asid->asnum, indent,
-                                   "Autonomous System Numbers") &&
-            i2r_ASIdentifierChoice(out, asid->rdi, indent,
-                                   "Routing Domain Identifiers"));
+                "Autonomous System Numbers")
+        && i2r_ASIdentifierChoice(out, asid->rdi, indent,
+            "Routing Domain Identifiers"));
 }
 
 /*
  * Sort comparison function for a sequence of ASIdOrRange elements.
  */
 static int ASIdOrRange_cmp(const ASIdOrRange *const *a_,
-                           const ASIdOrRange *const *b_)
+    const ASIdOrRange *const *b_)
 {
     const ASIdOrRange *a = *a_, *b = *b_;
 
-    assert((a->type == ASIdOrRange_id && a->u.id != NULL) ||
-           (a->type == ASIdOrRange_range && a->u.range != NULL &&
-            a->u.range->min != NULL && a->u.range->max != NULL));
+    assert((a->type == ASIdOrRange_id && a->u.id != NULL) || (a->type == ASIdOrRange_range && a->u.range != NULL && a->u.range->min != NULL && a->u.range->max != NULL));
 
-    assert((b->type == ASIdOrRange_id && b->u.id != NULL) ||
-           (b->type == ASIdOrRange_range && b->u.range != NULL &&
-            b->u.range->min != NULL && b->u.range->max != NULL));
+    assert((b->type == ASIdOrRange_id && b->u.id != NULL) || (b->type == ASIdOrRange_range && b->u.range != NULL && b->u.range->min != NULL && b->u.range->max != NULL));
 
     if (a->type == ASIdOrRange_id && b->type == ASIdOrRange_id)
         return ASN1_INTEGER_cmp(a->u.id, b->u.id);
 
     if (a->type == ASIdOrRange_range && b->type == ASIdOrRange_range) {
         int r = ASN1_INTEGER_cmp(a->u.range->min, b->u.range->min);
-        return r != 0 ? r : ASN1_INTEGER_cmp(a->u.range->max,
-                                             b->u.range->max);
+        return r != 0 ? r : ASN1_INTEGER_cmp(a->u.range->max, b->u.range->max);
     }
 
     if (a->type == ASIdOrRange_id)
@@ -169,8 +163,11 @@ int X509v3_asid_add_inherit(ASIdentifiers *asid, int which)
     if (*choice == NULL) {
         if ((*choice = ASIdentifierChoice_new()) == NULL)
             return 0;
-        if (((*choice)->u.inherit = ASN1_NULL_new()) == NULL)
+        if (((*choice)->u.inherit = ASN1_NULL_new()) == NULL) {
+            ASIdentifierChoice_free(*choice);
+            *choice = NULL;
             return 0;
+        }
         (*choice)->type = ASIdentifierChoice_inherit;
     }
     return (*choice)->type == ASIdentifierChoice_inherit;
@@ -180,7 +177,7 @@ int X509v3_asid_add_inherit(ASIdentifiers *asid, int which)
  * Add an ID or range to an ASIdentifierChoice.
  */
 int X509v3_asid_add_id_or_range(ASIdentifiers *asid,
-                                int which, ASN1_INTEGER *min, ASN1_INTEGER *max)
+    int which, ASN1_INTEGER *min, ASN1_INTEGER *max)
 {
     ASIdentifierChoice **choice;
     ASIdOrRange *aor;
@@ -196,18 +193,23 @@ int X509v3_asid_add_id_or_range(ASIdentifiers *asid,
     default:
         return 0;
     }
-    if (*choice != NULL && (*choice)->type == ASIdentifierChoice_inherit)
+    if (*choice != NULL && (*choice)->type != ASIdentifierChoice_asIdsOrRanges)
         return 0;
     if (*choice == NULL) {
         if ((*choice = ASIdentifierChoice_new()) == NULL)
             return 0;
         (*choice)->u.asIdsOrRanges = sk_ASIdOrRange_new(ASIdOrRange_cmp);
-        if ((*choice)->u.asIdsOrRanges == NULL)
+        if ((*choice)->u.asIdsOrRanges == NULL) {
+            ASIdentifierChoice_free(*choice);
+            *choice = NULL;
             return 0;
+        }
         (*choice)->type = ASIdentifierChoice_asIdsOrRanges;
     }
     if ((aor = ASIdOrRange_new()) == NULL)
         return 0;
+    if (!sk_ASIdOrRange_reserve((*choice)->u.asIdsOrRanges, 1))
+        goto err;
     if (max == NULL) {
         aor->type = ASIdOrRange_id;
         aor->u.id = min;
@@ -220,11 +222,12 @@ int X509v3_asid_add_id_or_range(ASIdentifiers *asid,
         ASN1_INTEGER_free(aor->u.range->max);
         aor->u.range->max = max;
     }
-    if (!(sk_ASIdOrRange_push((*choice)->u.asIdsOrRanges, aor)))
+    /* Cannot fail due to the reservation above */
+    if (!ossl_assert(sk_ASIdOrRange_push((*choice)->u.asIdsOrRanges, aor)))
         goto err;
     return 1;
 
- err:
+err:
     ASIdOrRange_free(aor);
     return 0;
 }
@@ -233,7 +236,7 @@ int X509v3_asid_add_id_or_range(ASIdentifiers *asid,
  * Extract min and max values from an ASIdOrRange.
  */
 static int extract_min_max(ASIdOrRange *aor,
-                           ASN1_INTEGER **min, ASN1_INTEGER **max)
+    ASN1_INTEGER **min, ASN1_INTEGER **max)
 {
     if (!ossl_assert(aor != NULL))
         return 0;
@@ -270,8 +273,7 @@ static int ASIdentifierChoice_is_canonical(ASIdentifierChoice *choice)
     /*
      * If not a list, or if empty list, it's broken.
      */
-    if (choice->type != ASIdentifierChoice_asIdsOrRanges ||
-        sk_ASIdOrRange_num(choice->u.asIdsOrRanges) == 0)
+    if (choice->type != ASIdentifierChoice_asIdsOrRanges || sk_ASIdOrRange_num(choice->u.asIdsOrRanges) == 0)
         return 0;
 
     /*
@@ -280,33 +282,27 @@ static int ASIdentifierChoice_is_canonical(ASIdentifierChoice *choice)
     for (i = 0; i < sk_ASIdOrRange_num(choice->u.asIdsOrRanges) - 1; i++) {
         ASIdOrRange *a = sk_ASIdOrRange_value(choice->u.asIdsOrRanges, i);
         ASIdOrRange *b = sk_ASIdOrRange_value(choice->u.asIdsOrRanges, i + 1);
-        ASN1_INTEGER *a_min = NULL, *a_max = NULL, *b_min = NULL, *b_max =
-            NULL;
+        ASN1_INTEGER *a_min = NULL, *a_max = NULL, *b_min = NULL, *b_max = NULL;
 
         if (!extract_min_max(a, &a_min, &a_max)
-                || !extract_min_max(b, &b_min, &b_max))
+            || !extract_min_max(b, &b_min, &b_max))
             goto done;
 
         /*
          * Punt misordered list, overlapping start, or inverted range.
          */
-        if (ASN1_INTEGER_cmp(a_min, b_min) >= 0 ||
-            ASN1_INTEGER_cmp(a_min, a_max) > 0 ||
-            ASN1_INTEGER_cmp(b_min, b_max) > 0)
+        if (ASN1_INTEGER_cmp(a_min, b_min) >= 0 || ASN1_INTEGER_cmp(a_min, a_max) > 0 || ASN1_INTEGER_cmp(b_min, b_max) > 0)
             goto done;
 
         /*
          * Calculate a_max + 1 to check for adjacency.
          */
-        if ((bn == NULL && (bn = BN_new()) == NULL) ||
-            ASN1_INTEGER_to_BN(a_max, bn) == NULL ||
-            !BN_add_word(bn, 1)) {
+        if ((bn == NULL && (bn = BN_new()) == NULL) || ASN1_INTEGER_to_BN(a_max, bn) == NULL || !BN_add_word(bn, 1)) {
             ERR_raise(ERR_LIB_X509V3, ERR_R_BN_LIB);
             goto done;
         }
 
-        if ((a_max_plus_one =
-                BN_to_ASN1_INTEGER(bn, orig = a_max_plus_one)) == NULL) {
+        if ((a_max_plus_one = BN_to_ASN1_INTEGER(bn, orig = a_max_plus_one)) == NULL) {
             a_max_plus_one = orig;
             ERR_raise(ERR_LIB_X509V3, ERR_R_ASN1_LIB);
             goto done;
@@ -328,14 +324,14 @@ static int ASIdentifierChoice_is_canonical(ASIdentifierChoice *choice)
         ASN1_INTEGER *a_min, *a_max;
         if (a != NULL && a->type == ASIdOrRange_range) {
             if (!extract_min_max(a, &a_min, &a_max)
-                    || ASN1_INTEGER_cmp(a_min, a_max) > 0)
+                || ASN1_INTEGER_cmp(a_min, a_max) > 0)
                 goto done;
         }
     }
 
     ret = 1;
 
- done:
+done:
     ASN1_INTEGER_free(a_max_plus_one);
     BN_free(bn);
     return ret;
@@ -346,9 +342,7 @@ static int ASIdentifierChoice_is_canonical(ASIdentifierChoice *choice)
  */
 int X509v3_asid_is_canonical(ASIdentifiers *asid)
 {
-    return (asid == NULL ||
-            (ASIdentifierChoice_is_canonical(asid->asnum) &&
-             ASIdentifierChoice_is_canonical(asid->rdi)));
+    return (asid == NULL || (ASIdentifierChoice_is_canonical(asid->asnum) && ASIdentifierChoice_is_canonical(asid->rdi)));
 }
 
 /*
@@ -370,8 +364,7 @@ static int ASIdentifierChoice_canonize(ASIdentifierChoice *choice)
     /*
      * If not a list, or if empty list, it's broken.
      */
-    if (choice->type != ASIdentifierChoice_asIdsOrRanges ||
-        sk_ASIdOrRange_num(choice->u.asIdsOrRanges) == 0) {
+    if (choice->type != ASIdentifierChoice_asIdsOrRanges || sk_ASIdOrRange_num(choice->u.asIdsOrRanges) == 0) {
         ERR_raise(ERR_LIB_X509V3, X509V3_R_EXTENSION_VALUE_ERROR);
         return 0;
     }
@@ -388,11 +381,10 @@ static int ASIdentifierChoice_canonize(ASIdentifierChoice *choice)
     for (i = 0; i < sk_ASIdOrRange_num(choice->u.asIdsOrRanges) - 1; i++) {
         ASIdOrRange *a = sk_ASIdOrRange_value(choice->u.asIdsOrRanges, i);
         ASIdOrRange *b = sk_ASIdOrRange_value(choice->u.asIdsOrRanges, i + 1);
-        ASN1_INTEGER *a_min = NULL, *a_max = NULL, *b_min = NULL, *b_max =
-            NULL;
+        ASN1_INTEGER *a_min = NULL, *a_max = NULL, *b_min = NULL, *b_max = NULL;
 
         if (!extract_min_max(a, &a_min, &a_max)
-                || !extract_min_max(b, &b_min, &b_max))
+            || !extract_min_max(b, &b_min, &b_max))
             goto done;
 
         /*
@@ -404,8 +396,7 @@ static int ASIdentifierChoice_canonize(ASIdentifierChoice *choice)
         /*
          * Punt inverted ranges.
          */
-        if (ASN1_INTEGER_cmp(a_min, a_max) > 0 ||
-            ASN1_INTEGER_cmp(b_min, b_max) > 0)
+        if (ASN1_INTEGER_cmp(a_min, a_max) > 0 || ASN1_INTEGER_cmp(b_min, b_max) > 0)
             goto done;
 
         /*
@@ -419,15 +410,12 @@ static int ASIdentifierChoice_canonize(ASIdentifierChoice *choice)
         /*
          * Calculate a_max + 1 to check for adjacency.
          */
-        if ((bn == NULL && (bn = BN_new()) == NULL) ||
-            ASN1_INTEGER_to_BN(a_max, bn) == NULL ||
-            !BN_add_word(bn, 1)) {
+        if ((bn == NULL && (bn = BN_new()) == NULL) || ASN1_INTEGER_to_BN(a_max, bn) == NULL || !BN_add_word(bn, 1)) {
             ERR_raise(ERR_LIB_X509V3, ERR_R_BN_LIB);
             goto done;
         }
 
-        if ((a_max_plus_one =
-                 BN_to_ASN1_INTEGER(bn, orig = a_max_plus_one)) == NULL) {
+        if ((a_max_plus_one = BN_to_ASN1_INTEGER(bn, orig = a_max_plus_one)) == NULL) {
             a_max_plus_one = orig;
             ERR_raise(ERR_LIB_X509V3, ERR_R_ASN1_LIB);
             goto done;
@@ -476,7 +464,7 @@ static int ASIdentifierChoice_canonize(ASIdentifierChoice *choice)
         ASN1_INTEGER *a_min, *a_max;
         if (a != NULL && a->type == ASIdOrRange_range) {
             if (!extract_min_max(a, &a_min, &a_max)
-                    || ASN1_INTEGER_cmp(a_min, a_max) > 0)
+                || ASN1_INTEGER_cmp(a_min, a_max) > 0)
                 goto done;
         }
     }
@@ -487,7 +475,7 @@ static int ASIdentifierChoice_canonize(ASIdentifierChoice *choice)
 
     ret = 1;
 
- done:
+done:
     ASN1_INTEGER_free(a_max_plus_one);
     BN_free(bn);
     return ret;
@@ -498,17 +486,15 @@ static int ASIdentifierChoice_canonize(ASIdentifierChoice *choice)
  */
 int X509v3_asid_canonize(ASIdentifiers *asid)
 {
-    return (asid == NULL ||
-            (ASIdentifierChoice_canonize(asid->asnum) &&
-             ASIdentifierChoice_canonize(asid->rdi)));
+    return (asid == NULL || (ASIdentifierChoice_canonize(asid->asnum) && ASIdentifierChoice_canonize(asid->rdi)));
 }
 
 /*
  * v2i method for an ASIdentifier extension.
  */
 static void *v2i_ASIdentifiers(const struct v3_ext_method *method,
-                               struct v3_ext_ctx *ctx,
-                               STACK_OF(CONF_VALUE) *values)
+    struct v3_ext_ctx *ctx,
+    STACK_OF(CONF_VALUE) *values)
 {
     ASN1_INTEGER *min = NULL, *max = NULL;
     ASIdentifiers *asid = NULL;
@@ -536,6 +522,11 @@ static void *v2i_ASIdentifiers(const struct v3_ext_method *method,
             goto err;
         }
 
+        if (val->value == NULL) {
+            ERR_raise(ERR_LIB_X509V3, X509V3_R_EXTENSION_VALUE_ERROR);
+            goto err;
+        }
+
         /*
          * Handle inheritance.
          */
@@ -610,7 +601,7 @@ static void *v2i_ASIdentifiers(const struct v3_ext_method *method,
         goto err;
     return asid;
 
- err:
+err:
     ASIdentifiers_free(asid);
     ASN1_INTEGER_free(min);
     ASN1_INTEGER_free(max);
@@ -621,17 +612,17 @@ static void *v2i_ASIdentifiers(const struct v3_ext_method *method,
  * OpenSSL dispatch.
  */
 const X509V3_EXT_METHOD ossl_v3_asid = {
-    NID_sbgp_autonomousSysNum,  /* nid */
-    0,                          /* flags */
+    NID_sbgp_autonomousSysNum, /* nid */
+    0, /* flags */
     ASN1_ITEM_ref(ASIdentifiers), /* template */
-    0, 0, 0, 0,                 /* old functions, ignored */
-    0,                          /* i2s */
-    0,                          /* s2i */
-    0,                          /* i2v */
-    v2i_ASIdentifiers,          /* v2i */
-    i2r_ASIdentifiers,          /* i2r */
-    0,                          /* r2i */
-    NULL                        /* extension-specific data */
+    0, 0, 0, 0, /* old functions, ignored */
+    0, /* i2s */
+    0, /* s2i */
+    0, /* i2v */
+    v2i_ASIdentifiers, /* v2i */
+    i2r_ASIdentifiers, /* i2r */
+    0, /* r2i */
+    NULL /* extension-specific data */
 };
 
 /*
@@ -639,11 +630,7 @@ const X509V3_EXT_METHOD ossl_v3_asid = {
  */
 int X509v3_asid_inherits(ASIdentifiers *asid)
 {
-    return (asid != NULL &&
-            ((asid->asnum != NULL &&
-              asid->asnum->type == ASIdentifierChoice_inherit) ||
-             (asid->rdi != NULL &&
-              asid->rdi->type == ASIdentifierChoice_inherit)));
+    return (asid != NULL && ((asid->asnum != NULL && asid->asnum->type == ASIdentifierChoice_inherit) || (asid->rdi != NULL && asid->rdi->type == ASIdentifierChoice_inherit)));
 }
 
 /*
@@ -667,7 +654,7 @@ static int asid_contains(ASIdOrRanges *parent, ASIdOrRanges *child)
             if (p >= sk_ASIdOrRange_num(parent))
                 return 0;
             if (!extract_min_max(sk_ASIdOrRange_value(parent, p), &p_min,
-                                 &p_max))
+                    &p_max))
                 return 0;
             if (ASN1_INTEGER_cmp(p_max, c_max) < 0)
                 continue;
@@ -697,55 +684,54 @@ int X509v3_asid_subset(ASIdentifiers *a, ASIdentifiers *b)
         return 0;
 
     subset = a->asnum == NULL
-             || (b->asnum != NULL
-                 && asid_contains(b->asnum->u.asIdsOrRanges,
-                                  a->asnum->u.asIdsOrRanges));
+        || (b->asnum != NULL
+            && asid_contains(b->asnum->u.asIdsOrRanges,
+                a->asnum->u.asIdsOrRanges));
     if (!subset)
         return 0;
 
     return a->rdi == NULL
-           || (b->rdi != NULL
-               && asid_contains(b->rdi->u.asIdsOrRanges,
-                                a->rdi->u.asIdsOrRanges));
+        || (b->rdi != NULL
+            && asid_contains(b->rdi->u.asIdsOrRanges,
+                a->rdi->u.asIdsOrRanges));
 }
 
 /*
  * Validation error handling via callback.
  */
-#define validation_err(_err_)           \
-  do {                                  \
-    if (ctx != NULL) {                  \
-      ctx->error = _err_;               \
-      ctx->error_depth = i;             \
-      ctx->current_cert = x;            \
-      ret = ctx->verify_cb(0, ctx);     \
-    } else {                            \
-      ret = 0;                          \
-    }                                   \
-    if (!ret)                           \
-      goto done;                        \
-  } while (0)
+#define validation_err(_err_)             \
+    do {                                  \
+        if (ctx != NULL) {                \
+            ctx->error = _err_;           \
+            ctx->error_depth = i;         \
+            ctx->current_cert = x;        \
+            ret = ctx->verify_cb(0, ctx); \
+        } else {                          \
+            ret = 0;                      \
+        }                                 \
+        if (!ret)                         \
+            goto done;                    \
+    } while (0)
 
 /*
  * Core code for RFC 3779 3.3 path validation.
  */
 static int asid_validate_path_internal(X509_STORE_CTX *ctx,
-                                       STACK_OF(X509) *chain,
-                                       ASIdentifiers *ext)
+    STACK_OF(X509) *chain,
+    ASIdentifiers *ext)
 {
     ASIdOrRanges *child_as = NULL, *child_rdi = NULL;
     int i, ret = 1, inherit_as = 0, inherit_rdi = 0;
     X509 *x;
 
     if (!ossl_assert(chain != NULL && sk_X509_num(chain) > 0)
-            || !ossl_assert(ctx != NULL || ext != NULL)
-            || !ossl_assert(ctx == NULL || ctx->verify_cb != NULL)) {
+        || !ossl_assert(ctx != NULL || ext != NULL)
+        || !ossl_assert(ctx == NULL || ctx->verify_cb != NULL)) {
         if (ctx != NULL)
             ctx->error = X509_V_ERR_UNSPECIFIED;
         return 0;
     }
 
-
     /*
      * Figure out where to start.  If we don't have an extension to
      * check, we're done.  Otherwise, check canonical form and
@@ -806,12 +792,10 @@ static int asid_validate_path_internal(X509_STORE_CTX *ctx,
             child_as = NULL;
             inherit_as = 0;
         }
-        if (x->rfc3779_asid->asnum != NULL &&
-            x->rfc3779_asid->asnum->type ==
-            ASIdentifierChoice_asIdsOrRanges) {
+        if (x->rfc3779_asid->asnum != NULL && x->rfc3779_asid->asnum->type == ASIdentifierChoice_asIdsOrRanges) {
             if (inherit_as
                 || asid_contains(x->rfc3779_asid->asnum->u.asIdsOrRanges,
-                                 child_as)) {
+                    child_as)) {
                 child_as = x->rfc3779_asid->asnum->u.asIdsOrRanges;
                 inherit_as = 0;
             } else {
@@ -823,11 +807,8 @@ static int asid_validate_path_internal(X509_STORE_CTX *ctx,
             child_rdi = NULL;
             inherit_rdi = 0;
         }
-        if (x->rfc3779_asid->rdi != NULL &&
-            x->rfc3779_asid->rdi->type == ASIdentifierChoice_asIdsOrRanges) {
-            if (inherit_rdi ||
-                asid_contains(x->rfc3779_asid->rdi->u.asIdsOrRanges,
-                              child_rdi)) {
+        if (x->rfc3779_asid->rdi != NULL && x->rfc3779_asid->rdi->type == ASIdentifierChoice_asIdsOrRanges) {
+            if (inherit_rdi || asid_contains(x->rfc3779_asid->rdi->u.asIdsOrRanges, child_rdi)) {
                 child_rdi = x->rfc3779_asid->rdi->u.asIdsOrRanges;
                 inherit_rdi = 0;
             } else {
@@ -845,15 +826,13 @@ static int asid_validate_path_internal(X509_STORE_CTX *ctx,
         return 0;
     }
     if (x->rfc3779_asid != NULL) {
-        if (x->rfc3779_asid->asnum != NULL &&
-            x->rfc3779_asid->asnum->type == ASIdentifierChoice_inherit)
+        if (x->rfc3779_asid->asnum != NULL && x->rfc3779_asid->asnum->type == ASIdentifierChoice_inherit)
             validation_err(X509_V_ERR_UNNESTED_RESOURCE);
-        if (x->rfc3779_asid->rdi != NULL &&
-            x->rfc3779_asid->rdi->type == ASIdentifierChoice_inherit)
+        if (x->rfc3779_asid->rdi != NULL && x->rfc3779_asid->rdi->type == ASIdentifierChoice_inherit)
             validation_err(X509_V_ERR_UNNESTED_RESOURCE);
     }
 
- done:
+done:
     return ret;
 }
 
@@ -865,8 +844,8 @@ static int asid_validate_path_internal(X509_STORE_CTX *ctx,
 int X509v3_asid_validate_path(X509_STORE_CTX *ctx)
 {
     if (ctx->chain == NULL
-            || sk_X509_num(ctx->chain) == 0
-            || ctx->verify_cb == NULL) {
+        || sk_X509_num(ctx->chain) == 0
+        || ctx->verify_cb == NULL) {
         ctx->error = X509_V_ERR_UNSPECIFIED;
         return 0;
     }
@@ -878,7 +857,7 @@ int X509v3_asid_validate_path(X509_STORE_CTX *ctx)
  * Test whether chain covers extension.
  */
 int X509v3_asid_validate_resource_set(STACK_OF(X509) *chain,
-                                      ASIdentifiers *ext, int allow_inheritance)
+    ASIdentifiers *ext, int allow_inheritance)
 {
     if (ext == NULL)
         return 1;
@@ -889,4 +868,4 @@ int X509v3_asid_validate_resource_set(STACK_OF(X509) *chain,
     return asid_validate_path_internal(NULL, chain, ext);
 }
 
-#endif                          /* OPENSSL_NO_RFC3779 */
+#endif /* OPENSSL_NO_RFC3779 */
