@@ -13,7 +13,7 @@
 #include <openssl/x509.h>
 
 int X509_STORE_set_default_paths_ex(X509_STORE *ctx, OSSL_LIB_CTX *libctx,
-                                    const char *propq)
+    const char *propq)
 {
     X509_LOOKUP *lookup;
 
@@ -48,14 +48,15 @@ int X509_STORE_set_default_paths(X509_STORE *ctx)
 }
 
 int X509_STORE_load_file_ex(X509_STORE *ctx, const char *file,
-                            OSSL_LIB_CTX *libctx, const char *propq)
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     X509_LOOKUP *lookup;
 
     if (file == NULL
         || (lookup = X509_STORE_add_lookup(ctx, X509_LOOKUP_file())) == NULL
         || X509_LOOKUP_load_file_ex(lookup, file, X509_FILETYPE_PEM, libctx,
-                                    propq) <= 0)
+               propq)
+            <= 0)
         return 0;
 
     return 1;
@@ -79,7 +80,7 @@ int X509_STORE_load_path(X509_STORE *ctx, const char *path)
 }
 
 int X509_STORE_load_store_ex(X509_STORE *ctx, const char *uri,
-                             OSSL_LIB_CTX *libctx, const char *propq)
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     X509_LOOKUP *lookup;
 
@@ -97,8 +98,8 @@ int X509_STORE_load_store(X509_STORE *ctx, const char *uri)
 }
 
 int X509_STORE_load_locations_ex(X509_STORE *ctx, const char *file,
-                                 const char *path, OSSL_LIB_CTX *libctx,
-                                 const char *propq)
+    const char *path, OSSL_LIB_CTX *libctx,
+    const char *propq)
 {
     if (file == NULL && path == NULL)
         return 0;
@@ -110,7 +111,7 @@ int X509_STORE_load_locations_ex(X509_STORE *ctx, const char *file,
 }
 
 int X509_STORE_load_locations(X509_STORE *ctx, const char *file,
-                              const char *path)
+    const char *path)
 {
     return X509_STORE_load_locations_ex(ctx, file, path, NULL, NULL);
 }
