@@ -27,7 +27,7 @@ int X509_CRL_get_ext_by_NID(const X509_CRL *x, int nid, int lastpos)
 }
 
 int X509_CRL_get_ext_by_OBJ(const X509_CRL *x, const ASN1_OBJECT *obj,
-                            int lastpos)
+    int lastpos)
 {
     return X509v3_get_ext_by_OBJ(x->crl.extensions, obj, lastpos);
 }
@@ -65,7 +65,7 @@ void *X509_CRL_get_ext_d2i(const X509_CRL *x, int nid, int *crit, int *idx)
 }
 
 int X509_CRL_add1_ext_i2d(X509_CRL *x, int nid, void *value, int crit,
-                          unsigned long flags)
+    unsigned long flags)
 {
     return X509V3_add1_i2d(&x->crl.extensions, nid, value, crit, flags);
 }
@@ -92,8 +92,7 @@ int X509_get_ext_by_OBJ(const X509 *x, const ASN1_OBJECT *obj, int lastpos)
 
 int X509_get_ext_by_critical(const X509 *x, int crit, int lastpos)
 {
-    return (X509v3_get_ext_by_critical
-            (x->cert_info.extensions, crit, lastpos));
+    return (X509v3_get_ext_by_critical(x->cert_info.extensions, crit, lastpos));
 }
 
 X509_EXTENSION *X509_get_ext(const X509 *x, int loc)
@@ -117,10 +116,10 @@ void *X509_get_ext_d2i(const X509 *x, int nid, int *crit, int *idx)
 }
 
 int X509_add1_ext_i2d(X509 *x, int nid, void *value, int crit,
-                      unsigned long flags)
+    unsigned long flags)
 {
     return X509V3_add1_i2d(&x->cert_info.extensions, nid, value, crit,
-                           flags);
+        flags);
 }
 
 int X509_REVOKED_get_ext_count(const X509_REVOKED *x)
@@ -134,7 +133,7 @@ int X509_REVOKED_get_ext_by_NID(const X509_REVOKED *x, int nid, int lastpos)
 }
 
 int X509_REVOKED_get_ext_by_OBJ(const X509_REVOKED *x, const ASN1_OBJECT *obj,
-                                int lastpos)
+    int lastpos)
 {
     return X509v3_get_ext_by_OBJ(x->extensions, obj, lastpos);
 }
@@ -165,7 +164,7 @@ void *X509_REVOKED_get_ext_d2i(const X509_REVOKED *x, int nid, int *crit, int *i
 }
 
 int X509_REVOKED_add1_ext_i2d(X509_REVOKED *x, int nid, void *value, int crit,
-                              unsigned long flags)
+    unsigned long flags)
 {
     return X509V3_add1_i2d(&x->extensions, nid, value, crit, flags);
 }
