@@ -1,5 +1,5 @@
 /*
- * Copyright 1995-2022 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 1995-2021 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -16,16 +16,16 @@
 #include "crypto/x509.h"
 
 ASN1_SEQUENCE_enc(X509_CINF, enc, 0) = {
-        ASN1_EXP_OPT(X509_CINF, version, ASN1_INTEGER, 0),
-        ASN1_EMBED(X509_CINF, serialNumber, ASN1_INTEGER),
-        ASN1_EMBED(X509_CINF, signature, X509_ALGOR),
-        ASN1_SIMPLE(X509_CINF, issuer, X509_NAME),
-        ASN1_EMBED(X509_CINF, validity, X509_VAL),
-        ASN1_SIMPLE(X509_CINF, subject, X509_NAME),
-        ASN1_SIMPLE(X509_CINF, key, X509_PUBKEY),
-        ASN1_IMP_OPT(X509_CINF, issuerUID, ASN1_BIT_STRING, 1),
-        ASN1_IMP_OPT(X509_CINF, subjectUID, ASN1_BIT_STRING, 2),
-        ASN1_EXP_SEQUENCE_OF_OPT(X509_CINF, extensions, X509_EXTENSION, 3)
+    ASN1_EXP_OPT(X509_CINF, version, ASN1_INTEGER, 0),
+    ASN1_EMBED(X509_CINF, serialNumber, ASN1_INTEGER),
+    ASN1_EMBED(X509_CINF, signature, X509_ALGOR),
+    ASN1_SIMPLE(X509_CINF, issuer, X509_NAME),
+    ASN1_EMBED(X509_CINF, validity, X509_VAL),
+    ASN1_SIMPLE(X509_CINF, subject, X509_NAME),
+    ASN1_SIMPLE(X509_CINF, key, X509_PUBKEY),
+    ASN1_IMP_OPT(X509_CINF, issuerUID, ASN1_BIT_STRING, 1),
+    ASN1_IMP_OPT(X509_CINF, subjectUID, ASN1_BIT_STRING, 2),
+    ASN1_EXP_SEQUENCE_OF_OPT(X509_CINF, extensions, X509_EXTENSION, 3)
 } ASN1_SEQUENCE_END_enc(X509_CINF, X509_CINF)
 
 IMPLEMENT_ASN1_FUNCTIONS(X509_CINF)
@@ -34,7 +34,7 @@ IMPLEMENT_ASN1_FUNCTIONS(X509_CINF)
 extern void ossl_policy_cache_free(X509_POLICY_CACHE *cache);
 
 static int x509_cb(int operation, ASN1_VALUE **pval, const ASN1_ITEM *it,
-                   void *exarg)
+    void *exarg)
 {
     X509 *ret = (X509 *)*pval;
 
@@ -98,29 +98,23 @@ static int x509_cb(int operation, ASN1_VALUE **pval, const ASN1_ITEM *it,
         OPENSSL_free(ret->propq);
         break;
 
-    case ASN1_OP_DUP_POST:
-        {
-            X509 *old = exarg;
+    case ASN1_OP_DUP_POST: {
+        X509 *old = exarg;
 
-            if (!ossl_x509_set0_libctx(ret, old->libctx, old->propq))
-                return 0;
-        }
-        break;
-    case ASN1_OP_GET0_LIBCTX:
-        {
-            OSSL_LIB_CTX **libctx = exarg;
+        if (!ossl_x509_set0_libctx(ret, old->libctx, old->propq))
+            return 0;
+    } break;
+    case ASN1_OP_GET0_LIBCTX: {
+        OSSL_LIB_CTX **libctx = exarg;
 
-            *libctx = ret->libctx;
-        }
-        break;
+        *libctx = ret->libctx;
+    } break;
 
-    case ASN1_OP_GET0_PROPQ:
-        {
-            const char **propq = exarg;
+    case ASN1_OP_GET0_PROPQ: {
+        const char **propq = exarg;
 
-            *propq = ret->propq;
-        }
-        break;
+        *propq = ret->propq;
+    } break;
 
     default:
         break;
@@ -130,9 +124,9 @@ static int x509_cb(int operation, ASN1_VALUE **pval, const ASN1_ITEM *it,
 }
 
 ASN1_SEQUENCE_ref(X509, x509_cb) = {
-        ASN1_EMBED(X509, cert_info, X509_CINF),
-        ASN1_EMBED(X509, sig_alg, X509_ALGOR),
-        ASN1_EMBED(X509, signature, ASN1_BIT_STRING)
+    ASN1_EMBED(X509, cert_info, X509_CINF),
+    ASN1_EMBED(X509, sig_alg, X509_ALGOR),
+    ASN1_EMBED(X509, signature, ASN1_BIT_STRING)
 } ASN1_SEQUENCE_END_ref(X509, X509)
 
 IMPLEMENT_ASN1_FUNCTIONS(X509)
@@ -208,7 +202,7 @@ X509 *d2i_X509_AUX(X509 **a, const unsigned char **pp, long length)
         goto err;
     *pp = q;
     return ret;
- err:
+err:
     if (freeret) {
         X509_free(ret);
         if (a)
@@ -272,10 +266,8 @@ int i2d_X509_AUX(const X509 *a, unsigned char **pp)
 
     /* Allocate requisite combined storage */
     *pp = tmp = OPENSSL_malloc(length);
-    if (tmp == NULL) {
-        ERR_raise(ERR_LIB_X509, ERR_R_MALLOC_FAILURE);
+    if (tmp == NULL)
         return -1;
-    }
 
     /* Encode, but keep *pp at the originally malloced pointer */
     length = i2d_x509_aux_internal(a, &tmp);
@@ -293,7 +285,7 @@ int i2d_re_X509_tbs(X509 *x, unsigned char **pp)
 }
 
 void X509_get0_signature(const ASN1_BIT_STRING **psig,
-                         const X509_ALGOR **palg, const X509 *x)
+    const X509_ALGOR **palg, const X509 *x)
 {
     if (psig)
         *psig = &x->signature;
