@@ -23,11 +23,10 @@
 #include "rsa_encrypt.h"
 
 /* Input data to encrypt */
-static const unsigned char msg[] =
-    "To be, or not to be, that is the question,\n"
-    "Whether tis nobler in the minde to suffer\n"
-    "The slings and arrowes of outragious fortune,\n"
-    "Or to take Armes again in a sea of troubles";
+static const unsigned char msg[] = "To be, or not to be, that is the question,\n"
+                                   "Whether tis nobler in the minde to suffer\n"
+                                   "The slings and arrowes of outragious fortune,\n"
+                                   "Or to take Armes again in a sea of troubles";
 
 /*
  * For do_encrypt(), load an RSA public key from pub_key_der[].
@@ -51,7 +50,7 @@ static EVP_PKEY *get_key(OSSL_LIB_CTX *libctx, const char *propq, int public)
         data_len = sizeof(priv_key_der);
     }
     dctx = OSSL_DECODER_CTX_new_for_pkey(&pkey, "DER", NULL, "RSA",
-                                         selection, libctx, propq);
+        selection, libctx, propq);
     (void)OSSL_DECODER_from_data(dctx, &data, &data_len);
     OSSL_DECODER_CTX_free(dctx);
     return pkey;
@@ -64,20 +63,20 @@ static void set_optional_params(OSSL_PARAM *p, const char *propq)
 
     /* "pkcs1" is used by default if the padding mode is not set */
     *p++ = OSSL_PARAM_construct_utf8_string(OSSL_ASYM_CIPHER_PARAM_PAD_MODE,
-                                            OSSL_PKEY_RSA_PAD_MODE_OAEP, 0);
+        OSSL_PKEY_RSA_PAD_MODE_OAEP, 0);
     /* No oaep_label is used if this is not set */
     *p++ = OSSL_PARAM_construct_octet_string(OSSL_ASYM_CIPHER_PARAM_OAEP_LABEL,
-                                             label, sizeof(label));
+        label, sizeof(label));
     /* "SHA1" is used if this is not set */
     *p++ = OSSL_PARAM_construct_utf8_string(OSSL_ASYM_CIPHER_PARAM_OAEP_DIGEST,
-                                            "SHA256", 0);
+        "SHA256", 0);
     /*
      * If a non default property query needs to be specified when fetching the
      * OAEP digest then it needs to be specified here.
      */
     if (propq != NULL)
         *p++ = OSSL_PARAM_construct_utf8_string(OSSL_ASYM_CIPHER_PARAM_OAEP_DIGEST_PROPS,
-                                                (char *)propq, 0);
+            (char *)propq, 0);
 
     /*
      * OSSL_ASYM_CIPHER_PARAM_MGF1_DIGEST and
@@ -94,8 +93,8 @@ static void set_optional_params(OSSL_PARAM *p, const char *propq)
  *
  */
 static int do_encrypt(OSSL_LIB_CTX *libctx,
-                      const unsigned char *in, size_t in_len,
-                      unsigned char **out, size_t *out_len)
+    const unsigned char *in, size_t in_len,
+    unsigned char **out, size_t *out_len)
 {
     int ret = 0, public = 1;
     size_t buf_len = 0;
@@ -128,7 +127,7 @@ static int do_encrypt(OSSL_LIB_CTX *libctx,
         goto cleanup;
     }
     buf = OPENSSL_zalloc(buf_len);
-    if (buf  == NULL) {
+    if (buf == NULL) {
         fprintf(stderr, "Malloc failed.\n");
         goto cleanup;
     }
@@ -151,8 +150,8 @@ cleanup:
     return ret;
 }
 
-static int do_decrypt(OSSL_LIB_CTX *libctx, const char *in, size_t in_len,
-                      unsigned char **out, size_t *out_len)
+static int do_decrypt(OSSL_LIB_CTX *libctx, const unsigned char *in, size_t in_len,
+    unsigned char **out, size_t *out_len)
 {
     int ret = 0, public = 0;
     size_t buf_len = 0;
@@ -223,7 +222,7 @@ int main(void)
         goto cleanup;
     }
     if (!do_decrypt(libctx, encrypted, encrypted_len,
-                    &decrypted, &decrypted_len)) {
+            &decrypted, &decrypted_len)) {
         fprintf(stderr, "decryption failed.\n");
         goto cleanup;
     }
