@@ -18,37 +18,37 @@
 #include <sys/socket.h>
 
 #ifndef PATH_MAX
-# define PATH_MAX 255
+#define PATH_MAX 255
 #endif
 
 #define nghttp3_arraylen(A) (sizeof(A) / sizeof(*(A)))
 
 /* The crappy test wants 20 bytes */
 #define NULL_PAYLOAD "12345678901234567890"
-static uint8_t *nulldata = (uint8_t *) NULL_PAYLOAD;
+static uint8_t *nulldata = (uint8_t *)NULL_PAYLOAD;
 static size_t nulldata_sz = sizeof(NULL_PAYLOAD) - 1;
 
 /* The nghttp3 variable we need in the main part and read_from_ssl_ids */
 static nghttp3_settings settings;
 static const nghttp3_mem *mem;
-static nghttp3_callbacks callbacks = {0};
+static nghttp3_callbacks callbacks = { 0 };
 
 /* 3 streams created by the server and 4 by the client (one is bidi) */
 struct ssl_id {
-    SSL *s;      /* the stream openssl uses in SSL_read(),  SSL_write etc */
+    SSL *s; /* the stream openssl uses in SSL_read(),  SSL_write etc */
     uint64_t id; /* the stream identifier the nghttp3 uses */
-    int status;  /* 0 or one the below status and origin */
+    int status; /* 0 or one the below status and origin */
 };
 /* status and origin of the streams the possible values are: */
-#define CLIENTUNIOPEN  0x01 /* unidirectional open by the client (2, 6 and 10) */
-#define CLIENTCLOSED   0x02 /* closed by the client */
+#define CLIENTUNIOPEN 0x01 /* unidirectional open by the client (2, 6 and 10) */
+#define CLIENTCLOSED 0x02 /* closed by the client */
 #define CLIENTBIDIOPEN 0x04 /* bidirectional open by the client (something like 0, 4, 8 ...) */
-#define SERVERUNIOPEN  0x08 /* unidirectional open by the server (3, 7 and 11) */
-#define SERVERCLOSED   0x10 /* closed by the server (us) */
-#define TOBEREMOVED    0x20 /* marked for removing in read_from_ssl_ids, */
-                            /* it will be removed after processing all events */
-#define ISLISTENER     0x40 /* the stream is a listener from SSL_new_listener() */
-#define ISCONNECTION   0x80 /* the stream is a connection from SSL_accept_connection() */
+#define SERVERUNIOPEN 0x08 /* unidirectional open by the server (3, 7 and 11) */
+#define SERVERCLOSED 0x10 /* closed by the server (us) */
+#define TOBEREMOVED 0x20 /* marked for removing in read_from_ssl_ids, */
+/* it will be removed after processing all events */
+#define ISLISTENER 0x40 /* the stream is a listener from SSL_new_listener() */
+#define ISCONNECTION 0x80 /* the stream is a connection from SSL_accept_connection() */
 
 #define MAXSSL_IDS 20
 #define MAXURL 255
@@ -56,29 +56,29 @@ struct ssl_id {
 struct h3ssl {
     struct ssl_id ssl_ids[MAXSSL_IDS];
     int end_headers_received; /* h3 header received call back called */
-    int datadone;             /* h3 has given openssl all the data of the response */
-    int has_uni;              /* we have the 3 uni directional stream needed */
-    int close_done;           /* connection begins terminating EVENT_EC */
-    int close_wait;           /* we are waiting for a close or a new request */
-    int done;                 /* connection terminated EVENT_ECD, after EVENT_EC */
-    int new_conn;             /* a new connection has been received */
-    int received_from_two;    /* workaround for -607 on nghttp3_conn_read_stream on stream 2 */
-    int restart;              /* new request/response cycle started */
-    uint64_t id_bidi;         /* the id of the stream used to read request and send response */
-    char *fileprefix;         /* prefix of the directory to fetch files from */
-    char url[MAXURL];         /* url to serve the request */
-    uint8_t *ptr_data;        /* pointer to the data to send */
-    size_t ldata;             /* amount of bytes to send */
-    int offset_data;          /* offset to next data to send */
+    int datadone; /* h3 has given openssl all the data of the response */
+    int has_uni; /* we have the 3 uni directional stream needed */
+    int close_done; /* connection begins terminating EVENT_EC */
+    int close_wait; /* we are waiting for a close or a new request */
+    int done; /* connection terminated EVENT_ECD, after EVENT_EC */
+    int new_conn; /* a new connection has been received */
+    int received_from_two; /* workaround for -607 on nghttp3_conn_read_stream on stream 2 */
+    int restart; /* new request/response cycle started */
+    uint64_t id_bidi; /* the id of the stream used to read request and send response */
+    char *fileprefix; /* prefix of the directory to fetch files from */
+    char url[MAXURL]; /* url to serve the request */
+    uint8_t *ptr_data; /* pointer to the data to send */
+    size_t ldata; /* amount of bytes to send */
+    int offset_data; /* offset to next data to send */
 };
 
 static void make_nv(nghttp3_nv *nv, const char *name, const char *value)
 {
-    nv->name        = (uint8_t *)name;
-    nv->value       = (uint8_t *)value;
-    nv->namelen     = strlen(name);
-    nv->valuelen    = strlen(value);
-    nv->flags       = NGHTTP3_NV_FLAG_NONE;
+    nv->name = (uint8_t *)name;
+    nv->value = (uint8_t *)value;
+    nv->namelen = strlen(name);
+    nv->valuelen = strlen(value);
+    nv->flags = NGHTTP3_NV_FLAG_NONE;
 }
 
 static void init_ids(struct h3ssl *h3ssl)
@@ -184,7 +184,7 @@ static void remove_marked_ids(struct h3ssl *h3ssl)
     ssl_ids = h3ssl->ssl_ids;
     for (i = 0; i < MAXSSL_IDS; i++) {
         if (ssl_ids[i].status & TOBEREMOVED) {
-            printf("remove_id %llu\n", (unsigned long long) ssl_ids[i].id);
+            printf("remove_id %llu\n", (unsigned long long)ssl_ids[i].id);
             SSL_free(ssl_ids[i].s);
             ssl_ids[i].s = NULL;
             ssl_ids[i].id = UINT64_MAX;
@@ -203,7 +203,7 @@ static void set_id_status(uint64_t id, int status, struct h3ssl *h3ssl)
     ssl_ids = h3ssl->ssl_ids;
     for (i = 0; i < MAXSSL_IDS; i++) {
         if (ssl_ids[i].id == id) {
-            printf("set_id_status: %llu to %d\n", (unsigned long long) ssl_ids[i].id, status);
+            printf("set_id_status: %llu to %d\n", (unsigned long long)ssl_ids[i].id, status);
             ssl_ids[i].status = ssl_ids[i].status | status;
             return;
         }
@@ -220,7 +220,7 @@ static int get_id_status(uint64_t id, struct h3ssl *h3ssl)
     for (i = 0; i < MAXSSL_IDS; i++) {
         if (ssl_ids[i].id == id) {
             printf("get_id_status: %llu to %d\n",
-                   (unsigned long long) ssl_ids[i].id, ssl_ids[i].status);
+                (unsigned long long)ssl_ids[i].id, ssl_ids[i].status);
             return ssl_ids[i].status;
         }
     }
@@ -240,17 +240,17 @@ static int are_all_clientid_closed(struct h3ssl *h3ssl)
         if (ssl_ids[i].id == UINT64_MAX)
             continue;
         printf("are_all_clientid_closed: %llu status %d : %d\n",
-               (unsigned long long) ssl_ids[i].id, ssl_ids[i].status, CLIENTUNIOPEN | CLIENTCLOSED);
+            (unsigned long long)ssl_ids[i].id, ssl_ids[i].status, CLIENTUNIOPEN | CLIENTCLOSED);
         if (ssl_ids[i].status & CLIENTUNIOPEN) {
             if (ssl_ids[i].status & CLIENTCLOSED) {
                 printf("are_all_clientid_closed: %llu closed\n",
-                       (unsigned long long) ssl_ids[i].id);
+                    (unsigned long long)ssl_ids[i].id);
                 SSL_free(ssl_ids[i].s);
                 ssl_ids[i].s = NULL;
                 ssl_ids[i].id = UINT64_MAX;
                 continue;
             }
-            printf("are_all_clientid_closed: %llu open\n", (unsigned long long) ssl_ids[i].id);
+            printf("are_all_clientid_closed: %llu open\n", (unsigned long long)ssl_ids[i].id);
             return 0;
         }
     }
@@ -274,9 +274,9 @@ static void close_all_ids(struct h3ssl *h3ssl)
 }
 
 static int on_recv_header(nghttp3_conn *conn, int64_t stream_id, int32_t token,
-                          nghttp3_rcbuf *name, nghttp3_rcbuf *value,
-                          uint8_t flags, void *user_data,
-                          void *stream_user_data)
+    nghttp3_rcbuf *name, nghttp3_rcbuf *value,
+    uint8_t flags, void *user_data,
+    void *stream_user_data)
 {
     nghttp3_vec vname, vvalue;
     struct h3ssl *h3ssl = (struct h3ssl *)user_data;
@@ -310,7 +310,7 @@ static int on_recv_header(nghttp3_conn *conn, int64_t stream_id, int32_t token,
 }
 
 static int on_end_headers(nghttp3_conn *conn, int64_t stream_id, int fin,
-                          void *user_data, void *stream_user_data)
+    void *user_data, void *stream_user_data)
 {
     struct h3ssl *h3ssl = (struct h3ssl *)user_data;
 
@@ -320,8 +320,8 @@ static int on_end_headers(nghttp3_conn *conn, int64_t stream_id, int fin,
 }
 
 static int on_recv_data(nghttp3_conn *conn, int64_t stream_id,
-                        const uint8_t *data, size_t datalen,
-                        void *conn_user_data, void *stream_user_data)
+    const uint8_t *data, size_t datalen,
+    void *conn_user_data, void *stream_user_data)
 {
     fprintf(stderr, "on_recv_data! %ld\n", (unsigned long)datalen);
     fprintf(stderr, "on_recv_data! %.*s\n", (int)datalen, data);
@@ -329,7 +329,7 @@ static int on_recv_data(nghttp3_conn *conn, int64_t stream_id,
 }
 
 static int on_end_stream(nghttp3_conn *h3conn, int64_t stream_id,
-                         void *conn_user_data, void *stream_user_data)
+    void *conn_user_data, void *stream_user_data)
 {
     struct h3ssl *h3ssl = (struct h3ssl *)conn_user_data;
 
@@ -351,8 +351,8 @@ static int quic_server_read(nghttp3_conn *h3conn, SSL *stream, uint64_t id, stru
     ret = SSL_read(stream, msg2, l);
     if (ret <= 0) {
         fprintf(stderr, "SSL_read %d on %llu failed\n",
-                SSL_get_error(stream, ret),
-                (unsigned long long) id);
+            SSL_get_error(stream, ret),
+            (unsigned long long)id);
         switch (SSL_get_error(stream, ret)) {
         case SSL_ERROR_WANT_READ:
             return 0;
@@ -373,12 +373,12 @@ static int quic_server_read(nghttp3_conn *h3conn, SSL *stream, uint64_t id, stru
     }
 
     printf("nghttp3_conn_read_stream used %d of %d on %llu\n", r,
-           ret, (unsigned long long) id);
+        ret, (unsigned long long)id);
     if (r != ret) {
         /* chrome returns -607 on stream 2 */
         if (!nghttp3_err_is_fatal(r)) {
             printf("nghttp3_conn_read_stream used %d of %d (not fatal) on %llu\n", r,
-                   ret, (unsigned long long) id);
+                ret, (unsigned long long)id);
             if (id == 2)
                 h3ssl->received_from_two = 1;
             return 1;
@@ -409,7 +409,7 @@ static int quic_server_h3streams(nghttp3_conn *h3conn, struct h3ssl *h3ssl)
     rstream = SSL_new_stream(conn, SSL_STREAM_FLAG_UNI);
     if (rstream != NULL) {
         printf("=> Opened on %llu\n",
-               (unsigned long long)SSL_get_stream_id(rstream));
+            (unsigned long long)SSL_get_stream_id(rstream));
     } else {
         fprintf(stderr, "=> Stream == NULL!\n");
         goto err;
@@ -417,7 +417,7 @@ static int quic_server_h3streams(nghttp3_conn *h3conn, struct h3ssl *h3ssl)
     pstream = SSL_new_stream(conn, SSL_STREAM_FLAG_UNI);
     if (pstream != NULL) {
         printf("=> Opened on %llu\n",
-               (unsigned long long)SSL_get_stream_id(pstream));
+            (unsigned long long)SSL_get_stream_id(pstream));
     } else {
         fprintf(stderr, "=> Stream == NULL!\n");
         goto err;
@@ -425,7 +425,7 @@ static int quic_server_h3streams(nghttp3_conn *h3conn, struct h3ssl *h3ssl)
     cstream = SSL_new_stream(conn, SSL_STREAM_FLAG_UNI);
     if (cstream != NULL) {
         fprintf(stderr, "=> Opened on %llu\n",
-                (unsigned long long)SSL_get_stream_id(cstream));
+            (unsigned long long)SSL_get_stream_id(cstream));
         fflush(stderr);
     } else {
         fprintf(stderr, "=> Stream == NULL!\n");
@@ -443,9 +443,9 @@ static int quic_server_h3streams(nghttp3_conn *h3conn, struct h3ssl *h3ssl)
         goto err;
     }
     printf("control: %llu enc %llu dec %llu\n",
-           (unsigned long long)c_streamid,
-           (unsigned long long)p_streamid,
-           (unsigned long long)r_streamid);
+        (unsigned long long)c_streamid,
+        (unsigned long long)p_streamid,
+        (unsigned long long)r_streamid);
     add_id(SSL_get_stream_id(rstream), rstream, h3ssl);
     add_id(SSL_get_stream_id(pstream), pstream, h3ssl);
     add_id(SSL_get_stream_id(cstream), cstream, h3ssl);
@@ -464,8 +464,8 @@ static int read_from_ssl_ids(nghttp3_conn **curh3conn, struct h3ssl *h3ssl)
 {
     int hassomething = 0, i;
     struct ssl_id *ssl_ids = h3ssl->ssl_ids;
-    SSL_POLL_ITEM items[MAXSSL_IDS] = {0}, *item = items;
-    static const struct timeval nz_timeout = {0, 0};
+    SSL_POLL_ITEM items[MAXSSL_IDS] = { 0 }, *item = items;
+    static const struct timeval nz_timeout = { 0, 0 };
     size_t result_count = SIZE_MAX;
     int numitem = 0, ret;
     uint64_t processed_event = 0;
@@ -479,7 +479,7 @@ static int read_from_ssl_ids(nghttp3_conn **curh3conn, struct h3ssl *h3ssl)
     for (i = 0; i < MAXSSL_IDS; i++) {
         if (ssl_ids[i].s != NULL) {
             item->desc = SSL_as_poll_descriptor(ssl_ids[i].s);
-            item->events = UINT64_MAX;  /* TODO adjust to the event we need process */
+            item->events = UINT64_MAX; /* TODO adjust to the event we need process */
             item->revents = UINT64_MAX; /* TODO adjust to the event we need process */
             numitem++;
             item++;
@@ -496,7 +496,7 @@ static int read_from_ssl_ids(nghttp3_conn **curh3conn, struct h3ssl *h3ssl)
      * on an automatic basis.
      */
     ret = SSL_poll(items, numitem, sizeof(SSL_POLL_ITEM), &nz_timeout,
-                   SSL_POLL_FLAG_NO_HANDLE_EVENTS, &result_count);
+        SSL_POLL_FLAG_NO_HANDLE_EVENTS, &result_count);
     if (!ret) {
         fprintf(stderr, "SSL_poll failed\n");
         printf("SSL_poll failed\n");
@@ -555,7 +555,7 @@ static int read_from_ssl_ids(nghttp3_conn **curh3conn, struct h3ssl *h3ssl)
             nghttp3_conn_del(*curh3conn);
             nghttp3_settings_default(&settings);
             if (nghttp3_conn_server_new(curh3conn, &callbacks, &settings, mem,
-                                        h3ssl)) {
+                    h3ssl)) {
                 fprintf(stderr, "nghttp3_conn_client_new failed!\n");
                 exit(1);
             }
@@ -563,7 +563,7 @@ static int read_from_ssl_ids(nghttp3_conn **curh3conn, struct h3ssl *h3ssl)
             hassomething++;
 
             if (!SSL_set_incoming_stream_policy(conn,
-                                                SSL_INCOMING_STREAM_POLICY_ACCEPT, 0)) {
+                    SSL_INCOMING_STREAM_POLICY_ACCEPT, 0)) {
                 fprintf(stderr, "error while setting inccoming stream policy\n");
                 ret = -1;
                 goto err;
@@ -573,8 +573,7 @@ static int read_from_ssl_ids(nghttp3_conn **curh3conn, struct h3ssl *h3ssl)
             processed_event = processed_event | SSL_POLL_EVENT_IC;
         }
         /* SSL_accept_stream if SSL_POLL_EVENT_ISB or SSL_POLL_EVENT_ISU */
-        if ((item->revents & SSL_POLL_EVENT_ISB) ||
-            (item->revents & SSL_POLL_EVENT_ISU)) {
+        if ((item->revents & SSL_POLL_EVENT_ISB) || (item->revents & SSL_POLL_EVENT_ISU)) {
             SSL *stream = SSL_accept_stream(item->desc.value.ssl, 0);
             uint64_t new_id;
             int r;
@@ -584,8 +583,8 @@ static int read_from_ssl_ids(nghttp3_conn **curh3conn, struct h3ssl *h3ssl)
                 goto err;
             }
             new_id = SSL_get_stream_id(stream);
-            printf("=> Received connection on %lld %d\n", (unsigned long long) new_id,
-                   SSL_get_stream_type(stream));
+            printf("=> Received connection on %lld %d\n", (unsigned long long)new_id,
+                SSL_get_stream_type(stream));
             add_id(new_id, stream, h3ssl);
             if (h3ssl->close_wait) {
                 printf("in close_wait so we will have a new request\n");
@@ -738,8 +737,8 @@ static int read_from_ssl_ids(nghttp3_conn **curh3conn, struct h3ssl *h3ssl)
 
             id = SSL_get_stream_id(item->desc.value.ssl);
             printf("revent %llu (%d) on %llu NOT PROCESSED!\n",
-                   (unsigned long long)item->revents, SSL_POLL_EVENT_W,
-                   (unsigned long long)id);
+                (unsigned long long)item->revents, SSL_POLL_EVENT_W,
+                (unsigned long long)id);
         }
     }
     ret = hassomething;
@@ -756,8 +755,7 @@ static void handle_events_from_ids(struct h3ssl *h3ssl)
 
     ssl_ids = h3ssl->ssl_ids;
     for (i = 0; i < MAXSSL_IDS; i++) {
-        if (ssl_ids[i].s != NULL &&
-            (ssl_ids[i].status & ISCONNECTION || ssl_ids[i].status & ISLISTENER)) {
+        if (ssl_ids[i].s != NULL && (ssl_ids[i].status & ISCONNECTION || ssl_ids[i].status & ISLISTENER)) {
             if (SSL_handle_events(ssl_ids[i].s))
                 ERR_print_errors_fp(stderr);
         }
@@ -781,7 +779,7 @@ static size_t get_file_length(struct h3ssl *h3ssl)
     if (stat(filename, &st) == 0) {
         /* Only process regular files */
         if (S_ISREG(st.st_mode)) {
-            printf("get_file_length %s %lld\n", filename, (unsigned long long) st.st_size);
+            printf("get_file_length %s %lld\n", filename, (unsigned long long)st.st_size);
             return (size_t)st.st_size;
         }
     }
@@ -804,7 +802,7 @@ static char *get_file_data(struct h3ssl *h3ssl)
         strcat(filename, h3ssl->fileprefix);
     strcat(filename, h3ssl->url);
 
-    res = malloc(size+1);
+    res = malloc(size + 1);
     res[size] = '\0';
     fd = open(filename, O_RDONLY);
     if (read(fd, res, size) == -1) {
@@ -818,9 +816,9 @@ static char *get_file_data(struct h3ssl *h3ssl)
 }
 
 static nghttp3_ssize step_read_data(nghttp3_conn *conn, int64_t stream_id,
-                                    nghttp3_vec *vec, size_t veccnt,
-                                    uint32_t *pflags, void *user_data,
-                                    void *stream_user_data)
+    nghttp3_vec *vec, size_t veccnt,
+    uint32_t *pflags, void *user_data,
+    void *stream_user_data)
 {
     struct h3ssl *h3ssl = (struct h3ssl *)user_data;
 
@@ -850,8 +848,8 @@ static nghttp3_ssize step_read_data(nghttp3_conn *conn, int64_t stream_id,
 }
 
 static int quic_server_write(struct h3ssl *h3ssl, uint64_t streamid,
-                             uint8_t *buff, size_t len, uint64_t flags,
-                             size_t *written)
+    uint8_t *buff, size_t len, uint64_t flags,
+    size_t *written)
 {
     struct ssl_id *ssl_ids;
     int i;
@@ -859,19 +857,18 @@ static int quic_server_write(struct h3ssl *h3ssl, uint64_t streamid,
     ssl_ids = h3ssl->ssl_ids;
     for (i = 0; i < MAXSSL_IDS; i++) {
         if (ssl_ids[i].id == streamid) {
-            if (!SSL_write_ex2(ssl_ids[i].s, buff, len, flags, written) ||
-                *written != len) {
+            if (!SSL_write_ex2(ssl_ids[i].s, buff, len, flags, written) || *written != len) {
                 fprintf(stderr, "couldn't write on connection\n");
                 ERR_print_errors_fp(stderr);
                 return 0;
             }
             printf("written %lld on %lld flags %lld\n", (unsigned long long)len,
-                   (unsigned long long)streamid, (unsigned long long)flags);
+                (unsigned long long)streamid, (unsigned long long)flags);
             return 1;
         }
     }
     printf("quic_server_write %lld on %lld (NOT FOUND!)\n", (unsigned long long)len,
-           (unsigned long long)streamid);
+        (unsigned long long)streamid);
     return 0;
 }
 
@@ -883,19 +880,20 @@ static int quic_server_write(struct h3ssl *h3ssl, uint64_t streamid,
  */
 
 /* ALPN string for TLS handshake. We pretent h3-29 and h3 */
-static const unsigned char alpn_ossltest[] = { 5,   'h', '3', '-', '2',
-                                               '9', 2,   'h', '3' };
+static const unsigned char alpn_ossltest[] = { 5, 'h', '3', '-', '2',
+    '9', 2, 'h', '3' };
 
 /*
  * This callback validates and negotiates the desired ALPN on the server side.
  */
 static int select_alpn(SSL *ssl, const unsigned char **out,
-                       unsigned char *out_len, const unsigned char *in,
-                       unsigned int in_len, void *arg)
+    unsigned char *out_len, const unsigned char *in,
+    unsigned int in_len, void *arg)
 {
     if (SSL_select_next_proto((unsigned char **)out, out_len, alpn_ossltest,
-                              sizeof(alpn_ossltest), in,
-                              in_len) != OPENSSL_NPN_NEGOTIATED)
+            sizeof(alpn_ossltest), in,
+            in_len)
+        != OPENSSL_NPN_NEGOTIATED)
         return SSL_TLSEXT_ERR_ALERT_FATAL;
 
     return SSL_TLSEXT_ERR_OK;
@@ -939,7 +937,7 @@ err:
 static int create_socket(uint16_t port)
 {
     int fd = -1;
-    struct sockaddr_in sa = {0};
+    struct sockaddr_in sa = { 0 };
 
     if ((fd = socket(AF_INET, SOCK_DGRAM, IPPROTO_UDP)) < 0) {
         fprintf(stderr, "cannot create socket");
@@ -1172,16 +1170,16 @@ static int run_quic_server(SSL_CTX *ctx, int fd)
         } else if (h3ssl.ldata == INT_MAX) {
             /* endless file for tests */
             sprintf(slength, "%zu", h3ssl.ldata);
-            h3ssl.ptr_data = (uint8_t *) malloc(4096);
+            h3ssl.ptr_data = (uint8_t *)malloc(4096);
             memset(h3ssl.ptr_data, 'A', 4096);
         } else {
             /* normal file we have opened */
             sprintf(slength, "%zu", h3ssl.ldata);
-            h3ssl.ptr_data = (uint8_t *) get_file_data(&h3ssl);
+            h3ssl.ptr_data = (uint8_t *)get_file_data(&h3ssl);
             if (h3ssl.ptr_data == NULL)
                 abort();
             printf("before nghttp3_conn_submit_response on %llu for %s ...\n",
-                   (unsigned long long) h3ssl.id_bidi, h3ssl.url);
+                (unsigned long long)h3ssl.id_bidi, h3ssl.url);
             if (strstr(h3ssl.url, ".png"))
                 make_nv(&resp[num_nv++], "content-type", "image/png");
             else if (strstr(h3ssl.url, ".ico"))
@@ -1198,7 +1196,7 @@ static int run_quic_server(SSL_CTX *ctx, int fd)
             fprintf(stderr, "nghttp3_conn_submit_response failed!\n");
             goto err;
         }
-        printf("nghttp3_conn_submit_response on %llu...\n", (unsigned long long) h3ssl.id_bidi);
+        printf("nghttp3_conn_submit_response on %llu...\n", (unsigned long long)h3ssl.id_bidi);
         for (;;) {
             nghttp3_vec vec[256];
             nghttp3_ssize sveccnt;
@@ -1206,15 +1204,15 @@ static int run_quic_server(SSL_CTX *ctx, int fd)
             int64_t streamid;
 
             sveccnt = nghttp3_conn_writev_stream(h3conn, &streamid, &fin, vec,
-                                                 nghttp3_arraylen(vec));
+                nghttp3_arraylen(vec));
             if (sveccnt <= 0) {
                 printf("nghttp3_conn_writev_stream done: %ld stream: %llu fin %d\n",
-                       (long int)sveccnt,
-                       (unsigned long long)streamid,
-                       fin);
+                    (long int)sveccnt,
+                    (unsigned long long)streamid,
+                    fin);
                 if (streamid != -1 && fin) {
                     printf("Sending end data on %llu fin %d\n",
-                           (unsigned long long) streamid, fin);
+                        (unsigned long long)streamid, fin);
                     nghttp3_conn_add_write_offset(h3conn, streamid, 0);
                     continue;
                 }
@@ -1229,18 +1227,18 @@ static int run_quic_server(SSL_CTX *ctx, int fd)
                 int flagwrite = 0;
 
                 printf("quic_server_write on %llu for %ld\n",
-                       (unsigned long long)streamid, (unsigned long)vec[i].len);
+                    (unsigned long long)streamid, (unsigned long)vec[i].len);
                 if (fin && i == sveccnt - 1)
                     flagwrite = SSL_WRITE_FLAG_CONCLUDE;
                 if (!quic_server_write(&h3ssl, streamid, vec[i].base,
-                                       vec[i].len, flagwrite, &numbytes)) {
+                        vec[i].len, flagwrite, &numbytes)) {
                     fprintf(stderr, "quic_server_write failed!\n");
                     goto err;
                 }
             }
             if (nghttp3_conn_add_write_offset(
-                                              h3conn, streamid,
-                                              (size_t)nghttp3_vec_len(vec, (size_t)sveccnt))) {
+                    h3conn, streamid,
+                    (size_t)nghttp3_vec_len(vec, (size_t)sveccnt))) {
                 fprintf(stderr, "nghttp3_conn_add_write_offset failed!\n");
                 goto err;
             }
@@ -1348,7 +1346,7 @@ int main(int argc, char **argv)
 
     if (argc < 4) {
         fprintf(stderr, "usage: %s <port> <server.crt> <server.key>\n",
-                argv[0]);
+            argv[0]);
         goto err;
     }
 
