@@ -10,7 +10,7 @@
 #include <openssl/err.h>
 #include <assert.h>
 
-#define ARRAY_LEN(x) (sizeof(x)/sizeof((x)[0]))
+#define ARRAY_LEN(x) (sizeof(x) / sizeof((x)[0]))
 
 enum {
     OSSL_DEMO_H3_STREAM_TYPE_CTRL_SEND,
@@ -19,16 +19,16 @@ enum {
     OSSL_DEMO_H3_STREAM_TYPE_REQ,
 };
 
-#define BUF_SIZE    4096
+#define BUF_SIZE 4096
 
 struct ossl_demo_h3_stream_st {
-    uint64_t            id;             /* QUIC stream ID */
-    SSL                 *s;             /* QUIC stream SSL object */
-    int                 done_recv_fin;  /* Received FIN */
-    void                *user_data;
+    uint64_t id; /* QUIC stream ID */
+    SSL *s; /* QUIC stream SSL object */
+    int done_recv_fin; /* Received FIN */
+    void *user_data;
 
-    uint8_t             buf[BUF_SIZE];
-    size_t              buf_cur, buf_total;
+    uint8_t buf[BUF_SIZE];
+    size_t buf_cur, buf_total;
 };
 
 DEFINE_LHASH_OF_EX(OSSL_DEMO_H3_STREAM);
@@ -49,8 +49,10 @@ static unsigned long h3_stream_hash(const OSSL_DEMO_H3_STREAM *s)
 
 static int h3_stream_eq(const OSSL_DEMO_H3_STREAM *a, const OSSL_DEMO_H3_STREAM *b)
 {
-    if (a->id < b->id) return -1;
-    if (a->id > b->id) return 1;
+    if (a->id < b->id)
+        return -1;
+    if (a->id > b->id)
+        return 1;
     return 0;
 }
 
@@ -61,25 +63,25 @@ void *OSSL_DEMO_H3_STREAM_get_user_data(const OSSL_DEMO_H3_STREAM *s)
 
 struct ossl_demo_h3_conn_st {
     /* QUIC connection SSL object */
-    SSL                             *qconn;
+    SSL *qconn;
     /* BIO wrapping QCSO */
-    BIO                             *qconn_bio;
+    BIO *qconn_bio;
     /* HTTP/3 connection object */
-    nghttp3_conn                    *h3conn;
+    nghttp3_conn *h3conn;
     /* map of stream IDs to OSSL_DEMO_H3_STREAMs */
-    LHASH_OF(OSSL_DEMO_H3_STREAM)   *streams;
+    LHASH_OF(OSSL_DEMO_H3_STREAM) *streams;
     /* opaque user data pointer */
-    void                            *user_data;
+    void *user_data;
 
-    int                             pump_res;
-    size_t                          consumed_app_data;
+    int pump_res;
+    size_t consumed_app_data;
 
     /* Forwarding callbacks */
-    nghttp3_recv_data               recv_data_cb;
-    nghttp3_stream_close            stream_close_cb;
-    nghttp3_stop_sending            stop_sending_cb;
-    nghttp3_reset_stream            reset_stream_cb;
-    nghttp3_deferred_consume        deferred_consume_cb;
+    nghttp3_recv_data recv_data_cb;
+    nghttp3_stream_close stream_close_cb;
+    nghttp3_stop_sending stop_sending_cb;
+    nghttp3_reset_stream reset_stream_cb;
+    nghttp3_deferred_consume deferred_consume_cb;
 };
 
 void OSSL_DEMO_H3_CONN_free(OSSL_DEMO_H3_CONN *conn)
@@ -108,11 +110,11 @@ static OSSL_DEMO_H3_STREAM *h3_conn_create_stream(OSSL_DEMO_H3_CONN *conn, int t
 
     if ((s->s = SSL_new_stream(conn->qconn, flags)) == NULL) {
         ERR_raise_data(ERR_LIB_USER, ERR_R_INTERNAL_ERROR,
-                       "could not create QUIC stream object");
+            "could not create QUIC stream object");
         goto err;
     }
 
-    s->id   = SSL_get_stream_id(s->s);
+    s->id = SSL_get_stream_id(s->s);
     lh_OSSL_DEMO_H3_STREAM_insert(conn->streams, s);
     return s;
 
@@ -128,8 +130,8 @@ static OSSL_DEMO_H3_STREAM *h3_conn_accept_stream(OSSL_DEMO_H3_CONN *conn, SSL *
     if ((s = OPENSSL_zalloc(sizeof(OSSL_DEMO_H3_STREAM))) == NULL)
         return NULL;
 
-    s->id   = SSL_get_stream_id(qstream);
-    s->s    = qstream;
+    s->id = SSL_get_stream_id(qstream);
+    s->s = qstream;
     lh_OSSL_DEMO_H3_STREAM_insert(conn->streams, s);
     return s;
 }
@@ -144,8 +146,8 @@ static void h3_conn_remove_stream(OSSL_DEMO_H3_CONN *conn, OSSL_DEMO_H3_STREAM *
 }
 
 static int h3_conn_recv_data(nghttp3_conn *h3conn, int64_t stream_id,
-                             const uint8_t *data, size_t datalen,
-                             void *conn_user_data, void *stream_user_data)
+    const uint8_t *data, size_t datalen,
+    void *conn_user_data, void *stream_user_data)
 {
     OSSL_DEMO_H3_CONN *conn = conn_user_data;
 
@@ -154,12 +156,12 @@ static int h3_conn_recv_data(nghttp3_conn *h3conn, int64_t stream_id,
         return 0;
 
     return conn->recv_data_cb(h3conn, stream_id, data, datalen,
-                              conn_user_data, stream_user_data);
+        conn_user_data, stream_user_data);
 }
 
 static int h3_conn_stream_close(nghttp3_conn *h3conn, int64_t stream_id,
-                                uint64_t app_error_code,
-                                void *conn_user_data, void *stream_user_data)
+    uint64_t app_error_code,
+    void *conn_user_data, void *stream_user_data)
 {
     int ret = 0;
     OSSL_DEMO_H3_CONN *conn = conn_user_data;
@@ -167,15 +169,15 @@ static int h3_conn_stream_close(nghttp3_conn *h3conn, int64_t stream_id,
 
     if (conn->stream_close_cb != NULL)
         ret = conn->stream_close_cb(h3conn, stream_id, app_error_code,
-                                    conn_user_data, stream_user_data);
+            conn_user_data, stream_user_data);
 
     h3_conn_remove_stream(conn, stream);
     return ret;
 }
 
 static int h3_conn_stop_sending(nghttp3_conn *h3conn, int64_t stream_id,
-                                uint64_t app_error_code,
-                                void *conn_user_data, void *stream_user_data)
+    uint64_t app_error_code,
+    void *conn_user_data, void *stream_user_data)
 {
     int ret = 0;
     OSSL_DEMO_H3_CONN *conn = conn_user_data;
@@ -183,7 +185,7 @@ static int h3_conn_stop_sending(nghttp3_conn *h3conn, int64_t stream_id,
 
     if (conn->stop_sending_cb != NULL)
         ret = conn->stop_sending_cb(h3conn, stream_id, app_error_code,
-                                    conn_user_data, stream_user_data);
+            conn_user_data, stream_user_data);
 
     SSL_free(stream->s);
     stream->s = NULL;
@@ -191,17 +193,17 @@ static int h3_conn_stop_sending(nghttp3_conn *h3conn, int64_t stream_id,
 }
 
 static int h3_conn_reset_stream(nghttp3_conn *h3conn, int64_t stream_id,
-                                uint64_t app_error_code,
-                                void *conn_user_data, void *stream_user_data)
+    uint64_t app_error_code,
+    void *conn_user_data, void *stream_user_data)
 {
     int ret = 0;
     OSSL_DEMO_H3_CONN *conn = conn_user_data;
     OSSL_DEMO_H3_STREAM *stream = stream_user_data;
-    SSL_STREAM_RESET_ARGS args = {0};
+    SSL_STREAM_RESET_ARGS args = { 0 };
 
     if (conn->reset_stream_cb != NULL)
         ret = conn->reset_stream_cb(h3conn, stream_id, app_error_code,
-                                   conn_user_data, stream_user_data);
+            conn_user_data, stream_user_data);
 
     if (stream->s != NULL) {
         args.quic_error_code = app_error_code;
@@ -214,37 +216,37 @@ static int h3_conn_reset_stream(nghttp3_conn *h3conn, int64_t stream_id,
 }
 
 static int h3_conn_deferred_consume(nghttp3_conn *h3conn, int64_t stream_id,
-                                    size_t consumed,
-                                    void *conn_user_data, void *stream_user_data)
+    size_t consumed,
+    void *conn_user_data, void *stream_user_data)
 {
     int ret = 0;
     OSSL_DEMO_H3_CONN *conn = conn_user_data;
 
     if (conn->deferred_consume_cb != NULL)
         ret = conn->deferred_consume_cb(h3conn, stream_id, consumed,
-                                        conn_user_data, stream_user_data);
+            conn_user_data, stream_user_data);
 
     conn->consumed_app_data += consumed;
     return ret;
 }
 
 OSSL_DEMO_H3_CONN *OSSL_DEMO_H3_CONN_new_for_conn(BIO *qconn_bio,
-                                                  const nghttp3_callbacks *callbacks,
-                                                  const nghttp3_settings *settings,
-                                                  void *user_data)
+    const nghttp3_callbacks *callbacks,
+    const nghttp3_settings *settings,
+    void *user_data)
 {
     int ec;
     OSSL_DEMO_H3_CONN *conn;
     OSSL_DEMO_H3_STREAM *s_ctl_send = NULL;
     OSSL_DEMO_H3_STREAM *s_qpenc_send = NULL;
     OSSL_DEMO_H3_STREAM *s_qpdec_send = NULL;
-    nghttp3_settings dsettings = {0};
-    nghttp3_callbacks intl_callbacks = {0};
-    static const unsigned char alpn[] = {2, 'h', '3'};
+    nghttp3_settings dsettings = { 0 };
+    nghttp3_callbacks intl_callbacks = { 0 };
+    static const unsigned char alpn[] = { 2, 'h', '3' };
 
     if (qconn_bio == NULL) {
         ERR_raise_data(ERR_LIB_USER, ERR_R_PASSED_NULL_PARAMETER,
-                       "QUIC connection BIO must be provided");
+            "QUIC connection BIO must be provided");
         return NULL;
     }
 
@@ -256,7 +258,7 @@ OSSL_DEMO_H3_CONN *OSSL_DEMO_H3_CONN_new_for_conn(BIO *qconn_bio,
 
     if (BIO_get_ssl(qconn_bio, &conn->qconn) == 0) {
         ERR_raise_data(ERR_LIB_USER, ERR_R_PASSED_INVALID_ARGUMENT,
-                       "BIO must be an SSL BIO");
+            "BIO must be an SSL BIO");
         goto err;
     }
 
@@ -273,7 +275,7 @@ OSSL_DEMO_H3_CONN *OSSL_DEMO_H3_CONN_new_for_conn(BIO *qconn_bio,
         if (SSL_set_alpn_protos(conn->qconn, alpn, sizeof(alpn))) {
             /* SSL_set_alpn_protos returns 1 on failure */
             ERR_raise_data(ERR_LIB_USER, ERR_R_INTERNAL_ERROR,
-                           "failed to configure ALPN");
+                "failed to configure ALPN");
             goto err;
         }
 
@@ -292,7 +294,7 @@ OSSL_DEMO_H3_CONN *OSSL_DEMO_H3_CONN_new_for_conn(BIO *qconn_bio,
      */
     if (!SSL_set_default_stream_mode(conn->qconn, SSL_DEFAULT_STREAM_MODE_NONE)) {
         ERR_raise_data(ERR_LIB_USER, ERR_R_INTERNAL_ERROR,
-                       "failed to configure default stream mode");
+            "failed to configure default stream mode");
         goto err;
     }
 
@@ -305,15 +307,18 @@ OSSL_DEMO_H3_CONN *OSSL_DEMO_H3_CONN_new_for_conn(BIO *qconn_bio,
      * in the event handling code below).
      */
     if ((s_ctl_send
-            = h3_conn_create_stream(conn, OSSL_DEMO_H3_STREAM_TYPE_CTRL_SEND)) == NULL)
+            = h3_conn_create_stream(conn, OSSL_DEMO_H3_STREAM_TYPE_CTRL_SEND))
+        == NULL)
         goto err;
 
     if ((s_qpenc_send
-            = h3_conn_create_stream(conn, OSSL_DEMO_H3_STREAM_TYPE_QPACK_ENC_SEND)) == NULL)
+            = h3_conn_create_stream(conn, OSSL_DEMO_H3_STREAM_TYPE_QPACK_ENC_SEND))
+        == NULL)
         goto err;
 
     if ((s_qpdec_send
-            = h3_conn_create_stream(conn, OSSL_DEMO_H3_STREAM_TYPE_QPACK_DEC_SEND)) == NULL)
+            = h3_conn_create_stream(conn, OSSL_DEMO_H3_STREAM_TYPE_QPACK_DEC_SEND))
+        == NULL)
         goto err;
 
     if (settings == NULL) {
@@ -328,25 +333,25 @@ OSSL_DEMO_H3_CONN *OSSL_DEMO_H3_CONN_new_for_conn(BIO *qconn_bio,
      * We need to do some of our own processing when many of these events occur,
      * so we note the original callback functions and forward appropriately.
      */
-    conn->recv_data_cb          = intl_callbacks.recv_data;
-    conn->stream_close_cb       = intl_callbacks.stream_close;
-    conn->stop_sending_cb       = intl_callbacks.stop_sending;
-    conn->reset_stream_cb       = intl_callbacks.reset_stream;
-    conn->deferred_consume_cb   = intl_callbacks.deferred_consume;
+    conn->recv_data_cb = intl_callbacks.recv_data;
+    conn->stream_close_cb = intl_callbacks.stream_close;
+    conn->stop_sending_cb = intl_callbacks.stop_sending;
+    conn->reset_stream_cb = intl_callbacks.reset_stream;
+    conn->deferred_consume_cb = intl_callbacks.deferred_consume;
 
-    intl_callbacks.recv_data        = h3_conn_recv_data;
-    intl_callbacks.stream_close     = h3_conn_stream_close;
-    intl_callbacks.stop_sending     = h3_conn_stop_sending;
-    intl_callbacks.reset_stream     = h3_conn_reset_stream;
+    intl_callbacks.recv_data = h3_conn_recv_data;
+    intl_callbacks.stream_close = h3_conn_stream_close;
+    intl_callbacks.stop_sending = h3_conn_stop_sending;
+    intl_callbacks.reset_stream = h3_conn_reset_stream;
     intl_callbacks.deferred_consume = h3_conn_deferred_consume;
 
     /* Create the HTTP/3 client state. */
     ec = nghttp3_conn_client_new(&conn->h3conn, &intl_callbacks, settings,
-                                 NULL, conn);
+        NULL, conn);
     if (ec < 0) {
         ERR_raise_data(ERR_LIB_USER, ERR_R_INTERNAL_ERROR,
-                       "cannot create nghttp3 connection: %s (%d)",
-                       nghttp3_strerror(ec), ec);
+            "cannot create nghttp3 connection: %s (%d)",
+            nghttp3_strerror(ec), ec);
         goto err;
     }
 
@@ -361,18 +366,18 @@ OSSL_DEMO_H3_CONN *OSSL_DEMO_H3_CONN_new_for_conn(BIO *qconn_bio,
     ec = nghttp3_conn_bind_control_stream(conn->h3conn, s_ctl_send->id);
     if (ec < 0) {
         ERR_raise_data(ERR_LIB_USER, ERR_R_INTERNAL_ERROR,
-                       "cannot bind nghttp3 control stream: %s (%d)",
-                       nghttp3_strerror(ec), ec);
+            "cannot bind nghttp3 control stream: %s (%d)",
+            nghttp3_strerror(ec), ec);
         goto err;
     }
 
     ec = nghttp3_conn_bind_qpack_streams(conn->h3conn,
-                                         s_qpenc_send->id,
-                                         s_qpdec_send->id);
+        s_qpenc_send->id,
+        s_qpdec_send->id);
     if (ec < 0) {
         ERR_raise_data(ERR_LIB_USER, ERR_R_INTERNAL_ERROR,
-                       "cannot bind nghttp3 QPACK streams: %s (%d)",
-                       nghttp3_strerror(ec), ec);
+            "cannot bind nghttp3 QPACK streams: %s (%d)",
+            nghttp3_strerror(ec), ec);
         goto err;
     }
 
@@ -389,9 +394,9 @@ err:
 }
 
 OSSL_DEMO_H3_CONN *OSSL_DEMO_H3_CONN_new_for_addr(SSL_CTX *ctx, const char *addr,
-                                                  const nghttp3_callbacks *callbacks,
-                                                  const nghttp3_settings *settings,
-                                                  void *user_data)
+    const nghttp3_callbacks *callbacks,
+    const nghttp3_settings *settings,
+    void *user_data)
 {
     BIO *qconn_bio = NULL;
     SSL *qconn = NULL;
@@ -426,7 +431,7 @@ OSSL_DEMO_H3_CONN *OSSL_DEMO_H3_CONN_new_for_addr(SSL_CTX *ctx, const char *addr
         goto err;
 
     conn = OSSL_DEMO_H3_CONN_new_for_conn(qconn_bio, callbacks,
-                                          settings, user_data);
+        settings, user_data);
     if (conn == NULL)
         goto err;
 
@@ -492,17 +497,17 @@ static void h3_conn_pump_stream(OSSL_DEMO_H3_STREAM *s, void *conn_)
                 if (SSL_get_error(s->s, ec) == SSL_ERROR_ZERO_RETURN) {
                     /* Stream concluded normally. Pass FIN to HTTP/3 stack. */
                     ec = nghttp3_conn_read_stream(conn->h3conn, s->id, NULL, 0,
-                                                  /*fin=*/1);
+                        /*fin=*/1);
                     if (ec < 0) {
                         ERR_raise_data(ERR_LIB_USER, ERR_R_INTERNAL_ERROR,
-                                       "cannot pass FIN to nghttp3: %s (%d)",
-                                       nghttp3_strerror(ec), ec);
+                            "cannot pass FIN to nghttp3: %s (%d)",
+                            nghttp3_strerror(ec), ec);
                         goto err;
                     }
 
                     s->done_recv_fin = 1;
                 } else if (SSL_get_stream_read_state(s->s)
-                            == SSL_STREAM_STATE_RESET_REMOTE) {
+                    == SSL_STREAM_STATE_RESET_REMOTE) {
                     /* Stream was reset by peer. */
                     if (!SSL_get_stream_read_error_code(s->s, &aec))
                         goto err;
@@ -510,8 +515,8 @@ static void h3_conn_pump_stream(OSSL_DEMO_H3_STREAM *s, void *conn_)
                     ec = nghttp3_conn_close_stream(conn->h3conn, s->id, aec);
                     if (ec < 0) {
                         ERR_raise_data(ERR_LIB_USER, ERR_R_INTERNAL_ERROR,
-                                       "cannot mark stream as reset: %s (%d)",
-                                       nghttp3_strerror(ec), ec);
+                            "cannot mark stream as reset: %s (%d)",
+                            nghttp3_strerror(ec), ec);
                         goto err;
                     }
 
@@ -522,8 +527,8 @@ static void h3_conn_pump_stream(OSSL_DEMO_H3_STREAM *s, void *conn_)
                 }
             }
 
-            s->buf_cur      = 0;
-            s->buf_total    = num_bytes;
+            s->buf_cur = 0;
+            s->buf_total = num_bytes;
         }
 
         if (s->buf_cur == s->buf_total)
@@ -536,11 +541,11 @@ static void h3_conn_pump_stream(OSSL_DEMO_H3_STREAM *s, void *conn_)
          */
         assert(conn->consumed_app_data == 0);
         ec = nghttp3_conn_read_stream(conn->h3conn, s->id, s->buf + s->buf_cur,
-                                      s->buf_total - s->buf_cur, /*fin=*/0);
+            s->buf_total - s->buf_cur, /*fin=*/0);
         if (ec < 0) {
             ERR_raise_data(ERR_LIB_USER, ERR_R_INTERNAL_ERROR,
-                           "nghttp3 failed to process incoming data: %s (%d)",
-                           nghttp3_strerror(ec), ec);
+                "nghttp3 failed to process incoming data: %s (%d)",
+                nghttp3_strerror(ec), ec);
             goto err;
         }
 
@@ -568,7 +573,7 @@ int OSSL_DEMO_H3_CONN_handle_events(OSSL_DEMO_H3_CONN *conn)
     size_t i, num_vecs, written, total_written, total_len;
     int64_t stream_id;
     uint64_t flags;
-    nghttp3_vec vecs[8] = {0};
+    nghttp3_vec vecs[8] = { 0 };
     OSSL_DEMO_H3_STREAM key, *s;
     SSL *snew;
 
@@ -608,15 +613,15 @@ int OSSL_DEMO_H3_CONN_handle_events(OSSL_DEMO_H3_CONN *conn)
          * wants to *write* to the network.
          */
         ec = nghttp3_conn_writev_stream(conn->h3conn, &stream_id, &fin,
-                                        vecs, ARRAY_LEN(vecs));
+            vecs, ARRAY_LEN(vecs));
         if (ec < 0)
             return 0;
         if (ec == 0)
             break;
 
         /*
-	 * we let SSL_write_ex2(3) to conclude the stream for us (send FIN)
-	 * after all data are written.
+         * we let SSL_write_ex2(3) to conclude the stream for us (send FIN)
+         * after all data are written.
          */
         flags = (fin == 0) ? 0 : SSL_WRITE_FLAG_CONCLUDE;
 
@@ -624,7 +629,7 @@ int OSSL_DEMO_H3_CONN_handle_events(OSSL_DEMO_H3_CONN *conn)
         key.id = stream_id;
         if ((s = lh_OSSL_DEMO_H3_STREAM_retrieve(conn->streams, &key)) == NULL) {
             ERR_raise_data(ERR_LIB_USER, ERR_R_INTERNAL_ERROR,
-                           "no stream for ID %zd", stream_id);
+                "no stream for ID %zd", stream_id);
             return 0;
         }
 
@@ -648,7 +653,7 @@ int OSSL_DEMO_H3_CONN_handle_events(OSSL_DEMO_H3_CONN *conn)
                     nghttp3_conn_block_stream(conn->h3conn, stream_id);
                 } else {
                     ERR_raise_data(ERR_LIB_USER, ERR_R_INTERNAL_ERROR,
-                                   "writing HTTP/3 data to network failed");
+                        "writing HTTP/3 data to network failed");
                     return 0;
                 }
             } else {
@@ -707,16 +712,16 @@ int OSSL_DEMO_H3_CONN_handle_events(OSSL_DEMO_H3_CONN *conn)
 }
 
 int OSSL_DEMO_H3_CONN_submit_request(OSSL_DEMO_H3_CONN *conn,
-                                     const nghttp3_nv *nva, size_t nvlen,
-                                     const nghttp3_data_reader *dr,
-                                     void *user_data)
+    const nghttp3_nv *nva, size_t nvlen,
+    const nghttp3_data_reader *dr,
+    void *user_data)
 {
     int ec;
     OSSL_DEMO_H3_STREAM *s_req = NULL;
 
     if (conn == NULL) {
         ERR_raise_data(ERR_LIB_USER, ERR_R_PASSED_NULL_PARAMETER,
-                       "connection must be specified");
+            "connection must be specified");
         return 0;
     }
 
@@ -727,11 +732,11 @@ int OSSL_DEMO_H3_CONN_submit_request(OSSL_DEMO_H3_CONN *conn,
     s_req->user_data = user_data;
 
     ec = nghttp3_conn_submit_request(conn->h3conn, s_req->id, nva, nvlen,
-                                     dr, s_req);
+        dr, s_req);
     if (ec < 0) {
         ERR_raise_data(ERR_LIB_USER, ERR_R_INTERNAL_ERROR,
-                       "cannot submit HTTP/3 request: %s (%d)",
-                       nghttp3_strerror(ec), ec);
+            "cannot submit HTTP/3 request: %s (%d)",
+            nghttp3_strerror(ec), ec);
         goto err;
     }
 
