@@ -24,18 +24,14 @@
  * the soliloquy from Hamlet scene 1 act 3
  */
 
-static const char *hamlet_1 =
-    "To be, or not to be, that is the question,\n"
-    "Whether tis nobler in the minde to suffer\n"
-    "The slings and arrowes of outragious fortune,\n"
-    "Or to take Armes again in a sea of troubles,\n"
-;
-static const char *hamlet_2 =
-    "And by opposing, end them, to die to sleep;\n"
-    "No more, and by a sleep, to say we end\n"
-    "The heart-ache, and the thousand natural shocks\n"
-    "That flesh is heir to? tis a consumation\n"
-;
+static const char *hamlet_1 = "To be, or not to be, that is the question,\n"
+                              "Whether tis nobler in the minde to suffer\n"
+                              "The slings and arrowes of outragious fortune,\n"
+                              "Or to take Armes again in a sea of troubles,\n";
+static const char *hamlet_2 = "And by opposing, end them, to die to sleep;\n"
+                              "No more, and by a sleep, to say we end\n"
+                              "The heart-ache, and the thousand natural shocks\n"
+                              "That flesh is heir to? tis a consumation\n";
 
 /*
  * For demo_sign, load EC private key priv_key from priv_key_der[].
@@ -44,22 +40,22 @@ static const char *hamlet_2 =
 static EVP_PKEY *get_key(OSSL_LIB_CTX *libctx, const char *propq, int public)
 {
     OSSL_DECODER_CTX *dctx = NULL;
-    EVP_PKEY  *pkey = NULL;
+    EVP_PKEY *pkey = NULL;
     int selection;
     const unsigned char *data;
     size_t data_len;
 
     if (public) {
         selection = EVP_PKEY_PUBLIC_KEY;
-        data =  pub_key_der;
+        data = pub_key_der;
         data_len = sizeof(pub_key_der);
     } else {
-        selection =  EVP_PKEY_KEYPAIR;
+        selection = EVP_PKEY_KEYPAIR;
         data = priv_key_der;
         data_len = sizeof(priv_key_der);
     }
     dctx = OSSL_DECODER_CTX_new_for_pkey(&pkey, "DER", NULL, "EC",
-                                         selection, libctx, propq);
+        selection, libctx, propq);
     (void)OSSL_DECODER_from_data(dctx, &data, &data_len);
     OSSL_DECODER_CTX_free(dctx);
     if (pkey == NULL)
@@ -67,8 +63,8 @@ static EVP_PKEY *get_key(OSSL_LIB_CTX *libctx, const char *propq, int public)
     return pkey;
 }
 
-static int demo_sign(OSSL_LIB_CTX *libctx,  const char *sig_name,
-                     size_t *sig_out_len, unsigned char **sig_out_value)
+static int demo_sign(OSSL_LIB_CTX *libctx, const char *sig_name,
+    size_t *sig_out_len, unsigned char **sig_out_value)
 {
     int ret = 0, public = 0;
     size_t sig_len;
@@ -97,7 +93,7 @@ static int demo_sign(OSSL_LIB_CTX *libctx,  const char *sig_name,
      * sign provider.
      */
     if (!EVP_DigestSignInit_ex(sign_context, NULL, sig_name,
-                              libctx, NULL, priv_key, NULL)) {
+            libctx, NULL, priv_key, NULL)) {
         fprintf(stderr, "EVP_DigestSignInit_ex failed.\n");
         goto cleanup;
     }
@@ -148,7 +144,7 @@ cleanup:
 }
 
 static int demo_verify(OSSL_LIB_CTX *libctx, const char *sig_name,
-                       size_t sig_len, unsigned char *sig_value)
+    size_t sig_len, unsigned char *sig_value)
 {
     int ret = 0, public = 1;
     const char *propq = NULL;
@@ -172,7 +168,7 @@ static int demo_verify(OSSL_LIB_CTX *libctx, const char *sig_name,
     }
     /* Verify */
     if (!EVP_DigestVerifyInit_ex(verify_context, NULL, sig_name,
-                                libctx, NULL, pub_key, NULL)) {
+            libctx, NULL, pub_key, NULL)) {
         fprintf(stderr, "EVP_DigestVerifyInit failed.\n");
         goto cleanup;
     }
