@@ -8,14 +8,18 @@
  */
 
 #include <stdio.h>
-#include <unistd.h>
 #include <string.h>
+#include <signal.h>
+#include <openssl/ssl.h>
+#include <openssl/err.h>
+#if !defined(OPENSSL_SYS_WINDOWS)
+#include <unistd.h>
 #include <sys/socket.h>
 #include <arpa/inet.h>
 #include <netinet/in.h>
-#include <openssl/ssl.h>
-#include <openssl/err.h>
-#include <signal.h>
+#else
+#include <winsock.h>
+#endif
 
 static const int server_port = 4433;
 
@@ -29,7 +33,7 @@ typedef unsigned char flag;
  */
 static volatile flag server_running = true;
 
-int create_socket(flag isServer)
+static int create_socket(flag isServer)
 {
     int s;
     int optval = 1;
@@ -67,7 +71,7 @@ int create_socket(flag isServer)
     return s;
 }
 
-SSL_CTX *create_context(flag isServer)
+static SSL_CTX *create_context(flag isServer)
 {
     const SSL_METHOD *method;
     SSL_CTX *ctx;
@@ -87,7 +91,7 @@ SSL_CTX *create_context(flag isServer)
     return ctx;
 }
 
-void configure_server_context(SSL_CTX *ctx)
+static void configure_server_context(SSL_CTX *ctx)
 {
     /* Set the key and cert */
     if (SSL_CTX_use_certificate_chain_file(ctx, "cert.pem") <= 0) {
@@ -101,7 +105,7 @@ void configure_server_context(SSL_CTX *ctx)
     }
 }
 
-void configure_client_context(SSL_CTX *ctx)
+static void configure_client_context(SSL_CTX *ctx)
 {
     /*
      * Configure the client to abort the handshake if certificate verification
@@ -119,7 +123,7 @@ void configure_client_context(SSL_CTX *ctx)
     }
 }
 
-void usage(void)
+static void usage(void)
 {
     printf("Usage: sslecho s\n");
     printf("       --or--\n");
@@ -128,6 +132,7 @@ void usage(void)
     exit(EXIT_FAILURE);
 }
 
+#define BUFFERSIZE 1024
 int main(int argc, char **argv)
 {
     flag isServer;
@@ -139,10 +144,9 @@ int main(int argc, char **argv)
     int server_skt = -1;
     int client_skt = -1;
 
-    /* used by getline relying on realloc, can't be statically allocated */
-    char *txbuf = NULL;
-    size_t txcap = 0;
-    int txlen;
+    /* used by fgets */
+    char buffer[BUFFERSIZE];
+    char *txbuf;
 
     char rxbuf[128];
     size_t rxcap = sizeof(rxbuf);
@@ -151,10 +155,16 @@ int main(int argc, char **argv)
     char *rem_server_ip = NULL;
 
     struct sockaddr_in addr;
+#if defined(OPENSSL_SYS_CYGWIN) || defined(OPENSSL_SYS_WINDOWS)
+    int addr_len = sizeof(addr);
+#else
     unsigned int addr_len = sizeof(addr);
+#endif
 
+#if !defined(OPENSSL_SYS_WINDOWS)
     /* ignore SIGPIPE so that server can continue running when client pipe closes abruptly */
     signal(SIGPIPE, SIG_IGN);
+#endif
 
     /* Splash */
     printf("\nsslecho : Simple Echo Client/Server : %s : %s\n\n", __DATE__,
@@ -207,7 +217,10 @@ int main(int argc, char **argv)
 
             /* Create server SSL structure using newly accepted client socket */
             ssl = SSL_new(ssl_ctx);
-            SSL_set_fd(ssl, client_skt);
+            if (!SSL_set_fd(ssl, client_skt)) {
+                ERR_print_errors_fp(stderr);
+                exit(EXIT_FAILURE);
+            }
 
             /* Wait for SSL connection from the client */
             if (SSL_accept(ssl) <= 0) {
@@ -284,11 +297,17 @@ int main(int argc, char **argv)
 
         /* Create client SSL structure using dedicated client socket */
         ssl = SSL_new(ssl_ctx);
-        SSL_set_fd(ssl, client_skt);
+        if (!SSL_set_fd(ssl, client_skt)) {
+            ERR_print_errors_fp(stderr);
+            goto exit;
+        }
         /* Set hostname for SNI */
         SSL_set_tlsext_host_name(ssl, rem_server_ip);
         /* Configure server hostname check */
-        SSL_set1_host(ssl, rem_server_ip);
+        if (!SSL_set1_host(ssl, rem_server_ip)) {
+            ERR_print_errors_fp(stderr);
+            goto exit;
+        }
 
         /* Now do SSL connect with server */
         if (SSL_connect(ssl) == 1) {
@@ -298,9 +317,11 @@ int main(int argc, char **argv)
             /* Loop to send input from keyboard */
             while (true) {
                 /* Get a line of input */
-                txlen = getline(&txbuf, &txcap, stdin);
+                memset(buffer, 0, BUFFERSIZE);
+                txbuf = fgets(buffer, BUFFERSIZE, stdin);
+
                 /* Exit loop on error */
-                if (txlen < 0 || txbuf == NULL) {
+                if (txbuf == NULL) {
                     break;
                 }
                 /* Exit loop if just a carriage return */
@@ -308,7 +329,7 @@ int main(int argc, char **argv)
                     break;
                 }
                 /* Send it to the server */
-                if ((result = SSL_write(ssl, txbuf, txlen)) <= 0) {
+                if ((result = SSL_write(ssl, txbuf, strlen(txbuf))) <= 0) {
                     printf("Server closed connection\n");
                     ERR_print_errors_fp(stderr);
                     break;
@@ -347,9 +368,6 @@ exit:
     if (server_skt != -1)
         close(server_skt);
 
-    if (txbuf != NULL && txcap > 0)
-        free(txbuf);
-
     printf("sslecho exiting\n");
 
     return EXIT_SUCCESS;
