@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2021 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2015-2024 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -13,14 +13,14 @@
 /*
  * SHA-1 low level APIs are deprecated for public use, but still ok for
  * internal use.  Note, that due to symbols not being exported, only the
- * #defines and strucures can be accessed, in this case SHA_CBLOCK and
+ * #defines and structures can be accessed, in this case SHA_CBLOCK and
  * sizeof(SHA_CTX).
  */
 #include "internal/deprecated.h"
 
 #include <openssl/opensslconf.h>
 #if defined(_WIN32)
-# include <windows.h>
+#include <windows.h>
 #endif
 
 #include <stdio.h>
@@ -38,38 +38,38 @@
 #include <openssl/modes.h>
 
 #if defined(OPENSSL_SYS_UNIX) && defined(OPENSSL_THREADS)
-# undef ASYNC_POSIX
-# define ASYNC_POSIX
-# include <unistd.h>
+#undef ASYNC_POSIX
+#define ASYNC_POSIX
+#include <unistd.h>
 #elif defined(_WIN32)
-# undef ASYNC_WIN
-# define ASYNC_WIN
+#undef ASYNC_WIN
+#define ASYNC_WIN
 #endif
 
+/* clang-format off */
 #include "e_dasync_err.c"
+/* clang-format on */
 
 /* Engine Id and Name */
 static const char *engine_dasync_id = "dasync";
 static const char *engine_dasync_name = "Dummy Async engine support";
 
-
 /* Engine Lifetime functions */
 static int dasync_destroy(ENGINE *e);
 static int dasync_init(ENGINE *e);
 static int dasync_finish(ENGINE *e);
 void engine_load_dasync_int(void);
 
-
 /* Set up digests. Just SHA1 for now */
 static int dasync_digests(ENGINE *e, const EVP_MD **digest,
-                          const int **nids, int nid);
+    const int **nids, int nid);
 
 static void dummy_pause_job(void);
 
 /* SHA1 */
 static int dasync_sha1_init(EVP_MD_CTX *ctx);
 static int dasync_sha1_update(EVP_MD_CTX *ctx, const void *data,
-                             size_t count);
+    size_t count);
 static int dasync_sha1_final(EVP_MD_CTX *ctx, unsigned char *md);
 
 /*
@@ -106,7 +106,7 @@ static int dasync_digest_nids(const int **nids)
 
 /* RSA */
 static int dasync_pkey(ENGINE *e, EVP_PKEY_METHOD **pmeth,
-                       const int **pnids, int nid);
+    const int **pnids, int nid);
 
 static int dasync_rsa_init(EVP_PKEY_CTX *ctx);
 static void dasync_rsa_cleanup(EVP_PKEY_CTX *ctx);
@@ -116,15 +116,15 @@ static int dasync_rsa_keygen_init(EVP_PKEY_CTX *ctx);
 static int dasync_rsa_keygen(EVP_PKEY_CTX *ctx, EVP_PKEY *pkey);
 static int dasync_rsa_encrypt_init(EVP_PKEY_CTX *ctx);
 static int dasync_rsa_encrypt(EVP_PKEY_CTX *ctx, unsigned char *out,
-                              size_t *outlen, const unsigned char *in,
-                              size_t inlen);
+    size_t *outlen, const unsigned char *in,
+    size_t inlen);
 static int dasync_rsa_decrypt_init(EVP_PKEY_CTX *ctx);
 static int dasync_rsa_decrypt(EVP_PKEY_CTX *ctx, unsigned char *out,
-                              size_t *outlen, const unsigned char *in,
-                              size_t inlen);
+    size_t *outlen, const unsigned char *in,
+    size_t inlen);
 static int dasync_rsa_ctrl(EVP_PKEY_CTX *ctx, int type, int p1, void *p2);
 static int dasync_rsa_ctrl_str(EVP_PKEY_CTX *ctx, const char *type,
-                               const char *value);
+    const char *value);
 
 static EVP_PKEY_METHOD *dasync_rsa;
 static const EVP_PKEY_METHOD *dasync_rsa_orig;
@@ -132,31 +132,31 @@ static const EVP_PKEY_METHOD *dasync_rsa_orig;
 /* AES */
 
 static int dasync_aes128_cbc_ctrl(EVP_CIPHER_CTX *ctx, int type, int arg,
-                                  void *ptr);
+    void *ptr);
 static int dasync_aes128_init_key(EVP_CIPHER_CTX *ctx, const unsigned char *key,
-                                  const unsigned char *iv, int enc);
+    const unsigned char *iv, int enc);
 static int dasync_aes128_cbc_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
-                                    const unsigned char *in, size_t inl);
+    const unsigned char *in, size_t inl);
 static int dasync_aes128_cbc_cleanup(EVP_CIPHER_CTX *ctx);
 
 static int dasync_aes256_ctr_ctrl(EVP_CIPHER_CTX *ctx, int type, int arg,
-                                  void *ptr);
+    void *ptr);
 static int dasync_aes256_init_key(EVP_CIPHER_CTX *ctx, const unsigned char *key,
-                                  const unsigned char *iv, int enc);
+    const unsigned char *iv, int enc);
 static int dasync_aes256_ctr_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
-                                    const unsigned char *in, size_t inl);
+    const unsigned char *in, size_t inl);
 static int dasync_aes256_ctr_cleanup(EVP_CIPHER_CTX *ctx);
 
 static int dasync_aes128_cbc_hmac_sha1_ctrl(EVP_CIPHER_CTX *ctx, int type,
-                                             int arg, void *ptr);
+    int arg, void *ptr);
 static int dasync_aes128_cbc_hmac_sha1_init_key(EVP_CIPHER_CTX *ctx,
-                                                 const unsigned char *key,
-                                                 const unsigned char *iv,
-                                                 int enc);
+    const unsigned char *key,
+    const unsigned char *iv,
+    int enc);
 static int dasync_aes128_cbc_hmac_sha1_cipher(EVP_CIPHER_CTX *ctx,
-                                               unsigned char *out,
-                                               const unsigned char *in,
-                                               size_t inl);
+    unsigned char *out,
+    const unsigned char *in,
+    size_t inl);
 static int dasync_aes128_cbc_hmac_sha1_cleanup(EVP_CIPHER_CTX *ctx);
 
 struct dasync_pipeline_ctx {
@@ -214,7 +214,7 @@ static void destroy_ciphers(void)
 }
 
 static int dasync_ciphers(ENGINE *e, const EVP_CIPHER **cipher,
-                                   const int **nids, int nid);
+    const int **nids, int nid);
 
 static int dasync_cipher_nids[] = {
     NID_aes_128_cbc,
@@ -226,23 +226,23 @@ static int dasync_cipher_nids[] = {
 static int bind_dasync(ENGINE *e)
 {
     /* Setup RSA */
-    ;
     if ((dasync_rsa_orig = EVP_PKEY_meth_find(EVP_PKEY_RSA)) == NULL
         || (dasync_rsa = EVP_PKEY_meth_new(EVP_PKEY_RSA,
-                                           EVP_PKEY_FLAG_AUTOARGLEN)) == NULL)
+                EVP_PKEY_FLAG_AUTOARGLEN))
+            == NULL)
         return 0;
     EVP_PKEY_meth_set_init(dasync_rsa, dasync_rsa_init);
     EVP_PKEY_meth_set_cleanup(dasync_rsa, dasync_rsa_cleanup);
     EVP_PKEY_meth_set_paramgen(dasync_rsa, dasync_rsa_paramgen_init,
-                               dasync_rsa_paramgen);
+        dasync_rsa_paramgen);
     EVP_PKEY_meth_set_keygen(dasync_rsa, dasync_rsa_keygen_init,
-                             dasync_rsa_keygen);
+        dasync_rsa_keygen);
     EVP_PKEY_meth_set_encrypt(dasync_rsa, dasync_rsa_encrypt_init,
-                              dasync_rsa_encrypt);
+        dasync_rsa_encrypt);
     EVP_PKEY_meth_set_decrypt(dasync_rsa, dasync_rsa_decrypt_init,
-                              dasync_rsa_decrypt);
+        dasync_rsa_decrypt);
     EVP_PKEY_meth_set_ctrl(dasync_rsa, dasync_rsa_ctrl,
-                           dasync_rsa_ctrl_str);
+        dasync_rsa_ctrl_str);
 
     /* Ensure the dasync error handling is set up */
     ERR_load_DASYNC_strings();
@@ -268,7 +268,7 @@ static int bind_dasync(ENGINE *e)
         || !EVP_MD_meth_set_result_size(_hidden_sha1_md, SHA_DIGEST_LENGTH)
         || !EVP_MD_meth_set_input_blocksize(_hidden_sha1_md, SHA_CBLOCK)
         || !EVP_MD_meth_set_app_datasize(_hidden_sha1_md,
-                                         sizeof(EVP_MD *) + sizeof(SHA_CTX))
+            sizeof(EVP_MD *) + sizeof(SHA_CTX))
         || !EVP_MD_meth_set_flags(_hidden_sha1_md, EVP_MD_FLAG_DIGALGID_ABSENT)
         || !EVP_MD_meth_set_init(_hidden_sha1_md, dasync_sha1_init)
         || !EVP_MD_meth_set_update(_hidden_sha1_md, dasync_sha1_update)
@@ -278,75 +278,75 @@ static int bind_dasync(ENGINE *e)
     }
 
     _hidden_aes_128_cbc = EVP_CIPHER_meth_new(NID_aes_128_cbc,
-                                              16 /* block size */,
-                                              16 /* key len */);
+        16 /* block size */,
+        16 /* key len */);
     if (_hidden_aes_128_cbc == NULL
-            || !EVP_CIPHER_meth_set_iv_length(_hidden_aes_128_cbc,16)
-            || !EVP_CIPHER_meth_set_flags(_hidden_aes_128_cbc,
-                                          EVP_CIPH_FLAG_DEFAULT_ASN1
-                                          | EVP_CIPH_CBC_MODE
-                                          | EVP_CIPH_FLAG_PIPELINE
-                                          | EVP_CIPH_CUSTOM_COPY)
-            || !EVP_CIPHER_meth_set_init(_hidden_aes_128_cbc,
-                                         dasync_aes128_init_key)
-            || !EVP_CIPHER_meth_set_do_cipher(_hidden_aes_128_cbc,
-                                              dasync_aes128_cbc_cipher)
-            || !EVP_CIPHER_meth_set_cleanup(_hidden_aes_128_cbc,
-                                            dasync_aes128_cbc_cleanup)
-            || !EVP_CIPHER_meth_set_ctrl(_hidden_aes_128_cbc,
-                                         dasync_aes128_cbc_ctrl)
-            || !EVP_CIPHER_meth_set_impl_ctx_size(_hidden_aes_128_cbc,
-                                sizeof(struct dasync_pipeline_ctx))) {
+        || !EVP_CIPHER_meth_set_iv_length(_hidden_aes_128_cbc, 16)
+        || !EVP_CIPHER_meth_set_flags(_hidden_aes_128_cbc,
+            EVP_CIPH_FLAG_DEFAULT_ASN1
+                | EVP_CIPH_CBC_MODE
+                | EVP_CIPH_FLAG_PIPELINE
+                | EVP_CIPH_CUSTOM_COPY)
+        || !EVP_CIPHER_meth_set_init(_hidden_aes_128_cbc,
+            dasync_aes128_init_key)
+        || !EVP_CIPHER_meth_set_do_cipher(_hidden_aes_128_cbc,
+            dasync_aes128_cbc_cipher)
+        || !EVP_CIPHER_meth_set_cleanup(_hidden_aes_128_cbc,
+            dasync_aes128_cbc_cleanup)
+        || !EVP_CIPHER_meth_set_ctrl(_hidden_aes_128_cbc,
+            dasync_aes128_cbc_ctrl)
+        || !EVP_CIPHER_meth_set_impl_ctx_size(_hidden_aes_128_cbc,
+            sizeof(struct dasync_pipeline_ctx))) {
         EVP_CIPHER_meth_free(_hidden_aes_128_cbc);
         _hidden_aes_128_cbc = NULL;
     }
 
     _hidden_aes_256_ctr = EVP_CIPHER_meth_new(NID_aes_256_ctr,
-                                              1  /* block size */,
-                                              32 /* key len */);
+        1 /* block size */,
+        32 /* key len */);
     if (_hidden_aes_256_ctr == NULL
-            || !EVP_CIPHER_meth_set_iv_length(_hidden_aes_256_ctr,16)
-            || !EVP_CIPHER_meth_set_flags(_hidden_aes_256_ctr,
-                                          EVP_CIPH_FLAG_DEFAULT_ASN1
-                                          | EVP_CIPH_CTR_MODE
-                                          | EVP_CIPH_FLAG_PIPELINE
-                                          | EVP_CIPH_CUSTOM_COPY)
-            || !EVP_CIPHER_meth_set_init(_hidden_aes_256_ctr,
-                                         dasync_aes256_init_key)
-            || !EVP_CIPHER_meth_set_do_cipher(_hidden_aes_256_ctr,
-                                              dasync_aes256_ctr_cipher)
-            || !EVP_CIPHER_meth_set_cleanup(_hidden_aes_256_ctr,
-                                            dasync_aes256_ctr_cleanup)
-            || !EVP_CIPHER_meth_set_ctrl(_hidden_aes_256_ctr,
-                                         dasync_aes256_ctr_ctrl)
-            || !EVP_CIPHER_meth_set_impl_ctx_size(_hidden_aes_256_ctr,
-                                sizeof(struct dasync_pipeline_ctx))) {
+        || !EVP_CIPHER_meth_set_iv_length(_hidden_aes_256_ctr, 16)
+        || !EVP_CIPHER_meth_set_flags(_hidden_aes_256_ctr,
+            EVP_CIPH_FLAG_DEFAULT_ASN1
+                | EVP_CIPH_CTR_MODE
+                | EVP_CIPH_FLAG_PIPELINE
+                | EVP_CIPH_CUSTOM_COPY)
+        || !EVP_CIPHER_meth_set_init(_hidden_aes_256_ctr,
+            dasync_aes256_init_key)
+        || !EVP_CIPHER_meth_set_do_cipher(_hidden_aes_256_ctr,
+            dasync_aes256_ctr_cipher)
+        || !EVP_CIPHER_meth_set_cleanup(_hidden_aes_256_ctr,
+            dasync_aes256_ctr_cleanup)
+        || !EVP_CIPHER_meth_set_ctrl(_hidden_aes_256_ctr,
+            dasync_aes256_ctr_ctrl)
+        || !EVP_CIPHER_meth_set_impl_ctx_size(_hidden_aes_256_ctr,
+            sizeof(struct dasync_pipeline_ctx))) {
         EVP_CIPHER_meth_free(_hidden_aes_256_ctr);
         _hidden_aes_256_ctr = NULL;
     }
 
     _hidden_aes_128_cbc_hmac_sha1 = EVP_CIPHER_meth_new(
-                                                NID_aes_128_cbc_hmac_sha1,
-                                                16 /* block size */,
-                                                16 /* key len */);
+        NID_aes_128_cbc_hmac_sha1,
+        16 /* block size */,
+        16 /* key len */);
     if (_hidden_aes_128_cbc_hmac_sha1 == NULL
-            || !EVP_CIPHER_meth_set_iv_length(_hidden_aes_128_cbc_hmac_sha1,16)
-            || !EVP_CIPHER_meth_set_flags(_hidden_aes_128_cbc_hmac_sha1,
-                                            EVP_CIPH_CBC_MODE
-                                          | EVP_CIPH_FLAG_DEFAULT_ASN1
-                                          | EVP_CIPH_FLAG_AEAD_CIPHER
-                                          | EVP_CIPH_FLAG_PIPELINE
-                                          | EVP_CIPH_CUSTOM_COPY)
-            || !EVP_CIPHER_meth_set_init(_hidden_aes_128_cbc_hmac_sha1,
-                                         dasync_aes128_cbc_hmac_sha1_init_key)
-            || !EVP_CIPHER_meth_set_do_cipher(_hidden_aes_128_cbc_hmac_sha1,
-                                            dasync_aes128_cbc_hmac_sha1_cipher)
-            || !EVP_CIPHER_meth_set_cleanup(_hidden_aes_128_cbc_hmac_sha1,
-                                            dasync_aes128_cbc_hmac_sha1_cleanup)
-            || !EVP_CIPHER_meth_set_ctrl(_hidden_aes_128_cbc_hmac_sha1,
-                                         dasync_aes128_cbc_hmac_sha1_ctrl)
-            || !EVP_CIPHER_meth_set_impl_ctx_size(_hidden_aes_128_cbc_hmac_sha1,
-                                sizeof(struct dasync_pipeline_ctx))) {
+        || !EVP_CIPHER_meth_set_iv_length(_hidden_aes_128_cbc_hmac_sha1, 16)
+        || !EVP_CIPHER_meth_set_flags(_hidden_aes_128_cbc_hmac_sha1,
+            EVP_CIPH_CBC_MODE
+                | EVP_CIPH_FLAG_DEFAULT_ASN1
+                | EVP_CIPH_FLAG_AEAD_CIPHER
+                | EVP_CIPH_FLAG_PIPELINE
+                | EVP_CIPH_CUSTOM_COPY)
+        || !EVP_CIPHER_meth_set_init(_hidden_aes_128_cbc_hmac_sha1,
+            dasync_aes128_cbc_hmac_sha1_init_key)
+        || !EVP_CIPHER_meth_set_do_cipher(_hidden_aes_128_cbc_hmac_sha1,
+            dasync_aes128_cbc_hmac_sha1_cipher)
+        || !EVP_CIPHER_meth_set_cleanup(_hidden_aes_128_cbc_hmac_sha1,
+            dasync_aes128_cbc_hmac_sha1_cleanup)
+        || !EVP_CIPHER_meth_set_ctrl(_hidden_aes_128_cbc_hmac_sha1,
+            dasync_aes128_cbc_hmac_sha1_ctrl)
+        || !EVP_CIPHER_meth_set_impl_ctx_size(_hidden_aes_128_cbc_hmac_sha1,
+            sizeof(struct dasync_pipeline_ctx))) {
         EVP_CIPHER_meth_free(_hidden_aes_128_cbc_hmac_sha1);
         _hidden_aes_128_cbc_hmac_sha1 = NULL;
     }
@@ -364,7 +364,7 @@ static void destroy_pkey(void)
     dasync_rsa = NULL;
 }
 
-# ifndef OPENSSL_NO_DYNAMIC_ENGINE
+#ifndef OPENSSL_NO_DYNAMIC_ENGINE
 static int bind_helper(ENGINE *e, const char *id)
 {
     if (id && (strcmp(id, engine_dasync_id) != 0))
@@ -375,8 +375,8 @@ static int bind_helper(ENGINE *e, const char *id)
 }
 
 IMPLEMENT_DYNAMIC_CHECK_FN()
-    IMPLEMENT_DYNAMIC_BIND_FN(bind_helper)
-# endif
+IMPLEMENT_DYNAMIC_BIND_FN(bind_helper)
+#endif
 
 static ENGINE *engine_dasync(void)
 {
@@ -415,13 +415,11 @@ static int dasync_init(ENGINE *e)
     return 1;
 }
 
-
 static int dasync_finish(ENGINE *e)
 {
     return 1;
 }
 
-
 static int dasync_destroy(ENGINE *e)
 {
     destroy_digests();
@@ -432,7 +430,7 @@ static int dasync_destroy(ENGINE *e)
 }
 
 static int dasync_pkey(ENGINE *e, EVP_PKEY_METHOD **pmeth,
-                       const int **pnids, int nid)
+    const int **pnids, int nid)
 {
     static const int rnid = EVP_PKEY_RSA;
 
@@ -451,7 +449,7 @@ static int dasync_pkey(ENGINE *e, EVP_PKEY_METHOD **pmeth,
 }
 
 static int dasync_digests(ENGINE *e, const EVP_MD **digest,
-                          const int **nids, int nid)
+    const int **nids, int nid)
 {
     int ok = 1;
     if (!digest) {
@@ -472,14 +470,13 @@ static int dasync_digests(ENGINE *e, const EVP_MD **digest,
 }
 
 static int dasync_ciphers(ENGINE *e, const EVP_CIPHER **cipher,
-                                   const int **nids, int nid)
+    const int **nids, int nid)
 {
     int ok = 1;
     if (cipher == NULL) {
         /* We are returning a list of supported nids */
         *nids = dasync_cipher_nids;
-        return (sizeof(dasync_cipher_nids) -
-                1) / sizeof(dasync_cipher_nids[0]);
+        return (sizeof(dasync_cipher_nids) - 1) / sizeof(dasync_cipher_nids[0]);
     }
     /* We are being asked for a specific cipher */
     switch (nid) {
@@ -501,7 +498,7 @@ static int dasync_ciphers(ENGINE *e, const EVP_CIPHER **cipher,
 }
 
 static void wait_cleanup(ASYNC_WAIT_CTX *ctx, const void *key,
-                         OSSL_ASYNC_FD readfd, void *pvwritefd)
+    OSSL_ASYNC_FD readfd, void *pvwritefd)
 {
     OSSL_ASYNC_FD *pwritefd = (OSSL_ASYNC_FD *)pvwritefd;
 #if defined(ASYNC_WIN)
@@ -516,12 +513,13 @@ static void wait_cleanup(ASYNC_WAIT_CTX *ctx, const void *key,
 
 #define DUMMY_CHAR 'X'
 
-static void dummy_pause_job(void) {
+static void dummy_pause_job(void)
+{
     ASYNC_JOB *job;
     ASYNC_WAIT_CTX *waitctx;
     ASYNC_callback_fn callback;
-    void * callback_arg;
-    OSSL_ASYNC_FD pipefds[2] = {0, 0};
+    void *callback_arg;
+    OSSL_ASYNC_FD pipefds[2] = { 0, 0 };
     OSSL_ASYNC_FD *writefd;
 #if defined(ASYNC_WIN)
     DWORD numwritten, numread;
@@ -546,9 +544,8 @@ static void dummy_pause_job(void) {
         return;
     }
 
-
     if (ASYNC_WAIT_CTX_get_fd(waitctx, engine_dasync_id, &pipefds[0],
-                              (void **)&writefd)) {
+            (void **)&writefd)) {
         pipefds[1] = *writefd;
     } else {
         writefd = OPENSSL_malloc(sizeof(*writefd));
@@ -568,7 +565,7 @@ static void dummy_pause_job(void) {
         *writefd = pipefds[1];
 
         if (!ASYNC_WAIT_CTX_set_wait_fd(waitctx, engine_dasync_id, pipefds[0],
-                                        writefd, wait_cleanup)) {
+                writefd, wait_cleanup)) {
             wait_cleanup(waitctx, engine_dasync_id, pipefds[0], writefd);
             return;
         }
@@ -609,7 +606,7 @@ static int dasync_sha1_init(EVP_MD_CTX *ctx)
 }
 
 static int dasync_sha1_update(EVP_MD_CTX *ctx, const void *data,
-                             size_t count)
+    size_t count)
 {
     dummy_pause_job();
 
@@ -626,109 +623,101 @@ static int dasync_sha1_final(EVP_MD_CTX *ctx, unsigned char *md)
 /* Cipher helper functions */
 
 static int dasync_cipher_ctrl_helper(EVP_CIPHER_CTX *ctx, int type, int arg,
-                                     void *ptr, int aeadcapable,
-                                     const EVP_CIPHER *ciph)
+    void *ptr, int aeadcapable,
+    const EVP_CIPHER *ciph)
 {
     int ret;
-    struct dasync_pipeline_ctx *pipe_ctx =
-        (struct dasync_pipeline_ctx *)EVP_CIPHER_CTX_get_cipher_data(ctx);
+    struct dasync_pipeline_ctx *pipe_ctx = (struct dasync_pipeline_ctx *)EVP_CIPHER_CTX_get_cipher_data(ctx);
 
     if (pipe_ctx == NULL)
         return 0;
 
     switch (type) {
-        case EVP_CTRL_COPY:
-            {
-                size_t sz = EVP_CIPHER_impl_ctx_size(ciph);
-                void *inner_cipher_data = OPENSSL_malloc(sz);
+    case EVP_CTRL_COPY: {
+        size_t sz = EVP_CIPHER_impl_ctx_size(ciph);
+        void *inner_cipher_data = OPENSSL_malloc(sz);
 
-                if (inner_cipher_data == NULL)
-                    return -1;
-                memcpy(inner_cipher_data, pipe_ctx->inner_cipher_data, sz);
-                pipe_ctx->inner_cipher_data = inner_cipher_data;
+        if (inner_cipher_data == NULL)
+            return -1;
+        memcpy(inner_cipher_data, pipe_ctx->inner_cipher_data, sz);
+        pipe_ctx->inner_cipher_data = inner_cipher_data;
+    } break;
+
+    case EVP_CTRL_SET_PIPELINE_OUTPUT_BUFS:
+        pipe_ctx->numpipes = arg;
+        pipe_ctx->outbufs = (unsigned char **)ptr;
+        break;
+
+    case EVP_CTRL_SET_PIPELINE_INPUT_BUFS:
+        pipe_ctx->numpipes = arg;
+        pipe_ctx->inbufs = (unsigned char **)ptr;
+        break;
+
+    case EVP_CTRL_SET_PIPELINE_INPUT_LENS:
+        pipe_ctx->numpipes = arg;
+        pipe_ctx->lens = (size_t *)ptr;
+        break;
+
+    case EVP_CTRL_AEAD_SET_MAC_KEY:
+        if (!aeadcapable)
+            return -1;
+        EVP_CIPHER_CTX_set_cipher_data(ctx, pipe_ctx->inner_cipher_data);
+        ret = EVP_CIPHER_meth_get_ctrl(EVP_aes_128_cbc_hmac_sha1())(ctx, type, arg, ptr);
+        EVP_CIPHER_CTX_set_cipher_data(ctx, pipe_ctx);
+        return ret;
+
+    case EVP_CTRL_AEAD_TLS1_AAD: {
+        unsigned char *p = ptr;
+        unsigned int len;
+
+        if (!aeadcapable || arg != EVP_AEAD_TLS1_AAD_LEN)
+            return -1;
+
+        if (pipe_ctx->aadctr >= SSL_MAX_PIPELINES)
+            return -1;
+
+        memcpy(pipe_ctx->tlsaad[pipe_ctx->aadctr], ptr,
+            EVP_AEAD_TLS1_AAD_LEN);
+        pipe_ctx->aadctr++;
+
+        len = p[arg - 2] << 8 | p[arg - 1];
+
+        if (EVP_CIPHER_CTX_is_encrypting(ctx)) {
+            if ((p[arg - 4] << 8 | p[arg - 3]) >= TLS1_1_VERSION) {
+                if (len < AES_BLOCK_SIZE)
+                    return 0;
+                len -= AES_BLOCK_SIZE;
             }
-            break;
 
-        case EVP_CTRL_SET_PIPELINE_OUTPUT_BUFS:
-            pipe_ctx->numpipes = arg;
-            pipe_ctx->outbufs = (unsigned char **)ptr;
-            break;
-
-        case EVP_CTRL_SET_PIPELINE_INPUT_BUFS:
-            pipe_ctx->numpipes = arg;
-            pipe_ctx->inbufs = (unsigned char **)ptr;
-            break;
-
-        case EVP_CTRL_SET_PIPELINE_INPUT_LENS:
-            pipe_ctx->numpipes = arg;
-            pipe_ctx->lens = (size_t *)ptr;
-            break;
-
-        case EVP_CTRL_AEAD_SET_MAC_KEY:
-            if (!aeadcapable)
-                return -1;
-            EVP_CIPHER_CTX_set_cipher_data(ctx, pipe_ctx->inner_cipher_data);
-            ret = EVP_CIPHER_meth_get_ctrl(EVP_aes_128_cbc_hmac_sha1())
-                                          (ctx, type, arg, ptr);
-            EVP_CIPHER_CTX_set_cipher_data(ctx, pipe_ctx);
-            return ret;
-
-        case EVP_CTRL_AEAD_TLS1_AAD:
-        {
-            unsigned char *p = ptr;
-            unsigned int len;
-
-            if (!aeadcapable || arg != EVP_AEAD_TLS1_AAD_LEN)
-                return -1;
-
-            if (pipe_ctx->aadctr >= SSL_MAX_PIPELINES)
-                return -1;
-
-            memcpy(pipe_ctx->tlsaad[pipe_ctx->aadctr], ptr,
-                   EVP_AEAD_TLS1_AAD_LEN);
-            pipe_ctx->aadctr++;
-
-            len = p[arg - 2] << 8 | p[arg - 1];
-
-            if (EVP_CIPHER_CTX_is_encrypting(ctx)) {
-                if ((p[arg - 4] << 8 | p[arg - 3]) >= TLS1_1_VERSION) {
-                    if (len < AES_BLOCK_SIZE)
-                        return 0;
-                    len -= AES_BLOCK_SIZE;
-                }
-
-                return ((len + SHA_DIGEST_LENGTH + AES_BLOCK_SIZE)
-                        & -AES_BLOCK_SIZE) - len;
-            } else {
-                return SHA_DIGEST_LENGTH;
-            }
+            return ((len + SHA_DIGEST_LENGTH + AES_BLOCK_SIZE)
+                       & -AES_BLOCK_SIZE)
+                - len;
+        } else {
+            return SHA_DIGEST_LENGTH;
         }
+    }
 
-        default:
-            return 0;
+    default:
+        return 0;
     }
 
     return 1;
 }
 
 static int dasync_cipher_init_key_helper(EVP_CIPHER_CTX *ctx,
-                                         const unsigned char *key,
-                                         const unsigned char *iv, int enc,
-                                         const EVP_CIPHER *cipher)
+    const unsigned char *key,
+    const unsigned char *iv, int enc,
+    const EVP_CIPHER *cipher)
 {
     int ret;
-    struct dasync_pipeline_ctx *pipe_ctx =
-        (struct dasync_pipeline_ctx *)EVP_CIPHER_CTX_get_cipher_data(ctx);
+    struct dasync_pipeline_ctx *pipe_ctx = (struct dasync_pipeline_ctx *)EVP_CIPHER_CTX_get_cipher_data(ctx);
 
     if (pipe_ctx->inner_cipher_data == NULL
-            && EVP_CIPHER_impl_ctx_size(cipher) != 0) {
+        && EVP_CIPHER_impl_ctx_size(cipher) != 0) {
         pipe_ctx->inner_cipher_data = OPENSSL_zalloc(
             EVP_CIPHER_impl_ctx_size(cipher));
-        if (pipe_ctx->inner_cipher_data == NULL) {
-            DASYNCerr(DASYNC_F_DASYNC_CIPHER_INIT_KEY_HELPER,
-                        ERR_R_MALLOC_FAILURE);
+        if (pipe_ctx->inner_cipher_data == NULL)
             return 0;
-        }
     }
 
     pipe_ctx->numpipes = 0;
@@ -742,13 +731,12 @@ static int dasync_cipher_init_key_helper(EVP_CIPHER_CTX *ctx,
 }
 
 static int dasync_cipher_helper(EVP_CIPHER_CTX *ctx, unsigned char *out,
-                                const unsigned char *in, size_t inl,
-                                const EVP_CIPHER *cipher)
+    const unsigned char *in, size_t inl,
+    const EVP_CIPHER *cipher)
 {
     int ret = 1;
     unsigned int i, pipes;
-    struct dasync_pipeline_ctx *pipe_ctx =
-        (struct dasync_pipeline_ctx *)EVP_CIPHER_CTX_get_cipher_data(ctx);
+    struct dasync_pipeline_ctx *pipe_ctx = (struct dasync_pipeline_ctx *)EVP_CIPHER_CTX_get_cipher_data(ctx);
 
     pipes = pipe_ctx->numpipes;
     EVP_CIPHER_CTX_set_cipher_data(ctx, pipe_ctx->inner_cipher_data);
@@ -756,26 +744,21 @@ static int dasync_cipher_helper(EVP_CIPHER_CTX *ctx, unsigned char *out,
         if (pipe_ctx->aadctr != 0) {
             if (pipe_ctx->aadctr != 1)
                 return -1;
-            EVP_CIPHER_meth_get_ctrl(cipher)
-                                    (ctx, EVP_CTRL_AEAD_TLS1_AAD,
-                                     EVP_AEAD_TLS1_AAD_LEN,
-                                     pipe_ctx->tlsaad[0]);
+            EVP_CIPHER_meth_get_ctrl(cipher)(ctx, EVP_CTRL_AEAD_TLS1_AAD,
+                EVP_AEAD_TLS1_AAD_LEN,
+                pipe_ctx->tlsaad[0]);
         }
-        ret = EVP_CIPHER_meth_get_do_cipher(cipher)
-                                           (ctx, out, in, inl);
+        ret = EVP_CIPHER_meth_get_do_cipher(cipher)(ctx, out, in, inl);
     } else {
         if (pipe_ctx->aadctr > 0 && pipe_ctx->aadctr != pipes)
             return -1;
         for (i = 0; i < pipes; i++) {
             if (pipe_ctx->aadctr > 0) {
-                EVP_CIPHER_meth_get_ctrl(cipher)
-                                        (ctx, EVP_CTRL_AEAD_TLS1_AAD,
-                                         EVP_AEAD_TLS1_AAD_LEN,
-                                         pipe_ctx->tlsaad[i]);
+                EVP_CIPHER_meth_get_ctrl(cipher)(ctx, EVP_CTRL_AEAD_TLS1_AAD,
+                    EVP_AEAD_TLS1_AAD_LEN,
+                    pipe_ctx->tlsaad[i]);
             }
-            ret = ret && EVP_CIPHER_meth_get_do_cipher(cipher)
-                                (ctx, pipe_ctx->outbufs[i], pipe_ctx->inbufs[i],
-                                 pipe_ctx->lens[i]);
+            ret = ret && EVP_CIPHER_meth_get_do_cipher(cipher)(ctx, pipe_ctx->outbufs[i], pipe_ctx->inbufs[i], pipe_ctx->lens[i]);
         }
         pipe_ctx->numpipes = 0;
     }
@@ -785,13 +768,12 @@ static int dasync_cipher_helper(EVP_CIPHER_CTX *ctx, unsigned char *out,
 }
 
 static int dasync_cipher_cleanup_helper(EVP_CIPHER_CTX *ctx,
-                                        const EVP_CIPHER *cipher)
+    const EVP_CIPHER *cipher)
 {
-    struct dasync_pipeline_ctx *pipe_ctx =
-        (struct dasync_pipeline_ctx *)EVP_CIPHER_CTX_get_cipher_data(ctx);
+    struct dasync_pipeline_ctx *pipe_ctx = (struct dasync_pipeline_ctx *)EVP_CIPHER_CTX_get_cipher_data(ctx);
 
     OPENSSL_clear_free(pipe_ctx->inner_cipher_data,
-                       EVP_CIPHER_impl_ctx_size(cipher));
+        EVP_CIPHER_impl_ctx_size(cipher));
 
     return 1;
 }
@@ -801,19 +783,19 @@ static int dasync_cipher_cleanup_helper(EVP_CIPHER_CTX *ctx,
  */
 
 static int dasync_aes128_cbc_ctrl(EVP_CIPHER_CTX *ctx, int type, int arg,
-                                  void *ptr)
+    void *ptr)
 {
     return dasync_cipher_ctrl_helper(ctx, type, arg, ptr, 0, EVP_aes_128_cbc());
 }
 
 static int dasync_aes128_init_key(EVP_CIPHER_CTX *ctx, const unsigned char *key,
-                             const unsigned char *iv, int enc)
+    const unsigned char *iv, int enc)
 {
     return dasync_cipher_init_key_helper(ctx, key, iv, enc, EVP_aes_128_cbc());
 }
 
 static int dasync_aes128_cbc_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
-                               const unsigned char *in, size_t inl)
+    const unsigned char *in, size_t inl)
 {
     return dasync_cipher_helper(ctx, out, in, inl, EVP_aes_128_cbc());
 }
@@ -824,19 +806,19 @@ static int dasync_aes128_cbc_cleanup(EVP_CIPHER_CTX *ctx)
 }
 
 static int dasync_aes256_ctr_ctrl(EVP_CIPHER_CTX *ctx, int type, int arg,
-                                  void *ptr)
+    void *ptr)
 {
     return dasync_cipher_ctrl_helper(ctx, type, arg, ptr, 0, EVP_aes_256_ctr());
 }
 
 static int dasync_aes256_init_key(EVP_CIPHER_CTX *ctx, const unsigned char *key,
-                             const unsigned char *iv, int enc)
+    const unsigned char *iv, int enc)
 {
     return dasync_cipher_init_key_helper(ctx, key, iv, enc, EVP_aes_256_ctr());
 }
 
 static int dasync_aes256_ctr_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
-                               const unsigned char *in, size_t inl)
+    const unsigned char *in, size_t inl)
 {
     return dasync_cipher_helper(ctx, out, in, inl, EVP_aes_256_ctr());
 }
@@ -846,34 +828,33 @@ static int dasync_aes256_ctr_cleanup(EVP_CIPHER_CTX *ctx)
     return dasync_cipher_cleanup_helper(ctx, EVP_aes_256_ctr());
 }
 
-
 /*
  * AES128 CBC HMAC SHA1 Implementation
  */
 
 static int dasync_aes128_cbc_hmac_sha1_ctrl(EVP_CIPHER_CTX *ctx, int type,
-                                             int arg, void *ptr)
+    int arg, void *ptr)
 {
     return dasync_cipher_ctrl_helper(ctx, type, arg, ptr, 1, EVP_aes_128_cbc_hmac_sha1());
 }
 
 static int dasync_aes128_cbc_hmac_sha1_init_key(EVP_CIPHER_CTX *ctx,
-                                                const unsigned char *key,
-                                                const unsigned char *iv,
-                                                int enc)
+    const unsigned char *key,
+    const unsigned char *iv,
+    int enc)
 {
     /*
      * We can safely assume that EVP_aes_128_cbc_hmac_sha1() != NULL,
      * see comment before the definition of dasync_aes_128_cbc_hmac_sha1().
      */
     return dasync_cipher_init_key_helper(ctx, key, iv, enc,
-                                         EVP_aes_128_cbc_hmac_sha1());
+        EVP_aes_128_cbc_hmac_sha1());
 }
 
 static int dasync_aes128_cbc_hmac_sha1_cipher(EVP_CIPHER_CTX *ctx,
-                                               unsigned char *out,
-                                               const unsigned char *in,
-                                               size_t inl)
+    unsigned char *out,
+    const unsigned char *in,
+    size_t inl)
 {
     return dasync_cipher_helper(ctx, out, in, inl, EVP_aes_128_cbc_hmac_sha1());
 }
@@ -887,7 +868,6 @@ static int dasync_aes128_cbc_hmac_sha1_cleanup(EVP_CIPHER_CTX *ctx)
     return dasync_cipher_cleanup_helper(ctx, EVP_aes_128_cbc_hmac_sha1());
 }
 
-
 /*
  * RSA implementation
  */
@@ -955,12 +935,12 @@ static int dasync_rsa_encrypt_init(EVP_PKEY_CTX *ctx)
 }
 
 static int dasync_rsa_encrypt(EVP_PKEY_CTX *ctx, unsigned char *out,
-                              size_t *outlen, const unsigned char *in,
-                              size_t inlen)
+    size_t *outlen, const unsigned char *in,
+    size_t inlen)
 {
     static int (*pencryptfn)(EVP_PKEY_CTX *ctx, unsigned char *out,
-                             size_t *outlen, const unsigned char *in,
-                             size_t inlen);
+        size_t *outlen, const unsigned char *in,
+        size_t inlen);
 
     if (pencryptfn == NULL)
         EVP_PKEY_meth_get_encrypt(dasync_rsa_orig, NULL, &pencryptfn);
@@ -977,15 +957,15 @@ static int dasync_rsa_decrypt_init(EVP_PKEY_CTX *ctx)
 }
 
 static int dasync_rsa_decrypt(EVP_PKEY_CTX *ctx, unsigned char *out,
-                              size_t *outlen, const unsigned char *in,
-                              size_t inlen)
+    size_t *outlen, const unsigned char *in,
+    size_t inlen)
 {
     static int (*pdecrypt)(EVP_PKEY_CTX *ctx, unsigned char *out,
-                             size_t *outlen, const unsigned char *in,
-                             size_t inlen);
+        size_t *outlen, const unsigned char *in,
+        size_t inlen);
 
     if (pdecrypt == NULL)
-        EVP_PKEY_meth_get_encrypt(dasync_rsa_orig, NULL, &pdecrypt);
+        EVP_PKEY_meth_get_decrypt(dasync_rsa_orig, NULL, &pdecrypt);
     return pdecrypt(ctx, out, outlen, in, inlen);
 }
 
@@ -999,10 +979,10 @@ static int dasync_rsa_ctrl(EVP_PKEY_CTX *ctx, int type, int p1, void *p2)
 }
 
 static int dasync_rsa_ctrl_str(EVP_PKEY_CTX *ctx, const char *type,
-                               const char *value)
+    const char *value)
 {
     static int (*pctrl_str)(EVP_PKEY_CTX *ctx, const char *type,
-                            const char *value);
+        const char *value);
 
     if (pctrl_str == NULL)
         EVP_PKEY_meth_get_ctrl(dasync_rsa_orig, NULL, &pctrl_str);
