@@ -27,6 +27,7 @@
 
 #include <stdio.h>
 #include <string.h>
+#include "internal/common.h" /* for CHECK_AND_SKIP_CASE_PREFIX */
 
 #include <openssl/engine.h>
 #include <openssl/sha.h>
@@ -40,33 +41,29 @@
 #include <openssl/pem.h>
 #include <crypto/evp.h>
 
+/* clang-format off */
 #include "e_ossltest_err.c"
-
-#ifdef _WIN32
-# define strncasecmp _strnicmp
-#endif
+/* clang-format on */
 
 /* Engine Id and Name */
 static const char *engine_ossltest_id = "ossltest";
 static const char *engine_ossltest_name = "OpenSSL Test engine support";
 
-
 /* Engine Lifetime functions */
 static int ossltest_destroy(ENGINE *e);
 static int ossltest_init(ENGINE *e);
 static int ossltest_finish(ENGINE *e);
 void ENGINE_load_ossltest(void);
 
-
 /* Set up digests */
 static int ossltest_digests(ENGINE *e, const EVP_MD **digest,
-                          const int **nids, int nid);
+    const int **nids, int nid);
 static const RAND_METHOD *ossltest_rand_method(void);
 
 /* MD5 */
 static int digest_md5_init(EVP_MD_CTX *ctx);
 static int digest_md5_update(EVP_MD_CTX *ctx, const void *data,
-                             size_t count);
+    size_t count);
 static int digest_md5_final(EVP_MD_CTX *ctx, unsigned char *md);
 
 static EVP_MD *_hidden_md5_md = NULL;
@@ -79,7 +76,7 @@ static const EVP_MD *digest_md5(void)
             || !EVP_MD_meth_set_result_size(md, MD5_DIGEST_LENGTH)
             || !EVP_MD_meth_set_input_blocksize(md, MD5_CBLOCK)
             || !EVP_MD_meth_set_app_datasize(md,
-                                             sizeof(EVP_MD *) + sizeof(MD5_CTX))
+                sizeof(EVP_MD *) + sizeof(MD5_CTX))
             || !EVP_MD_meth_set_flags(md, 0)
             || !EVP_MD_meth_set_init(md, digest_md5_init)
             || !EVP_MD_meth_set_update(md, digest_md5_update)
@@ -95,7 +92,7 @@ static const EVP_MD *digest_md5(void)
 /* SHA1 */
 static int digest_sha1_init(EVP_MD_CTX *ctx);
 static int digest_sha1_update(EVP_MD_CTX *ctx, const void *data,
-                              size_t count);
+    size_t count);
 static int digest_sha1_final(EVP_MD_CTX *ctx, unsigned char *md);
 
 static EVP_MD *_hidden_sha1_md = NULL;
@@ -108,7 +105,7 @@ static const EVP_MD *digest_sha1(void)
             || !EVP_MD_meth_set_result_size(md, SHA_DIGEST_LENGTH)
             || !EVP_MD_meth_set_input_blocksize(md, SHA_CBLOCK)
             || !EVP_MD_meth_set_app_datasize(md,
-                                             sizeof(EVP_MD *) + sizeof(SHA_CTX))
+                sizeof(EVP_MD *) + sizeof(SHA_CTX))
             || !EVP_MD_meth_set_flags(md, EVP_MD_FLAG_DIGALGID_ABSENT)
             || !EVP_MD_meth_set_init(md, digest_sha1_init)
             || !EVP_MD_meth_set_update(md, digest_sha1_update)
@@ -124,7 +121,7 @@ static const EVP_MD *digest_sha1(void)
 /* SHA256 */
 static int digest_sha256_init(EVP_MD_CTX *ctx);
 static int digest_sha256_update(EVP_MD_CTX *ctx, const void *data,
-                                size_t count);
+    size_t count);
 static int digest_sha256_final(EVP_MD_CTX *ctx, unsigned char *md);
 
 static EVP_MD *_hidden_sha256_md = NULL;
@@ -137,7 +134,7 @@ static const EVP_MD *digest_sha256(void)
             || !EVP_MD_meth_set_result_size(md, SHA256_DIGEST_LENGTH)
             || !EVP_MD_meth_set_input_blocksize(md, SHA256_CBLOCK)
             || !EVP_MD_meth_set_app_datasize(md,
-                                             sizeof(EVP_MD *) + sizeof(SHA256_CTX))
+                sizeof(EVP_MD *) + sizeof(SHA256_CTX))
             || !EVP_MD_meth_set_flags(md, EVP_MD_FLAG_DIGALGID_ABSENT)
             || !EVP_MD_meth_set_init(md, digest_sha256_init)
             || !EVP_MD_meth_set_update(md, digest_sha256_update)
@@ -153,12 +150,12 @@ static const EVP_MD *digest_sha256(void)
 /* SHA384/SHA512 */
 static int digest_sha384_init(EVP_MD_CTX *ctx);
 static int digest_sha384_update(EVP_MD_CTX *ctx, const void *data,
-                                size_t count);
+    size_t count);
 static int digest_sha384_final(EVP_MD_CTX *ctx, unsigned char *md);
 
 static int digest_sha512_init(EVP_MD_CTX *ctx);
 static int digest_sha512_update(EVP_MD_CTX *ctx, const void *data,
-                                size_t count);
+    size_t count);
 static int digest_sha512_final(EVP_MD_CTX *ctx, unsigned char *md);
 
 static EVP_MD *_hidden_sha384_md = NULL;
@@ -171,7 +168,7 @@ static const EVP_MD *digest_sha384(void)
             || !EVP_MD_meth_set_result_size(md, SHA384_DIGEST_LENGTH)
             || !EVP_MD_meth_set_input_blocksize(md, SHA512_CBLOCK)
             || !EVP_MD_meth_set_app_datasize(md,
-                                             sizeof(EVP_MD *) + sizeof(SHA512_CTX))
+                sizeof(EVP_MD *) + sizeof(SHA512_CTX))
             || !EVP_MD_meth_set_flags(md, EVP_MD_FLAG_DIGALGID_ABSENT)
             || !EVP_MD_meth_set_init(md, digest_sha384_init)
             || !EVP_MD_meth_set_update(md, digest_sha384_update)
@@ -193,7 +190,7 @@ static const EVP_MD *digest_sha512(void)
             || !EVP_MD_meth_set_result_size(md, SHA512_DIGEST_LENGTH)
             || !EVP_MD_meth_set_input_blocksize(md, SHA512_CBLOCK)
             || !EVP_MD_meth_set_app_datasize(md,
-                                             sizeof(EVP_MD *) + sizeof(SHA512_CTX))
+                sizeof(EVP_MD *) + sizeof(SHA512_CTX))
             || !EVP_MD_meth_set_flags(md, EVP_MD_FLAG_DIGALGID_ABSENT)
             || !EVP_MD_meth_set_init(md, digest_sha512_init)
             || !EVP_MD_meth_set_update(md, digest_sha512_update)
@@ -245,7 +242,7 @@ static int ossltest_digest_nids(const int **nids)
 
 /* Setup ciphers */
 static int ossltest_ciphers(ENGINE *, const EVP_CIPHER **,
-                            const int **, int);
+    const int **, int);
 
 static int ossltest_cipher_nids[] = {
     NID_aes_128_cbc, NID_aes_128_gcm,
@@ -255,30 +252,30 @@ static int ossltest_cipher_nids[] = {
 /* AES128 */
 
 static int ossltest_aes128_init_key(EVP_CIPHER_CTX *ctx,
-                                    const unsigned char *key,
-                                    const unsigned char *iv, int enc);
+    const unsigned char *key,
+    const unsigned char *iv, int enc);
 static int ossltest_aes128_cbc_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
-                                      const unsigned char *in, size_t inl);
+    const unsigned char *in, size_t inl);
 static int ossltest_aes128_gcm_init_key(EVP_CIPHER_CTX *ctx,
-                                        const unsigned char *key,
-                                        const unsigned char *iv, int enc);
+    const unsigned char *key,
+    const unsigned char *iv, int enc);
 static int ossltest_aes128_gcm_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
-                                      const unsigned char *in, size_t inl);
+    const unsigned char *in, size_t inl);
 static int ossltest_aes128_gcm_ctrl(EVP_CIPHER_CTX *ctx, int type, int arg,
-                                    void *ptr);
+    void *ptr);
 static int ossltest_aes128_cbc_hmac_sha1_init_key(EVP_CIPHER_CTX *ctx,
-                                                  const unsigned char *key,
-                                                  const unsigned char *iv,
-                                                  int enc);
+    const unsigned char *key,
+    const unsigned char *iv,
+    int enc);
 static int ossltest_aes128_cbc_hmac_sha1_cipher(EVP_CIPHER_CTX *ctx,
-                                                unsigned char *out,
-                                                const unsigned char *in,
-                                                size_t inl);
+    unsigned char *out,
+    const unsigned char *in,
+    size_t inl);
 static int ossltest_aes128_cbc_hmac_sha1_ctrl(EVP_CIPHER_CTX *ctx, int type,
-                                              int arg, void *ptr);
+    int arg, void *ptr);
 
 typedef struct {
-    size_t payload_length;      /* AAD length in decrypt case */
+    size_t payload_length; /* AAD length in decrypt case */
     unsigned int tls_ver;
 } EVP_AES_HMAC_SHA1;
 
@@ -287,18 +284,19 @@ static const EVP_CIPHER *ossltest_aes_128_cbc(void)
 {
     if (_hidden_aes_128_cbc == NULL
         && ((_hidden_aes_128_cbc = EVP_CIPHER_meth_new(NID_aes_128_cbc,
-                                                       16 /* block size */,
-                                                       16 /* key len */)) == NULL
-            || !EVP_CIPHER_meth_set_iv_length(_hidden_aes_128_cbc,16)
+                 16 /* block size */,
+                 16 /* key len */))
+                == NULL
+            || !EVP_CIPHER_meth_set_iv_length(_hidden_aes_128_cbc, 16)
             || !EVP_CIPHER_meth_set_flags(_hidden_aes_128_cbc,
-                                          EVP_CIPH_FLAG_DEFAULT_ASN1
-                                          | EVP_CIPH_CBC_MODE)
+                EVP_CIPH_FLAG_DEFAULT_ASN1
+                    | EVP_CIPH_CBC_MODE)
             || !EVP_CIPHER_meth_set_init(_hidden_aes_128_cbc,
-                                         ossltest_aes128_init_key)
+                ossltest_aes128_init_key)
             || !EVP_CIPHER_meth_set_do_cipher(_hidden_aes_128_cbc,
-                                              ossltest_aes128_cbc_cipher)
+                ossltest_aes128_cbc_cipher)
             || !EVP_CIPHER_meth_set_impl_ctx_size(_hidden_aes_128_cbc,
-                    EVP_CIPHER_impl_ctx_size(EVP_aes_128_cbc())))) {
+                EVP_CIPHER_impl_ctx_size(EVP_aes_128_cbc())))) {
         EVP_CIPHER_meth_free(_hidden_aes_128_cbc);
         _hidden_aes_128_cbc = NULL;
     }
@@ -307,28 +305,29 @@ static const EVP_CIPHER *ossltest_aes_128_cbc(void)
 
 static EVP_CIPHER *_hidden_aes_128_gcm = NULL;
 
-#define AES_GCM_FLAGS   (EVP_CIPH_FLAG_DEFAULT_ASN1 \
-                | EVP_CIPH_CUSTOM_IV | EVP_CIPH_FLAG_CUSTOM_CIPHER \
-                | EVP_CIPH_ALWAYS_CALL_INIT | EVP_CIPH_CTRL_INIT \
-                | EVP_CIPH_CUSTOM_COPY |EVP_CIPH_FLAG_AEAD_CIPHER \
-                | EVP_CIPH_GCM_MODE)
+#define AES_GCM_FLAGS (EVP_CIPH_FLAG_DEFAULT_ASN1      \
+    | EVP_CIPH_CUSTOM_IV | EVP_CIPH_FLAG_CUSTOM_CIPHER \
+    | EVP_CIPH_ALWAYS_CALL_INIT | EVP_CIPH_CTRL_INIT   \
+    | EVP_CIPH_CUSTOM_COPY | EVP_CIPH_FLAG_AEAD_CIPHER \
+    | EVP_CIPH_GCM_MODE)
 
 static const EVP_CIPHER *ossltest_aes_128_gcm(void)
 {
     if (_hidden_aes_128_gcm == NULL
         && ((_hidden_aes_128_gcm = EVP_CIPHER_meth_new(NID_aes_128_gcm,
-                                                       1 /* block size */,
-                                                       16 /* key len */)) == NULL
-            || !EVP_CIPHER_meth_set_iv_length(_hidden_aes_128_gcm,12)
+                 1 /* block size */,
+                 16 /* key len */))
+                == NULL
+            || !EVP_CIPHER_meth_set_iv_length(_hidden_aes_128_gcm, 12)
             || !EVP_CIPHER_meth_set_flags(_hidden_aes_128_gcm, AES_GCM_FLAGS)
             || !EVP_CIPHER_meth_set_init(_hidden_aes_128_gcm,
-                                         ossltest_aes128_gcm_init_key)
+                ossltest_aes128_gcm_init_key)
             || !EVP_CIPHER_meth_set_do_cipher(_hidden_aes_128_gcm,
-                                              ossltest_aes128_gcm_cipher)
+                ossltest_aes128_gcm_cipher)
             || !EVP_CIPHER_meth_set_ctrl(_hidden_aes_128_gcm,
-                                              ossltest_aes128_gcm_ctrl)
+                ossltest_aes128_gcm_ctrl)
             || !EVP_CIPHER_meth_set_impl_ctx_size(_hidden_aes_128_gcm,
-                    EVP_CIPHER_impl_ctx_size(EVP_aes_128_gcm())))) {
+                EVP_CIPHER_impl_ctx_size(EVP_aes_128_gcm())))) {
         EVP_CIPHER_meth_free(_hidden_aes_128_gcm);
         _hidden_aes_128_gcm = NULL;
     }
@@ -341,25 +340,25 @@ static const EVP_CIPHER *ossltest_aes_128_cbc_hmac_sha1(void)
 {
     if (_hidden_aes_128_cbc_hmac_sha1 == NULL
         && ((_hidden_aes_128_cbc_hmac_sha1
-             = EVP_CIPHER_meth_new(NID_aes_128_cbc_hmac_sha1,
-                                   16 /* block size */,
-                                   16 /* key len */)) == NULL
-            || !EVP_CIPHER_meth_set_iv_length(_hidden_aes_128_cbc_hmac_sha1,16)
+                = EVP_CIPHER_meth_new(NID_aes_128_cbc_hmac_sha1,
+                    16 /* block size */,
+                    16 /* key len */))
+                == NULL
+            || !EVP_CIPHER_meth_set_iv_length(_hidden_aes_128_cbc_hmac_sha1, 16)
             || !EVP_CIPHER_meth_set_flags(_hidden_aes_128_cbc_hmac_sha1,
-                   EVP_CIPH_CBC_MODE | EVP_CIPH_FLAG_DEFAULT_ASN1 |
-                   EVP_CIPH_FLAG_AEAD_CIPHER)
+                EVP_CIPH_CBC_MODE | EVP_CIPH_FLAG_DEFAULT_ASN1 | EVP_CIPH_FLAG_AEAD_CIPHER)
             || !EVP_CIPHER_meth_set_init(_hidden_aes_128_cbc_hmac_sha1,
-                   ossltest_aes128_cbc_hmac_sha1_init_key)
+                ossltest_aes128_cbc_hmac_sha1_init_key)
             || !EVP_CIPHER_meth_set_do_cipher(_hidden_aes_128_cbc_hmac_sha1,
-                   ossltest_aes128_cbc_hmac_sha1_cipher)
+                ossltest_aes128_cbc_hmac_sha1_cipher)
             || !EVP_CIPHER_meth_set_ctrl(_hidden_aes_128_cbc_hmac_sha1,
-                                         ossltest_aes128_cbc_hmac_sha1_ctrl)
+                ossltest_aes128_cbc_hmac_sha1_ctrl)
             || !EVP_CIPHER_meth_set_set_asn1_params(_hidden_aes_128_cbc_hmac_sha1,
-                   EVP_CIPH_FLAG_DEFAULT_ASN1 ? NULL : EVP_CIPHER_set_asn1_iv)
+                EVP_CIPH_FLAG_DEFAULT_ASN1 ? NULL : EVP_CIPHER_set_asn1_iv)
             || !EVP_CIPHER_meth_set_get_asn1_params(_hidden_aes_128_cbc_hmac_sha1,
-                   EVP_CIPH_FLAG_DEFAULT_ASN1 ? NULL : EVP_CIPHER_get_asn1_iv)
+                EVP_CIPH_FLAG_DEFAULT_ASN1 ? NULL : EVP_CIPHER_get_asn1_iv)
             || !EVP_CIPHER_meth_set_impl_ctx_size(_hidden_aes_128_cbc_hmac_sha1,
-                   sizeof(EVP_AES_HMAC_SHA1)))) {
+                sizeof(EVP_AES_HMAC_SHA1)))) {
         EVP_CIPHER_meth_free(_hidden_aes_128_cbc_hmac_sha1);
         _hidden_aes_128_cbc_hmac_sha1 = NULL;
     }
@@ -378,17 +377,16 @@ static void destroy_ciphers(void)
 
 /* Key loading */
 static EVP_PKEY *load_key(ENGINE *eng, const char *key_id, int pub,
-                          UI_METHOD *ui_method, void *ui_data)
+    UI_METHOD *ui_method, void *ui_data)
 {
     BIO *in;
     EVP_PKEY *key;
 
-    if (strncasecmp(key_id, "ot:", 3) != 0)
+    if (!CHECK_AND_SKIP_CASE_PREFIX(key_id, "ot:"))
         return NULL;
-    key_id += 3;
 
     fprintf(stderr, "[ossltest]Loading %s key %s\n",
-            pub ? "Public" : "Private", key_id);
+        pub ? "Public" : "Private", key_id);
     in = BIO_new_file(key_id, "r");
     if (!in)
         return NULL;
@@ -401,18 +399,17 @@ static EVP_PKEY *load_key(ENGINE *eng, const char *key_id, int pub,
 }
 
 static EVP_PKEY *ossltest_load_privkey(ENGINE *eng, const char *key_id,
-                                       UI_METHOD *ui_method, void *ui_data)
+    UI_METHOD *ui_method, void *ui_data)
 {
     return load_key(eng, key_id, 0, ui_method, ui_data);
 }
 
 static EVP_PKEY *ossltest_load_pubkey(ENGINE *eng, const char *key_id,
-                                      UI_METHOD *ui_method, void *ui_data)
+    UI_METHOD *ui_method, void *ui_data)
 {
     return load_key(eng, key_id, 1, ui_method, ui_data);
 }
 
-
 static int bind_ossltest(ENGINE *e)
 {
     /* Ensure the ossltest error handling is set up */
@@ -446,7 +443,7 @@ static int bind_helper(ENGINE *e, const char *id)
 }
 
 IMPLEMENT_DYNAMIC_CHECK_FN()
-    IMPLEMENT_DYNAMIC_BIND_FN(bind_helper)
+IMPLEMENT_DYNAMIC_BIND_FN(bind_helper)
 #endif
 
 static ENGINE *engine_ossltest(void)
@@ -472,19 +469,16 @@ void ENGINE_load_ossltest(void)
     ERR_clear_error();
 }
 
-
 static int ossltest_init(ENGINE *e)
 {
     return 1;
 }
 
-
 static int ossltest_finish(ENGINE *e)
 {
     return 1;
 }
 
-
 static int ossltest_destroy(ENGINE *e)
 {
     destroy_digests();
@@ -494,7 +488,7 @@ static int ossltest_destroy(ENGINE *e)
 }
 
 static int ossltest_digests(ENGINE *e, const EVP_MD **digest,
-                          const int **nids, int nid)
+    const int **nids, int nid)
 {
     int ok = 1;
     if (!digest) {
@@ -527,14 +521,14 @@ static int ossltest_digests(ENGINE *e, const EVP_MD **digest,
 }
 
 static int ossltest_ciphers(ENGINE *e, const EVP_CIPHER **cipher,
-                          const int **nids, int nid)
+    const int **nids, int nid)
 {
     int ok = 1;
     if (!cipher) {
         /* We are returning a list of supported nids */
         *nids = ossltest_cipher_nids;
         return (sizeof(ossltest_cipher_nids) - 1)
-               / sizeof(ossltest_cipher_nids[0]);
+            / sizeof(ossltest_cipher_nids[0]);
     }
     /* We are being asked for a specific cipher */
     switch (nid) {
@@ -559,7 +553,7 @@ static void fill_known_data(unsigned char *md, unsigned int len)
 {
     unsigned int i;
 
-    for (i=0; i<len; i++) {
+    for (i = 0; i < len; i++) {
         md[i] = (unsigned char)(i & 0xff);
     }
 }
@@ -572,11 +566,11 @@ static void fill_known_data(unsigned char *md, unsigned int len)
  */
 static int digest_md5_init(EVP_MD_CTX *ctx)
 {
-   return EVP_MD_meth_get_init(EVP_md5())(ctx);
+    return EVP_MD_meth_get_init(EVP_md5())(ctx);
 }
 
 static int digest_md5_update(EVP_MD_CTX *ctx, const void *data,
-                             size_t count)
+    size_t count)
 {
     return EVP_MD_meth_get_update(EVP_md5())(ctx, data, count);
 }
@@ -600,7 +594,7 @@ static int digest_sha1_init(EVP_MD_CTX *ctx)
 }
 
 static int digest_sha1_update(EVP_MD_CTX *ctx, const void *data,
-                              size_t count)
+    size_t count)
 {
     return EVP_MD_meth_get_update(EVP_sha1())(ctx, data, count);
 }
@@ -624,7 +618,7 @@ static int digest_sha256_init(EVP_MD_CTX *ctx)
 }
 
 static int digest_sha256_update(EVP_MD_CTX *ctx, const void *data,
-                                size_t count)
+    size_t count)
 {
     return EVP_MD_meth_get_update(EVP_sha256())(ctx, data, count);
 }
@@ -648,7 +642,7 @@ static int digest_sha384_init(EVP_MD_CTX *ctx)
 }
 
 static int digest_sha384_update(EVP_MD_CTX *ctx, const void *data,
-                                size_t count)
+    size_t count)
 {
     return EVP_MD_meth_get_update(EVP_sha384())(ctx, data, count);
 }
@@ -672,7 +666,7 @@ static int digest_sha512_init(EVP_MD_CTX *ctx)
 }
 
 static int digest_sha512_update(EVP_MD_CTX *ctx, const void *data,
-                                size_t count)
+    size_t count)
 {
     return EVP_MD_meth_get_update(EVP_sha512())(ctx, data, count);
 }
@@ -692,14 +686,14 @@ static int digest_sha512_final(EVP_MD_CTX *ctx, unsigned char *md)
  */
 
 static int ossltest_aes128_init_key(EVP_CIPHER_CTX *ctx,
-                                    const unsigned char *key,
-                                    const unsigned char *iv, int enc)
+    const unsigned char *key,
+    const unsigned char *iv, int enc)
 {
-    return EVP_CIPHER_meth_get_init(EVP_aes_128_cbc()) (ctx, key, iv, enc);
+    return EVP_CIPHER_meth_get_init(EVP_aes_128_cbc())(ctx, key, iv, enc);
 }
 
 static int ossltest_aes128_cbc_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
-                                      const unsigned char *in, size_t inl)
+    const unsigned char *in, size_t inl)
 {
     unsigned char *tmpbuf;
     int ret;
@@ -726,14 +720,14 @@ static int ossltest_aes128_cbc_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
 }
 
 static int ossltest_aes128_gcm_init_key(EVP_CIPHER_CTX *ctx,
-                                        const unsigned char *key,
-                                        const unsigned char *iv, int enc)
+    const unsigned char *key,
+    const unsigned char *iv, int enc)
 {
-    return EVP_CIPHER_meth_get_init(EVP_aes_128_gcm()) (ctx, key, iv, enc);
+    return EVP_CIPHER_meth_get_init(EVP_aes_128_gcm())(ctx, key, iv, enc);
 }
 
 static int ossltest_aes128_gcm_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
-                                      const unsigned char *in, size_t inl)
+    const unsigned char *in, size_t inl)
 {
     unsigned char *tmpbuf = OPENSSL_malloc(inl);
 
@@ -757,7 +751,7 @@ static int ossltest_aes128_gcm_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
 }
 
 static int ossltest_aes128_gcm_ctrl(EVP_CIPHER_CTX *ctx, int type, int arg,
-                                    void *ptr)
+    void *ptr)
 {
     /* Pass the ctrl down */
     int ret = EVP_CIPHER_meth_get_ctrl(EVP_aes_128_gcm())(ctx, type, arg, ptr);
@@ -765,7 +759,7 @@ static int ossltest_aes128_gcm_ctrl(EVP_CIPHER_CTX *ctx, int type, int arg,
     if (ret <= 0)
         return ret;
 
-    switch(type) {
+    switch (type) {
     case EVP_CTRL_AEAD_GET_TAG:
         /* Always give the same tag */
         memset(ptr, 0, EVP_GCM_TLS_TAG_LEN);
@@ -778,13 +772,13 @@ static int ossltest_aes128_gcm_ctrl(EVP_CIPHER_CTX *ctx, int type, int arg,
     return 1;
 }
 
-#define NO_PAYLOAD_LENGTH       ((size_t)-1)
-# define data(ctx) ((EVP_AES_HMAC_SHA1 *)EVP_CIPHER_CTX_get_cipher_data(ctx))
+#define NO_PAYLOAD_LENGTH ((size_t)-1)
+#define data(ctx) ((EVP_AES_HMAC_SHA1 *)EVP_CIPHER_CTX_get_cipher_data(ctx))
 
 static int ossltest_aes128_cbc_hmac_sha1_init_key(EVP_CIPHER_CTX *ctx,
-                                                  const unsigned char *inkey,
-                                                  const unsigned char *iv,
-                                                  int enc)
+    const unsigned char *inkey,
+    const unsigned char *iv,
+    int enc)
 {
     EVP_AES_HMAC_SHA1 *key = data(ctx);
     key->payload_length = NO_PAYLOAD_LENGTH;
@@ -792,9 +786,9 @@ static int ossltest_aes128_cbc_hmac_sha1_init_key(EVP_CIPHER_CTX *ctx,
 }
 
 static int ossltest_aes128_cbc_hmac_sha1_cipher(EVP_CIPHER_CTX *ctx,
-                                                unsigned char *out,
-                                                const unsigned char *in,
-                                                size_t len)
+    unsigned char *out,
+    const unsigned char *in,
+    size_t len)
 {
     EVP_AES_HMAC_SHA1 *key = data(ctx);
     unsigned int l;
@@ -808,14 +802,12 @@ static int ossltest_aes128_cbc_hmac_sha1_cipher(EVP_CIPHER_CTX *ctx,
     if (EVP_CIPHER_CTX_is_encrypting(ctx)) {
         if (plen == NO_PAYLOAD_LENGTH)
             plen = len;
-        else if (len !=
-                 ((plen + SHA_DIGEST_LENGTH +
-                   AES_BLOCK_SIZE) & -AES_BLOCK_SIZE))
+        else if (len != ((plen + SHA_DIGEST_LENGTH + AES_BLOCK_SIZE) & -AES_BLOCK_SIZE))
             return 0;
 
         memmove(out, in, plen);
 
-        if (plen != len) {      /* "TLS" mode of operation */
+        if (plen != len) { /* "TLS" mode of operation */
             /* calculate HMAC and append it to payload */
             fill_known_data(out + plen, SHA_DIGEST_LENGTH);
 
@@ -857,7 +849,7 @@ static int ossltest_aes128_cbc_hmac_sha1_cipher(EVP_CIPHER_CTX *ctx,
 }
 
 static int ossltest_aes128_cbc_hmac_sha1_ctrl(EVP_CIPHER_CTX *ctx, int type,
-                                              int arg, void *ptr)
+    int arg, void *ptr)
 {
     EVP_AES_HMAC_SHA1 *key = data(ctx);
 
@@ -865,36 +857,34 @@ static int ossltest_aes128_cbc_hmac_sha1_ctrl(EVP_CIPHER_CTX *ctx, int type,
     case EVP_CTRL_AEAD_SET_MAC_KEY:
         return 1;
 
-    case EVP_CTRL_AEAD_TLS1_AAD:
-        {
-            unsigned char *p = ptr;
-            unsigned int len;
+    case EVP_CTRL_AEAD_TLS1_AAD: {
+        unsigned char *p = ptr;
+        unsigned int len;
 
-            if (arg != EVP_AEAD_TLS1_AAD_LEN)
-                return -1;
+        if (arg != EVP_AEAD_TLS1_AAD_LEN)
+            return -1;
 
-            len = p[arg - 2] << 8 | p[arg - 1];
-            key->tls_ver = p[arg - 4] << 8 | p[arg - 3];
+        len = p[arg - 2] << 8 | p[arg - 1];
+        key->tls_ver = p[arg - 4] << 8 | p[arg - 3];
 
-            if (EVP_CIPHER_CTX_is_encrypting(ctx)) {
-                key->payload_length = len;
-                if (key->tls_ver >= TLS1_1_VERSION) {
-                    if (len < AES_BLOCK_SIZE)
-                        return 0;
-                    len -= AES_BLOCK_SIZE;
-                    p[arg - 2] = len >> 8;
-                    p[arg - 1] = len;
-                }
-
-                return (int)(((len + SHA_DIGEST_LENGTH +
-                               AES_BLOCK_SIZE) & -AES_BLOCK_SIZE)
-                             - len);
-            } else {
-                key->payload_length = arg;
-
-                return SHA_DIGEST_LENGTH;
+        if (EVP_CIPHER_CTX_is_encrypting(ctx)) {
+            key->payload_length = len;
+            if (key->tls_ver >= TLS1_1_VERSION) {
+                if (len < AES_BLOCK_SIZE)
+                    return 0;
+                len -= AES_BLOCK_SIZE;
+                p[arg - 2] = len >> 8;
+                p[arg - 1] = len;
             }
+
+            return (int)(((len + SHA_DIGEST_LENGTH + AES_BLOCK_SIZE) & -AES_BLOCK_SIZE)
+                - len);
+        } else {
+            key->payload_length = arg;
+
+            return SHA_DIGEST_LENGTH;
         }
+    }
     default:
         return -1;
     }
