@@ -1,5 +1,5 @@
 /*
- * Copyright 2022-2024 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2022-2025 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -116,6 +116,7 @@ typedef struct quic_channel_args_st {
     QUIC_LCIDM *lcidm;
     /* SRTM to register SRTs with. */
     QUIC_SRTM *srtm;
+    OSSL_QRX *qrx;
 
     int is_server;
     SSL *tls;
@@ -123,6 +124,8 @@ typedef struct quic_channel_args_st {
     /* Whether to use qlog. */
     int use_qlog;
 
+    int is_tserver_ch;
+
     /* Title to use for the qlog session, or NULL. */
     const char *qlog_title;
 } QUIC_CHANNEL_ARGS;
@@ -175,7 +178,9 @@ typedef struct quic_terminate_cause_st {
  *
  * Only QUIC_PORT should use this function.
  */
-QUIC_CHANNEL *ossl_quic_channel_new(const QUIC_CHANNEL_ARGS *args);
+QUIC_CHANNEL *ossl_quic_channel_alloc(const QUIC_CHANNEL_ARGS *args);
+int ossl_quic_channel_init(QUIC_CHANNEL *ch);
+void ossl_quic_channel_bind_qrx(QUIC_CHANNEL *tserver_ch, OSSL_QRX *qrx);
 
 /* No-op if ch is NULL. */
 void ossl_quic_channel_free(QUIC_CHANNEL *ch);
@@ -208,6 +213,13 @@ int ossl_quic_channel_start(QUIC_CHANNEL *ch);
 void ossl_quic_channel_local_close(QUIC_CHANNEL *ch, uint64_t app_error_code,
     const char *app_reason);
 
+/**
+ * @brief schedules a NEW_TOKEN frame for sending on the channel
+ */
+int ossl_quic_channel_schedule_new_token(QUIC_CHANNEL *ch,
+    const unsigned char *token,
+    size_t token_len);
+
 /*
  * Called when the handshake is confirmed.
  */
@@ -286,6 +298,8 @@ void ossl_quic_channel_on_stateless_reset(QUIC_CHANNEL *ch);
 
 void ossl_quic_channel_inject(QUIC_CHANNEL *ch, QUIC_URXE *e);
 
+void ossl_quic_channel_inject_pkt(QUIC_CHANNEL *ch, OSSL_QRX_PKT *qpkt);
+
 /*
  * Queries and Accessors
  * =====================
@@ -300,6 +314,12 @@ QUIC_STREAM_MAP *ossl_quic_channel_get_qsm(QUIC_CHANNEL *ch);
 /* Gets the statistics manager used with the channel. */
 OSSL_STATM *ossl_quic_channel_get_statm(QUIC_CHANNEL *ch);
 
+/* Gets the TLS handshake layer used with the channel. */
+SSL *ossl_quic_channel_get0_tls(QUIC_CHANNEL *ch);
+
+/* Gets the channels short header connection id length */
+size_t ossl_quic_channel_get_short_header_conn_id_len(QUIC_CHANNEL *ch);
+
 /*
  * Gets/sets the current peer address. Generally this should be used before
  * starting a channel in client mode.
@@ -444,6 +464,10 @@ uint64_t ossl_quic_channel_get_max_idle_timeout_peer_request(const QUIC_CHANNEL
 /* Get the idle timeout actually negotiated. */
 uint64_t ossl_quic_channel_get_max_idle_timeout_actual(const QUIC_CHANNEL *ch);
 
+int ossl_quic_bind_channel(QUIC_CHANNEL *ch, const BIO_ADDR *peer,
+    const QUIC_CONN_ID *scid, const QUIC_CONN_ID *dcid,
+    const QUIC_CONN_ID *odcid);
+
 #endif
 
 #endif
