@@ -1,5 +1,5 @@
 /*
- * Copyright 2022-2024 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2022-2025 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -12,13 +12,41 @@
 
 #include <openssl/ssl.h>
 #include <openssl/bio.h>
+#include "internal/refcount.h"
 #include "internal/quic_record_rx.h" /* OSSL_QRX */
 #include "internal/quic_ackm.h" /* OSSL_ACKM */
 #include "internal/quic_channel.h" /* QUIC_CHANNEL */
+#include "internal/quic_predef.h"
 
 #ifndef OPENSSL_NO_QUIC
 
 __owur SSL *ossl_quic_new(SSL_CTX *ctx);
+__owur SSL *ossl_quic_new_listener(SSL_CTX *ctx, uint64_t flags);
+__owur SSL *ossl_quic_new_listener_from(SSL *ssl, uint64_t flags);
+__owur SSL *ossl_quic_new_from_listener(SSL *ssl, uint64_t flags);
+__owur SSL *ossl_quic_new_domain(SSL_CTX *ctx, uint64_t flags);
+
+/*
+ * Datatype returned from ossl_quic_get_peer_token
+ */
+typedef struct quic_token_st {
+    CRYPTO_REF_COUNT references;
+    uint8_t *hashkey;
+    size_t hashkey_len;
+    uint8_t *token;
+    size_t token_len;
+} QUIC_TOKEN;
+
+SSL_TOKEN_STORE *ossl_quic_new_token_store(void);
+void ossl_quic_free_token_store(SSL_TOKEN_STORE *hdl);
+SSL_TOKEN_STORE *ossl_quic_get0_token_store(SSL_CTX *ctx);
+int ossl_quic_set1_token_store(SSL_CTX *ctx, SSL_TOKEN_STORE *hdl);
+int ossl_quic_set_peer_token(SSL_CTX *ctx, BIO_ADDR *peer,
+    const uint8_t *token, size_t token_len);
+int ossl_quic_get_peer_token(SSL_CTX *ctx, BIO_ADDR *peer,
+    QUIC_TOKEN **token);
+void ossl_quic_free_peer_token(QUIC_TOKEN *token);
+
 __owur int ossl_quic_init(SSL *s);
 void ossl_quic_deinit(SSL *s);
 void ossl_quic_free(SSL *s);
@@ -43,12 +71,9 @@ __owur int ossl_quic_num_ciphers(void);
 __owur const SSL_CIPHER *ossl_quic_get_cipher(unsigned int u);
 int ossl_quic_renegotiate_check(SSL *ssl, int initok);
 
-typedef struct quic_conn_st QUIC_CONNECTION;
-typedef struct quic_xso_st QUIC_XSO;
-
 int ossl_quic_do_handshake(SSL *s);
-void ossl_quic_set_connect_state(SSL *s);
-void ossl_quic_set_accept_state(SSL *s);
+int ossl_quic_set_connect_state(SSL *s, int raiseerrs);
+int ossl_quic_set_accept_state(SSL *s, int raiseerrs);
 
 __owur int ossl_quic_has_pending(const SSL *s);
 __owur int ossl_quic_handle_events(SSL *s);
@@ -75,6 +100,9 @@ __owur int ossl_quic_conn_set_initial_peer_addr(SSL *s,
     const BIO_ADDR *peer_addr);
 __owur SSL *ossl_quic_conn_stream_new(SSL *s, uint64_t flags);
 __owur SSL *ossl_quic_get0_connection(SSL *s);
+__owur SSL *ossl_quic_get0_listener(SSL *s);
+__owur SSL *ossl_quic_get0_domain(SSL *s);
+__owur int ossl_quic_get_domain_flags(const SSL *s, uint64_t *domain_flags);
 __owur int ossl_quic_get_stream_type(SSL *s);
 __owur uint64_t ossl_quic_get_stream_id(SSL *s);
 __owur int ossl_quic_is_stream_local(SSL *s);
@@ -89,6 +117,9 @@ __owur int ossl_quic_get_value_uint(SSL *s, uint32_t class_, uint32_t id,
     uint64_t *value);
 __owur int ossl_quic_set_value_uint(SSL *s, uint32_t class_, uint32_t id,
     uint64_t value);
+__owur SSL *ossl_quic_accept_connection(SSL *ssl, uint64_t flags);
+__owur size_t ossl_quic_get_accept_connection_queue_len(SSL *ssl);
+__owur int ossl_quic_listen(SSL *ssl);
 
 __owur int ossl_quic_stream_reset(SSL *ssl,
     const SSL_STREAM_RESET_ARGS *args,
@@ -116,7 +147,7 @@ __owur int ossl_quic_set_write_buffer_size(SSL *s, size_t size);
  * overridden at any time, expect strange results if you change it after
  * connecting.
  */
-int ossl_quic_conn_set_override_now_cb(SSL *s,
+int ossl_quic_set_override_now_cb(SSL *s,
     OSSL_TIME (*now_cb)(void *arg),
     void *now_cb_arg);
 
@@ -145,6 +176,9 @@ int ossl_quic_set_diag_title(SSL_CTX *ctx, const char *title);
 /* APIs used by the polling infrastructure */
 int ossl_quic_conn_poll_events(SSL *ssl, uint64_t events, int do_tick,
     uint64_t *revents);
+int ossl_quic_get_notifier_fd(SSL *ssl);
+void ossl_quic_enter_blocking_section(SSL *ssl, QUIC_REACTOR_WAIT_CTX *wctx);
+void ossl_quic_leave_blocking_section(SSL *ssl, QUIC_REACTOR_WAIT_CTX *wctx);
 
 #endif
 
