@@ -7,30 +7,30 @@
  * https://www.openssl.org/source/license.html
  */
 #ifndef OSSL_INTERNAL_REFCOUNT_H
-# define OSSL_INTERNAL_REFCOUNT_H
-# pragma once
+#define OSSL_INTERNAL_REFCOUNT_H
+#pragma once
 
-# include <openssl/e_os2.h>
-# include <openssl/trace.h>
-# include <openssl/err.h>
+#include <openssl/e_os2.h>
+#include <openssl/trace.h>
+#include <openssl/err.h>
 
-# if defined(OPENSSL_THREADS) && !defined(OPENSSL_DEV_NO_ATOMICS)
-#  if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L \
-      && !defined(__STDC_NO_ATOMICS__)
-#   include <stdatomic.h>
-#   define HAVE_C11_ATOMICS
-#  endif
+#if defined(OPENSSL_THREADS) && !defined(OPENSSL_DEV_NO_ATOMICS)
+#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L \
+    && !defined(__STDC_NO_ATOMICS__)
+#include <stdatomic.h>
+#define HAVE_C11_ATOMICS
+#endif
 
-#  if defined(HAVE_C11_ATOMICS) && defined(ATOMIC_INT_LOCK_FREE) \
-      && ATOMIC_INT_LOCK_FREE > 0
+#if defined(HAVE_C11_ATOMICS) && defined(ATOMIC_INT_LOCK_FREE) \
+    && ATOMIC_INT_LOCK_FREE > 0
 
-#   define HAVE_ATOMICS 1
+#define HAVE_ATOMICS 1
 
-#   if defined(__has_feature)
-#    if __has_feature(thread_sanitizer)
-#     define OSSL_TSAN_BUILD
-#    endif
-#   endif
+#if defined(__has_feature)
+#if __has_feature(thread_sanitizer)
+#define OSSL_TSAN_BUILD
+#endif
+#endif
 
 typedef struct {
     _Atomic int val;
@@ -54,17 +54,17 @@ static inline int CRYPTO_UP_REF(CRYPTO_REF_COUNT *refcnt, int *ret)
  */
 static inline int CRYPTO_DOWN_REF(CRYPTO_REF_COUNT *refcnt, int *ret)
 {
-#   ifdef OSSL_TSAN_BUILD
+#ifdef OSSL_TSAN_BUILD
     /*
      * TSAN requires acq_rel as it indicates a false positive error when
      * the object that contains the refcount is freed otherwise.
      */
     *ret = atomic_fetch_sub_explicit(&refcnt->val, 1, memory_order_acq_rel) - 1;
-#   else
+#else
     *ret = atomic_fetch_sub_explicit(&refcnt->val, 1, memory_order_release) - 1;
     if (*ret == 0)
         atomic_thread_fence(memory_order_acquire);
-#   endif
+#endif
     return 1;
 }
 
@@ -74,9 +74,9 @@ static inline int CRYPTO_GET_REF(CRYPTO_REF_COUNT *refcnt, int *ret)
     return 1;
 }
 
-#  elif defined(__GNUC__) && defined(__ATOMIC_RELAXED) && __GCC_ATOMIC_INT_LOCK_FREE > 0
+#elif defined(__GNUC__) && defined(__ATOMIC_RELAXED) && __GCC_ATOMIC_INT_LOCK_FREE > 0
 
-#   define HAVE_ATOMICS 1
+#define HAVE_ATOMICS 1
 
 typedef struct {
     int val;
@@ -102,8 +102,8 @@ static __inline__ int CRYPTO_GET_REF(CRYPTO_REF_COUNT *refcnt, int *ret)
     return 1;
 }
 
-#  elif defined(__ICL) && defined(_WIN32)
-#   define HAVE_ATOMICS 1
+#elif defined(__ICL) && defined(_WIN32)
+#define HAVE_ATOMICS 1
 
 typedef struct {
     volatile int val;
@@ -127,19 +127,19 @@ static __inline int CRYPTO_GET_REF(CRYPTO_REF_COUNT *refcnt, int *ret)
     return 1;
 }
 
-#  elif defined(_MSC_VER) && _MSC_VER>=1200
+#elif defined(_MSC_VER) && _MSC_VER >= 1200
 
-#   define HAVE_ATOMICS 1
+#define HAVE_ATOMICS 1
 
 typedef struct {
     volatile int val;
 } CRYPTO_REF_COUNT;
 
-#   if (defined(_M_ARM) && _M_ARM>=7 && !defined(_WIN32_WCE)) || defined(_M_ARM64)
-#    include <intrin.h>
-#    if defined(_M_ARM64) && !defined(_ARM_BARRIER_ISH)
-#     define _ARM_BARRIER_ISH _ARM64_BARRIER_ISH
-#    endif
+#if (defined(_M_ARM) && _M_ARM >= 7 && !defined(_WIN32_WCE)) || defined(_M_ARM64)
+#include <intrin.h>
+#if defined(_M_ARM64) && !defined(_ARM_BARRIER_ISH)
+#define _ARM_BARRIER_ISH _ARM64_BARRIER_ISH
+#endif
 
 static __inline int CRYPTO_UP_REF(CRYPTO_REF_COUNT *refcnt, int *ret)
 {
@@ -159,18 +159,18 @@ static __inline int CRYPTO_GET_REF(CRYPTO_REF_COUNT *refcnt, int *ret)
     return 1;
 }
 
-#   else
-#    if !defined(_WIN32_WCE)
-#     pragma intrinsic(_InterlockedExchangeAdd)
-#    else
-#     if _WIN32_WCE >= 0x600
-       extern long __cdecl _InterlockedExchangeAdd(long volatile*, long);
-#     else
-       /* under Windows CE we still have old-style Interlocked* functions */
-       extern long __cdecl InterlockedExchangeAdd(long volatile*, long);
-#      define _InterlockedExchangeAdd InterlockedExchangeAdd
-#     endif
-#    endif
+#else
+#if !defined(_WIN32_WCE)
+#pragma intrinsic(_InterlockedExchangeAdd)
+#else
+#if _WIN32_WCE >= 0x600
+extern long __cdecl _InterlockedExchangeAdd(long volatile *, long);
+#else
+/* under Windows CE we still have old-style Interlocked* functions */
+extern long __cdecl InterlockedExchangeAdd(long volatile *, long);
+#define _InterlockedExchangeAdd InterlockedExchangeAdd
+#endif
+#endif
 
 static __inline int CRYPTO_UP_REF(CRYPTO_REF_COUNT *refcnt, int *ret)
 {
@@ -190,46 +190,46 @@ static __inline int CRYPTO_GET_REF(CRYPTO_REF_COUNT *refcnt, int *ret)
     return 1;
 }
 
-#   endif
+#endif
 
-#  endif
-# endif  /* !OPENSSL_DEV_NO_ATOMICS */
+#endif
+#endif /* !OPENSSL_DEV_NO_ATOMICS */
 
 /*
  * All the refcounting implementations above define HAVE_ATOMICS, so if it's
  * still undefined here (such as when OPENSSL_DEV_NO_ATOMICS is defined), it
  * means we need to implement a fallback.  This fallback uses locks.
  */
-# ifndef HAVE_ATOMICS
+#ifndef HAVE_ATOMICS
 
 typedef struct {
     int val;
-#  ifdef OPENSSL_THREADS
+#ifdef OPENSSL_THREADS
     CRYPTO_RWLOCK *lock;
-#  endif
+#endif
 } CRYPTO_REF_COUNT;
 
-#  ifdef OPENSSL_THREADS
+#ifdef OPENSSL_THREADS
 
 static ossl_unused ossl_inline int CRYPTO_UP_REF(CRYPTO_REF_COUNT *refcnt,
-                                                 int *ret)
+    int *ret)
 {
     return CRYPTO_atomic_add(&refcnt->val, 1, ret, refcnt->lock);
 }
 
 static ossl_unused ossl_inline int CRYPTO_DOWN_REF(CRYPTO_REF_COUNT *refcnt,
-                                                   int *ret)
+    int *ret)
 {
     return CRYPTO_atomic_add(&refcnt->val, -1, ret, refcnt->lock);
 }
 
 static ossl_unused ossl_inline int CRYPTO_GET_REF(CRYPTO_REF_COUNT *refcnt,
-                                                   int *ret)
+    int *ret)
 {
     return CRYPTO_atomic_load_int(&refcnt->val, ret, refcnt->lock);
 }
 
-#   define CRYPTO_NEW_FREE_DEFINED  1
+#define CRYPTO_NEW_FREE_DEFINED 1
 static ossl_unused ossl_inline int CRYPTO_NEW_REF(CRYPTO_REF_COUNT *refcnt, int n)
 {
     refcnt->val = n;
@@ -241,16 +241,16 @@ static ossl_unused ossl_inline int CRYPTO_NEW_REF(CRYPTO_REF_COUNT *refcnt, int
     return 1;
 }
 
-static ossl_unused ossl_inline void CRYPTO_FREE_REF(CRYPTO_REF_COUNT *refcnt)                                  \
+static ossl_unused ossl_inline void CRYPTO_FREE_REF(CRYPTO_REF_COUNT *refcnt)
 {
     if (refcnt != NULL)
         CRYPTO_THREAD_lock_free(refcnt->lock);
 }
 
-#  else     /* OPENSSL_THREADS */
+#else /* OPENSSL_THREADS */
 
 static ossl_unused ossl_inline int CRYPTO_UP_REF(CRYPTO_REF_COUNT *refcnt,
-                                                 int *ret)
+    int *ret)
 {
     refcnt->val++;
     *ret = refcnt->val;
@@ -258,7 +258,7 @@ static ossl_unused ossl_inline int CRYPTO_UP_REF(CRYPTO_REF_COUNT *refcnt,
 }
 
 static ossl_unused ossl_inline int CRYPTO_DOWN_REF(CRYPTO_REF_COUNT *refcnt,
-                                                   int *ret)
+    int *ret)
 {
     refcnt->val--;
     *ret = refcnt->val;
@@ -266,38 +266,38 @@ static ossl_unused ossl_inline int CRYPTO_DOWN_REF(CRYPTO_REF_COUNT *refcnt,
 }
 
 static ossl_unused ossl_inline int CRYPTO_GET_REF(CRYPTO_REF_COUNT *refcnt,
-                                                   int *ret)
+    int *ret)
 {
     *ret = refcnt->val;
     return 1;
 }
 
-#  endif    /* OPENSSL_THREADS */
-# endif
+#endif /* OPENSSL_THREADS */
+#endif
 
-# ifndef CRYPTO_NEW_FREE_DEFINED
+#ifndef CRYPTO_NEW_FREE_DEFINED
 static ossl_unused ossl_inline int CRYPTO_NEW_REF(CRYPTO_REF_COUNT *refcnt, int n)
 {
     refcnt->val = n;
     return 1;
 }
 
-static ossl_unused ossl_inline void CRYPTO_FREE_REF(CRYPTO_REF_COUNT *refcnt)                                  \
+static ossl_unused ossl_inline void CRYPTO_FREE_REF(CRYPTO_REF_COUNT *refcnt)
 {
 }
-# endif /* CRYPTO_NEW_FREE_DEFINED */
+#endif /* CRYPTO_NEW_FREE_DEFINED */
 #undef CRYPTO_NEW_FREE_DEFINED
 
-# if !defined(NDEBUG) && !defined(OPENSSL_NO_STDIO)
-#  define REF_ASSERT_ISNT(test) \
+#if !defined(NDEBUG) && !defined(OPENSSL_NO_STDIO)
+#define REF_ASSERT_ISNT(test) \
     (void)((test) ? (OPENSSL_die("refcount error", __FILE__, __LINE__), 1) : 0)
-# else
-#  define REF_ASSERT_ISNT(i)
-# endif
+#else
+#define REF_ASSERT_ISNT(i)
+#endif
 
-# define REF_PRINT_EX(text, count, object) \
+#define REF_PRINT_EX(text, count, object) \
     OSSL_TRACE3(REF_COUNT, "%p:%4d:%s\n", (object), (count), (text));
-# define REF_PRINT_COUNT(text, val, object) \
+#define REF_PRINT_COUNT(text, val, object) \
     REF_PRINT_EX(text, val, (void *)object)
 
 #endif
