@@ -17,6 +17,7 @@
 #include <openssl/proverr.h>
 #include <openssl/indicator.h>
 #include "internal/cryptlib.h"
+#include "internal/provider.h"
 #include "prov/implementations.h"
 #include "prov/names.h"
 #include "prov/provider_ctx.h"
@@ -43,7 +44,7 @@ static OSSL_FUNC_provider_query_operation_fn fips_query;
 static OSSL_FUNC_provider_query_operation_fn fips_query_internal;
 static OSSL_FUNC_provider_random_bytes_fn fips_random_bytes;
 
-#define ALGC(NAMES, FUNC, CHECK)                \
+#define ALGC(NAMES, FUNC, CHECK) \
     { { NAMES, FIPS_DEFAULT_PROPERTIES, FUNC }, CHECK }
 #define ALG(NAMES, FUNC) ALGC(NAMES, FUNC, NULL)
 
@@ -64,6 +65,7 @@ static OSSL_FUNC_core_vset_error_fn *c_vset_error;
 static OSSL_FUNC_core_set_error_mark_fn *c_set_error_mark;
 static OSSL_FUNC_core_clear_last_error_mark_fn *c_clear_last_error_mark;
 static OSSL_FUNC_core_pop_error_to_mark_fn *c_pop_error_to_mark;
+static OSSL_FUNC_core_count_to_mark_fn *c_count_to_mark;
 static OSSL_FUNC_CRYPTO_malloc_fn *c_CRYPTO_malloc;
 static OSSL_FUNC_CRYPTO_zalloc_fn *c_CRYPTO_zalloc;
 static OSSL_FUNC_CRYPTO_free_fn *c_CRYPTO_free;
@@ -123,7 +125,7 @@ void ossl_fips_prov_ossl_ctx_free(void *fgbl)
 }
 
 static int fips_random_bytes(ossl_unused void *vprov, int which,
-                             void *buf, size_t n, unsigned int strength)
+    void *buf, size_t n, unsigned int strength)
 {
     OSSL_LIB_CTX *libctx;
     PROV_CTX *prov = (PROV_CTX *)vprov;
@@ -145,21 +147,21 @@ static int fips_get_params_from_core(FIPS_GLOBAL *fgbl)
 {
     OSSL_PARAM core_params[32], *p = core_params;
 
-#define OSSL_FIPS_PARAM(structname, paramname)                                 \
-    *p++ = OSSL_PARAM_construct_utf8_ptr(                                      \
-            paramname, (char **)&fgbl->selftest_params.structname,             \
-            sizeof(fgbl->selftest_params.structname));
+#define OSSL_FIPS_PARAM(structname, paramname)                 \
+    *p++ = OSSL_PARAM_construct_utf8_ptr(                      \
+        paramname, (char **)&fgbl->selftest_params.structname, \
+        sizeof(fgbl->selftest_params.structname));
 
 /* Parameters required for self testing */
 #include "fips_selftest_params.inc"
 #undef OSSL_FIPS_PARAM
 
 /* FIPS indicator options can be enabled or disabled independently */
-#define OSSL_FIPS_PARAM(structname, paramname, initvalue)                      \
-    *p++ = OSSL_PARAM_construct_utf8_ptr(                                      \
-            OSSL_PROV_PARAM_##paramname,                                       \
-            (char **)&fgbl->fips_##structname.option,                          \
-            sizeof(fgbl->fips_##structname.option));
+#define OSSL_FIPS_PARAM(structname, paramname, initvalue) \
+    *p++ = OSSL_PARAM_construct_utf8_ptr(                 \
+        OSSL_PROV_PARAM_##paramname,                      \
+        (char **)&fgbl->fips_##structname.option,         \
+        sizeof(fgbl->fips_##structname.option));
 #include "fips_indicator_params.inc"
 #undef OSSL_FIPS_PARAM
 
@@ -183,7 +185,7 @@ static const OSSL_PARAM *fips_gettable_params(void *provctx)
         OSSL_PARAM_DEFN(OSSL_PROV_PARAM_STATUS, OSSL_PARAM_INTEGER, NULL, 0),
 
 #define OSSL_FIPS_PARAM(structname, paramname, initvalue) \
-        OSSL_PARAM_DEFN(OSSL_PROV_PARAM_##paramname, OSSL_PARAM_INTEGER, NULL, 0),
+    OSSL_PARAM_DEFN(OSSL_PROV_PARAM_##paramname, OSSL_PARAM_INTEGER, NULL, 0),
 #include "fips_indicator_params.inc"
 #undef OSSL_FIPS_PARAM
 
@@ -196,7 +198,7 @@ static int fips_get_params(void *provctx, OSSL_PARAM params[])
 {
     OSSL_PARAM *p;
     FIPS_GLOBAL *fgbl = ossl_lib_ctx_get_data(ossl_prov_ctx_get0_libctx(provctx),
-                                              OSSL_LIB_CTX_FIPS_PROV_INDEX);
+        OSSL_LIB_CTX_FIPS_PROV_INDEX);
 
     p = OSSL_PARAM_locate(params, OSSL_PROV_PARAM_NAME);
     if (p != NULL && !OSSL_PARAM_set_utf8_ptr(p, FIPS_VENDOR))
@@ -211,9 +213,9 @@ static int fips_get_params(void *provctx, OSSL_PARAM params[])
     if (p != NULL && !OSSL_PARAM_set_int(p, ossl_prov_is_running()))
         return 0;
 
-#define OSSL_FIPS_PARAM(structname, paramname, initvalue)                      \
-    p = OSSL_PARAM_locate(params, OSSL_PROV_PARAM_##paramname);                \
-    if (p != NULL && !OSSL_PARAM_set_int(p, fgbl->fips_##structname.enabled))  \
+#define OSSL_FIPS_PARAM(structname, paramname, initvalue)                     \
+    p = OSSL_PARAM_locate(params, OSSL_PROV_PARAM_##paramname);               \
+    if (p != NULL && !OSSL_PARAM_set_int(p, fgbl->fips_##structname.enabled)) \
         return 0;
 #include "fips_indicator_params.inc"
 #undef OSSL_FIPS_PARAM
@@ -223,12 +225,11 @@ static int fips_get_params(void *provctx, OSSL_PARAM params[])
 
 static void set_self_test_cb(FIPS_GLOBAL *fgbl)
 {
-    const OSSL_CORE_HANDLE *handle =
-        FIPS_get_core_handle(fgbl->selftest_params.libctx);
+    const OSSL_CORE_HANDLE *handle = FIPS_get_core_handle(fgbl->selftest_params.libctx);
 
     if (c_stcbfn != NULL && c_get_libctx != NULL) {
         c_stcbfn(c_get_libctx(handle), &fgbl->selftest_params.cb,
-                              &fgbl->selftest_params.cb_arg);
+            &fgbl->selftest_params.cb_arg);
     } else {
         fgbl->selftest_params.cb = NULL;
         fgbl->selftest_params.cb_arg = NULL;
@@ -238,7 +239,7 @@ static void set_self_test_cb(FIPS_GLOBAL *fgbl)
 static int fips_self_test(void *provctx)
 {
     FIPS_GLOBAL *fgbl = ossl_lib_ctx_get_data(ossl_prov_ctx_get0_libctx(provctx),
-                                              OSSL_LIB_CTX_FIPS_PROV_INDEX);
+        OSSL_LIB_CTX_FIPS_PROV_INDEX);
 
     set_self_test_cb(fgbl);
     return SELF_TEST_post(&fgbl->selftest_params, 1) ? 1 : 0;
@@ -276,9 +277,9 @@ static const OSSL_ALGORITHM fips_digests[] = {
     { PROV_NAMES_SHA2_384, FIPS_DEFAULT_PROPERTIES, ossl_sha384_functions },
     { PROV_NAMES_SHA2_512, FIPS_DEFAULT_PROPERTIES, ossl_sha512_functions },
     { PROV_NAMES_SHA2_512_224, FIPS_DEFAULT_PROPERTIES,
-      ossl_sha512_224_functions },
+        ossl_sha512_224_functions },
     { PROV_NAMES_SHA2_512_256, FIPS_DEFAULT_PROPERTIES,
-      ossl_sha512_256_functions },
+        ossl_sha512_256_functions },
 
     /* We agree with NIST here, so one name only */
     { PROV_NAMES_SHA3_224, FIPS_DEFAULT_PROPERTIES, ossl_sha3_224_functions },
@@ -294,9 +295,9 @@ static const OSSL_ALGORITHM fips_digests[] = {
      * KMAC128 and KMAC256.
      */
     { PROV_NAMES_KECCAK_KMAC_128, FIPS_DEFAULT_PROPERTIES,
-      ossl_keccak_kmac_128_functions },
+        ossl_keccak_kmac_128_functions },
     { PROV_NAMES_KECCAK_KMAC_256, FIPS_DEFAULT_PROPERTIES,
-      ossl_keccak_kmac_256_functions },
+        ossl_keccak_kmac_256_functions },
     { NULL, NULL, NULL }
 };
 
@@ -347,17 +348,17 @@ static const OSSL_ALGORITHM_CAPABLE fips_ciphers[] = {
     ALG(PROV_NAMES_AES_192_WRAP_PAD_INV, ossl_aes192wrappadinv_functions),
     ALG(PROV_NAMES_AES_128_WRAP_PAD_INV, ossl_aes128wrappadinv_functions),
     ALGC(PROV_NAMES_AES_128_CBC_HMAC_SHA1, ossl_aes128cbc_hmac_sha1_functions,
-         ossl_cipher_capable_aes_cbc_hmac_sha1),
+        ossl_cipher_capable_aes_cbc_hmac_sha1),
     ALGC(PROV_NAMES_AES_256_CBC_HMAC_SHA1, ossl_aes256cbc_hmac_sha1_functions,
-         ossl_cipher_capable_aes_cbc_hmac_sha1),
+        ossl_cipher_capable_aes_cbc_hmac_sha1),
     ALGC(PROV_NAMES_AES_128_CBC_HMAC_SHA256, ossl_aes128cbc_hmac_sha256_functions,
-         ossl_cipher_capable_aes_cbc_hmac_sha256),
+        ossl_cipher_capable_aes_cbc_hmac_sha256),
     ALGC(PROV_NAMES_AES_256_CBC_HMAC_SHA256, ossl_aes256cbc_hmac_sha256_functions,
-         ossl_cipher_capable_aes_cbc_hmac_sha256),
+        ossl_cipher_capable_aes_cbc_hmac_sha256),
 #ifndef OPENSSL_NO_DES
     ALG(PROV_NAMES_DES_EDE3_ECB, ossl_tdes_ede3_ecb_functions),
     ALG(PROV_NAMES_DES_EDE3_CBC, ossl_tdes_ede3_cbc_functions),
-#endif  /* OPENSSL_NO_DES */
+#endif /* OPENSSL_NO_DES */
     { { NULL, NULL, NULL }, NULL }
 };
 static OSSL_ALGORITHM exported_fips_ciphers[OSSL_NELEM(fips_ciphers)];
@@ -386,16 +387,16 @@ static const OSSL_ALGORITHM fips_macs_internal[] = {
 static const OSSL_ALGORITHM fips_kdfs[] = {
     { PROV_NAMES_HKDF, FIPS_DEFAULT_PROPERTIES, ossl_kdf_hkdf_functions },
     { PROV_NAMES_TLS1_3_KDF, FIPS_DEFAULT_PROPERTIES,
-      ossl_kdf_tls1_3_kdf_functions },
+        ossl_kdf_tls1_3_kdf_functions },
     { PROV_NAMES_SSKDF, FIPS_DEFAULT_PROPERTIES, ossl_kdf_sskdf_functions },
     { PROV_NAMES_PBKDF2, FIPS_DEFAULT_PROPERTIES, ossl_kdf_pbkdf2_functions },
     { PROV_NAMES_SSHKDF, FIPS_DEFAULT_PROPERTIES, ossl_kdf_sshkdf_functions },
     { PROV_NAMES_X963KDF, FIPS_DEFAULT_PROPERTIES,
-      ossl_kdf_x963_kdf_functions },
+        ossl_kdf_x963_kdf_functions },
     { PROV_NAMES_X942KDF_ASN1, FIPS_DEFAULT_PROPERTIES,
-      ossl_kdf_x942_kdf_functions },
+        ossl_kdf_x942_kdf_functions },
     { PROV_NAMES_TLS1_PRF, FIPS_DEFAULT_PROPERTIES,
-      ossl_kdf_tls1_prf_functions },
+        ossl_kdf_tls1_prf_functions },
     { PROV_NAMES_KBKDF, FIPS_DEFAULT_PROPERTIES, ossl_kdf_kbkdf_functions },
     { NULL, NULL, NULL }
 };
@@ -418,13 +419,13 @@ static const OSSL_ALGORITHM fips_keyexch[] = {
 #endif
 #ifndef OPENSSL_NO_EC
     { PROV_NAMES_ECDH, FIPS_DEFAULT_PROPERTIES, ossl_ecdh_keyexch_functions },
-# ifndef OPENSSL_NO_ECX
+#ifndef OPENSSL_NO_ECX
     { PROV_NAMES_X25519, FIPS_UNAPPROVED_PROPERTIES, ossl_x25519_keyexch_functions },
     { PROV_NAMES_X448, FIPS_UNAPPROVED_PROPERTIES, ossl_x448_keyexch_functions },
-# endif
+#endif
 #endif
     { PROV_NAMES_TLS1_PRF, FIPS_DEFAULT_PROPERTIES,
-      ossl_kdf_tls1_prf_keyexch_functions },
+        ossl_kdf_tls1_prf_keyexch_functions },
     { PROV_NAMES_HKDF, FIPS_DEFAULT_PROPERTIES, ossl_kdf_hkdf_keyexch_functions },
     { NULL, NULL, NULL }
 };
@@ -444,40 +445,38 @@ static const OSSL_ALGORITHM fips_signature[] = {
 #endif
     { PROV_NAMES_RSA, FIPS_DEFAULT_PROPERTIES, ossl_rsa_signature_functions },
     { PROV_NAMES_RSA_SHA1, FIPS_DEFAULT_PROPERTIES,
-      ossl_rsa_sha1_signature_functions },
+        ossl_rsa_sha1_signature_functions },
     { PROV_NAMES_RSA_SHA224, FIPS_DEFAULT_PROPERTIES,
-      ossl_rsa_sha224_signature_functions },
+        ossl_rsa_sha224_signature_functions },
     { PROV_NAMES_RSA_SHA256, FIPS_DEFAULT_PROPERTIES,
-      ossl_rsa_sha256_signature_functions },
+        ossl_rsa_sha256_signature_functions },
     { PROV_NAMES_RSA_SHA384, FIPS_DEFAULT_PROPERTIES,
-      ossl_rsa_sha384_signature_functions },
+        ossl_rsa_sha384_signature_functions },
     { PROV_NAMES_RSA_SHA512, FIPS_DEFAULT_PROPERTIES,
-      ossl_rsa_sha512_signature_functions },
+        ossl_rsa_sha512_signature_functions },
     { PROV_NAMES_RSA_SHA512_224, FIPS_DEFAULT_PROPERTIES,
-      ossl_rsa_sha512_224_signature_functions },
+        ossl_rsa_sha512_224_signature_functions },
     { PROV_NAMES_RSA_SHA512_256, FIPS_DEFAULT_PROPERTIES,
-      ossl_rsa_sha512_256_signature_functions },
+        ossl_rsa_sha512_256_signature_functions },
     { PROV_NAMES_RSA_SHA3_224, FIPS_DEFAULT_PROPERTIES,
-      ossl_rsa_sha3_224_signature_functions },
+        ossl_rsa_sha3_224_signature_functions },
     { PROV_NAMES_RSA_SHA3_256, FIPS_DEFAULT_PROPERTIES,
-      ossl_rsa_sha3_256_signature_functions },
+        ossl_rsa_sha3_256_signature_functions },
     { PROV_NAMES_RSA_SHA3_384, FIPS_DEFAULT_PROPERTIES,
-      ossl_rsa_sha3_384_signature_functions },
+        ossl_rsa_sha3_384_signature_functions },
     { PROV_NAMES_RSA_SHA3_512, FIPS_DEFAULT_PROPERTIES,
-      ossl_rsa_sha3_512_signature_functions },
+        ossl_rsa_sha3_512_signature_functions },
 #ifndef OPENSSL_NO_EC
-# ifndef OPENSSL_NO_ECX
+#ifndef OPENSSL_NO_ECX
     { PROV_NAMES_ED25519, FIPS_DEFAULT_PROPERTIES,
-      ossl_ed25519_signature_functions },
+        ossl_ed25519_signature_functions },
     { PROV_NAMES_ED25519ph, FIPS_DEFAULT_PROPERTIES,
-      ossl_ed25519ph_signature_functions },
-    { PROV_NAMES_ED25519ctx, FIPS_DEFAULT_PROPERTIES,
-      ossl_ed25519ctx_signature_functions },
+        ossl_ed25519ph_signature_functions },
     { PROV_NAMES_ED448, FIPS_DEFAULT_PROPERTIES,
-      ossl_ed448_signature_functions },
+        ossl_ed448_signature_functions },
     { PROV_NAMES_ED448ph, FIPS_DEFAULT_PROPERTIES,
-      ossl_ed448ph_signature_functions },
-# endif
+        ossl_ed448ph_signature_functions },
+#endif
     { PROV_NAMES_ECDSA, FIPS_DEFAULT_PROPERTIES, ossl_ecdsa_signature_functions },
     { PROV_NAMES_ECDSA_SHA1, FIPS_DEFAULT_PROPERTIES, ossl_ecdsa_sha1_signature_functions },
     { PROV_NAMES_ECDSA_SHA224, FIPS_DEFAULT_PROPERTIES, ossl_ecdsa_sha224_signature_functions },
@@ -495,36 +494,36 @@ static const OSSL_ALGORITHM fips_signature[] = {
     { PROV_NAMES_ML_DSA_87, FIPS_DEFAULT_PROPERTIES, ossl_ml_dsa_87_signature_functions },
 #endif
     { PROV_NAMES_HMAC, FIPS_DEFAULT_PROPERTIES,
-      ossl_mac_legacy_hmac_signature_functions },
+        ossl_mac_legacy_hmac_signature_functions },
 #ifndef OPENSSL_NO_CMAC
     { PROV_NAMES_CMAC, FIPS_DEFAULT_PROPERTIES,
-      ossl_mac_legacy_cmac_signature_functions },
+        ossl_mac_legacy_cmac_signature_functions },
 #endif
 #ifndef OPENSSL_NO_SLH_DSA
     { PROV_NAMES_SLH_DSA_SHA2_128S, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_sha2_128s_signature_functions, PROV_DESCS_SLH_DSA_SHA2_128S },
+        ossl_slh_dsa_sha2_128s_signature_functions, PROV_DESCS_SLH_DSA_SHA2_128S },
     { PROV_NAMES_SLH_DSA_SHA2_128F, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_sha2_128f_signature_functions, PROV_DESCS_SLH_DSA_SHA2_128F },
+        ossl_slh_dsa_sha2_128f_signature_functions, PROV_DESCS_SLH_DSA_SHA2_128F },
     { PROV_NAMES_SLH_DSA_SHA2_192S, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_sha2_192s_signature_functions, PROV_DESCS_SLH_DSA_SHA2_192S },
+        ossl_slh_dsa_sha2_192s_signature_functions, PROV_DESCS_SLH_DSA_SHA2_192S },
     { PROV_NAMES_SLH_DSA_SHA2_192F, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_sha2_192f_signature_functions, PROV_DESCS_SLH_DSA_SHA2_192F },
+        ossl_slh_dsa_sha2_192f_signature_functions, PROV_DESCS_SLH_DSA_SHA2_192F },
     { PROV_NAMES_SLH_DSA_SHA2_256S, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_sha2_256s_signature_functions, PROV_DESCS_SLH_DSA_SHA2_256S },
+        ossl_slh_dsa_sha2_256s_signature_functions, PROV_DESCS_SLH_DSA_SHA2_256S },
     { PROV_NAMES_SLH_DSA_SHA2_256F, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_sha2_256f_signature_functions, PROV_DESCS_SLH_DSA_SHA2_256F },
+        ossl_slh_dsa_sha2_256f_signature_functions, PROV_DESCS_SLH_DSA_SHA2_256F },
     { PROV_NAMES_SLH_DSA_SHAKE_128S, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_shake_128s_signature_functions, PROV_DESCS_SLH_DSA_SHAKE_128S },
+        ossl_slh_dsa_shake_128s_signature_functions, PROV_DESCS_SLH_DSA_SHAKE_128S },
     { PROV_NAMES_SLH_DSA_SHAKE_128F, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_shake_128f_signature_functions, PROV_DESCS_SLH_DSA_SHAKE_128F },
+        ossl_slh_dsa_shake_128f_signature_functions, PROV_DESCS_SLH_DSA_SHAKE_128F },
     { PROV_NAMES_SLH_DSA_SHAKE_192S, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_shake_192s_signature_functions, PROV_DESCS_SLH_DSA_SHAKE_192S },
+        ossl_slh_dsa_shake_192s_signature_functions, PROV_DESCS_SLH_DSA_SHAKE_192S },
     { PROV_NAMES_SLH_DSA_SHAKE_192F, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_shake_192f_signature_functions, PROV_DESCS_SLH_DSA_SHAKE_192F },
+        ossl_slh_dsa_shake_192f_signature_functions, PROV_DESCS_SLH_DSA_SHAKE_192F },
     { PROV_NAMES_SLH_DSA_SHAKE_256S, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_shake_256s_signature_functions, PROV_DESCS_SLH_DSA_SHAKE_256S },
+        ossl_slh_dsa_shake_256s_signature_functions, PROV_DESCS_SLH_DSA_SHAKE_256S },
     { PROV_NAMES_SLH_DSA_SHAKE_256F, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_shake_256f_signature_functions, PROV_DESCS_SLH_DSA_SHAKE_256F },
+        ossl_slh_dsa_shake_256f_signature_functions, PROV_DESCS_SLH_DSA_SHAKE_256F },
 #endif /* OPENSSL_NO_SLH_DSA */
     { NULL, NULL, NULL }
 };
@@ -540,14 +539,14 @@ static const OSSL_ALGORITHM fips_asym_kem[] = {
     { PROV_NAMES_ML_KEM_512, FIPS_DEFAULT_PROPERTIES, ossl_ml_kem_asym_kem_functions },
     { PROV_NAMES_ML_KEM_768, FIPS_DEFAULT_PROPERTIES, ossl_ml_kem_asym_kem_functions },
     { PROV_NAMES_ML_KEM_1024, FIPS_DEFAULT_PROPERTIES, ossl_ml_kem_asym_kem_functions },
-# if !defined(OPENSSL_NO_ECX)
+#if !defined(OPENSSL_NO_ECX)
     { "X25519MLKEM768", FIPS_DEFAULT_PROPERTIES, ossl_mlx_kem_asym_kem_functions },
     { "X448MLKEM1024", FIPS_DEFAULT_PROPERTIES, ossl_mlx_kem_asym_kem_functions },
-# endif
-# if !defined(OPENSSL_NO_EC)
+#endif
+#if !defined(OPENSSL_NO_EC)
     { "SecP256r1MLKEM768", FIPS_DEFAULT_PROPERTIES, ossl_mlx_kem_asym_kem_functions },
     { "SecP384r1MLKEM1024", FIPS_DEFAULT_PROPERTIES, ossl_mlx_kem_asym_kem_functions },
-# endif
+#endif
 #endif
     { NULL, NULL, NULL }
 };
@@ -555,101 +554,101 @@ static const OSSL_ALGORITHM fips_asym_kem[] = {
 static const OSSL_ALGORITHM fips_keymgmt[] = {
 #ifndef OPENSSL_NO_DH
     { PROV_NAMES_DH, FIPS_DEFAULT_PROPERTIES, ossl_dh_keymgmt_functions,
-      PROV_DESCS_DH },
+        PROV_DESCS_DH },
     { PROV_NAMES_DHX, FIPS_DEFAULT_PROPERTIES, ossl_dhx_keymgmt_functions,
-      PROV_DESCS_DHX },
+        PROV_DESCS_DHX },
 #endif
 #ifndef OPENSSL_NO_DSA
     { PROV_NAMES_DSA, FIPS_DEFAULT_PROPERTIES, ossl_dsa_keymgmt_functions,
-      PROV_DESCS_DSA },
+        PROV_DESCS_DSA },
 #endif
     { PROV_NAMES_RSA, FIPS_DEFAULT_PROPERTIES, ossl_rsa_keymgmt_functions,
-      PROV_DESCS_RSA },
+        PROV_DESCS_RSA },
     { PROV_NAMES_RSA_PSS, FIPS_DEFAULT_PROPERTIES,
-      ossl_rsapss_keymgmt_functions, PROV_DESCS_RSA_PSS },
+        ossl_rsapss_keymgmt_functions, PROV_DESCS_RSA_PSS },
 #ifndef OPENSSL_NO_EC
     { PROV_NAMES_EC, FIPS_DEFAULT_PROPERTIES, ossl_ec_keymgmt_functions,
-      PROV_DESCS_EC },
-# ifndef OPENSSL_NO_ECX
+        PROV_DESCS_EC },
+#ifndef OPENSSL_NO_ECX
     { PROV_NAMES_X25519, FIPS_UNAPPROVED_PROPERTIES, ossl_x25519_keymgmt_functions,
-      PROV_DESCS_X25519 },
+        PROV_DESCS_X25519 },
     { PROV_NAMES_X448, FIPS_UNAPPROVED_PROPERTIES, ossl_x448_keymgmt_functions,
-      PROV_DESCS_X448 },
+        PROV_DESCS_X448 },
     { PROV_NAMES_ED25519, FIPS_DEFAULT_PROPERTIES, ossl_ed25519_keymgmt_functions,
-      PROV_DESCS_ED25519 },
+        PROV_DESCS_ED25519 },
     { PROV_NAMES_ED448, FIPS_DEFAULT_PROPERTIES, ossl_ed448_keymgmt_functions,
-      PROV_DESCS_ED448 },
-# endif
+        PROV_DESCS_ED448 },
+#endif
 #endif
 #ifndef OPENSSL_NO_ML_DSA
     { PROV_NAMES_ML_DSA_44, FIPS_DEFAULT_PROPERTIES, ossl_ml_dsa_44_keymgmt_functions,
-      PROV_DESCS_ML_DSA_44 },
+        PROV_DESCS_ML_DSA_44 },
     { PROV_NAMES_ML_DSA_65, FIPS_DEFAULT_PROPERTIES, ossl_ml_dsa_65_keymgmt_functions,
-      PROV_DESCS_ML_DSA_65 },
+        PROV_DESCS_ML_DSA_65 },
     { PROV_NAMES_ML_DSA_87, FIPS_DEFAULT_PROPERTIES, ossl_ml_dsa_87_keymgmt_functions,
-      PROV_DESCS_ML_DSA_87 },
+        PROV_DESCS_ML_DSA_87 },
 #endif /* OPENSSL_NO_ML_DSA */
     { PROV_NAMES_TLS1_PRF, FIPS_DEFAULT_PROPERTIES, ossl_kdf_keymgmt_functions,
-      PROV_DESCS_TLS1_PRF_SIGN },
+        PROV_DESCS_TLS1_PRF_SIGN },
     { PROV_NAMES_HKDF, FIPS_DEFAULT_PROPERTIES, ossl_kdf_keymgmt_functions,
-      PROV_DESCS_HKDF_SIGN },
+        PROV_DESCS_HKDF_SIGN },
     { PROV_NAMES_HMAC, FIPS_DEFAULT_PROPERTIES, ossl_mac_legacy_keymgmt_functions,
-      PROV_DESCS_HMAC_SIGN },
+        PROV_DESCS_HMAC_SIGN },
 #ifndef OPENSSL_NO_CMAC
     { PROV_NAMES_CMAC, FIPS_DEFAULT_PROPERTIES,
-      ossl_cmac_legacy_keymgmt_functions, PROV_DESCS_CMAC_SIGN },
+        ossl_cmac_legacy_keymgmt_functions, PROV_DESCS_CMAC_SIGN },
 #endif
 #ifndef OPENSSL_NO_ML_KEM
     { PROV_NAMES_ML_KEM_512, FIPS_DEFAULT_PROPERTIES, ossl_ml_kem_512_keymgmt_functions,
-      PROV_DESCS_ML_KEM_512 },
+        PROV_DESCS_ML_KEM_512 },
     { PROV_NAMES_ML_KEM_768, FIPS_DEFAULT_PROPERTIES, ossl_ml_kem_768_keymgmt_functions,
-      PROV_DESCS_ML_KEM_768 },
+        PROV_DESCS_ML_KEM_768 },
     { PROV_NAMES_ML_KEM_1024, FIPS_DEFAULT_PROPERTIES, ossl_ml_kem_1024_keymgmt_functions,
-      PROV_DESCS_ML_KEM_1024 },
-# if !defined(OPENSSL_NO_ECX)
+        PROV_DESCS_ML_KEM_1024 },
+#if !defined(OPENSSL_NO_ECX)
     { PROV_NAMES_X25519MLKEM768, FIPS_DEFAULT_PROPERTIES, ossl_mlx_x25519_kem_kmgmt_functions,
-      PROV_DESCS_X25519MLKEM768 },
+        PROV_DESCS_X25519MLKEM768 },
     { PROV_NAMES_X448MLKEM1024, FIPS_DEFAULT_PROPERTIES, ossl_mlx_x448_kem_kmgmt_functions,
-      PROV_DESCS_X448MLKEM1024 },
-# endif
-# if !defined(OPENSSL_NO_EC)
+        PROV_DESCS_X448MLKEM1024 },
+#endif
+#if !defined(OPENSSL_NO_EC)
     { PROV_NAMES_SecP256r1MLKEM768, FIPS_DEFAULT_PROPERTIES, ossl_mlx_p256_kem_kmgmt_functions,
-      PROV_DESCS_SecP256r1MLKEM768 },
+        PROV_DESCS_SecP256r1MLKEM768 },
     { PROV_NAMES_SecP384r1MLKEM1024, FIPS_DEFAULT_PROPERTIES, ossl_mlx_p384_kem_kmgmt_functions,
-      PROV_DESCS_SecP384r1MLKEM1024 },
-# endif
+        PROV_DESCS_SecP384r1MLKEM1024 },
+#endif
 #endif
 #ifndef OPENSSL_NO_SLH_DSA
     { PROV_NAMES_SLH_DSA_SHA2_128S, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_sha2_128s_keymgmt_functions, PROV_DESCS_SLH_DSA_SHA2_128S },
+        ossl_slh_dsa_sha2_128s_keymgmt_functions, PROV_DESCS_SLH_DSA_SHA2_128S },
     { PROV_NAMES_SLH_DSA_SHA2_128F, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_sha2_128f_keymgmt_functions, PROV_DESCS_SLH_DSA_SHA2_128F },
+        ossl_slh_dsa_sha2_128f_keymgmt_functions, PROV_DESCS_SLH_DSA_SHA2_128F },
     { PROV_NAMES_SLH_DSA_SHA2_192S, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_sha2_192s_keymgmt_functions, PROV_DESCS_SLH_DSA_SHA2_192S },
+        ossl_slh_dsa_sha2_192s_keymgmt_functions, PROV_DESCS_SLH_DSA_SHA2_192S },
     { PROV_NAMES_SLH_DSA_SHA2_192F, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_sha2_192f_keymgmt_functions, PROV_DESCS_SLH_DSA_SHA2_192F },
+        ossl_slh_dsa_sha2_192f_keymgmt_functions, PROV_DESCS_SLH_DSA_SHA2_192F },
     { PROV_NAMES_SLH_DSA_SHA2_256S, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_sha2_256s_keymgmt_functions, PROV_DESCS_SLH_DSA_SHA2_256S },
+        ossl_slh_dsa_sha2_256s_keymgmt_functions, PROV_DESCS_SLH_DSA_SHA2_256S },
     { PROV_NAMES_SLH_DSA_SHA2_256F, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_sha2_256f_keymgmt_functions, PROV_DESCS_SLH_DSA_SHA2_256F },
+        ossl_slh_dsa_sha2_256f_keymgmt_functions, PROV_DESCS_SLH_DSA_SHA2_256F },
     { PROV_NAMES_SLH_DSA_SHAKE_128S, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_shake_128s_keymgmt_functions, PROV_DESCS_SLH_DSA_SHAKE_128S },
+        ossl_slh_dsa_shake_128s_keymgmt_functions, PROV_DESCS_SLH_DSA_SHAKE_128S },
     { PROV_NAMES_SLH_DSA_SHAKE_128F, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_shake_128f_keymgmt_functions, PROV_DESCS_SLH_DSA_SHAKE_128F },
+        ossl_slh_dsa_shake_128f_keymgmt_functions, PROV_DESCS_SLH_DSA_SHAKE_128F },
     { PROV_NAMES_SLH_DSA_SHAKE_192S, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_shake_192s_keymgmt_functions, PROV_DESCS_SLH_DSA_SHAKE_192S },
+        ossl_slh_dsa_shake_192s_keymgmt_functions, PROV_DESCS_SLH_DSA_SHAKE_192S },
     { PROV_NAMES_SLH_DSA_SHAKE_192F, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_shake_192f_keymgmt_functions, PROV_DESCS_SLH_DSA_SHAKE_192F },
+        ossl_slh_dsa_shake_192f_keymgmt_functions, PROV_DESCS_SLH_DSA_SHAKE_192F },
     { PROV_NAMES_SLH_DSA_SHAKE_256S, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_shake_256s_keymgmt_functions, PROV_DESCS_SLH_DSA_SHAKE_256S },
+        ossl_slh_dsa_shake_256s_keymgmt_functions, PROV_DESCS_SLH_DSA_SHAKE_256S },
     { PROV_NAMES_SLH_DSA_SHAKE_256F, FIPS_DEFAULT_PROPERTIES,
-      ossl_slh_dsa_shake_256f_keymgmt_functions, PROV_DESCS_SLH_DSA_SHAKE_256F },
+        ossl_slh_dsa_shake_256f_keymgmt_functions, PROV_DESCS_SLH_DSA_SHAKE_256F },
 #endif /* OPENSSL_NO_SLH_DSA */
     { NULL, NULL, NULL }
 };
 
 static const OSSL_ALGORITHM *fips_query(void *provctx, int operation_id,
-                                        int *no_cache)
+    int *no_cache)
 {
     *no_cache = 0;
 
@@ -682,7 +681,7 @@ static const OSSL_ALGORITHM *fips_query(void *provctx, int operation_id,
 }
 
 static const OSSL_ALGORITHM *fips_query_internal(void *provctx, int operation_id,
-                                                 int *no_cache)
+    int *no_cache)
 {
     if (operation_id == OSSL_OP_MAC) {
         *no_cache = 0;
@@ -715,7 +714,7 @@ static const OSSL_DISPATCH fips_dispatch_table[] = {
     { OSSL_FUNC_PROVIDER_GET_PARAMS, (void (*)(void))fips_get_params },
     { OSSL_FUNC_PROVIDER_QUERY_OPERATION, (void (*)(void))fips_query },
     { OSSL_FUNC_PROVIDER_GET_CAPABILITIES,
-      (void (*)(void))ossl_prov_get_capabilities },
+        (void (*)(void))ossl_prov_get_capabilities },
     { OSSL_FUNC_PROVIDER_SELF_TEST, (void (*)(void))fips_self_test },
     { OSSL_FUNC_PROVIDER_RANDOM_BYTES, (void (*)(void))fips_random_bytes },
     OSSL_DISPATCH_END
@@ -737,17 +736,17 @@ static const OSSL_DISPATCH intern_dispatch_table[] = {
  * we must switch back to this default explicitly here.
  */
 #ifdef __VMS
-# pragma names save
-# pragma names uppercase,truncated
+#pragma names save
+#pragma names uppercase, truncated
 #endif
 OSSL_provider_init_fn OSSL_provider_init_int;
 #ifdef __VMS
-# pragma names restore
+#pragma names restore
 #endif
 int OSSL_provider_init_int(const OSSL_CORE_HANDLE *handle,
-                           const OSSL_DISPATCH *in,
-                           const OSSL_DISPATCH **out,
-                           void **provctx)
+    const OSSL_DISPATCH *in,
+    const OSSL_DISPATCH **out,
+    void **provctx)
 {
     FIPS_GLOBAL *fgbl;
     OSSL_LIB_CTX *libctx = NULL;
@@ -763,7 +762,11 @@ int OSSL_provider_init_int(const OSSL_CORE_HANDLE *handle,
          * multiple versions of libcrypto (e.g. one static and one dynamic), but
          * sharing a single fips.so. We do a simple sanity check here.
          */
-#define set_func(c, f) if (c == NULL) c = f; else if (c != f) return 0;
+#define set_func(c, f) \
+    if (c == NULL)     \
+        c = f;         \
+    else if (c != f)   \
+        return 0;
         switch (in->function_id) {
         case OSSL_FUNC_CORE_GET_LIBCTX:
             set_func(c_get_libctx, OSSL_FUNC_core_get_libctx(in));
@@ -791,11 +794,14 @@ int OSSL_provider_init_int(const OSSL_CORE_HANDLE *handle,
             break;
         case OSSL_FUNC_CORE_CLEAR_LAST_ERROR_MARK:
             set_func(c_clear_last_error_mark,
-                     OSSL_FUNC_core_clear_last_error_mark(in));
+                OSSL_FUNC_core_clear_last_error_mark(in));
             break;
         case OSSL_FUNC_CORE_POP_ERROR_TO_MARK:
             set_func(c_pop_error_to_mark, OSSL_FUNC_core_pop_error_to_mark(in));
             break;
+        case OSSL_FUNC_CORE_COUNT_TO_MARK:
+            set_func(c_count_to_mark, OSSL_FUNC_core_count_to_mark(in));
+            break;
         case OSSL_FUNC_CRYPTO_MALLOC:
             set_func(c_CRYPTO_malloc, OSSL_FUNC_CRYPTO_malloc(in));
             break;
@@ -813,39 +819,39 @@ int OSSL_provider_init_int(const OSSL_CORE_HANDLE *handle,
             break;
         case OSSL_FUNC_CRYPTO_CLEAR_REALLOC:
             set_func(c_CRYPTO_clear_realloc,
-                     OSSL_FUNC_CRYPTO_clear_realloc(in));
+                OSSL_FUNC_CRYPTO_clear_realloc(in));
             break;
         case OSSL_FUNC_CRYPTO_SECURE_MALLOC:
             set_func(c_CRYPTO_secure_malloc,
-                     OSSL_FUNC_CRYPTO_secure_malloc(in));
+                OSSL_FUNC_CRYPTO_secure_malloc(in));
             break;
         case OSSL_FUNC_CRYPTO_SECURE_ZALLOC:
             set_func(c_CRYPTO_secure_zalloc,
-                     OSSL_FUNC_CRYPTO_secure_zalloc(in));
+                OSSL_FUNC_CRYPTO_secure_zalloc(in));
             break;
         case OSSL_FUNC_CRYPTO_SECURE_FREE:
             set_func(c_CRYPTO_secure_free,
-                     OSSL_FUNC_CRYPTO_secure_free(in));
+                OSSL_FUNC_CRYPTO_secure_free(in));
             break;
         case OSSL_FUNC_CRYPTO_SECURE_CLEAR_FREE:
             set_func(c_CRYPTO_secure_clear_free,
-                     OSSL_FUNC_CRYPTO_secure_clear_free(in));
+                OSSL_FUNC_CRYPTO_secure_clear_free(in));
             break;
         case OSSL_FUNC_CRYPTO_SECURE_ALLOCATED:
             set_func(c_CRYPTO_secure_allocated,
-                     OSSL_FUNC_CRYPTO_secure_allocated(in));
+                OSSL_FUNC_CRYPTO_secure_allocated(in));
             break;
         case OSSL_FUNC_BIO_NEW_FILE:
             set_func(selftest_params.bio_new_file_cb,
-                     OSSL_FUNC_BIO_new_file(in));
+                OSSL_FUNC_BIO_new_file(in));
             break;
         case OSSL_FUNC_BIO_NEW_MEMBUF:
             set_func(selftest_params.bio_new_buffer_cb,
-                     OSSL_FUNC_BIO_new_membuf(in));
+                OSSL_FUNC_BIO_new_membuf(in));
             break;
         case OSSL_FUNC_BIO_READ_EX:
             set_func(selftest_params.bio_read_ex_cb,
-                     OSSL_FUNC_BIO_read_ex(in));
+                OSSL_FUNC_BIO_read_ex(in));
             break;
         case OSSL_FUNC_BIO_FREE:
             set_func(selftest_params.bio_free_cb, OSSL_FUNC_BIO_free(in));
@@ -869,7 +875,7 @@ int OSSL_provider_init_int(const OSSL_CORE_HANDLE *handle,
 
     /*  Create a context. */
     if ((*provctx = ossl_prov_ctx_new()) == NULL
-            || (libctx = OSSL_LIB_CTX_new()) == NULL)
+        || (libctx = OSSL_LIB_CTX_new()) == NULL)
         goto err;
 
     if ((fgbl = ossl_lib_ctx_get_data(libctx, OSSL_LIB_CTX_FIPS_PROV_INDEX)) == NULL)
@@ -886,6 +892,15 @@ int OSSL_provider_init_int(const OSSL_CORE_HANDLE *handle,
     if (!ossl_thread_register_fips(libctx))
         goto err;
 
+    /*
+     * Ensure our internal provider is loaded. We use this whenever the FIPS
+     * provider internally uses the EVP API. We proactively load this now
+     * rather than waiting for lazy loading to ensure it is always present when
+     * we need it.
+     */
+    if (!ossl_provider_activate_fallbacks(libctx))
+        goto err;
+
     /*
      * We did initial set up of selftest_params in a local copy, because we
      * could not create fgbl until c_CRYPTO_zalloc was defined in the loop
@@ -910,14 +925,14 @@ int OSSL_provider_init_int(const OSSL_CORE_HANDLE *handle,
         SELF_TEST_disable_conditional_error_state();
 
     /* Enable or disable FIPS provider options */
-#define OSSL_FIPS_PARAM(structname, paramname, unused)                         \
-    if (fgbl->fips_##structname.option != NULL) {                              \
-        if (strcmp(fgbl->fips_##structname.option, "1") == 0)                  \
-            fgbl->fips_##structname.enabled = 1;                               \
-        else if (strcmp(fgbl->fips_##structname.option, "0") == 0)             \
-            fgbl->fips_##structname.enabled = 0;                               \
-        else                                                                   \
-            goto err;                                                          \
+#define OSSL_FIPS_PARAM(structname, paramname, unused)             \
+    if (fgbl->fips_##structname.option != NULL) {                  \
+        if (strcmp(fgbl->fips_##structname.option, "1") == 0)      \
+            fgbl->fips_##structname.enabled = 1;                   \
+        else if (strcmp(fgbl->fips_##structname.option, "0") == 0) \
+            fgbl->fips_##structname.enabled = 0;                   \
+        else                                                       \
+            goto err;                                              \
     }
 #include "fips_indicator_params.inc"
 #undef OSSL_FIPS_PARAM
@@ -935,7 +950,7 @@ int OSSL_provider_init_int(const OSSL_CORE_HANDLE *handle,
 
     *out = fips_dispatch_table;
     return 1;
- err:
+err:
     fips_teardown(*provctx);
     OSSL_LIB_CTX_free(libctx);
     *provctx = NULL;
@@ -951,9 +966,9 @@ int OSSL_provider_init_int(const OSSL_CORE_HANDLE *handle,
  */
 OSSL_provider_init_fn ossl_fips_intern_provider_init;
 int ossl_fips_intern_provider_init(const OSSL_CORE_HANDLE *handle,
-                                   const OSSL_DISPATCH *in,
-                                   const OSSL_DISPATCH **out,
-                                   void **provctx)
+    const OSSL_DISPATCH *in,
+    const OSSL_DISPATCH **out,
+    void **provctx)
 {
     OSSL_FUNC_core_get_libctx_fn *c_internal_get_libctx = NULL;
 
@@ -979,7 +994,7 @@ int ossl_fips_intern_provider_init(const OSSL_CORE_HANDLE *handle,
      * able to do.
      */
     ossl_prov_ctx_set0_libctx(*provctx,
-                              (OSSL_LIB_CTX *)c_internal_get_libctx(handle));
+        (OSSL_LIB_CTX *)c_internal_get_libctx(handle));
     ossl_prov_ctx_set0_handle(*provctx, handle);
 
     *out = intern_dispatch_table;
@@ -1025,6 +1040,11 @@ int ERR_pop_to_mark(void)
     return c_pop_error_to_mark(NULL);
 }
 
+int ERR_count_to_mark(void)
+{
+    return c_count_to_mark != NULL ? c_count_to_mark(NULL) : 0;
+}
+
 /*
  * This must take a library context, since it's called from the depths
  * of crypto/initthread.c code, where it's (correctly) assumed that the
@@ -1035,7 +1055,7 @@ int ERR_pop_to_mark(void)
 const OSSL_CORE_HANDLE *FIPS_get_core_handle(OSSL_LIB_CTX *libctx)
 {
     FIPS_GLOBAL *fgbl = ossl_lib_ctx_get_data(libctx,
-                                              OSSL_LIB_CTX_FIPS_PROV_INDEX);
+        OSSL_LIB_CTX_FIPS_PROV_INDEX);
 
     if (fgbl == NULL)
         return NULL;
@@ -1069,7 +1089,7 @@ void *CRYPTO_realloc(void *addr, size_t num, const char *file, int line)
 }
 
 void *CRYPTO_clear_realloc(void *addr, size_t old_num, size_t num,
-                           const char *file, int line)
+    const char *file, int line)
 {
     return c_CRYPTO_clear_realloc(addr, old_num, num, file, line);
 }
@@ -1100,7 +1120,7 @@ int CRYPTO_secure_allocated(const void *ptr)
 }
 
 void *CRYPTO_aligned_alloc(size_t num, size_t align, void **freeptr,
-                           const char *file, int line)
+    const char *file, int line)
 {
     return NULL;
 }
@@ -1116,19 +1136,18 @@ int BIO_snprintf(char *buf, size_t n, const char *format, ...)
     return ret;
 }
 
-#define OSSL_FIPS_PARAM(structname, paramname, unused)                         \
-    int ossl_fips_config_##structname(OSSL_LIB_CTX *libctx)                    \
-    {                                                                          \
-        FIPS_GLOBAL *fgbl =                                                    \
-            ossl_lib_ctx_get_data(libctx, OSSL_LIB_CTX_FIPS_PROV_INDEX);       \
-                                                                               \
-        return fgbl->fips_##structname.enabled;                                \
+#define OSSL_FIPS_PARAM(structname, paramname, unused)                                   \
+    int ossl_fips_config_##structname(OSSL_LIB_CTX *libctx)                              \
+    {                                                                                    \
+        FIPS_GLOBAL *fgbl = ossl_lib_ctx_get_data(libctx, OSSL_LIB_CTX_FIPS_PROV_INDEX); \
+                                                                                         \
+        return fgbl->fips_##structname.enabled;                                          \
     }
 #include "fips_indicator_params.inc"
 #undef OSSL_FIPS_PARAM
 
 void OSSL_SELF_TEST_get_callback(OSSL_LIB_CTX *libctx, OSSL_CALLBACK **cb,
-                                 void **cbarg)
+    void **cbarg)
 {
     assert(libctx != NULL);
 
@@ -1144,7 +1163,7 @@ void OSSL_SELF_TEST_get_callback(OSSL_LIB_CTX *libctx, OSSL_CALLBACK **cb,
 }
 
 void OSSL_INDICATOR_get_callback(OSSL_LIB_CTX *libctx,
-                                 OSSL_INDICATOR_CALLBACK **cb)
+    OSSL_INDICATOR_CALLBACK **cb)
 {
     assert(libctx != NULL);
 
