@@ -18,8 +18,8 @@
 #define CHACHA20_POLY1305_BLKLEN 1
 #define CHACHA20_POLY1305_MAX_IVLEN 12
 #define CHACHA20_POLY1305_MODE 0
-#define CHACHA20_POLY1305_FLAGS (PROV_CIPHER_FLAG_AEAD                         \
-                                 | PROV_CIPHER_FLAG_CUSTOM_IV)
+#define CHACHA20_POLY1305_FLAGS (PROV_CIPHER_FLAG_AEAD \
+    | PROV_CIPHER_FLAG_CUSTOM_IV)
 
 static OSSL_FUNC_cipher_newctx_fn chacha20_poly1305_newctx;
 static OSSL_FUNC_cipher_freectx_fn chacha20_poly1305_freectx;
@@ -46,13 +46,13 @@ static void *chacha20_poly1305_newctx(void *provctx)
     ctx = OPENSSL_zalloc(sizeof(*ctx));
     if (ctx != NULL) {
         ossl_cipher_generic_initkey(&ctx->base, CHACHA20_POLY1305_KEYLEN * 8,
-                                    CHACHA20_POLY1305_BLKLEN * 8,
-                                    CHACHA20_POLY1305_IVLEN * 8,
-                                    CHACHA20_POLY1305_MODE,
-                                    CHACHA20_POLY1305_FLAGS,
-                                    ossl_prov_cipher_hw_chacha20_poly1305(
-                                        CHACHA20_POLY1305_KEYLEN * 8),
-                                    NULL);
+            CHACHA20_POLY1305_BLKLEN * 8,
+            CHACHA20_POLY1305_IVLEN * 8,
+            CHACHA20_POLY1305_MODE,
+            CHACHA20_POLY1305_FLAGS,
+            ossl_prov_cipher_hw_chacha20_poly1305(
+                CHACHA20_POLY1305_KEYLEN * 8),
+            NULL);
         ctx->tls_payload_length = NO_TLS_PAYLOAD_LENGTH;
         ossl_chacha20_initctx(&ctx->chacha);
     }
@@ -69,7 +69,7 @@ static void *chacha20_poly1305_dupctx(void *provctx)
     dctx = OPENSSL_memdup(ctx, sizeof(*ctx));
     if (dctx != NULL && dctx->base.tlsmac != NULL && dctx->base.alloced) {
         dctx->base.tlsmac = OPENSSL_memdup(dctx->base.tlsmac,
-                                           dctx->base.tlsmacsize);
+            dctx->base.tlsmacsize);
         if (dctx->base.tlsmac == NULL) {
             OPENSSL_free(dctx);
             dctx = NULL;
@@ -91,9 +91,9 @@ static void chacha20_poly1305_freectx(void *vctx)
 static int chacha20_poly1305_get_params(OSSL_PARAM params[])
 {
     return ossl_cipher_generic_get_params(params, 0, CHACHA20_POLY1305_FLAGS,
-                                          CHACHA20_POLY1305_KEYLEN * 8,
-                                          CHACHA20_POLY1305_BLKLEN * 8,
-                                          CHACHA20_POLY1305_IVLEN * 8);
+        CHACHA20_POLY1305_KEYLEN * 8,
+        CHACHA20_POLY1305_BLKLEN * 8,
+        CHACHA20_POLY1305_IVLEN * 8);
 }
 
 static int chacha20_poly1305_get_ctx_params(void *vctx, OSSL_PARAM params[])
@@ -152,8 +152,7 @@ static const OSSL_PARAM chacha20_poly1305_known_gettable_ctx_params[] = {
     OSSL_PARAM_size_t(OSSL_CIPHER_PARAM_AEAD_TLS1_AAD_PAD, NULL),
     OSSL_PARAM_END
 };
-static const OSSL_PARAM *chacha20_poly1305_gettable_ctx_params
-    (ossl_unused void *cctx, ossl_unused void *provctx)
+static const OSSL_PARAM *chacha20_poly1305_gettable_ctx_params(ossl_unused void *cctx, ossl_unused void *provctx)
 {
     return chacha20_poly1305_known_gettable_ctx_params;
 }
@@ -167,20 +166,18 @@ static const OSSL_PARAM chacha20_poly1305_known_settable_ctx_params[] = {
     OSSL_PARAM_END
 };
 static const OSSL_PARAM *chacha20_poly1305_settable_ctx_params(
-        ossl_unused void *cctx, ossl_unused void *provctx
-    )
+    ossl_unused void *cctx, ossl_unused void *provctx)
 {
     return chacha20_poly1305_known_settable_ctx_params;
 }
 
 static int chacha20_poly1305_set_ctx_params(void *vctx,
-                                            const OSSL_PARAM params[])
+    const OSSL_PARAM params[])
 {
     const OSSL_PARAM *p;
     size_t len;
     PROV_CHACHA20_POLY1305_CTX *ctx = (PROV_CHACHA20_POLY1305_CTX *)vctx;
-    PROV_CIPHER_HW_CHACHA20_POLY1305 *hw =
-        (PROV_CIPHER_HW_CHACHA20_POLY1305 *)ctx->base.hw;
+    PROV_CIPHER_HW_CHACHA20_POLY1305 *hw = (PROV_CIPHER_HW_CHACHA20_POLY1305 *)ctx->base.hw;
 
     if (ossl_param_is_empty(params))
         return 1;
@@ -257,8 +254,8 @@ static int chacha20_poly1305_set_ctx_params(void *vctx,
 }
 
 static int chacha20_poly1305_einit(void *vctx, const unsigned char *key,
-                                  size_t keylen, const unsigned char *iv,
-                                  size_t ivlen, const OSSL_PARAM params[])
+    size_t keylen, const unsigned char *iv,
+    size_t ivlen, const OSSL_PARAM params[])
 {
     int ret;
 
@@ -266,8 +263,7 @@ static int chacha20_poly1305_einit(void *vctx, const unsigned char *key,
     ret = ossl_cipher_generic_einit(vctx, key, keylen, iv, ivlen, NULL);
     if (ret && iv != NULL) {
         PROV_CIPHER_CTX *ctx = (PROV_CIPHER_CTX *)vctx;
-        PROV_CIPHER_HW_CHACHA20_POLY1305 *hw =
-            (PROV_CIPHER_HW_CHACHA20_POLY1305 *)ctx->hw;
+        PROV_CIPHER_HW_CHACHA20_POLY1305 *hw = (PROV_CIPHER_HW_CHACHA20_POLY1305 *)ctx->hw;
 
         hw->initiv(ctx);
     }
@@ -277,8 +273,8 @@ static int chacha20_poly1305_einit(void *vctx, const unsigned char *key,
 }
 
 static int chacha20_poly1305_dinit(void *vctx, const unsigned char *key,
-                                  size_t keylen, const unsigned char *iv,
-                                  size_t ivlen, const OSSL_PARAM params[])
+    size_t keylen, const unsigned char *iv,
+    size_t ivlen, const OSSL_PARAM params[])
 {
     int ret;
 
@@ -286,8 +282,7 @@ static int chacha20_poly1305_dinit(void *vctx, const unsigned char *key,
     ret = ossl_cipher_generic_dinit(vctx, key, keylen, iv, ivlen, NULL);
     if (ret && iv != NULL) {
         PROV_CIPHER_CTX *ctx = (PROV_CIPHER_CTX *)vctx;
-        PROV_CIPHER_HW_CHACHA20_POLY1305 *hw =
-            (PROV_CIPHER_HW_CHACHA20_POLY1305 *)ctx->hw;
+        PROV_CIPHER_HW_CHACHA20_POLY1305 *hw = (PROV_CIPHER_HW_CHACHA20_POLY1305 *)ctx->hw;
 
         hw->initiv(ctx);
     }
@@ -297,12 +292,11 @@ static int chacha20_poly1305_dinit(void *vctx, const unsigned char *key,
 }
 
 static int chacha20_poly1305_cipher(void *vctx, unsigned char *out,
-                                    size_t *outl, size_t outsize,
-                                    const unsigned char *in, size_t inl)
+    size_t *outl, size_t outsize,
+    const unsigned char *in, size_t inl)
 {
     PROV_CIPHER_CTX *ctx = (PROV_CIPHER_CTX *)vctx;
-    PROV_CIPHER_HW_CHACHA20_POLY1305 *hw =
-        (PROV_CIPHER_HW_CHACHA20_POLY1305 *)ctx->hw;
+    PROV_CIPHER_HW_CHACHA20_POLY1305 *hw = (PROV_CIPHER_HW_CHACHA20_POLY1305 *)ctx->hw;
 
     if (!ossl_prov_is_running())
         return 0;
@@ -324,11 +318,10 @@ static int chacha20_poly1305_cipher(void *vctx, unsigned char *out,
 }
 
 static int chacha20_poly1305_final(void *vctx, unsigned char *out, size_t *outl,
-                                   size_t outsize)
+    size_t outsize)
 {
     PROV_CIPHER_CTX *ctx = (PROV_CIPHER_CTX *)vctx;
-    PROV_CIPHER_HW_CHACHA20_POLY1305 *hw =
-        (PROV_CIPHER_HW_CHACHA20_POLY1305 *)ctx->hw;
+    PROV_CIPHER_HW_CHACHA20_POLY1305 *hw = (PROV_CIPHER_HW_CHACHA20_POLY1305 *)ctx->hw;
 
     if (!ossl_prov_is_running())
         return 0;
@@ -355,7 +348,7 @@ const OSSL_DISPATCH ossl_chacha20_ossl_poly1305_functions[] = {
     { OSSL_FUNC_CIPHER_GETTABLE_PARAMS,
         (void (*)(void))chacha20_poly1305_gettable_params },
     { OSSL_FUNC_CIPHER_GET_CTX_PARAMS,
-         (void (*)(void))chacha20_poly1305_get_ctx_params },
+        (void (*)(void))chacha20_poly1305_get_ctx_params },
     { OSSL_FUNC_CIPHER_GETTABLE_CTX_PARAMS,
         (void (*)(void))chacha20_poly1305_gettable_ctx_params },
     { OSSL_FUNC_CIPHER_SET_CTX_PARAMS,
@@ -364,4 +357,3 @@ const OSSL_DISPATCH ossl_chacha20_ossl_poly1305_functions[] = {
         (void (*)(void))chacha20_poly1305_settable_ctx_params },
     OSSL_DISPATCH_END
 };
-
