@@ -249,7 +249,7 @@ int ossl_gcm_set_ctx_params(void *vctx, const OSSL_PARAM params[])
     void *vp;
     int type;
 
-    if (params == NULL)
+    if (ossl_param_is_empty(params))
         return 1;
 
     for (p = params; p->key != NULL; p++) {
