@@ -42,7 +42,7 @@
                                                                                                                   \
         if (ctx == NULL)                                                                                          \
             return 0;                                                                                             \
-        if (params == NULL)                                                                                       \
+        if (ossl_param_is_empty(params))                                                                          \
             return 1;                                                                                             \
                                                                                                                   \
         p = OSSL_PARAM_locate(params, OSSL_DIGEST_PARAM_SIZE);                                                    \
@@ -65,7 +65,7 @@
                                                                                                                   \
         if (ctx == NULL)                                                                                          \
             return 0;                                                                                             \
-        if (params == NULL)                                                                                       \
+        if (ossl_param_is_empty(params))                                                                          \
             return 1;                                                                                             \
                                                                                                                   \
         p = OSSL_PARAM_locate_const(params, OSSL_DIGEST_PARAM_SIZE);                                              \
@@ -135,6 +135,15 @@
         return ret;                                                                                               \
     }                                                                                                             \
                                                                                                                   \
+    static void blake##variantsize##_copyctx(void *voutctx, void *vinctx)                                         \
+    {                                                                                                             \
+        struct blake##variant##_md_data_st *inctx, *outctx;                                                       \
+                                                                                                                  \
+        outctx = (struct blake##variant##_md_data_st *)voutctx;                                                   \
+        inctx = (struct blake##variant##_md_data_st *)vinctx;                                                     \
+        *outctx = *inctx;                                                                                         \
+    }                                                                                                             \
+                                                                                                                  \
     static int blake##variantsize##_internal_final(void *ctx, unsigned char *out,                                 \
         size_t *outl, size_t outsz)                                                                               \
     {                                                                                                             \
@@ -169,6 +178,7 @@
         { OSSL_FUNC_DIGEST_FINAL, (void (*)(void))blake##variantsize##_internal_final },                          \
         { OSSL_FUNC_DIGEST_FREECTX, (void (*)(void))blake##variantsize##_freectx },                               \
         { OSSL_FUNC_DIGEST_DUPCTX, (void (*)(void))blake##variantsize##_dupctx },                                 \
+        { OSSL_FUNC_DIGEST_COPYCTX, (void (*)(void))blake##variantsize##_copyctx },                               \
         { OSSL_FUNC_DIGEST_GET_PARAMS, (void (*)(void))blake##variantsize##_get_params },                         \
         { OSSL_FUNC_DIGEST_GETTABLE_PARAMS,                                                                       \
             (void (*)(void))ossl_digest_default_gettable_params },                                                \
