@@ -1,5 +1,5 @@
 /*
- * Copyright 2019-2024 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2019-2025 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -20,7 +20,7 @@
 #include "prov/implementations.h"
 
 #define SHA3_FLAGS PROV_DIGEST_FLAG_ALGID_ABSENT
-#define SHAKE_FLAGS PROV_DIGEST_FLAG_XOF
+#define SHAKE_FLAGS (PROV_DIGEST_FLAG_XOF | PROV_DIGEST_FLAG_ALGID_ABSENT)
 #define KMAC_FLAGS PROV_DIGEST_FLAG_XOF
 
 /*
@@ -48,11 +48,10 @@ static sha3_squeeze_fn generic_sha3_squeeze;
 /*
  * IBM S390X support
  */
-# include "s390x_arch.h"
-# define S390_SHA3 1
-# define S390_SHA3_CAPABLE(name) \
-    ((OPENSSL_s390xcap_P.kimd[0] & S390X_CAPBIT(S390X_##name)) && \
-     (OPENSSL_s390xcap_P.klmd[0] & S390X_CAPBIT(S390X_##name)))
+#include "s390x_arch.h"
+#define S390_SHA3 1
+#define S390_SHA3_CAPABLE(name) \
+    ((OPENSSL_s390xcap_P.kimd[0] & S390X_CAPBIT(S390X_##name)) && (OPENSSL_s390xcap_P.klmd[0] & S390X_CAPBIT(S390X_##name)))
 
 #endif
 
@@ -68,7 +67,7 @@ static int keccak_init(void *vctx, ossl_unused const OSSL_PARAM params[])
 static int keccak_init_params(void *vctx, const OSSL_PARAM params[])
 {
     return keccak_init(vctx, NULL)
-            && shake_set_ctx_params(vctx, params);
+        && shake_set_ctx_params(vctx, params);
 }
 
 static int keccak_update(void *vctx, const unsigned char *inp, size_t len)
@@ -109,7 +108,7 @@ static int keccak_update(void *vctx, const unsigned char *inp, size_t len)
 }
 
 static int keccak_final(void *vctx, unsigned char *out, size_t *outl,
-                        size_t outlen)
+    size_t outlen)
 {
     int ret = 1;
     KECCAK1600_CTX *ctx = vctx;
@@ -128,7 +127,7 @@ static int keccak_final(void *vctx, unsigned char *out, size_t *outl,
 }
 
 static int shake_squeeze(void *vctx, unsigned char *out, size_t *outl,
-                         size_t outlen)
+    size_t outlen)
 {
     int ret = 1;
     KECCAK1600_CTX *ctx = vctx;
@@ -151,8 +150,7 @@ static size_t generic_sha3_absorb(void *vctx, const void *inp, size_t len)
 {
     KECCAK1600_CTX *ctx = vctx;
 
-    if (!(ctx->xof_state == XOF_STATE_INIT ||
-          ctx->xof_state == XOF_STATE_ABSORB))
+    if (!(ctx->xof_state == XOF_STATE_INIT || ctx->xof_state == XOF_STATE_ABSORB))
         return 0;
     ctx->xof_state = XOF_STATE_ABSORB;
     return SHA3_absorb(ctx->A, inp, len, ctx->block_size);
@@ -174,8 +172,7 @@ static PROV_SHA3_METHOD sha3_generic_md = {
     NULL
 };
 
-static PROV_SHA3_METHOD shake_generic_md =
-{
+static PROV_SHA3_METHOD shake_generic_md = {
     generic_sha3_absorb,
     generic_sha3_final,
     generic_sha3_squeeze
@@ -196,8 +193,7 @@ static size_t s390x_sha3_absorb(void *vctx, const void *inp, size_t len)
     size_t rem = len % ctx->block_size;
     unsigned int fc;
 
-    if (!(ctx->xof_state == XOF_STATE_INIT ||
-          ctx->xof_state == XOF_STATE_ABSORB))
+    if (!(ctx->xof_state == XOF_STATE_INIT || ctx->xof_state == XOF_STATE_ABSORB))
         return 0;
     if (len - rem > 0) {
         fc = ctx->pad;
@@ -215,8 +211,7 @@ static int s390x_sha3_final(void *vctx, unsigned char *out, size_t outlen)
 
     if (!ossl_prov_is_running())
         return 0;
-    if (!(ctx->xof_state == XOF_STATE_INIT ||
-          ctx->xof_state == XOF_STATE_ABSORB))
+    if (!(ctx->xof_state == XOF_STATE_INIT || ctx->xof_state == XOF_STATE_ABSORB))
         return 0;
     fc = ctx->pad | S390X_KLMD_DUFOP;
     fc |= ctx->xof_state == XOF_STATE_INIT ? S390X_KLMD_NIP : 0;
@@ -233,8 +228,7 @@ static int s390x_shake_final(void *vctx, unsigned char *out, size_t outlen)
 
     if (!ossl_prov_is_running())
         return 0;
-    if (!(ctx->xof_state == XOF_STATE_INIT ||
-          ctx->xof_state == XOF_STATE_ABSORB))
+    if (!(ctx->xof_state == XOF_STATE_INIT || ctx->xof_state == XOF_STATE_ABSORB))
         return 0;
     fc = ctx->pad | S390X_KLMD_DUFOP;
     fc |= ctx->xof_state == XOF_STATE_INIT ? S390X_KLMD_NIP : 0;
@@ -286,7 +280,7 @@ static int s390x_shake_squeeze(void *vctx, unsigned char *out, size_t outlen)
 }
 
 static int s390x_keccakc_final(void *vctx, unsigned char *out, size_t outlen,
-                               int padding)
+    int padding)
 {
     KECCAK1600_CTX *ctx = vctx;
     size_t bsz = ctx->block_size;
@@ -296,8 +290,7 @@ static int s390x_keccakc_final(void *vctx, unsigned char *out, size_t outlen,
 
     if (!ossl_prov_is_running())
         return 0;
-    if (!(ctx->xof_state == XOF_STATE_INIT ||
-          ctx->xof_state == XOF_STATE_ABSORB))
+    if (!(ctx->xof_state == XOF_STATE_INIT || ctx->xof_state == XOF_STATE_ABSORB))
         return 0;
     fc = ctx->pad;
     fc |= ctx->xof_state == XOF_STATE_INIT ? S390X_KIMD_NIP : 0;
@@ -313,7 +306,7 @@ static int s390x_keccakc_final(void *vctx, unsigned char *out, size_t outlen,
     needed -= num;
     if (needed > 0)
         s390x_klmd(NULL, 0, out + bsz, needed,
-                   ctx->pad | S390X_KLMD_PS | S390X_KLMD_DUFOP, ctx->A);
+            ctx->pad | S390X_KLMD_PS | S390X_KLMD_DUFOP, ctx->A);
 
     return 1;
 }
@@ -329,7 +322,7 @@ static int s390x_kmac_final(void *vctx, unsigned char *out, size_t outlen)
 }
 
 static int s390x_keccakc_squeeze(void *vctx, unsigned char *out, size_t outlen,
-                                 int padding)
+    int padding)
 {
     KECCAK1600_CTX *ctx = vctx;
     size_t len;
@@ -377,12 +370,12 @@ static int s390x_keccakc_squeeze(void *vctx, unsigned char *out, size_t outlen,
 
 static int s390x_keccak_squeeze(void *vctx, unsigned char *out, size_t outlen)
 {
-     return s390x_keccakc_squeeze(vctx, out, outlen, 0x01);
+    return s390x_keccakc_squeeze(vctx, out, outlen, 0x01);
 }
 
 static int s390x_kmac_squeeze(void *vctx, unsigned char *out, size_t outlen)
 {
-     return s390x_keccakc_squeeze(vctx, out, outlen, 0x04);
+    return s390x_keccakc_squeeze(vctx, out, outlen, 0x04);
 }
 
 static PROV_SHA3_METHOD sha3_s390x_md = {
@@ -409,35 +402,35 @@ static PROV_SHA3_METHOD kmac_s390x_md = {
     s390x_kmac_squeeze,
 };
 
-# define SHAKE_SET_MD(uname, typ)                                              \
-    if (S390_SHA3_CAPABLE(uname)) {                                            \
-        ctx->pad = S390X_##uname;                                              \
-        ctx->meth = typ##_s390x_md;                                            \
-    } else {                                                                   \
-        ctx->meth = shake_generic_md;                                          \
+#define SHAKE_SET_MD(uname, typ)      \
+    if (S390_SHA3_CAPABLE(uname)) {   \
+        ctx->pad = S390X_##uname;     \
+        ctx->meth = typ##_s390x_md;   \
+    } else {                          \
+        ctx->meth = shake_generic_md; \
     }
 
-# define SHA3_SET_MD(uname, typ)                                               \
-    if (S390_SHA3_CAPABLE(uname)) {                                            \
-        ctx->pad = S390X_##uname;                                              \
-        ctx->meth = typ##_s390x_md;                                            \
-    } else {                                                                   \
-        ctx->meth = sha3_generic_md;                                           \
+#define SHA3_SET_MD(uname, typ)      \
+    if (S390_SHA3_CAPABLE(uname)) {  \
+        ctx->pad = S390X_##uname;    \
+        ctx->meth = typ##_s390x_md;  \
+    } else {                         \
+        ctx->meth = sha3_generic_md; \
     }
-# define KMAC_SET_MD(bitlen)                                                   \
-    if (S390_SHA3_CAPABLE(SHAKE_##bitlen)) {                                   \
-        ctx->pad = S390X_SHAKE_##bitlen;                                       \
-        ctx->meth = kmac_s390x_md;                                             \
-    } else {                                                                   \
-        ctx->meth = sha3_generic_md;                                           \
+#define KMAC_SET_MD(bitlen)                  \
+    if (S390_SHA3_CAPABLE(SHAKE_##bitlen)) { \
+        ctx->pad = S390X_SHAKE_##bitlen;     \
+        ctx->meth = kmac_s390x_md;           \
+    } else {                                 \
+        ctx->meth = sha3_generic_md;         \
     }
 #elif defined(__aarch64__) && defined(KECCAK1600_ASM)
-# include "arm_arch.h"
+#include "arm_arch.h"
 
 static sha3_absorb_fn armsha3_sha3_absorb;
 
 size_t SHA3_absorb_cext(uint64_t A[5][5], const unsigned char *inp, size_t len,
-                        size_t r);
+    size_t r);
 /*-
  * Hardware-assisted ARMv8.2 SHA3 extension version of the absorb()
  */
@@ -452,114 +445,113 @@ static PROV_SHA3_METHOD sha3_ARMSHA3_md = {
     armsha3_sha3_absorb,
     generic_sha3_final
 };
-static PROV_SHA3_METHOD shake_ARMSHA3_md =
-{
+static PROV_SHA3_METHOD shake_ARMSHA3_md = {
     armsha3_sha3_absorb,
     generic_sha3_final,
     generic_sha3_squeeze
 };
-# define SHAKE_SET_MD(uname, typ)                                              \
-    if (OPENSSL_armcap_P & ARMV8_HAVE_SHA3_AND_WORTH_USING) {                  \
-        ctx->meth = shake_ARMSHA3_md;                                          \
-    } else {                                                                   \
-        ctx->meth = shake_generic_md;                                          \
+#define SHAKE_SET_MD(uname, typ)                              \
+    if (OPENSSL_armcap_P & ARMV8_HAVE_SHA3_AND_WORTH_USING) { \
+        ctx->meth = shake_ARMSHA3_md;                         \
+    } else {                                                  \
+        ctx->meth = shake_generic_md;                         \
     }
 
-# define SHA3_SET_MD(uname, typ)                                               \
-    if (OPENSSL_armcap_P & ARMV8_HAVE_SHA3_AND_WORTH_USING) {                  \
-        ctx->meth = sha3_ARMSHA3_md;                                           \
-    } else {                                                                   \
-        ctx->meth = sha3_generic_md;                                           \
+#define SHA3_SET_MD(uname, typ)                               \
+    if (OPENSSL_armcap_P & ARMV8_HAVE_SHA3_AND_WORTH_USING) { \
+        ctx->meth = sha3_ARMSHA3_md;                          \
+    } else {                                                  \
+        ctx->meth = sha3_generic_md;                          \
     }
-# define KMAC_SET_MD(bitlen)                                                   \
-    if (OPENSSL_armcap_P & ARMV8_HAVE_SHA3_AND_WORTH_USING) {                  \
-        ctx->meth = sha3_ARMSHA3_md;                                           \
-    } else {                                                                   \
-        ctx->meth = sha3_generic_md;                                           \
+#define KMAC_SET_MD(bitlen)                                   \
+    if (OPENSSL_armcap_P & ARMV8_HAVE_SHA3_AND_WORTH_USING) { \
+        ctx->meth = sha3_ARMSHA3_md;                          \
+    } else {                                                  \
+        ctx->meth = sha3_generic_md;                          \
     }
 #else
-# define SHA3_SET_MD(uname, typ) ctx->meth = sha3_generic_md;
-# define KMAC_SET_MD(bitlen) ctx->meth = sha3_generic_md;
-# define SHAKE_SET_MD(uname, typ) ctx->meth = shake_generic_md;
+#define SHA3_SET_MD(uname, typ) ctx->meth = sha3_generic_md;
+#define KMAC_SET_MD(bitlen) ctx->meth = sha3_generic_md;
+#define SHAKE_SET_MD(uname, typ) ctx->meth = shake_generic_md;
 #endif /* S390_SHA3 */
 
-#define SHA3_newctx(typ, uname, name, bitlen, pad)                             \
-static OSSL_FUNC_digest_newctx_fn name##_newctx;                               \
-static void *name##_newctx(void *provctx)                                      \
-{                                                                              \
-    KECCAK1600_CTX *ctx = ossl_prov_is_running() ? OPENSSL_zalloc(sizeof(*ctx)) \
-                                                : NULL;                        \
-                                                                               \
-    if (ctx == NULL)                                                           \
-        return NULL;                                                           \
-    ossl_sha3_init(ctx, pad, bitlen);                                          \
-    SHA3_SET_MD(uname, typ)                                                    \
-    return ctx;                                                                \
-}
+#define SHA3_newctx(typ, uname, name, bitlen, pad)                                  \
+    static OSSL_FUNC_digest_newctx_fn name##_newctx;                                \
+    static void *name##_newctx(void *provctx)                                       \
+    {                                                                               \
+        KECCAK1600_CTX *ctx = ossl_prov_is_running() ? OPENSSL_zalloc(sizeof(*ctx)) \
+                                                     : NULL;                        \
+                                                                                    \
+        if (ctx == NULL)                                                            \
+            return NULL;                                                            \
+        ossl_sha3_init(ctx, pad, bitlen);                                           \
+        SHA3_SET_MD(uname, typ)                                                     \
+        return ctx;                                                                 \
+    }
 
-#define SHAKE_newctx(typ, uname, name, bitlen, mdlen, pad)                     \
-static OSSL_FUNC_digest_newctx_fn name##_newctx;                               \
-static void *name##_newctx(void *provctx)                                      \
-{                                                                              \
-    KECCAK1600_CTX *ctx = ossl_prov_is_running() ? OPENSSL_zalloc(sizeof(*ctx))\
-                                                : NULL;                        \
-                                                                               \
-    if (ctx == NULL)                                                           \
-        return NULL;                                                           \
-    ossl_keccak_init(ctx, pad, bitlen, mdlen);                                 \
-    if (mdlen == 0)                                                            \
-        ctx->md_size = SIZE_MAX;                                               \
-    SHAKE_SET_MD(uname, typ)                                                   \
-    return ctx;                                                                \
-}
+#define SHAKE_newctx(typ, uname, name, bitlen, mdlen, pad)                          \
+    static OSSL_FUNC_digest_newctx_fn name##_newctx;                                \
+    static void *name##_newctx(void *provctx)                                       \
+    {                                                                               \
+        KECCAK1600_CTX *ctx = ossl_prov_is_running() ? OPENSSL_zalloc(sizeof(*ctx)) \
+                                                     : NULL;                        \
+                                                                                    \
+        if (ctx == NULL)                                                            \
+            return NULL;                                                            \
+        ossl_keccak_init(ctx, pad, bitlen, mdlen);                                  \
+        if (mdlen == 0)                                                             \
+            ctx->md_size = SIZE_MAX;                                                \
+        SHAKE_SET_MD(uname, typ)                                                    \
+        return ctx;                                                                 \
+    }
 
-#define KMAC_newctx(uname, bitlen, pad)                                        \
-static OSSL_FUNC_digest_newctx_fn uname##_newctx;                              \
-static void *uname##_newctx(void *provctx)                                     \
-{                                                                              \
-    KECCAK1600_CTX *ctx = ossl_prov_is_running() ? OPENSSL_zalloc(sizeof(*ctx)) \
-                                                : NULL;                        \
-                                                                               \
-    if (ctx == NULL)                                                           \
-        return NULL;                                                           \
-    ossl_keccak_init(ctx, pad, bitlen, 2 * bitlen);                            \
-    KMAC_SET_MD(bitlen)                                                        \
-    return ctx;                                                                \
-}
+#define KMAC_newctx(uname, bitlen, pad)                                             \
+    static OSSL_FUNC_digest_newctx_fn uname##_newctx;                               \
+    static void *uname##_newctx(void *provctx)                                      \
+    {                                                                               \
+        KECCAK1600_CTX *ctx = ossl_prov_is_running() ? OPENSSL_zalloc(sizeof(*ctx)) \
+                                                     : NULL;                        \
+                                                                                    \
+        if (ctx == NULL)                                                            \
+            return NULL;                                                            \
+        ossl_keccak_init(ctx, pad, bitlen, 2 * bitlen);                             \
+        KMAC_SET_MD(bitlen)                                                         \
+        return ctx;                                                                 \
+    }
 
-#define PROV_FUNC_SHA3_DIGEST_COMMON(name, bitlen, blksize, dgstsize, flags)   \
-PROV_FUNC_DIGEST_GET_PARAM(name, blksize, dgstsize, flags)                     \
-const OSSL_DISPATCH ossl_##name##_functions[] = {                              \
-    { OSSL_FUNC_DIGEST_NEWCTX, (void (*)(void))name##_newctx },                \
-    { OSSL_FUNC_DIGEST_UPDATE, (void (*)(void))keccak_update },                \
-    { OSSL_FUNC_DIGEST_FINAL, (void (*)(void))keccak_final },                  \
-    { OSSL_FUNC_DIGEST_FREECTX, (void (*)(void))keccak_freectx },              \
-    { OSSL_FUNC_DIGEST_DUPCTX, (void (*)(void))keccak_dupctx },                \
-    { OSSL_FUNC_DIGEST_COPYCTX, (void (*)(void))keccak_copyctx },              \
-    PROV_DISPATCH_FUNC_DIGEST_GET_PARAMS(name)
+#define PROV_FUNC_SHA3_DIGEST_COMMON(name, bitlen, blksize, dgstsize, flags) \
+    PROV_FUNC_DIGEST_GET_PARAM(name, blksize, dgstsize, flags)               \
+    const OSSL_DISPATCH ossl_##name##_functions[] = {                        \
+        { OSSL_FUNC_DIGEST_NEWCTX, (void (*)(void))name##_newctx },          \
+        { OSSL_FUNC_DIGEST_UPDATE, (void (*)(void))keccak_update },          \
+        { OSSL_FUNC_DIGEST_FINAL, (void (*)(void))keccak_final },            \
+        { OSSL_FUNC_DIGEST_FREECTX, (void (*)(void))keccak_freectx },        \
+        { OSSL_FUNC_DIGEST_DUPCTX, (void (*)(void))keccak_dupctx },          \
+        { OSSL_FUNC_DIGEST_COPYCTX, (void (*)(void))keccak_copyctx },        \
+        PROV_DISPATCH_FUNC_DIGEST_GET_PARAMS(name)
 
-#define PROV_FUNC_SHA3_DIGEST(name, bitlen, blksize, dgstsize, flags)          \
-    PROV_FUNC_SHA3_DIGEST_COMMON(name, bitlen, blksize, dgstsize, flags),      \
-    { OSSL_FUNC_DIGEST_INIT, (void (*)(void))keccak_init },                    \
-    PROV_DISPATCH_FUNC_DIGEST_CONSTRUCT_END
+#define PROV_FUNC_SHA3_DIGEST(name, bitlen, blksize, dgstsize, flags)     \
+    PROV_FUNC_SHA3_DIGEST_COMMON(name, bitlen, blksize, dgstsize, flags), \
+        { OSSL_FUNC_DIGEST_INIT, (void (*)(void))keccak_init },           \
+        PROV_DISPATCH_FUNC_DIGEST_CONSTRUCT_END
 
-#define PROV_FUNC_SHAKE_DIGEST(name, bitlen, blksize, dgstsize, flags)         \
-    PROV_FUNC_SHA3_DIGEST_COMMON(name, bitlen, blksize, dgstsize, flags),      \
-    { OSSL_FUNC_DIGEST_SQUEEZE, (void (*)(void))shake_squeeze },               \
-    { OSSL_FUNC_DIGEST_INIT, (void (*)(void))keccak_init_params },             \
-    { OSSL_FUNC_DIGEST_SET_CTX_PARAMS, (void (*)(void))shake_set_ctx_params }, \
-    { OSSL_FUNC_DIGEST_SETTABLE_CTX_PARAMS,                                    \
-     (void (*)(void))shake_settable_ctx_params },                              \
-    { OSSL_FUNC_DIGEST_GET_CTX_PARAMS, (void (*)(void))shake_get_ctx_params }, \
-    { OSSL_FUNC_DIGEST_GETTABLE_CTX_PARAMS,                                    \
-     (void (*)(void))shake_gettable_ctx_params },                              \
-    PROV_DISPATCH_FUNC_DIGEST_CONSTRUCT_END
+#define PROV_FUNC_SHAKE_DIGEST(name, bitlen, blksize, dgstsize, flags)             \
+    PROV_FUNC_SHA3_DIGEST_COMMON(name, bitlen, blksize, dgstsize, flags),          \
+        { OSSL_FUNC_DIGEST_SQUEEZE, (void (*)(void))shake_squeeze },               \
+        { OSSL_FUNC_DIGEST_INIT, (void (*)(void))keccak_init_params },             \
+        { OSSL_FUNC_DIGEST_SET_CTX_PARAMS, (void (*)(void))shake_set_ctx_params }, \
+        { OSSL_FUNC_DIGEST_SETTABLE_CTX_PARAMS,                                    \
+            (void (*)(void))shake_settable_ctx_params },                           \
+        { OSSL_FUNC_DIGEST_GET_CTX_PARAMS, (void (*)(void))shake_get_ctx_params }, \
+        { OSSL_FUNC_DIGEST_GETTABLE_CTX_PARAMS,                                    \
+            (void (*)(void))shake_gettable_ctx_params },                           \
+        PROV_DISPATCH_FUNC_DIGEST_CONSTRUCT_END
 
 static void keccak_freectx(void *vctx)
 {
     KECCAK1600_CTX *ctx = (KECCAK1600_CTX *)vctx;
 
-    OPENSSL_clear_free(ctx,  sizeof(*ctx));
+    OPENSSL_clear_free(ctx, sizeof(*ctx));
 }
 
 static void keccak_copyctx(void *voutctx, void *vinctx)
@@ -582,11 +574,11 @@ static void *keccak_dupctx(void *ctx)
 }
 
 static const OSSL_PARAM *shake_gettable_ctx_params(ossl_unused void *ctx,
-                                                   ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     static const OSSL_PARAM known_shake_gettable_ctx_params[] = {
-        {OSSL_DIGEST_PARAM_XOFLEN, OSSL_PARAM_UNSIGNED_INTEGER, NULL, 0, 0},
-        {OSSL_DIGEST_PARAM_SIZE, OSSL_PARAM_UNSIGNED_INTEGER, NULL, 0, 0},
+        { OSSL_DIGEST_PARAM_XOFLEN, OSSL_PARAM_UNSIGNED_INTEGER, NULL, 0, 0 },
+        { OSSL_DIGEST_PARAM_SIZE, OSSL_PARAM_UNSIGNED_INTEGER, NULL, 0, 0 },
         OSSL_PARAM_END
     };
     return known_shake_gettable_ctx_params;
@@ -617,11 +609,11 @@ static int shake_get_ctx_params(void *vctx, OSSL_PARAM params[])
 }
 
 static const OSSL_PARAM *shake_settable_ctx_params(ossl_unused void *ctx,
-                                                   ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     static const OSSL_PARAM known_shake_settable_ctx_params[] = {
-        {OSSL_DIGEST_PARAM_XOFLEN, OSSL_PARAM_UNSIGNED_INTEGER, NULL, 0, 0},
-        {OSSL_DIGEST_PARAM_SIZE, OSSL_PARAM_UNSIGNED_INTEGER, NULL, 0, 0},
+        { OSSL_DIGEST_PARAM_XOFLEN, OSSL_PARAM_UNSIGNED_INTEGER, NULL, 0, 0 },
+        { OSSL_DIGEST_PARAM_SIZE, OSSL_PARAM_UNSIGNED_INTEGER, NULL, 0, 0 },
         OSSL_PARAM_END
     };
 
@@ -649,30 +641,30 @@ static int shake_set_ctx_params(void *vctx, const OSSL_PARAM params[])
     return 1;
 }
 
-#define IMPLEMENT_SHA3_functions(bitlen)                                       \
-    SHA3_newctx(sha3, SHA3_##bitlen, sha3_##bitlen, bitlen, '\x06')            \
-    PROV_FUNC_SHA3_DIGEST(sha3_##bitlen, bitlen,                               \
-                          SHA3_BLOCKSIZE(bitlen), SHA3_MDSIZE(bitlen),         \
-                          SHA3_FLAGS)
+#define IMPLEMENT_SHA3_functions(bitlen)                            \
+    SHA3_newctx(sha3, SHA3_##bitlen, sha3_##bitlen, bitlen, '\x06') \
+        PROV_FUNC_SHA3_DIGEST(sha3_##bitlen, bitlen,                \
+            SHA3_BLOCKSIZE(bitlen), SHA3_MDSIZE(bitlen),            \
+            SHA3_FLAGS)
 
-#define IMPLEMENT_KECCAK_functions(bitlen)                                     \
-    SHA3_newctx(keccak, KECCAK_##bitlen, keccak_##bitlen, bitlen, '\x01')      \
-    PROV_FUNC_SHA3_DIGEST(keccak_##bitlen, bitlen,                             \
-                          SHA3_BLOCKSIZE(bitlen), SHA3_MDSIZE(bitlen),         \
-                          SHA3_FLAGS)
+#define IMPLEMENT_KECCAK_functions(bitlen)                                \
+    SHA3_newctx(keccak, KECCAK_##bitlen, keccak_##bitlen, bitlen, '\x01') \
+        PROV_FUNC_SHA3_DIGEST(keccak_##bitlen, bitlen,                    \
+            SHA3_BLOCKSIZE(bitlen), SHA3_MDSIZE(bitlen),                  \
+            SHA3_FLAGS)
 
-#define IMPLEMENT_SHAKE_functions(bitlen)                                      \
-    SHAKE_newctx(shake, SHAKE_##bitlen, shake_##bitlen, bitlen,                \
-                 0 /* no default md length */, '\x1f')                         \
-    PROV_FUNC_SHAKE_DIGEST(shake_##bitlen, bitlen,                             \
-                           SHA3_BLOCKSIZE(bitlen), 0,                          \
-                           SHAKE_FLAGS)
+#define IMPLEMENT_SHAKE_functions(bitlen)                       \
+    SHAKE_newctx(shake, SHAKE_##bitlen, shake_##bitlen, bitlen, \
+        0 /* no default md length */, '\x1f')                   \
+        PROV_FUNC_SHAKE_DIGEST(shake_##bitlen, bitlen,          \
+            SHA3_BLOCKSIZE(bitlen), 0,                          \
+            SHAKE_FLAGS)
 
-#define IMPLEMENT_KMAC_functions(bitlen)                                       \
-    KMAC_newctx(keccak_kmac_##bitlen, bitlen, '\x04')                          \
-    PROV_FUNC_SHAKE_DIGEST(keccak_kmac_##bitlen, bitlen,                       \
-                           SHA3_BLOCKSIZE(bitlen), KMAC_MDSIZE(bitlen),        \
-                           KMAC_FLAGS)
+#define IMPLEMENT_KMAC_functions(bitlen)                     \
+    KMAC_newctx(keccak_kmac_##bitlen, bitlen, '\x04')        \
+        PROV_FUNC_SHAKE_DIGEST(keccak_kmac_##bitlen, bitlen, \
+            SHA3_BLOCKSIZE(bitlen), KMAC_MDSIZE(bitlen),     \
+            KMAC_FLAGS)
 
 /* ossl_sha3_224_functions */
 IMPLEMENT_SHA3_functions(224)
