@@ -75,8 +75,8 @@ static int spki2typespki_set_ctx_params(void *vctx, const OSSL_PARAM params[])
 }
 
 static int spki2typespki_decode(void *vctx, OSSL_CORE_BIO *cin, int selection,
-                                OSSL_CALLBACK *data_cb, void *data_cbarg,
-                                OSSL_PASSPHRASE_CALLBACK *pw_cb, void *pw_cbarg)
+    OSSL_CALLBACK *data_cb, void *data_cbarg,
+    OSSL_PASSPHRASE_CALLBACK *pw_cb, void *pw_cbarg)
 {
     struct spki2typespki_ctx_st *ctx = vctx;
     unsigned char *der;
@@ -87,16 +87,16 @@ static int spki2typespki_decode(void *vctx, OSSL_CORE_BIO *cin, int selection,
         return 1;
 
     ok = ossl_spki2typespki_der_decode(der, len, selection, data_cb, data_cbarg,
-                                       pw_cb, pw_cbarg,
-                                       PROV_LIBCTX_OF(ctx->provctx), ctx->propq);
+        pw_cb, pw_cbarg,
+        PROV_LIBCTX_OF(ctx->provctx), ctx->propq);
     OPENSSL_free(der);
     return ok;
 }
 
 int ossl_spki2typespki_der_decode(unsigned char *der, long len, int selection,
-                                  OSSL_CALLBACK *data_cb, void *data_cbarg,
-                                  OSSL_PASSPHRASE_CALLBACK *pw_cb, void *pw_cbarg,
-                                  OSSL_LIB_CTX *libctx, const char *propq)
+    OSSL_CALLBACK *data_cb, void *data_cbarg,
+    OSSL_PASSPHRASE_CALLBACK *pw_cb, void *pw_cbarg,
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     const unsigned char *derp = der;
     X509_PUBKEY *xpub = NULL;
@@ -122,37 +122,33 @@ int ossl_spki2typespki_der_decode(unsigned char *der, long len, int selection,
 #ifndef OPENSSL_NO_EC
     /* SM2 abuses the EC oid, so this could actually be SM2 */
     if (OBJ_obj2nid(oid) == NID_X9_62_id_ecPublicKey
-            && ossl_x509_algor_is_sm2(algor))
+        && ossl_x509_algor_is_sm2(algor))
         strcpy(dataname, "SM2");
     else
 #endif
-    if (OBJ_obj2txt(dataname, sizeof(dataname), oid, 0) <= 0)
+        if (OBJ_obj2txt(dataname, sizeof(dataname), oid, 0) <= 0)
         goto end;
 
     ossl_X509_PUBKEY_INTERNAL_free(xpub);
     xpub = NULL;
 
-    *p++ =
-        OSSL_PARAM_construct_utf8_string(OSSL_OBJECT_PARAM_DATA_TYPE,
-                                            dataname, 0);
+    *p++ = OSSL_PARAM_construct_utf8_string(OSSL_OBJECT_PARAM_DATA_TYPE,
+        dataname, 0);
 
     *p++ = OSSL_PARAM_construct_utf8_string(OSSL_OBJECT_PARAM_INPUT_TYPE,
-                                            "DER", 0);
+        "DER", 0);
 
-    *p++ =
-        OSSL_PARAM_construct_utf8_string(OSSL_OBJECT_PARAM_DATA_STRUCTURE,
-                                            "SubjectPublicKeyInfo",
-                                            0);
-    *p++ =
-        OSSL_PARAM_construct_octet_string(OSSL_OBJECT_PARAM_DATA, der, len);
-    *p++ =
-        OSSL_PARAM_construct_int(OSSL_OBJECT_PARAM_TYPE, &objtype);
+    *p++ = OSSL_PARAM_construct_utf8_string(OSSL_OBJECT_PARAM_DATA_STRUCTURE,
+        "SubjectPublicKeyInfo",
+        0);
+    *p++ = OSSL_PARAM_construct_octet_string(OSSL_OBJECT_PARAM_DATA, der, len);
+    *p++ = OSSL_PARAM_construct_int(OSSL_OBJECT_PARAM_TYPE, &objtype);
 
     *p = OSSL_PARAM_construct_end();
 
     ok = data_cb(params, data_cbarg);
 
- end:
+end:
     ossl_X509_PUBKEY_INTERNAL_free(xpub);
     return ok;
 }
@@ -162,8 +158,8 @@ const OSSL_DISPATCH ossl_SubjectPublicKeyInfo_der_to_der_decoder_functions[] = {
     { OSSL_FUNC_DECODER_FREECTX, (void (*)(void))spki2typespki_freectx },
     { OSSL_FUNC_DECODER_DECODE, (void (*)(void))spki2typespki_decode },
     { OSSL_FUNC_DECODER_SETTABLE_CTX_PARAMS,
-      (void (*)(void))spki2typespki_settable_ctx_params },
+        (void (*)(void))spki2typespki_settable_ctx_params },
     { OSSL_FUNC_DECODER_SET_CTX_PARAMS,
-      (void (*)(void))spki2typespki_set_ctx_params },
+        (void (*)(void))spki2typespki_set_ctx_params },
     OSSL_DISPATCH_END
 };
