@@ -50,7 +50,7 @@ static OSSL_FUNC_keymgmt_export_fn dh_export;
 static OSSL_FUNC_keymgmt_export_types_fn dh_export_types;
 static OSSL_FUNC_keymgmt_dup_fn dh_dup;
 
-#define DH_POSSIBLE_SELECTIONS                                                 \
+#define DH_POSSIBLE_SELECTIONS \
     (OSSL_KEYMGMT_SELECT_KEYPAIR | OSSL_KEYMGMT_SELECT_DOMAIN_PARAMETERS)
 
 struct dh_gen_ctx {
@@ -205,8 +205,7 @@ static int dh_import(void *keydata, int selection, const OSSL_PARAM params[])
     ok = ok && ossl_dh_params_fromdata(dh, params);
 
     if ((selection & OSSL_KEYMGMT_SELECT_KEYPAIR) != 0) {
-        int include_private =
-            selection & OSSL_KEYMGMT_SELECT_PRIVATE_KEY ? 1 : 0;
+        int include_private = selection & OSSL_KEYMGMT_SELECT_PRIVATE_KEY ? 1 : 0;
 
         ok = ok && ossl_dh_key_fromdata(dh, params, include_private);
     }
@@ -215,7 +214,7 @@ static int dh_import(void *keydata, int selection, const OSSL_PARAM params[])
 }
 
 static int dh_export(void *keydata, int selection, OSSL_CALLBACK *param_cb,
-                     void *cbarg)
+    void *cbarg)
 {
     DH *dh = keydata;
     OSSL_PARAM_BLD *tmpl = NULL;
@@ -236,8 +235,7 @@ static int dh_export(void *keydata, int selection, OSSL_CALLBACK *param_cb,
         ok = ok && ossl_dh_params_todata(dh, tmpl, NULL);
 
     if ((selection & OSSL_KEYMGMT_SELECT_KEYPAIR) != 0) {
-        int include_private =
-            selection & OSSL_KEYMGMT_SELECT_PRIVATE_KEY ? 1 : 0;
+        int include_private = selection & OSSL_KEYMGMT_SELECT_PRIVATE_KEY ? 1 : 0;
 
         ok = ok && ossl_dh_key_todata(dh, tmpl, NULL, include_private);
     }
@@ -256,20 +254,20 @@ err:
 
 /* IMEXPORT = IMPORT + EXPORT */
 
-# define DH_IMEXPORTABLE_PARAMETERS                                            \
-    OSSL_PARAM_BN(OSSL_PKEY_PARAM_FFC_P, NULL, 0),                             \
-    OSSL_PARAM_BN(OSSL_PKEY_PARAM_FFC_Q, NULL, 0),                             \
-    OSSL_PARAM_BN(OSSL_PKEY_PARAM_FFC_G, NULL, 0),                             \
-    OSSL_PARAM_BN(OSSL_PKEY_PARAM_FFC_COFACTOR, NULL, 0),                      \
-    OSSL_PARAM_int(OSSL_PKEY_PARAM_FFC_GINDEX, NULL),                          \
-    OSSL_PARAM_int(OSSL_PKEY_PARAM_FFC_PCOUNTER, NULL),                        \
-    OSSL_PARAM_int(OSSL_PKEY_PARAM_FFC_H, NULL),                               \
-    OSSL_PARAM_int(OSSL_PKEY_PARAM_DH_PRIV_LEN, NULL),                         \
-    OSSL_PARAM_octet_string(OSSL_PKEY_PARAM_FFC_SEED, NULL, 0),                \
-    OSSL_PARAM_utf8_string(OSSL_PKEY_PARAM_GROUP_NAME, NULL, 0)
-# define DH_IMEXPORTABLE_PUBLIC_KEY                                            \
+#define DH_IMEXPORTABLE_PARAMETERS                                  \
+    OSSL_PARAM_BN(OSSL_PKEY_PARAM_FFC_P, NULL, 0),                  \
+        OSSL_PARAM_BN(OSSL_PKEY_PARAM_FFC_Q, NULL, 0),              \
+        OSSL_PARAM_BN(OSSL_PKEY_PARAM_FFC_G, NULL, 0),              \
+        OSSL_PARAM_BN(OSSL_PKEY_PARAM_FFC_COFACTOR, NULL, 0),       \
+        OSSL_PARAM_int(OSSL_PKEY_PARAM_FFC_GINDEX, NULL),           \
+        OSSL_PARAM_int(OSSL_PKEY_PARAM_FFC_PCOUNTER, NULL),         \
+        OSSL_PARAM_int(OSSL_PKEY_PARAM_FFC_H, NULL),                \
+        OSSL_PARAM_int(OSSL_PKEY_PARAM_DH_PRIV_LEN, NULL),          \
+        OSSL_PARAM_octet_string(OSSL_PKEY_PARAM_FFC_SEED, NULL, 0), \
+        OSSL_PARAM_utf8_string(OSSL_PKEY_PARAM_GROUP_NAME, NULL, 0)
+#define DH_IMEXPORTABLE_PUBLIC_KEY \
     OSSL_PARAM_BN(OSSL_PKEY_PARAM_PUB_KEY, NULL, 0)
-# define DH_IMEXPORTABLE_PRIVATE_KEY                                           \
+#define DH_IMEXPORTABLE_PRIVATE_KEY \
     OSSL_PARAM_BN(OSSL_PKEY_PARAM_PRIV_KEY, NULL, 0)
 static const OSSL_PARAM dh_all_types[] = {
     DH_IMEXPORTABLE_PARAMETERS,
@@ -287,10 +285,10 @@ static const OSSL_PARAM dh_key_types[] = {
     OSSL_PARAM_END
 };
 static const OSSL_PARAM *dh_types[] = {
-    NULL,                        /* Index 0 = none of them */
-    dh_parameter_types,          /* Index 1 = parameter types */
-    dh_key_types,                /* Index 2 = key types */
-    dh_all_types                 /* Index 3 = 1 + 2 */
+    NULL, /* Index 0 = none of them */
+    dh_parameter_types, /* Index 1 = parameter types */
+    dh_key_types, /* Index 2 = key types */
+    dh_all_types /* Index 3 = 1 + 2 */
 };
 
 static const OSSL_PARAM *dh_imexport_types(int selection)
@@ -332,7 +330,7 @@ static ossl_inline int dh_get_params(void *key, OSSL_PARAM params[])
         if (p->data_type != OSSL_PARAM_OCTET_STRING)
             return 0;
         p->return_size = ossl_dh_key2buf(dh, (unsigned char **)&p->data,
-                                         p->data_size, 0);
+            p->data_size, 0);
         if (p->return_size == 0)
             return 0;
     }
@@ -374,8 +372,8 @@ static int dh_set_params(void *key, const OSSL_PARAM params[])
 
     p = OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_ENCODED_PUBLIC_KEY);
     if (p != NULL
-            && (p->data_type != OSSL_PARAM_OCTET_STRING
-                || !ossl_dh_buf2key(dh, p->data, p->data_size)))
+        && (p->data_type != OSSL_PARAM_OCTET_STRING
+            || !ossl_dh_buf2key(dh, p->data, p->data_size)))
         return 0;
 
     return 1;
@@ -441,13 +439,13 @@ static int dh_validate(const void *keydata, int selection, int checktype)
         ok = ok && dh_validate_private(dh);
 
     if ((selection & OSSL_KEYMGMT_SELECT_KEYPAIR)
-            == OSSL_KEYMGMT_SELECT_KEYPAIR)
+        == OSSL_KEYMGMT_SELECT_KEYPAIR)
         ok = ok && ossl_dh_check_pairwise(dh, 0);
     return ok;
 }
 
 static void *dh_gen_init_base(void *provctx, int selection,
-                              const OSSL_PARAM params[], int type)
+    const OSSL_PARAM params[], int type)
 {
     OSSL_LIB_CTX *libctx = PROV_LIBCTX_OF(provctx);
     struct dh_gen_ctx *gctx = NULL;
@@ -455,8 +453,7 @@ static void *dh_gen_init_base(void *provctx, int selection,
     if (!ossl_prov_is_running())
         return NULL;
 
-    if ((selection & (OSSL_KEYMGMT_SELECT_KEYPAIR
-                      | OSSL_KEYMGMT_SELECT_DOMAIN_PARAMETERS)) == 0)
+    if ((selection & (OSSL_KEYMGMT_SELECT_KEYPAIR | OSSL_KEYMGMT_SELECT_DOMAIN_PARAMETERS)) == 0)
         return NULL;
 
     if ((gctx = OPENSSL_zalloc(sizeof(*gctx))) != NULL) {
@@ -467,12 +464,12 @@ static void *dh_gen_init_base(void *provctx, int selection,
         gctx->mdname = NULL;
 #ifdef FIPS_MODULE
         gctx->gen_type = (type == DH_FLAG_TYPE_DHX)
-                         ? DH_PARAMGEN_TYPE_FIPS_186_4
-                         : DH_PARAMGEN_TYPE_GROUP;
+            ? DH_PARAMGEN_TYPE_FIPS_186_4
+            : DH_PARAMGEN_TYPE_GROUP;
 #else
         gctx->gen_type = (type == DH_FLAG_TYPE_DHX)
-                         ? DH_PARAMGEN_TYPE_FIPS_186_2
-                         : DH_PARAMGEN_TYPE_GENERATOR;
+            ? DH_PARAMGEN_TYPE_FIPS_186_2
+            : DH_PARAMGEN_TYPE_GENERATOR;
 #endif
         gctx->gindex = -1;
         gctx->hindex = 0;
@@ -488,15 +485,15 @@ static void *dh_gen_init_base(void *provctx, int selection,
 }
 
 static void *dh_gen_init(void *provctx, int selection,
-                         const OSSL_PARAM params[])
+    const OSSL_PARAM params[])
 {
     return dh_gen_init_base(provctx, selection, params, DH_FLAG_TYPE_DH);
 }
 
 static void *dhx_gen_init(void *provctx, int selection,
-                          const OSSL_PARAM params[])
+    const OSSL_PARAM params[])
 {
-   return dh_gen_init_base(provctx, selection, params, DH_FLAG_TYPE_DHX);
+    return dh_gen_init_base(provctx, selection, params, DH_FLAG_TYPE_DHX);
 }
 
 static int dh_gen_set_template(void *genctx, void *templ)
@@ -511,7 +508,7 @@ static int dh_gen_set_template(void *genctx, void *templ)
 }
 
 static int dh_set_gen_seed(struct dh_gen_ctx *gctx, unsigned char *seed,
-                           size_t seedlen)
+    size_t seedlen)
 {
     OPENSSL_clear_free(gctx->seed, gctx->seedlen);
     gctx->seed = NULL;
@@ -539,8 +536,7 @@ static int dh_gen_common_set_params(void *genctx, const OSSL_PARAM params[])
     p = OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_FFC_TYPE);
     if (p != NULL) {
         if (p->data_type != OSSL_PARAM_UTF8_STRING
-            || ((gen_type =
-                 dh_gen_type_name2id_w_default(p->data, gctx->dh_type)) == -1)) {
+            || ((gen_type = dh_gen_type_name2id_w_default(p->data, gctx->dh_type)) == -1)) {
             ERR_raise(ERR_LIB_PROV, ERR_R_PASSED_INVALID_ARGUMENT);
             return 0;
         }
@@ -554,8 +550,7 @@ static int dh_gen_common_set_params(void *genctx, const OSSL_PARAM params[])
         if (p->data_type != OSSL_PARAM_UTF8_STRING
             || p->data == NULL
             || (group = ossl_ffc_name_to_dh_named_group(p->data)) == NULL
-            || ((gctx->group_nid =
-                 ossl_ffc_named_group_get_uid(group)) == NID_undef)) {
+            || ((gctx->group_nid = ossl_ffc_named_group_get_uid(group)) == NID_undef)) {
             ERR_raise(ERR_LIB_PROV, ERR_R_PASSED_INVALID_ARGUMENT);
             return 0;
         }
@@ -570,7 +565,7 @@ static int dh_gen_common_set_params(void *genctx, const OSSL_PARAM params[])
 }
 
 static const OSSL_PARAM *dh_gen_settable_params(ossl_unused void *genctx,
-                                                ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     static const OSSL_PARAM dh_gen_settable[] = {
         OSSL_PARAM_utf8_string(OSSL_PKEY_PARAM_FFC_TYPE, NULL, 0),
@@ -584,7 +579,7 @@ static const OSSL_PARAM *dh_gen_settable_params(ossl_unused void *genctx,
 }
 
 static const OSSL_PARAM *dhx_gen_settable_params(ossl_unused void *genctx,
-                                                 ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     static const OSSL_PARAM dhx_gen_settable[] = {
         OSSL_PARAM_utf8_string(OSSL_PKEY_PARAM_FFC_TYPE, NULL, 0),
@@ -625,7 +620,7 @@ static int dhx_gen_set_params(void *genctx, const OSSL_PARAM params[])
     if (p != NULL
         && (p->data_type != OSSL_PARAM_OCTET_STRING
             || !dh_set_gen_seed(gctx, p->data, p->data_size)))
-            return 0;
+        return 0;
     if ((p = OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_FFC_QBITS)) != NULL
         && !OSSL_PARAM_get_size_t(p, &gctx->qbits))
         return 0;
@@ -677,7 +672,8 @@ static int dh_gen_set_params(void *genctx, const OSSL_PARAM params[])
         || OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_FFC_QBITS) != NULL
         || OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_FFC_DIGEST) != NULL
         || OSSL_PARAM_locate_const(params,
-                                   OSSL_PKEY_PARAM_FFC_DIGEST_PROPS) != NULL) {
+               OSSL_PKEY_PARAM_FFC_DIGEST_PROPS)
+            != NULL) {
         ERR_raise(ERR_LIB_PROV, ERR_R_PASSED_INVALID_ARGUMENT);
         return 0;
     }
@@ -721,15 +717,15 @@ static void *dh_gen(void *genctx, OSSL_CALLBACK *osslcb, void *cbarg)
      * added.
      */
     if (!ossl_assert((gctx->gen_type >= DH_PARAMGEN_TYPE_GENERATOR)
-                    && (gctx->gen_type <= DH_PARAMGEN_TYPE_GROUP))) {
+            && (gctx->gen_type <= DH_PARAMGEN_TYPE_GROUP))) {
         ERR_raise_data(ERR_LIB_PROV, ERR_R_INTERNAL_ERROR,
-                       "gen_type set to unsupported value %d", gctx->gen_type);
+            "gen_type set to unsupported value %d", gctx->gen_type);
         return NULL;
     }
 
     /* For parameter generation - If there is a group name just create it */
     if (gctx->gen_type == DH_PARAMGEN_TYPE_GROUP
-            && gctx->ffc_params == NULL) {
+        && gctx->ffc_params == NULL) {
         /* Select a named group if there is not one already */
         if (gctx->group_nid == NID_undef)
             gctx->group_nid = ossl_dh_get_named_group_uid_from_size(gctx->pbits);
@@ -775,11 +771,11 @@ static void *dh_gen(void *genctx, OSSL_CALLBACK *osslcb, void *cbarg)
              */
             if (gctx->gen_type == DH_PARAMGEN_TYPE_GENERATOR)
                 ret = DH_generate_parameters_ex(dh, gctx->pbits,
-                                                gctx->generator, gencb);
+                    gctx->generator, gencb);
             else
                 ret = ossl_dh_generate_ffc_parameters(dh, gctx->gen_type,
-                                                      gctx->pbits, gctx->qbits,
-                                                      gencb);
+                    gctx->pbits, gctx->qbits,
+                    gencb);
             if (ret <= 0)
                 goto end;
         }
@@ -791,7 +787,7 @@ static void *dh_gen(void *genctx, OSSL_CALLBACK *osslcb, void *cbarg)
         if (gctx->priv_len > 0)
             DH_set_length(dh, (long)gctx->priv_len);
         ossl_ffc_params_enable_flags(ffc, FFC_PARAM_FLAG_VALIDATE_LEGACY,
-                                     gctx->gen_type == DH_PARAMGEN_TYPE_FIPS_186_2);
+            gctx->gen_type == DH_PARAMGEN_TYPE_FIPS_186_2);
         if (DH_generate_key(dh) <= 0)
             goto end;
 #ifdef FIPS_MODULE
@@ -857,15 +853,15 @@ const OSSL_DISPATCH ossl_dh_keymgmt_functions[] = {
     { OSSL_FUNC_KEYMGMT_GEN_SET_TEMPLATE, (void (*)(void))dh_gen_set_template },
     { OSSL_FUNC_KEYMGMT_GEN_SET_PARAMS, (void (*)(void))dh_gen_set_params },
     { OSSL_FUNC_KEYMGMT_GEN_SETTABLE_PARAMS,
-      (void (*)(void))dh_gen_settable_params },
+        (void (*)(void))dh_gen_settable_params },
     { OSSL_FUNC_KEYMGMT_GEN, (void (*)(void))dh_gen },
     { OSSL_FUNC_KEYMGMT_GEN_CLEANUP, (void (*)(void))dh_gen_cleanup },
     { OSSL_FUNC_KEYMGMT_LOAD, (void (*)(void))dh_load },
     { OSSL_FUNC_KEYMGMT_FREE, (void (*)(void))dh_freedata },
-    { OSSL_FUNC_KEYMGMT_GET_PARAMS, (void (*) (void))dh_get_params },
-    { OSSL_FUNC_KEYMGMT_GETTABLE_PARAMS, (void (*) (void))dh_gettable_params },
-    { OSSL_FUNC_KEYMGMT_SET_PARAMS, (void (*) (void))dh_set_params },
-    { OSSL_FUNC_KEYMGMT_SETTABLE_PARAMS, (void (*) (void))dh_settable_params },
+    { OSSL_FUNC_KEYMGMT_GET_PARAMS, (void (*)(void))dh_get_params },
+    { OSSL_FUNC_KEYMGMT_GETTABLE_PARAMS, (void (*)(void))dh_gettable_params },
+    { OSSL_FUNC_KEYMGMT_SET_PARAMS, (void (*)(void))dh_set_params },
+    { OSSL_FUNC_KEYMGMT_SETTABLE_PARAMS, (void (*)(void))dh_settable_params },
     { OSSL_FUNC_KEYMGMT_HAS, (void (*)(void))dh_has },
     { OSSL_FUNC_KEYMGMT_MATCH, (void (*)(void))dh_match },
     { OSSL_FUNC_KEYMGMT_VALIDATE, (void (*)(void))dh_validate },
@@ -889,15 +885,15 @@ const OSSL_DISPATCH ossl_dhx_keymgmt_functions[] = {
     { OSSL_FUNC_KEYMGMT_GEN_SET_TEMPLATE, (void (*)(void))dh_gen_set_template },
     { OSSL_FUNC_KEYMGMT_GEN_SET_PARAMS, (void (*)(void))dhx_gen_set_params },
     { OSSL_FUNC_KEYMGMT_GEN_SETTABLE_PARAMS,
-      (void (*)(void))dhx_gen_settable_params },
+        (void (*)(void))dhx_gen_settable_params },
     { OSSL_FUNC_KEYMGMT_GEN, (void (*)(void))dh_gen },
     { OSSL_FUNC_KEYMGMT_GEN_CLEANUP, (void (*)(void))dh_gen_cleanup },
     { OSSL_FUNC_KEYMGMT_LOAD, (void (*)(void))dh_load },
     { OSSL_FUNC_KEYMGMT_FREE, (void (*)(void))dh_freedata },
-    { OSSL_FUNC_KEYMGMT_GET_PARAMS, (void (*) (void))dh_get_params },
-    { OSSL_FUNC_KEYMGMT_GETTABLE_PARAMS, (void (*) (void))dh_gettable_params },
-    { OSSL_FUNC_KEYMGMT_SET_PARAMS, (void (*) (void))dh_set_params },
-    { OSSL_FUNC_KEYMGMT_SETTABLE_PARAMS, (void (*) (void))dh_settable_params },
+    { OSSL_FUNC_KEYMGMT_GET_PARAMS, (void (*)(void))dh_get_params },
+    { OSSL_FUNC_KEYMGMT_GETTABLE_PARAMS, (void (*)(void))dh_gettable_params },
+    { OSSL_FUNC_KEYMGMT_SET_PARAMS, (void (*)(void))dh_set_params },
+    { OSSL_FUNC_KEYMGMT_SETTABLE_PARAMS, (void (*)(void))dh_settable_params },
     { OSSL_FUNC_KEYMGMT_HAS, (void (*)(void))dh_has },
     { OSSL_FUNC_KEYMGMT_MATCH, (void (*)(void))dh_match },
     { OSSL_FUNC_KEYMGMT_VALIDATE, (void (*)(void))dh_validate },
@@ -906,7 +902,7 @@ const OSSL_DISPATCH ossl_dhx_keymgmt_functions[] = {
     { OSSL_FUNC_KEYMGMT_EXPORT, (void (*)(void))dh_export },
     { OSSL_FUNC_KEYMGMT_EXPORT_TYPES, (void (*)(void))dh_export_types },
     { OSSL_FUNC_KEYMGMT_QUERY_OPERATION_NAME,
-      (void (*)(void))dhx_query_operation_name },
+        (void (*)(void))dhx_query_operation_name },
     { OSSL_FUNC_KEYMGMT_DUP, (void (*)(void))dh_dup },
     OSSL_DISPATCH_END
 };
