@@ -99,8 +99,8 @@ static int ml_kem_pairwise_test(const ML_KEM_KEY *key, int key_flags)
         return 0;
 
     OSSL_SELF_TEST_onbegin(st, OSSL_SELF_TEST_TYPE_PCT,
-                           OSSL_SELF_TEST_DESC_PCT_ML_KEM);
-#endif  /* FIPS_MODULE */
+        OSSL_SELF_TEST_DESC_PCT_ML_KEM);
+#endif /* FIPS_MODULE */
 
     ctext = OPENSSL_malloc(v->ctext_bytes);
     if (ctext == NULL)
@@ -114,13 +114,13 @@ static int ml_kem_pairwise_test(const ML_KEM_KEY *key, int key_flags)
      */
     if (key_flags & ML_KEM_KEY_RANDOM_PCT) {
         operation_result = ossl_ml_kem_encap_rand(ctext, v->ctext_bytes,
-                                                  secret, sizeof(secret), key);
+            secret, sizeof(secret), key);
     } else {
         memset(entropy, 0125, sizeof(entropy));
         operation_result = ossl_ml_kem_encap_seed(ctext, v->ctext_bytes,
-                                                  secret, sizeof(secret),
-                                                  entropy, sizeof(entropy),
-                                                  key);
+            secret, sizeof(secret),
+            entropy, sizeof(entropy),
+            key);
     }
     if (operation_result != 1)
         goto err;
@@ -130,7 +130,7 @@ static int ml_kem_pairwise_test(const ML_KEM_KEY *key, int key_flags)
 #endif
 
     operation_result = ossl_ml_kem_decap(out, sizeof(out), ctext, v->ctext_bytes,
-                                         key);
+        key);
     if (operation_result != 1 || memcmp(out, secret, sizeof(out)) != 0)
         goto err;
 
@@ -142,8 +142,8 @@ err:
 #else
     if (ret == 0) {
         ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_KEY,
-                       "public part of %s private key fails to match private",
-                       v->algorithm_name);
+            "public part of %s private key fails to match private",
+            v->algorithm_name);
     }
 #endif
     OPENSSL_free(ctext);
@@ -167,12 +167,12 @@ ML_KEM_KEY *ossl_prov_ml_kem_new(PROV_CTX *ctx, const char *propq, int evp_type)
             ctx, OSSL_PKEY_PARAM_ML_KEM_IMPORT_PCT_TYPE, "random");
 
         if (ossl_prov_ctx_get_bool_param(
-            ctx, OSSL_PKEY_PARAM_ML_KEM_RETAIN_SEED, 1))
+                ctx, OSSL_PKEY_PARAM_ML_KEM_RETAIN_SEED, 1))
             key->prov_flags |= ML_KEM_KEY_RETAIN_SEED;
         else
             key->prov_flags &= ~ML_KEM_KEY_RETAIN_SEED;
         if (ossl_prov_ctx_get_bool_param(
-            ctx, OSSL_PKEY_PARAM_ML_KEM_PREFER_SEED, 1))
+                ctx, OSSL_PKEY_PARAM_ML_KEM_PREFER_SEED, 1))
             key->prov_flags |= ML_KEM_KEY_PREFER_SEED;
         else
             key->prov_flags &= ~ML_KEM_KEY_PREFER_SEED;
@@ -232,7 +232,7 @@ static int ml_kem_validate(const void *vkey, int selection, int check_type)
 }
 
 static int ml_kem_export(void *vkey, int selection, OSSL_CALLBACK *param_cb,
-                         void *cbarg)
+    void *cbarg)
 {
     ML_KEM_KEY *key = vkey;
     OSSL_PARAM_BLD *tmpl = NULL;
@@ -295,20 +295,20 @@ static int ml_kem_export(void *vkey, int selection, OSSL_CALLBACK *param_cb,
     /* The (d, z) seed, when available and private keys are requested. */
     if (seedenc != NULL
         && !ossl_param_build_set_octet_string(
-                tmpl, params, OSSL_PKEY_PARAM_ML_KEM_SEED, seedenc, seedlen))
+            tmpl, params, OSSL_PKEY_PARAM_ML_KEM_SEED, seedenc, seedlen))
         goto err;
 
     /* The private key in the FIPS 203 |dk| format, when requested. */
     if (prvenc != NULL
         && !ossl_param_build_set_octet_string(
-                tmpl, params, OSSL_PKEY_PARAM_PRIV_KEY, prvenc, prvlen))
-            goto err;
+            tmpl, params, OSSL_PKEY_PARAM_PRIV_KEY, prvenc, prvlen))
+        goto err;
 
     /* The public key on request; it is always available when either is */
     if (pubenc != NULL
         && !ossl_param_build_set_octet_string(
-               tmpl, params, OSSL_PKEY_PARAM_PUB_KEY, pubenc, v->pubkey_bytes))
-            goto err;
+            tmpl, params, OSSL_PKEY_PARAM_PUB_KEY, pubenc, v->pubkey_bytes))
+        goto err;
 
     params = OSSL_PARAM_BLD_to_param(tmpl);
     if (params == NULL)
@@ -340,16 +340,18 @@ static const OSSL_PARAM *ml_kem_imexport_types(int selection)
 }
 
 static int check_seed(const uint8_t *seed, const uint8_t *prvenc,
-                      ML_KEM_KEY *key)
+    ML_KEM_KEY *key)
 {
     size_t zlen = ML_KEM_RANDOM_BYTES;
 
     if (memcmp(seed + ML_KEM_SEED_BYTES - zlen,
-               prvenc + key->vinfo->prvkey_bytes - zlen, zlen) == 0)
+            prvenc + key->vinfo->prvkey_bytes - zlen, zlen)
+        == 0)
         return 1;
     ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_KEY,
-                   "private %s key implicit rejection secret does"
-                   " not match seed", key->vinfo->algorithm_name);
+        "private %s key implicit rejection secret does"
+        " not match seed",
+        key->vinfo->algorithm_name);
     return 0;
 }
 
@@ -368,15 +370,15 @@ static int check_prvenc(const uint8_t *prvenc, ML_KEM_KEY *key)
 
     if (buf != NULL)
         ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_KEY,
-                       "explicit %s private key does not match seed",
-                       key->vinfo->algorithm_name);
+            "explicit %s private key does not match seed",
+            key->vinfo->algorithm_name);
     ossl_ml_kem_key_reset(key);
     return 0;
 }
 
 static int ml_kem_key_fromdata(ML_KEM_KEY *key,
-                               const OSSL_PARAM params[],
-                               int include_private)
+    const OSSL_PARAM params[],
+    int include_private)
 {
     const OSSL_PARAM *p = NULL;
     const void *pubenc = NULL, *prvenc = NULL, *seedenc = NULL;
@@ -438,8 +440,8 @@ static int ml_kem_key_fromdata(ML_KEM_KEY *key,
         puboff = prvlen - ML_KEM_RANDOM_BYTES - ML_KEM_PKHASH_BYTES - publen;
         if (memcmp(pubenc, (unsigned char *)prvenc + puboff, publen) != 0) {
             ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_KEY,
-                           "explicit %s public key does not match private",
-                           v->algorithm_name);
+                "explicit %s public key does not match private",
+                v->algorithm_name);
             return 0;
         }
     }
@@ -475,7 +477,7 @@ static int ml_kem_import(void *vkey, int selection, const OSSL_PARAM params[])
     if (res > 0 && include_private
         && !ml_kem_pairwise_test(key, key->prov_flags)) {
 #ifdef FIPS_MODULE
-        ossl_set_error_state(OSSL_SELF_TEST_TYPE_PCT);
+        ossl_set_error_state(OSSL_SELF_TEST_TYPE_PCT_IMPORT);
 #endif
         ossl_ml_kem_key_reset(key);
         res = 0;
@@ -504,7 +506,7 @@ static const OSSL_PARAM *ml_kem_gettable_params(void *provctx)
 }
 
 #ifndef FIPS_MODULE
-void *ml_kem_load(const void *reference, size_t reference_sz)
+static void *ml_kem_load(const void *reference, size_t reference_sz)
 {
     ML_KEM_KEY *key = NULL;
     uint8_t *encoded_dk = NULL;
@@ -530,10 +532,10 @@ void *ml_kem_load(const void *reference, size_t reference_sz)
                 goto err;
         } else if (encoded_dk != NULL) {
             if (!ossl_ml_kem_parse_private_key(encoded_dk,
-                                               key->vinfo->prvkey_bytes, key)) {
+                    key->vinfo->prvkey_bytes, key)) {
                 ERR_raise_data(ERR_LIB_PROV, PROV_R_INVALID_KEY,
-                               "error parsing %s private key",
-                               key->vinfo->algorithm_name);
+                    "error parsing %s private key",
+                    key->vinfo->algorithm_name);
                 goto err;
             }
             if (!ml_kem_pairwise_test(key, key->prov_flags))
@@ -543,7 +545,7 @@ void *ml_kem_load(const void *reference, size_t reference_sz)
         return key;
     }
 
- err:
+err:
     OPENSSL_free(encoded_dk);
     ossl_ml_kem_key_free(key);
     return NULL;
@@ -667,8 +669,8 @@ static int ml_kem_set_params(void *vkey, const OSSL_PARAM params[])
     /* Key mutation is reportedly generally not allowed */
     if (ossl_ml_kem_have_pubkey(key)) {
         ERR_raise_data(ERR_LIB_PROV,
-                       PROV_R_OPERATION_NOT_SUPPORTED_FOR_THIS_KEYTYPE,
-                       "ML-KEM keys cannot be mutated");
+            PROV_R_OPERATION_NOT_SUPPORTED_FOR_THIS_KEYTYPE,
+            "ML-KEM keys cannot be mutated");
         return 0;
     }
 
@@ -713,7 +715,7 @@ static int ml_kem_gen_set_params(void *vgctx, const OSSL_PARAM params[])
 }
 
 static void *ml_kem_gen_init(void *provctx, int selection,
-                             const OSSL_PARAM params[], int evp_type)
+    const OSSL_PARAM params[], int evp_type)
 {
     PROV_ML_KEM_GEN_CTX *gctx = NULL;
 
@@ -737,7 +739,7 @@ static void *ml_kem_gen_init(void *provctx, int selection,
 }
 
 static const OSSL_PARAM *ml_kem_gen_settable_params(ossl_unused void *vgctx,
-                                                    ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     static OSSL_PARAM settable[] = {
         OSSL_PARAM_octet_string(OSSL_PKEY_PARAM_ML_KEM_SEED, NULL, 0),
@@ -755,8 +757,7 @@ static void *ml_kem_gen(void *vgctx, OSSL_CALLBACK *osslcb, void *cbarg)
     int genok = 0;
 
     if (gctx == NULL
-        || (gctx->selection & OSSL_KEYMGMT_SELECT_KEYPAIR) ==
-            OSSL_KEYMGMT_SELECT_PUBLIC_KEY)
+        || (gctx->selection & OSSL_KEYMGMT_SELECT_KEYPAIR) == OSSL_KEYMGMT_SELECT_PUBLIC_KEY)
         return NULL;
     seed = gctx->seed;
     key = ossl_prov_ml_kem_new(gctx->provctx, gctx->propq, gctx->evp_type);
@@ -782,7 +783,7 @@ static void *ml_kem_gen(void *vgctx, OSSL_CALLBACK *osslcb, void *cbarg)
             ossl_ml_kem_key_free(key);
             return NULL;
         }
-#endif  /* FIPS_MODULE */
+#endif /* FIPS_MODULE */
         return key;
     }
 
@@ -814,45 +815,44 @@ static void *ml_kem_dup(const void *vkey, int selection)
 }
 
 #ifndef FIPS_MODULE
-# define DISPATCH_LOAD_FN \
-        { OSSL_FUNC_KEYMGMT_LOAD, (OSSL_FUNC) ml_kem_load },
+#define DISPATCH_LOAD_FN \
+    { OSSL_FUNC_KEYMGMT_LOAD, (OSSL_FUNC)ml_kem_load },
 #else
-# define DISPATCH_LOAD_FN   /* Non-FIPS only */
+#define DISPATCH_LOAD_FN /* Non-FIPS only */
 #endif
 
-#define DECLARE_VARIANT(bits) \
-    static void *ml_kem_##bits##_new(void *provctx) \
-    { \
-        return ossl_prov_ml_kem_new(provctx, NULL, EVP_PKEY_ML_KEM_##bits); \
-    } \
-    static void *ml_kem_##bits##_gen_init(void *provctx, int selection, \
-                                          const OSSL_PARAM params[]) \
-    { \
-        return ml_kem_gen_init(provctx, selection, params, \
-                               EVP_PKEY_ML_KEM_##bits); \
-    } \
-    const OSSL_DISPATCH ossl_ml_kem_##bits##_keymgmt_functions[] = { \
-        { OSSL_FUNC_KEYMGMT_NEW, (OSSL_FUNC) ml_kem_##bits##_new }, \
-        { OSSL_FUNC_KEYMGMT_FREE, (OSSL_FUNC) ossl_ml_kem_key_free }, \
-        { OSSL_FUNC_KEYMGMT_GET_PARAMS, (OSSL_FUNC) ml_kem_get_params }, \
-        { OSSL_FUNC_KEYMGMT_GETTABLE_PARAMS, (OSSL_FUNC) ml_kem_gettable_params }, \
-        { OSSL_FUNC_KEYMGMT_SET_PARAMS, (OSSL_FUNC) ml_kem_set_params }, \
-        { OSSL_FUNC_KEYMGMT_SETTABLE_PARAMS, (OSSL_FUNC) ml_kem_settable_params }, \
-        { OSSL_FUNC_KEYMGMT_HAS, (OSSL_FUNC) ml_kem_has }, \
-        { OSSL_FUNC_KEYMGMT_MATCH, (OSSL_FUNC) ml_kem_match }, \
-        { OSSL_FUNC_KEYMGMT_VALIDATE, (OSSL_FUNC) ml_kem_validate }, \
-        { OSSL_FUNC_KEYMGMT_GEN_INIT, (OSSL_FUNC) ml_kem_##bits##_gen_init }, \
-        { OSSL_FUNC_KEYMGMT_GEN_SET_PARAMS, (OSSL_FUNC) ml_kem_gen_set_params }, \
-        { OSSL_FUNC_KEYMGMT_GEN_SETTABLE_PARAMS, (OSSL_FUNC) ml_kem_gen_settable_params }, \
-        { OSSL_FUNC_KEYMGMT_GEN, (OSSL_FUNC) ml_kem_gen }, \
-        { OSSL_FUNC_KEYMGMT_GEN_CLEANUP, (OSSL_FUNC) ml_kem_gen_cleanup }, \
-        DISPATCH_LOAD_FN \
-        { OSSL_FUNC_KEYMGMT_DUP, (OSSL_FUNC) ml_kem_dup }, \
-        { OSSL_FUNC_KEYMGMT_IMPORT, (OSSL_FUNC) ml_kem_import }, \
-        { OSSL_FUNC_KEYMGMT_IMPORT_TYPES, (OSSL_FUNC) ml_kem_imexport_types }, \
-        { OSSL_FUNC_KEYMGMT_EXPORT, (OSSL_FUNC) ml_kem_export }, \
-        { OSSL_FUNC_KEYMGMT_EXPORT_TYPES, (OSSL_FUNC) ml_kem_imexport_types }, \
-        OSSL_DISPATCH_END \
+#define DECLARE_VARIANT(bits)                                                             \
+    static void *ml_kem_##bits##_new(void *provctx)                                       \
+    {                                                                                     \
+        return ossl_prov_ml_kem_new(provctx, NULL, EVP_PKEY_ML_KEM_##bits);               \
+    }                                                                                     \
+    static void *ml_kem_##bits##_gen_init(void *provctx, int selection,                   \
+        const OSSL_PARAM params[])                                                        \
+    {                                                                                     \
+        return ml_kem_gen_init(provctx, selection, params,                                \
+            EVP_PKEY_ML_KEM_##bits);                                                      \
+    }                                                                                     \
+    const OSSL_DISPATCH ossl_ml_kem_##bits##_keymgmt_functions[] = {                      \
+        { OSSL_FUNC_KEYMGMT_NEW, (OSSL_FUNC)ml_kem_##bits##_new },                        \
+        { OSSL_FUNC_KEYMGMT_FREE, (OSSL_FUNC)ossl_ml_kem_key_free },                      \
+        { OSSL_FUNC_KEYMGMT_GET_PARAMS, (OSSL_FUNC)ml_kem_get_params },                   \
+        { OSSL_FUNC_KEYMGMT_GETTABLE_PARAMS, (OSSL_FUNC)ml_kem_gettable_params },         \
+        { OSSL_FUNC_KEYMGMT_SET_PARAMS, (OSSL_FUNC)ml_kem_set_params },                   \
+        { OSSL_FUNC_KEYMGMT_SETTABLE_PARAMS, (OSSL_FUNC)ml_kem_settable_params },         \
+        { OSSL_FUNC_KEYMGMT_HAS, (OSSL_FUNC)ml_kem_has },                                 \
+        { OSSL_FUNC_KEYMGMT_MATCH, (OSSL_FUNC)ml_kem_match },                             \
+        { OSSL_FUNC_KEYMGMT_VALIDATE, (OSSL_FUNC)ml_kem_validate },                       \
+        { OSSL_FUNC_KEYMGMT_GEN_INIT, (OSSL_FUNC)ml_kem_##bits##_gen_init },              \
+        { OSSL_FUNC_KEYMGMT_GEN_SET_PARAMS, (OSSL_FUNC)ml_kem_gen_set_params },           \
+        { OSSL_FUNC_KEYMGMT_GEN_SETTABLE_PARAMS, (OSSL_FUNC)ml_kem_gen_settable_params }, \
+        { OSSL_FUNC_KEYMGMT_GEN, (OSSL_FUNC)ml_kem_gen },                                 \
+        { OSSL_FUNC_KEYMGMT_GEN_CLEANUP, (OSSL_FUNC)ml_kem_gen_cleanup },                 \
+        DISPATCH_LOAD_FN { OSSL_FUNC_KEYMGMT_DUP, (OSSL_FUNC)ml_kem_dup },                \
+        { OSSL_FUNC_KEYMGMT_IMPORT, (OSSL_FUNC)ml_kem_import },                           \
+        { OSSL_FUNC_KEYMGMT_IMPORT_TYPES, (OSSL_FUNC)ml_kem_imexport_types },             \
+        { OSSL_FUNC_KEYMGMT_EXPORT, (OSSL_FUNC)ml_kem_export },                           \
+        { OSSL_FUNC_KEYMGMT_EXPORT_TYPES, (OSSL_FUNC)ml_kem_imexport_types },             \
+        OSSL_DISPATCH_END                                                                 \
     }
 DECLARE_VARIANT(512);
 DECLARE_VARIANT(768);
