@@ -1,5 +1,5 @@
 /*
- * Copyright 2011-2024 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2011-2026 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -19,6 +19,9 @@
 #include "prov/provider_ctx.h"
 #include "prov/hmac_drbg.h"
 #include "drbg_local.h"
+#include "crypto/evp.h"
+#include "crypto/evp/evp_local.h"
+#include "internal/provider.h"
 
 static OSSL_FUNC_rand_newctx_fn drbg_hmac_new_wrapper;
 static OSSL_FUNC_rand_freectx_fn drbg_hmac_free;
@@ -406,11 +409,91 @@ static const OSSL_PARAM *drbg_hmac_gettable_ctx_params(ossl_unused void *vctx,
     return known_gettable_ctx_params;
 }
 
+static int drbg_fetch_algs_from_prov(const OSSL_PARAM params[],
+    OSSL_LIB_CTX *libctx,
+    EVP_MAC_CTX **macctx,
+    EVP_MD **digest)
+{
+    OSSL_PROVIDER *prov = NULL;
+    const OSSL_PARAM *p;
+    const char *digest_name = NULL;
+    const char *hmac_name = NULL;
+    EVP_MD *md = NULL;
+    EVP_MAC *mac = NULL;
+    OSSL_PARAM mac_params[2], *mp = mac_params;
+    int ret = 0;
+
+    if (macctx == NULL || digest == NULL)
+        return 0;
+
+    if ((p = OSSL_PARAM_locate_const(params,
+             OSSL_PROV_PARAM_CORE_PROV_NAME))
+        == NULL)
+        return 0;
+    if (p->data_type != OSSL_PARAM_UTF8_STRING)
+        return 0;
+    if ((prov = ossl_provider_find(libctx, (const char *)p->data, 1)) == NULL)
+        return 0;
+
+    p = OSSL_PARAM_locate_const(params, OSSL_ALG_PARAM_DIGEST);
+    if (p) {
+        if (OSSL_PARAM_get_utf8_string_ptr(p, &digest_name)) {
+            ERR_raise(ERR_LIB_PROV, PROV_R_VALUE_ERROR);
+            goto done;
+        }
+        md = evp_digest_fetch_from_prov(prov, digest_name, NULL);
+        if (md) {
+            EVP_MD_free(*digest);
+            *digest = md;
+        } else {
+            ERR_raise(ERR_LIB_PROV, PROV_R_INVALID_DIGEST);
+            goto done;
+        }
+    } else {
+        /* we need a digest */
+        ERR_raise(ERR_LIB_PROV, PROV_R_INVALID_DIGEST);
+        goto done;
+    }
+    p = OSSL_PARAM_locate_const(params, OSSL_ALG_PARAM_MAC);
+    if (p == NULL) {
+        hmac_name = "HMAC";
+    } else {
+        if (OSSL_PARAM_get_utf8_string_ptr(p, &hmac_name)) {
+            ERR_raise(ERR_LIB_PROV, PROV_R_VALUE_ERROR);
+            goto done;
+        }
+    }
+
+    EVP_MAC_CTX_free(*macctx);
+    *macctx = NULL;
+
+    mac = evp_mac_fetch_from_prov(prov, hmac_name, NULL);
+    if (mac) {
+        *macctx = EVP_MAC_CTX_new(mac);
+        /* The context holds on to the MAC */
+        EVP_MAC_free(mac);
+        *mp++ = OSSL_PARAM_construct_utf8_string(OSSL_MAC_PARAM_DIGEST, (char *)digest_name, 0);
+        *mp = OSSL_PARAM_construct_end();
+        if (!EVP_MAC_CTX_set_params(*macctx, mac_params)) {
+            ERR_raise(ERR_LIB_PROV, PROV_R_INVALID_MAC);
+            EVP_MAC_CTX_free(*macctx);
+            *macctx = NULL;
+            goto done;
+        }
+        ret = 1;
+    }
+
+done:
+    ossl_provider_free(prov);
+    return ret;
+}
+
 static int drbg_hmac_set_ctx_params_locked(void *vctx, const OSSL_PARAM params[])
 {
     PROV_DRBG *ctx = (PROV_DRBG *)vctx;
     PROV_DRBG_HMAC *hmac = (PROV_DRBG_HMAC *)ctx->data;
     OSSL_LIB_CTX *libctx = PROV_LIBCTX_OF(ctx->provctx);
+    EVP_MD *prov_md = NULL;
     const EVP_MD *md;
     int md_size;
 
@@ -418,17 +501,27 @@ static int drbg_hmac_set_ctx_params_locked(void *vctx, const OSSL_PARAM params[]
             OSSL_DRBG_PARAM_FIPS_DIGEST_CHECK))
         return 0;
 
-    if (!ossl_prov_digest_load_from_params(&hmac->digest, params, libctx))
-        return 0;
+    /* try to fetch mac and digest from provider */
+    (void)ERR_set_mark();
+    if (!drbg_fetch_algs_from_prov(params, libctx, &hmac->ctx, &prov_md)) {
+        (void)ERR_pop_to_mark();
+        /* fall back to full implementation search */
+        if (!ossl_prov_digest_load_from_params(&hmac->digest, params, libctx))
+            return 0;
+
+        if (!ossl_prov_macctx_load_from_params(&hmac->ctx, params,
+                NULL, NULL, NULL, libctx))
+            return 0;
+    } else {
+        (void)ERR_clear_last_mark();
+        if (prov_md)
+            ossl_prov_digest_set_md(&hmac->digest, prov_md);
+    }
 
     md = ossl_prov_digest_md(&hmac->digest);
     if (md != NULL && !ossl_drbg_verify_digest(ctx, libctx, md))
         return 0; /* Error already raised for us */
 
-    if (!ossl_prov_macctx_load_from_params(&hmac->ctx, params,
-            NULL, NULL, NULL, libctx))
-        return 0;
-
     if (md != NULL && hmac->ctx != NULL) {
         /* These are taken from SP 800-90 10.1 Table 2 */
         md_size = EVP_MD_get_size(md);
