@@ -25,9 +25,9 @@
 #include "crypto/rand_pool.h"
 
 #ifndef OPENSSL_NO_JITTER
-# include <jitterentropy.h>
+#include <jitterentropy.h>
 
-# define JITTER_MAX_NUM_TRIES 3
+#define JITTER_MAX_NUM_TRIES 3
 
 static OSSL_FUNC_rand_newctx_fn jitter_new;
 static OSSL_FUNC_rand_freectx_fn jitter_free;
@@ -58,7 +58,7 @@ static size_t get_jitter_random_value(PROV_JITTER *s, unsigned char *buf, size_t
  * entropy count. Otherwise, returns an entropy count of 0.
  */
 static size_t ossl_prov_acquire_entropy_from_jitter(PROV_JITTER *s,
-                                                    RAND_POOL *pool)
+    RAND_POOL *pool)
 {
     size_t bytes_needed;
     unsigned char *buffer;
@@ -81,7 +81,7 @@ static size_t ossl_prov_acquire_entropy_from_jitter(PROV_JITTER *s,
 
 /* Obtain random bytes from the jitter library */
 static size_t get_jitter_random_value(PROV_JITTER *s,
-                                      unsigned char *buf, size_t len)
+    unsigned char *buf, size_t len)
 {
     struct rand_data *jitter_ec = NULL;
     ssize_t result = 0;
@@ -95,17 +95,15 @@ static size_t get_jitter_random_value(PROV_JITTER *s,
             continue;
 
         /* Do not use _safe API as per typical security policies */
-        result = jent_read_entropy(jitter_ec, (char *) buf, len);
+        result = jent_read_entropy(jitter_ec, (char *)buf, len);
         jent_entropy_collector_free(jitter_ec);
 
         /*
          * Permanent Failure
          * https://github.com/smuellerDD/jitterentropy-library/blob/master/doc/jitterentropy.3#L234
          */
-        if (result < -5) {
-            ossl_set_error_state(OSSL_SELF_TEST_TYPE_CRNG);
+        if (result < -5)
             break;
-        }
 
         /* Success */
         if (result >= 0 && (size_t)result == len)
@@ -114,13 +112,14 @@ static size_t get_jitter_random_value(PROV_JITTER *s,
 
     /* Permanent failure or too many intermittent failures */
     s->state = EVP_RAND_STATE_ERROR;
+    ossl_set_error_state(OSSL_SELF_TEST_TYPE_CRNG);
     ERR_raise_data(ERR_LIB_RAND, RAND_R_ERROR_RETRIEVING_ENTROPY,
-                   "jent_read_entropy (%d)", result);
+        "jent_read_entropy (%d)", result);
     return 0;
 }
 
 static void *jitter_new(void *provctx, void *parent,
-                        const OSSL_DISPATCH *parent_dispatch)
+    const OSSL_DISPATCH *parent_dispatch)
 {
     PROV_JITTER *s;
 
@@ -144,18 +143,19 @@ static void jitter_free(void *vseed)
 }
 
 static int jitter_instantiate(void *vseed, unsigned int strength,
-                              int prediction_resistance,
-                              const unsigned char *pstr,
-                              size_t pstr_len,
-                              ossl_unused const OSSL_PARAM params[])
+    int prediction_resistance,
+    const unsigned char *pstr,
+    size_t pstr_len,
+    ossl_unused const OSSL_PARAM params[])
 {
     PROV_JITTER *s = (PROV_JITTER *)vseed;
     int ret;
 
     if ((ret = jent_entropy_init_ex(0, JENT_FORCE_FIPS)) != 0) {
         ERR_raise_data(ERR_LIB_RAND, RAND_R_ERROR_RETRIEVING_ENTROPY,
-                       "jent_entropy_init_ex (%d)", ret);
+            "jent_entropy_init_ex (%d)", ret);
         s->state = EVP_RAND_STATE_ERROR;
+        ossl_set_error_state(OSSL_SELF_TEST_TYPE_CRNG);
         return 0;
     }
 
@@ -172,10 +172,10 @@ static int jitter_uninstantiate(void *vseed)
 }
 
 static int jitter_generate(void *vseed, unsigned char *out, size_t outlen,
-                           unsigned int strength,
-                           ossl_unused int prediction_resistance,
-                           ossl_unused const unsigned char *adin,
-                           ossl_unused size_t adin_len)
+    unsigned int strength,
+    ossl_unused int prediction_resistance,
+    ossl_unused const unsigned char *adin,
+    ossl_unused size_t adin_len)
 {
     PROV_JITTER *s = (PROV_JITTER *)vseed;
     size_t entropy_available;
@@ -183,8 +183,8 @@ static int jitter_generate(void *vseed, unsigned char *out, size_t outlen,
 
     if (s->state != EVP_RAND_STATE_READY) {
         ERR_raise(ERR_LIB_PROV,
-                  s->state == EVP_RAND_STATE_ERROR ? PROV_R_IN_ERROR_STATE
-                                                   : PROV_R_NOT_INSTANTIATED);
+            s->state == EVP_RAND_STATE_ERROR ? PROV_R_IN_ERROR_STATE
+                                             : PROV_R_NOT_INSTANTIATED);
         return 0;
     }
 
@@ -210,18 +210,18 @@ static int jitter_generate(void *vseed, unsigned char *out, size_t outlen,
 }
 
 static int jitter_reseed(void *vseed,
-                         ossl_unused int prediction_resistance,
-                         ossl_unused const unsigned char *ent,
-                         ossl_unused size_t ent_len,
-                         ossl_unused const unsigned char *adin,
-                         ossl_unused size_t adin_len)
+    ossl_unused int prediction_resistance,
+    ossl_unused const unsigned char *ent,
+    ossl_unused size_t ent_len,
+    ossl_unused const unsigned char *adin,
+    ossl_unused size_t adin_len)
 {
     PROV_JITTER *s = (PROV_JITTER *)vseed;
 
     if (s->state != EVP_RAND_STATE_READY) {
         ERR_raise(ERR_LIB_PROV,
-                  s->state == EVP_RAND_STATE_ERROR ? PROV_R_IN_ERROR_STATE
-                                                   : PROV_R_NOT_INSTANTIATED);
+            s->state == EVP_RAND_STATE_ERROR ? PROV_R_IN_ERROR_STATE
+                                             : PROV_R_NOT_INSTANTIATED);
         return 0;
     }
     return 1;
@@ -247,7 +247,7 @@ static int jitter_get_ctx_params(void *vseed, OSSL_PARAM params[])
 }
 
 static const OSSL_PARAM *jitter_gettable_ctx_params(ossl_unused void *vseed,
-                                                    ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     static const OSSL_PARAM known_gettable_ctx_params[] = {
         OSSL_PARAM_int(OSSL_RAND_PARAM_STATE, NULL),
@@ -264,11 +264,11 @@ static int jitter_verify_zeroization(ossl_unused void *vseed)
 }
 
 static size_t jitter_get_seed(void *vseed, unsigned char **pout,
-                              int entropy, size_t min_len,
-                              size_t max_len,
-                              int prediction_resistance,
-                              const unsigned char *adin,
-                              size_t adin_len)
+    int entropy, size_t min_len,
+    size_t max_len,
+    int prediction_resistance,
+    const unsigned char *adin,
+    size_t adin_len)
 {
     size_t ret = 0;
     size_t entropy_available = 0;
@@ -295,7 +295,7 @@ static size_t jitter_get_seed(void *vseed, unsigned char **pout,
     return ret;
 }
 
-# ifndef OPENSSL_NO_FIPS_JITTER
+#ifndef OPENSSL_NO_FIPS_JITTER
 size_t ossl_rand_jitter_get_seed(unsigned char **pout, int entropy, size_t min_len, size_t max_len)
 {
     size_t ret = 0;
@@ -307,14 +307,14 @@ size_t ossl_rand_jitter_get_seed(unsigned char **pout, int entropy, size_t min_l
     if (!jitter_instantiate(s, 0, 0, NULL, 0, params))
         goto end;
     ret = jitter_get_seed(s, pout, entropy, min_len, max_len, 0, NULL, 0);
- end:
+end:
     jitter_free(s);
     return ret;
 }
-# endif
+#endif
 
 static void jitter_clear_seed(ossl_unused void *vdrbg,
-                              unsigned char *out, size_t outlen)
+    unsigned char *out, size_t outlen)
 {
     OPENSSL_secure_clear_free(out, outlen);
 }
@@ -334,24 +334,24 @@ void jitter_unlock(ossl_unused void *vctx)
 }
 
 const OSSL_DISPATCH ossl_jitter_functions[] = {
-    { OSSL_FUNC_RAND_NEWCTX, (void(*)(void))jitter_new },
-    { OSSL_FUNC_RAND_FREECTX, (void(*)(void))jitter_free },
+    { OSSL_FUNC_RAND_NEWCTX, (void (*)(void))jitter_new },
+    { OSSL_FUNC_RAND_FREECTX, (void (*)(void))jitter_free },
     { OSSL_FUNC_RAND_INSTANTIATE,
-      (void(*)(void))jitter_instantiate },
+        (void (*)(void))jitter_instantiate },
     { OSSL_FUNC_RAND_UNINSTANTIATE,
-      (void(*)(void))jitter_uninstantiate },
-    { OSSL_FUNC_RAND_GENERATE, (void(*)(void))jitter_generate },
-    { OSSL_FUNC_RAND_RESEED, (void(*)(void))jitter_reseed },
-    { OSSL_FUNC_RAND_ENABLE_LOCKING, (void(*)(void))jitter_enable_locking },
-    { OSSL_FUNC_RAND_LOCK, (void(*)(void))jitter_lock },
-    { OSSL_FUNC_RAND_UNLOCK, (void(*)(void))jitter_unlock },
+        (void (*)(void))jitter_uninstantiate },
+    { OSSL_FUNC_RAND_GENERATE, (void (*)(void))jitter_generate },
+    { OSSL_FUNC_RAND_RESEED, (void (*)(void))jitter_reseed },
+    { OSSL_FUNC_RAND_ENABLE_LOCKING, (void (*)(void))jitter_enable_locking },
+    { OSSL_FUNC_RAND_LOCK, (void (*)(void))jitter_lock },
+    { OSSL_FUNC_RAND_UNLOCK, (void (*)(void))jitter_unlock },
     { OSSL_FUNC_RAND_GETTABLE_CTX_PARAMS,
-      (void(*)(void))jitter_gettable_ctx_params },
-    { OSSL_FUNC_RAND_GET_CTX_PARAMS, (void(*)(void))jitter_get_ctx_params },
+        (void (*)(void))jitter_gettable_ctx_params },
+    { OSSL_FUNC_RAND_GET_CTX_PARAMS, (void (*)(void))jitter_get_ctx_params },
     { OSSL_FUNC_RAND_VERIFY_ZEROIZATION,
-      (void(*)(void))jitter_verify_zeroization },
-    { OSSL_FUNC_RAND_GET_SEED, (void(*)(void))jitter_get_seed },
-    { OSSL_FUNC_RAND_CLEAR_SEED, (void(*)(void))jitter_clear_seed },
+        (void (*)(void))jitter_verify_zeroization },
+    { OSSL_FUNC_RAND_GET_SEED, (void (*)(void))jitter_get_seed },
+    { OSSL_FUNC_RAND_CLEAR_SEED, (void (*)(void))jitter_clear_seed },
     OSSL_DISPATCH_END
 };
 #else
