@@ -9,7 +9,7 @@
 
 #include "internal/e_os.h"
 
-#define __NEW_STARLET 1         /* New starlet definitions since VMS 7.0 */
+#define __NEW_STARLET 1 /* New starlet definitions since VMS 7.0 */
 #include <unistd.h>
 #include "internal/cryptlib.h"
 #include "internal/nelem.h"
@@ -30,13 +30,13 @@
 #include <iledef.h>
 #include <lib$routines.h>
 #ifdef __DECC
-# pragma message disable DOLLARID
+#pragma message disable DOLLARID
 #endif
 
-#include <dlfcn.h>              /* SYS$GET_ENTROPY presence */
+#include <dlfcn.h> /* SYS$GET_ENTROPY presence */
 
 #ifndef OPENSSL_RAND_SEED_OS
-# error "Unsupported seeding method configured; must be os"
+#error "Unsupported seeding method configured; must be os"
 #endif
 
 /*
@@ -50,221 +50,221 @@
 
 /* We need to make sure we have the right size pointer in some cases */
 #if __INITIAL_POINTER_SIZE == 64
-# pragma pointer_size save
-# pragma pointer_size 32
+#pragma pointer_size save
+#pragma pointer_size 32
 #endif
 typedef uint32_t *uint32_t__ptr32;
 #if __INITIAL_POINTER_SIZE == 64
-# pragma pointer_size restore
+#pragma pointer_size restore
 #endif
 
 struct item_st {
-    short length, code;         /* length is number of bytes */
+    short length, code; /* length is number of bytes */
 };
 
 static const struct item_st DVI_item_data[] = {
-    {4,   DVI$_ERRCNT},
-    {4,   DVI$_REFCNT},
+    { 4, DVI$_ERRCNT },
+    { 4, DVI$_REFCNT },
 };
 
 static const struct item_st JPI_item_data[] = {
-    {4,   JPI$_BUFIO},
-    {4,   JPI$_CPUTIM},
-    {4,   JPI$_DIRIO},
-    {4,   JPI$_IMAGECOUNT},
-    {4,   JPI$_PAGEFLTS},
-    {4,   JPI$_PID},
-    {4,   JPI$_PPGCNT},
-    {4,   JPI$_WSPEAK},
+    { 4, JPI$_BUFIO },
+    { 4, JPI$_CPUTIM },
+    { 4, JPI$_DIRIO },
+    { 4, JPI$_IMAGECOUNT },
+    { 4, JPI$_PAGEFLTS },
+    { 4, JPI$_PID },
+    { 4, JPI$_PPGCNT },
+    { 4, JPI$_WSPEAK },
     /*
      * Note: the direct result is just a 32-bit address.  However, it points
      * to a list of 4 32-bit words, so we make extra space for them so we can
      * do in-place replacement of values
      */
-    {16,  JPI$_FINALEXC},
+    { 16, JPI$_FINALEXC },
 };
 
 static const struct item_st JPI_item_data_64bit[] = {
-    {8,   JPI$_LAST_LOGIN_I},
-    {8,   JPI$_LOGINTIM},
+    { 8, JPI$_LAST_LOGIN_I },
+    { 8, JPI$_LOGINTIM },
 };
 
 static const struct item_st RMI_item_data[] = {
-    {4,   RMI$_COLPG},
-    {4,   RMI$_MWAIT},
-    {4,   RMI$_CEF},
-    {4,   RMI$_PFW},
-    {4,   RMI$_LEF},
-    {4,   RMI$_LEFO},
-    {4,   RMI$_HIB},
-    {4,   RMI$_HIBO},
-    {4,   RMI$_SUSP},
-    {4,   RMI$_SUSPO},
-    {4,   RMI$_FPG},
-    {4,   RMI$_COM},
-    {4,   RMI$_COMO},
-    {4,   RMI$_CUR},
+    { 4, RMI$_COLPG },
+    { 4, RMI$_MWAIT },
+    { 4, RMI$_CEF },
+    { 4, RMI$_PFW },
+    { 4, RMI$_LEF },
+    { 4, RMI$_LEFO },
+    { 4, RMI$_HIB },
+    { 4, RMI$_HIBO },
+    { 4, RMI$_SUSP },
+    { 4, RMI$_SUSPO },
+    { 4, RMI$_FPG },
+    { 4, RMI$_COM },
+    { 4, RMI$_COMO },
+    { 4, RMI$_CUR },
 #if defined __alpha
-    {4,   RMI$_FRLIST},
-    {4,   RMI$_MODLIST},
+    { 4, RMI$_FRLIST },
+    { 4, RMI$_MODLIST },
 #endif
-    {4,   RMI$_FAULTS},
-    {4,   RMI$_PREADS},
-    {4,   RMI$_PWRITES},
-    {4,   RMI$_PWRITIO},
-    {4,   RMI$_PREADIO},
-    {4,   RMI$_GVALFLTS},
-    {4,   RMI$_WRTINPROG},
-    {4,   RMI$_FREFLTS},
-    {4,   RMI$_DZROFLTS},
-    {4,   RMI$_SYSFAULTS},
-    {4,   RMI$_ISWPCNT},
-    {4,   RMI$_DIRIO},
-    {4,   RMI$_BUFIO},
-    {4,   RMI$_MBREADS},
-    {4,   RMI$_MBWRITES},
-    {4,   RMI$_LOGNAM},
-    {4,   RMI$_FCPCALLS},
-    {4,   RMI$_FCPREAD},
-    {4,   RMI$_FCPWRITE},
-    {4,   RMI$_FCPCACHE},
-    {4,   RMI$_FCPCPU},
-    {4,   RMI$_FCPHIT},
-    {4,   RMI$_FCPSPLIT},
-    {4,   RMI$_FCPFAULT},
-    {4,   RMI$_ENQNEW},
-    {4,   RMI$_ENQCVT},
-    {4,   RMI$_DEQ},
-    {4,   RMI$_BLKAST},
-    {4,   RMI$_ENQWAIT},
-    {4,   RMI$_ENQNOTQD},
-    {4,   RMI$_DLCKSRCH},
-    {4,   RMI$_DLCKFND},
-    {4,   RMI$_NUMLOCKS},
-    {4,   RMI$_NUMRES},
-    {4,   RMI$_ARRLOCPK},
-    {4,   RMI$_DEPLOCPK},
-    {4,   RMI$_ARRTRAPK},
-    {4,   RMI$_TRCNGLOS},
-    {4,   RMI$_RCVBUFFL},
-    {4,   RMI$_ENQNEWLOC},
-    {4,   RMI$_ENQNEWIN},
-    {4,   RMI$_ENQNEWOUT},
-    {4,   RMI$_ENQCVTLOC},
-    {4,   RMI$_ENQCVTIN},
-    {4,   RMI$_ENQCVTOUT},
-    {4,   RMI$_DEQLOC},
-    {4,   RMI$_DEQIN},
-    {4,   RMI$_DEQOUT},
-    {4,   RMI$_BLKLOC},
-    {4,   RMI$_BLKIN},
-    {4,   RMI$_BLKOUT},
-    {4,   RMI$_DIRIN},
-    {4,   RMI$_DIROUT},
-    /* We currently get a fault when trying these */
+    { 4, RMI$_FAULTS },
+    { 4, RMI$_PREADS },
+    { 4, RMI$_PWRITES },
+    { 4, RMI$_PWRITIO },
+    { 4, RMI$_PREADIO },
+    { 4, RMI$_GVALFLTS },
+    { 4, RMI$_WRTINPROG },
+    { 4, RMI$_FREFLTS },
+    { 4, RMI$_DZROFLTS },
+    { 4, RMI$_SYSFAULTS },
+    { 4, RMI$_ISWPCNT },
+    { 4, RMI$_DIRIO },
+    { 4, RMI$_BUFIO },
+    { 4, RMI$_MBREADS },
+    { 4, RMI$_MBWRITES },
+    { 4, RMI$_LOGNAM },
+    { 4, RMI$_FCPCALLS },
+    { 4, RMI$_FCPREAD },
+    { 4, RMI$_FCPWRITE },
+    { 4, RMI$_FCPCACHE },
+    { 4, RMI$_FCPCPU },
+    { 4, RMI$_FCPHIT },
+    { 4, RMI$_FCPSPLIT },
+    { 4, RMI$_FCPFAULT },
+    { 4, RMI$_ENQNEW },
+    { 4, RMI$_ENQCVT },
+    { 4, RMI$_DEQ },
+    { 4, RMI$_BLKAST },
+    { 4, RMI$_ENQWAIT },
+    { 4, RMI$_ENQNOTQD },
+    { 4, RMI$_DLCKSRCH },
+    { 4, RMI$_DLCKFND },
+    { 4, RMI$_NUMLOCKS },
+    { 4, RMI$_NUMRES },
+    { 4, RMI$_ARRLOCPK },
+    { 4, RMI$_DEPLOCPK },
+    { 4, RMI$_ARRTRAPK },
+    { 4, RMI$_TRCNGLOS },
+    { 4, RMI$_RCVBUFFL },
+    { 4, RMI$_ENQNEWLOC },
+    { 4, RMI$_ENQNEWIN },
+    { 4, RMI$_ENQNEWOUT },
+    { 4, RMI$_ENQCVTLOC },
+    { 4, RMI$_ENQCVTIN },
+    { 4, RMI$_ENQCVTOUT },
+    { 4, RMI$_DEQLOC },
+    { 4, RMI$_DEQIN },
+    { 4, RMI$_DEQOUT },
+    { 4, RMI$_BLKLOC },
+    { 4, RMI$_BLKIN },
+    { 4, RMI$_BLKOUT },
+    { 4, RMI$_DIRIN },
+    { 4, RMI$_DIROUT },
+/* We currently get a fault when trying these */
 #if 0
     {140, RMI$_MSCP_EVERYTHING},   /* 35 32-bit words */
     {152, RMI$_DDTM_ALL},          /* 38 32-bit words */
     {80,  RMI$_TMSCP_EVERYTHING}   /* 20 32-bit words */
 #endif
-    {4,   RMI$_LPZ_PAGCNT},
-    {4,   RMI$_LPZ_HITS},
-    {4,   RMI$_LPZ_MISSES},
-    {4,   RMI$_LPZ_EXPCNT},
-    {4,   RMI$_LPZ_ALLOCF},
-    {4,   RMI$_LPZ_ALLOC2},
-    {4,   RMI$_ACCESS},
-    {4,   RMI$_ALLOC},
-    {4,   RMI$_FCPCREATE},
-    {4,   RMI$_VOLWAIT},
-    {4,   RMI$_FCPTURN},
-    {4,   RMI$_FCPERASE},
-    {4,   RMI$_OPENS},
-    {4,   RMI$_FIDHIT},
-    {4,   RMI$_FIDMISS},
-    {4,   RMI$_FILHDR_HIT},
-    {4,   RMI$_DIRFCB_HIT},
-    {4,   RMI$_DIRFCB_MISS},
-    {4,   RMI$_DIRDATA_HIT},
-    {4,   RMI$_EXTHIT},
-    {4,   RMI$_EXTMISS},
-    {4,   RMI$_QUOHIT},
-    {4,   RMI$_QUOMISS},
-    {4,   RMI$_STORAGMAP_HIT},
-    {4,   RMI$_VOLLCK},
-    {4,   RMI$_SYNCHLCK},
-    {4,   RMI$_SYNCHWAIT},
-    {4,   RMI$_ACCLCK},
-    {4,   RMI$_XQPCACHEWAIT},
-    {4,   RMI$_DIRDATA_MISS},
-    {4,   RMI$_FILHDR_MISS},
-    {4,   RMI$_STORAGMAP_MISS},
-    {4,   RMI$_PROCCNTMAX},
-    {4,   RMI$_PROCBATCNT},
-    {4,   RMI$_PROCINTCNT},
-    {4,   RMI$_PROCNETCNT},
-    {4,   RMI$_PROCSWITCHCNT},
-    {4,   RMI$_PROCBALSETCNT},
-    {4,   RMI$_PROCLOADCNT},
-    {4,   RMI$_BADFLTS},
-    {4,   RMI$_EXEFAULTS},
-    {4,   RMI$_HDRINSWAPS},
-    {4,   RMI$_HDROUTSWAPS},
-    {4,   RMI$_IOPAGCNT},
-    {4,   RMI$_ISWPCNTPG},
-    {4,   RMI$_OSWPCNT},
-    {4,   RMI$_OSWPCNTPG},
-    {4,   RMI$_RDFAULTS},
-    {4,   RMI$_TRANSFLTS},
-    {4,   RMI$_WRTFAULTS},
+    { 4, RMI$_LPZ_PAGCNT },
+    { 4, RMI$_LPZ_HITS },
+    { 4, RMI$_LPZ_MISSES },
+    { 4, RMI$_LPZ_EXPCNT },
+    { 4, RMI$_LPZ_ALLOCF },
+    { 4, RMI$_LPZ_ALLOC2 },
+    { 4, RMI$_ACCESS },
+    { 4, RMI$_ALLOC },
+    { 4, RMI$_FCPCREATE },
+    { 4, RMI$_VOLWAIT },
+    { 4, RMI$_FCPTURN },
+    { 4, RMI$_FCPERASE },
+    { 4, RMI$_OPENS },
+    { 4, RMI$_FIDHIT },
+    { 4, RMI$_FIDMISS },
+    { 4, RMI$_FILHDR_HIT },
+    { 4, RMI$_DIRFCB_HIT },
+    { 4, RMI$_DIRFCB_MISS },
+    { 4, RMI$_DIRDATA_HIT },
+    { 4, RMI$_EXTHIT },
+    { 4, RMI$_EXTMISS },
+    { 4, RMI$_QUOHIT },
+    { 4, RMI$_QUOMISS },
+    { 4, RMI$_STORAGMAP_HIT },
+    { 4, RMI$_VOLLCK },
+    { 4, RMI$_SYNCHLCK },
+    { 4, RMI$_SYNCHWAIT },
+    { 4, RMI$_ACCLCK },
+    { 4, RMI$_XQPCACHEWAIT },
+    { 4, RMI$_DIRDATA_MISS },
+    { 4, RMI$_FILHDR_MISS },
+    { 4, RMI$_STORAGMAP_MISS },
+    { 4, RMI$_PROCCNTMAX },
+    { 4, RMI$_PROCBATCNT },
+    { 4, RMI$_PROCINTCNT },
+    { 4, RMI$_PROCNETCNT },
+    { 4, RMI$_PROCSWITCHCNT },
+    { 4, RMI$_PROCBALSETCNT },
+    { 4, RMI$_PROCLOADCNT },
+    { 4, RMI$_BADFLTS },
+    { 4, RMI$_EXEFAULTS },
+    { 4, RMI$_HDRINSWAPS },
+    { 4, RMI$_HDROUTSWAPS },
+    { 4, RMI$_IOPAGCNT },
+    { 4, RMI$_ISWPCNTPG },
+    { 4, RMI$_OSWPCNT },
+    { 4, RMI$_OSWPCNTPG },
+    { 4, RMI$_RDFAULTS },
+    { 4, RMI$_TRANSFLTS },
+    { 4, RMI$_WRTFAULTS },
 #if defined __alpha
-    {4,   RMI$_USERPAGES},
+    { 4, RMI$_USERPAGES },
 #endif
-    {4,   RMI$_VMSPAGES},
-    {4,   RMI$_TTWRITES},
-    {4,   RMI$_BUFOBJPAG},
-    {4,   RMI$_BUFOBJPAGPEAK},
-    {4,   RMI$_BUFOBJPAGS01},
-    {4,   RMI$_BUFOBJPAGS2},
-    {4,   RMI$_BUFOBJPAGMAXS01},
-    {4,   RMI$_BUFOBJPAGMAXS2},
-    {4,   RMI$_BUFOBJPAGPEAKS01},
-    {4,   RMI$_BUFOBJPAGPEAKS2},
-    {4,   RMI$_BUFOBJPGLTMAXS01},
-    {4,   RMI$_BUFOBJPGLTMAXS2},
-    {4,   RMI$_DLCK_INCMPLT},
-    {4,   RMI$_DLCKMSGS_IN},
-    {4,   RMI$_DLCKMSGS_OUT},
-    {4,   RMI$_MCHKERRS},
-    {4,   RMI$_MEMERRS},
+    { 4, RMI$_VMSPAGES },
+    { 4, RMI$_TTWRITES },
+    { 4, RMI$_BUFOBJPAG },
+    { 4, RMI$_BUFOBJPAGPEAK },
+    { 4, RMI$_BUFOBJPAGS01 },
+    { 4, RMI$_BUFOBJPAGS2 },
+    { 4, RMI$_BUFOBJPAGMAXS01 },
+    { 4, RMI$_BUFOBJPAGMAXS2 },
+    { 4, RMI$_BUFOBJPAGPEAKS01 },
+    { 4, RMI$_BUFOBJPAGPEAKS2 },
+    { 4, RMI$_BUFOBJPGLTMAXS01 },
+    { 4, RMI$_BUFOBJPGLTMAXS2 },
+    { 4, RMI$_DLCK_INCMPLT },
+    { 4, RMI$_DLCKMSGS_IN },
+    { 4, RMI$_DLCKMSGS_OUT },
+    { 4, RMI$_MCHKERRS },
+    { 4, RMI$_MEMERRS },
 };
 
 static const struct item_st RMI_item_data_64bit[] = {
 #if defined __ia64
-    {8,   RMI$_FRLIST},
-    {8,   RMI$_MODLIST},
+    { 8, RMI$_FRLIST },
+    { 8, RMI$_MODLIST },
 #endif
-    {8,   RMI$_LCKMGR_REQCNT},
-    {8,   RMI$_LCKMGR_REQTIME},
-    {8,   RMI$_LCKMGR_SPINCNT},
-    {8,   RMI$_LCKMGR_SPINTIME},
-    {8,   RMI$_CPUINTSTK},
-    {8,   RMI$_CPUMPSYNCH},
-    {8,   RMI$_CPUKERNEL},
-    {8,   RMI$_CPUEXEC},
-    {8,   RMI$_CPUSUPER},
-    {8,   RMI$_CPUUSER},
+    { 8, RMI$_LCKMGR_REQCNT },
+    { 8, RMI$_LCKMGR_REQTIME },
+    { 8, RMI$_LCKMGR_SPINCNT },
+    { 8, RMI$_LCKMGR_SPINTIME },
+    { 8, RMI$_CPUINTSTK },
+    { 8, RMI$_CPUMPSYNCH },
+    { 8, RMI$_CPUKERNEL },
+    { 8, RMI$_CPUEXEC },
+    { 8, RMI$_CPUSUPER },
+    { 8, RMI$_CPUUSER },
 #if defined __ia64
-    {8,   RMI$_USERPAGES},
+    { 8, RMI$_USERPAGES },
 #endif
-    {8,   RMI$_TQETOTAL},
-    {8,   RMI$_TQESYSUB},
-    {8,   RMI$_TQEUSRTIMR},
-    {8,   RMI$_TQEUSRWAKE},
+    { 8, RMI$_TQETOTAL },
+    { 8, RMI$_TQESYSUB },
+    { 8, RMI$_TQEUSRTIMR },
+    { 8, RMI$_TQEUSRWAKE },
 };
 
 static const struct item_st SYI_item_data[] = {
-    {4,   SYI$_PAGEFILE_FREE},
+    { 4, SYI$_PAGEFILE_FREE },
 };
 
 /*
@@ -281,9 +281,9 @@ static const struct item_st SYI_item_data[] = {
  * Returns the number of elements used in databuffer
  */
 static size_t prepare_item_list(const struct item_st *items_input,
-                                size_t items_input_num,
-                                ILE3 *items,
-                                uint32_t__ptr32 databuffer)
+    size_t items_input_num,
+    ILE3 *items,
+    uint32_t__ptr32 databuffer)
 {
     size_t data_sz = 0;
 
@@ -340,7 +340,7 @@ static void massage_JPI(ILE3 *items)
  * For the moment, we assume about 0.05 entropy bits per data bit, or 1
  * bit of entropy per 20 data bits.
  */
-#define ENTROPY_FACTOR  20
+#define ENTROPY_FACTOR 20
 
 size_t data_collect_method(RAND_POOL *pool)
 {
@@ -354,12 +354,12 @@ size_t data_collect_method(RAND_POOL *pool)
         /* This ensures buffer starts at 64 bit boundary */
         uint64_t dummy;
         uint32_t buffer[OSSL_NELEM(JPI_item_data_64bit) * 2
-                        + OSSL_NELEM(RMI_item_data_64bit) * 2
-                        + OSSL_NELEM(DVI_item_data)
-                        + OSSL_NELEM(JPI_item_data)
-                        + OSSL_NELEM(RMI_item_data)
-                        + OSSL_NELEM(SYI_item_data)
-                        + 4 /* For JPI$_FINALEXC */];
+            + OSSL_NELEM(RMI_item_data_64bit) * 2
+            + OSSL_NELEM(DVI_item_data)
+            + OSSL_NELEM(JPI_item_data)
+            + OSSL_NELEM(RMI_item_data)
+            + OSSL_NELEM(SYI_item_data)
+            + 4 /* For JPI$_FINALEXC */];
     } data;
     size_t total_elems = 0;
     size_t total_length = 0;
@@ -367,21 +367,19 @@ size_t data_collect_method(RAND_POOL *pool)
     size_t bytes_remaining = ossl_rand_pool_bytes_remaining(pool);
 
     /* Take all the 64-bit items first, to ensure proper alignment of data */
-    total_elems +=
-        prepare_item_list(JPI_item_data_64bit, OSSL_NELEM(JPI_item_data_64bit),
-                          JPI_items_64bit, &data.buffer[total_elems]);
-    total_elems +=
-        prepare_item_list(RMI_item_data_64bit, OSSL_NELEM(RMI_item_data_64bit),
-                          RMI_items_64bit, &data.buffer[total_elems]);
+    total_elems += prepare_item_list(JPI_item_data_64bit, OSSL_NELEM(JPI_item_data_64bit),
+        JPI_items_64bit, &data.buffer[total_elems]);
+    total_elems += prepare_item_list(RMI_item_data_64bit, OSSL_NELEM(RMI_item_data_64bit),
+        RMI_items_64bit, &data.buffer[total_elems]);
     /* Now the 32-bit items */
     total_elems += prepare_item_list(DVI_item_data, OSSL_NELEM(DVI_item_data),
-                                     DVI_items, &data.buffer[total_elems]);
+        DVI_items, &data.buffer[total_elems]);
     total_elems += prepare_item_list(JPI_item_data, OSSL_NELEM(JPI_item_data),
-                                     JPI_items, &data.buffer[total_elems]);
+        JPI_items, &data.buffer[total_elems]);
     total_elems += prepare_item_list(RMI_item_data, OSSL_NELEM(RMI_item_data),
-                                     RMI_items, &data.buffer[total_elems]);
+        RMI_items, &data.buffer[total_elems]);
     total_elems += prepare_item_list(SYI_item_data, OSSL_NELEM(SYI_item_data),
-                                     SYI_items, &data.buffer[total_elems]);
+        SYI_items, &data.buffer[total_elems]);
     total_length = total_elems * sizeof(data.buffer[0]);
 
     /* Fill data.buffer with various info bits from this process */
@@ -389,10 +387,11 @@ size_t data_collect_method(RAND_POOL *pool)
         uint32_t status;
         uint32_t efn;
         IOSB iosb;
-        $DESCRIPTOR(SYSDEVICE,"SYS$SYSDEVICE:");
+        $DESCRIPTOR(SYSDEVICE, "SYS$SYSDEVICE:");
 
         if ((status = sys$getdviw(EFN$C_ENF, 0, &SYSDEVICE, DVI_items,
-                                  0, 0, 0, 0, 0)) != SS$_NORMAL) {
+                 0, 0, 0, 0, 0))
+            != SS$_NORMAL) {
             lib$signal(status);
             return 0;
         }
@@ -458,8 +457,8 @@ size_t data_collect_method(RAND_POOL *pool)
      */
     if (!ossl_assert(total_length >= bytes_needed)) {
         ERR_raise_data(ERR_LIB_RAND, RAND_R_RANDOM_POOL_UNDERFLOW,
-                       "Needed: %zu, Available: %zu",
-                       bytes_needed, total_length);
+            "Needed: %zu, Available: %zu",
+            bytes_needed, total_length);
         return 0;
     }
 
@@ -471,7 +470,7 @@ size_t data_collect_method(RAND_POOL *pool)
 
     /* We give the pessimistic value for the amount of entropy */
     ossl_rand_pool_add(pool, (unsigned char *)data.buffer, total_length,
-                       8 * total_length / ENTROPY_FACTOR);
+        8 * total_length / ENTROPY_FACTOR);
     return ossl_rand_pool_entropy_available(pool);
 }
 
@@ -510,10 +509,9 @@ size_t get_entropy_method(RAND_POOL *pool)
     uint32_t status;
 
     for (bytes_needed = ossl_rand_pool_bytes_needed(pool, 1);
-         bytes_needed > 0;
-         bytes_needed -= bytes_to_get) {
-        bytes_to_get =
-            bytes_needed > sizeof(buffer) ? sizeof(buffer) : bytes_needed;
+        bytes_needed > 0;
+        bytes_needed -= bytes_to_get) {
+        bytes_to_get = bytes_needed > sizeof(buffer) ? sizeof(buffer) : bytes_needed;
 
         status = get_entropy_address(buffer, bytes_to_get);
         if (status == SS$_RETRY) {
@@ -590,7 +588,7 @@ int ossl_pool_add_nonce_data(RAND_POOL *pool)
     data.pid = getpid();
     data.tid = CRYPTO_THREAD_get_current_id();
     data.seq = 0;
-    sys$gettim((void*)&data.time);
+    sys$gettim((void *)&data.time);
 
     if (data.time == last_time) {
         data.seq = ++last_seq;
