@@ -220,7 +220,7 @@ static int ecdsa_setup_md(PROV_ECDSA_CTX *ctx,
         if (!ossl_fips_ind_digest_sign_check(OSSL_FIPS_IND_GET(ctx),
                 OSSL_FIPS_IND_SETTABLE1,
                 ctx->libctx,
-                md_nid, sha1_allowed, desc,
+                md_nid, sha1_allowed, 0, desc,
                 ossl_fips_config_signature_digest_check))
             goto err;
     }
@@ -724,17 +724,16 @@ static const OSSL_PARAM *ecdsa_gettable_ctx_params(ossl_unused void *vctx,
     return known_gettable_ctx_params;
 }
 
-/* The common params for ecdsa_set_ctx_params and ecdsa_sigalg_set_ctx_params */
+/**
+ * @brief Set up common params for ecdsa_set_ctx_params and
+ * ecdsa_sigalg_set_ctx_params. The caller is responsible for checking |vctx| is
+ * not NULL and |params| is not empty.
+ */
 static int ecdsa_common_set_ctx_params(void *vctx, const OSSL_PARAM params[])
 {
     PROV_ECDSA_CTX *ctx = (PROV_ECDSA_CTX *)vctx;
     const OSSL_PARAM *p;
 
-    if (ctx == NULL)
-        return 0;
-    if (params == NULL)
-        return 1;
-
     if (!OSSL_FIPS_IND_SET_CTX_PARAM(ctx, OSSL_FIPS_IND_SETTABLE0, params,
             OSSL_SIGNATURE_PARAM_FIPS_KEY_CHECK))
         return 0;
@@ -769,12 +768,14 @@ static int ecdsa_set_ctx_params(void *vctx, const OSSL_PARAM params[])
     size_t mdsize = 0;
     int ret;
 
+    if (ctx == NULL)
+        return 0;
+    if (ossl_param_is_empty(params))
+        return 1;
+
     if ((ret = ecdsa_common_set_ctx_params(ctx, params)) <= 0)
         return ret;
 
-    if (params == NULL)
-        return 1;
-
     p = OSSL_PARAM_locate_const(params, OSSL_SIGNATURE_PARAM_DIGEST);
     if (p != NULL) {
         char mdname[OSSL_MAX_NAME_SIZE] = "", *pmdname = mdname;
@@ -972,12 +973,14 @@ static int ecdsa_sigalg_set_ctx_params(void *vctx, const OSSL_PARAM params[])
     const OSSL_PARAM *p;
     int ret;
 
+    if (ctx == NULL)
+        return 0;
+    if (ossl_param_is_empty(params))
+        return 1;
+
     if ((ret = ecdsa_common_set_ctx_params(ctx, params)) <= 0)
         return ret;
 
-    if (params == NULL)
-        return 1;
-
     if (ctx->operation == EVP_PKEY_OP_VERIFYMSG) {
         p = OSSL_PARAM_locate_const(params, OSSL_SIGNATURE_PARAM_SIGNATURE);
         if (p != NULL) {
