@@ -24,13 +24,13 @@
  * QUIC Port Structure
  * ===================
  */
-#define INIT_DCID_LEN                   8
+#define INIT_DCID_LEN 8
 
 static int port_init(QUIC_PORT *port);
 static void port_cleanup(QUIC_PORT *port);
 static OSSL_TIME get_time(void *arg);
 static void port_default_packet_handler(QUIC_URXE *e, void *arg,
-                                        const QUIC_CONN_ID *dcid);
+    const QUIC_CONN_ID *dcid);
 static void port_rx_pre(QUIC_PORT *port);
 
 /**
@@ -104,8 +104,8 @@ QUIC_PORT *ossl_quic_port_new(const QUIC_PORT_ARGS *args)
     if ((port = OPENSSL_zalloc(sizeof(QUIC_PORT))) == NULL)
         return NULL;
 
-    port->engine        = args->engine;
-    port->channel_ctx   = args->channel_ctx;
+    port->engine = args->engine;
+    port->channel_ctx = args->channel_ctx;
     port->is_multi_conn = args->is_multi_conn;
     port->validate_addr = args->do_addr_validation;
     port->get_conn_user_ssl = args->get_conn_user_ssl;
@@ -143,34 +143,38 @@ static int port_init(QUIC_PORT *port)
         goto err;
 
     if ((port->demux = ossl_quic_demux_new(/*BIO=*/NULL,
-                                           /*Short CID Len=*/rx_short_dcid_len,
-                                           get_time, port)) == NULL)
+             /*Short CID Len=*/rx_short_dcid_len,
+             get_time, port))
+        == NULL)
         goto err;
 
     ossl_quic_demux_set_default_handler(port->demux,
-                                        port_default_packet_handler,
-                                        port);
+        port_default_packet_handler,
+        port);
 
     if ((port->srtm = ossl_quic_srtm_new(port->engine->libctx,
-                                         port->engine->propq)) == NULL)
+             port->engine->propq))
+        == NULL)
         goto err;
 
     if ((port->lcidm = ossl_quic_lcidm_new(port->engine->libctx,
-                                           rx_short_dcid_len)) == NULL)
+             rx_short_dcid_len))
+        == NULL)
         goto err;
 
     port->rx_short_dcid_len = (unsigned char)rx_short_dcid_len;
-    port->tx_init_dcid_len  = INIT_DCID_LEN;
-    port->state             = QUIC_PORT_STATE_RUNNING;
+    port->tx_init_dcid_len = INIT_DCID_LEN;
+    port->state = QUIC_PORT_STATE_RUNNING;
 
     ossl_list_port_insert_tail(&port->engine->port_list, port);
-    port->on_engine_list    = 1;
-    port->bio_changed       = 1;
+    port->on_engine_list = 1;
+    port->bio_changed = 1;
 
     /* Generate random key for token encryption */
     if ((port->token_ctx = EVP_CIPHER_CTX_new()) == NULL
         || (cipher = EVP_CIPHER_fetch(port->engine->libctx,
-                                      "AES-256-GCM", NULL)) == NULL
+                "AES-256-GCM", NULL))
+            == NULL
         || !EVP_EncryptInit_ex(port->token_ctx, cipher, NULL, NULL, NULL)
         || (key_len = EVP_CIPHER_CTX_get_key_length(port->token_ctx)) <= 0
         || (token_key = OPENSSL_malloc(key_len)) == NULL
@@ -298,7 +302,7 @@ BIO *ossl_quic_port_get_net_wbio(QUIC_PORT *port)
 
 static int port_update_poll_desc(QUIC_PORT *port, BIO *net_bio, int for_write)
 {
-    BIO_POLL_DESCRIPTOR d = {0};
+    BIO_POLL_DESCRIPTOR d = { 0 };
 
     if (net_bio == NULL
         || (!for_write && !BIO_get_rpoll_descriptor(net_bio, &d))
@@ -433,7 +437,7 @@ int ossl_quic_port_set_net_wbio(QUIC_PORT *port, BIO *net_wbio)
         return 0;
 
     OSSL_LIST_FOREACH(ch, ch, &port->channel_list)
-        ossl_qtx_set_bio(ch->qtx, net_wbio);
+    ossl_qtx_set_bio(ch->qtx, net_wbio);
 
     port->net_wbio = net_wbio;
     port_update_addressing_mode(port);
@@ -458,64 +462,68 @@ static SSL *port_new_handshake_layer(QUIC_PORT *port, QUIC_CHANNEL *ch)
     QUIC_CONNECTION *qc = NULL;
     QUIC_LISTENER *ql = NULL;
 
-    if (port->get_conn_user_ssl != NULL) {
-        user_ssl = port->get_conn_user_ssl(ch, port->user_ssl_arg);
-        if (user_ssl == NULL)
-            return NULL;
-        qc = (QUIC_CONNECTION *)user_ssl;
-        ql = (QUIC_LISTENER *)port->user_ssl_arg;
+    /*
+     * It only makes sense to call this function if we know how to associate
+     * the handshake layer we are about to create with some user_ssl object.
+     */
+    if (!ossl_assert(port->get_conn_user_ssl != NULL))
+        return NULL;
+    user_ssl = port->get_conn_user_ssl(ch, port->user_ssl_arg);
+    if (user_ssl == NULL)
+        return NULL;
+    qc = (QUIC_CONNECTION *)user_ssl;
+    ql = (QUIC_LISTENER *)port->user_ssl_arg;
+
+    /*
+     * We expect the user_ssl to be newly created so it must not have an
+     * existing qc->tls
+     */
+    if (!ossl_assert(qc->tls == NULL)) {
+        SSL_free(user_ssl);
+        return NULL;
     }
 
     tls = ossl_ssl_connection_new_int(port->channel_ctx, user_ssl, TLS_method());
+    qc->tls = tls;
     if (tls == NULL || (tls_conn = SSL_CONNECTION_FROM_SSL(tls)) == NULL) {
         SSL_free(user_ssl);
         return NULL;
     }
 
-    /*
-     * If we got a user ssl, which will be embedded in a quic connection
-     * we need to fix up the connections tls pointer here
-     */
-    if (qc != NULL)
-        qc->tls = tls;
-
     if (ql != NULL && ql->obj.ssl.ctx->new_pending_conn_cb != NULL)
         if (!ql->obj.ssl.ctx->new_pending_conn_cb(ql->obj.ssl.ctx, user_ssl,
-                                                  ql->obj.ssl.ctx->new_pending_conn_arg)) {
-            SSL_free(tls);
+                ql->obj.ssl.ctx->new_pending_conn_arg)) {
             SSL_free(user_ssl);
-            if (qc != NULL)
-                qc->tls = NULL;
             return NULL;
         }
 
     /* Override the user_ssl of the inner connection. */
-    tls_conn->s3.flags      |= TLS1_FLAGS_QUIC | TLS1_FLAGS_QUIC_INTERNAL;
+    tls_conn->s3.flags |= TLS1_FLAGS_QUIC | TLS1_FLAGS_QUIC_INTERNAL;
 
     /* Restrict options derived from the SSL_CTX. */
-    tls_conn->options       &= OSSL_QUIC_PERMITTED_OPTIONS_CONN;
-    tls_conn->pha_enabled   = 0;
+    tls_conn->options &= OSSL_QUIC_PERMITTED_OPTIONS_CONN;
+    tls_conn->pha_enabled = 0;
     return tls;
 }
 
 static QUIC_CHANNEL *port_make_channel(QUIC_PORT *port, SSL *tls, OSSL_QRX *qrx,
-                                       int is_server, int is_tserver)
+    int is_server, int is_tserver)
 {
-    QUIC_CHANNEL_ARGS args = {0};
+    QUIC_CHANNEL_ARGS args = { 0 };
     QUIC_CHANNEL *ch;
 
-    args.port          = port;
-    args.is_server     = is_server;
-    args.lcidm         = port->lcidm;
-    args.srtm          = port->srtm;
-    args.qrx           = qrx;
+    args.port = port;
+    args.is_server = is_server;
+    args.lcidm = port->lcidm;
+    args.srtm = port->srtm;
+    args.qrx = qrx;
     args.is_tserver_ch = is_tserver;
 
     /*
      * Creating a a new channel is made a bit tricky here as there is a
-     * bit of a circular dependency.  Initalizing a channel requires that
+     * bit of a circular dependency.  Initializing a channel requires that
      * the ch->tls and optionally the qlog_title be configured prior to
-     * initalization, but we need the channel at least partially configured
+     * initialization, but we need the channel at least partially configured
      * to create the new handshake layer, so we have to do this in a few steps.
      */
 
@@ -531,6 +539,11 @@ static QUIC_CHANNEL *port_make_channel(QUIC_PORT *port, SSL *tls, OSSL_QRX *qrx,
      */
     ch->tls = (tls != NULL) ? tls : port_new_handshake_layer(port, ch);
 
+    if (ch->tls == NULL) {
+        OPENSSL_free(ch);
+        return NULL;
+    }
+
 #ifndef OPENSSL_NO_QLOG
     /*
      * If we're using qlog, make sure the tls get further configured properly
@@ -548,7 +561,6 @@ static QUIC_CHANNEL *port_make_channel(QUIC_PORT *port, SSL *tls, OSSL_QRX *qrx,
      * And finally init the channel struct
      */
     if (!ossl_quic_channel_init(ch)) {
-        SSL_free(ch->tls);
         OPENSSL_free(ch);
         return NULL;
     }
@@ -560,7 +572,7 @@ static QUIC_CHANNEL *port_make_channel(QUIC_PORT *port, SSL *tls, OSSL_QRX *qrx,
 QUIC_CHANNEL *ossl_quic_port_create_outgoing(QUIC_PORT *port, SSL *tls)
 {
     return port_make_channel(port, tls, NULL, /* is_server= */ 0,
-                             /* is_tserver= */ 0);
+        /* is_tserver= */ 0);
 }
 
 QUIC_CHANNEL *ossl_quic_port_create_incoming(QUIC_PORT *port, SSL *tls)
@@ -574,7 +586,7 @@ QUIC_CHANNEL *ossl_quic_port_create_incoming(QUIC_PORT *port, SSL *tls)
      * later in port_default_packet_handler() when calling port_bind_channel().
      */
     ch = port_make_channel(port, tls, NULL, /* is_server= */ 1,
-                           /* is_tserver_ch */ 1);
+        /* is_tserver_ch */ 1);
     port->tserver_ch = ch;
     port->allow_incoming = 1;
     return ch;
@@ -647,14 +659,14 @@ void ossl_quic_port_set_allow_incoming(QUIC_PORT *port, int allow_incoming)
  * this port's network BIOs, and services child channels.
  */
 void ossl_quic_port_subtick(QUIC_PORT *port, QUIC_TICK_RESULT *res,
-                            uint32_t flags)
+    uint32_t flags)
 {
     QUIC_CHANNEL *ch;
 
-    res->net_read_desired       = ossl_quic_port_is_running(port);
-    res->net_write_desired      = 0;
-    res->notify_other_threads   = 0;
-    res->tick_deadline          = ossl_time_infinite();
+    res->net_read_desired = ossl_quic_port_is_running(port);
+    res->net_write_desired = 0;
+    res->notify_other_threads = 0;
+    res->tick_deadline = ossl_time_infinite();
 
     if (!port->engine->inhibit_tick) {
         /* Handle any incoming data from network. */
@@ -662,8 +674,9 @@ void ossl_quic_port_subtick(QUIC_PORT *port, QUIC_TICK_RESULT *res,
             port_rx_pre(port);
 
         /* Iterate through all channels and service them. */
-        OSSL_LIST_FOREACH(ch, ch, &port->channel_list) {
-            QUIC_TICK_RESULT subr = {0};
+        OSSL_LIST_FOREACH(ch, ch, &port->channel_list)
+        {
+            QUIC_TICK_RESULT subr = { 0 };
 
             ossl_quic_channel_subtick(ch, &subr, flags);
             ossl_quic_tick_result_merge_into(res, &subr);
@@ -716,9 +729,9 @@ static void port_rx_pre(QUIC_PORT *port)
  * to *new_ch.
  */
 static void port_bind_channel(QUIC_PORT *port, const BIO_ADDR *peer,
-                              const QUIC_CONN_ID *scid, const QUIC_CONN_ID *dcid,
-                              const QUIC_CONN_ID *odcid, OSSL_QRX *qrx,
-                              QUIC_CHANNEL **new_ch)
+    const QUIC_CONN_ID *scid, const QUIC_CONN_ID *dcid,
+    const QUIC_CONN_ID *odcid, OSSL_QRX *qrx,
+    QUIC_CHANNEL **new_ch)
 {
     QUIC_CHANNEL *ch;
 
@@ -731,11 +744,11 @@ static void port_bind_channel(QUIC_PORT *port, const BIO_ADDR *peer,
         port->tserver_ch = NULL;
         ossl_quic_channel_bind_qrx(ch, qrx);
         ossl_qrx_set_msg_callback(ch->qrx, ch->msg_callback,
-                                  ch->msg_callback_ssl);
+            ch->msg_callback_ssl);
         ossl_qrx_set_msg_callback_arg(ch->qrx, ch->msg_callback_arg);
     } else {
         ch = port_make_channel(port, NULL, qrx, /* is_server= */ 1,
-                               /* is_tserver */ 0);
+            /* is_tserver */ 0);
     }
 
     if (ch == NULL)
@@ -751,9 +764,9 @@ static void port_bind_channel(QUIC_PORT *port, const BIO_ADDR *peer,
      */
     if (qrx == NULL)
         if (!ossl_quic_provide_initial_secret(ch->port->engine->libctx,
-                                              ch->port->engine->propq,
-                                              dcid, /* is_server */ 1,
-                                              ch->qrx, NULL))
+                ch->port->engine->propq,
+                dcid, /* is_server */ 1,
+                ch->qrx, NULL))
             return;
 
     if (odcid->id_len != 0) {
@@ -816,9 +829,9 @@ static int port_try_handle_stateless_reset(QUIC_PORT *port, const QUIC_URXE *e)
 
     for (i = 0;; ++i) {
         if (!ossl_quic_srtm_lookup(port->srtm,
-                                   (QUIC_STATELESS_RESET_TOKEN *)(data + e->data_len
-                                   - sizeof(QUIC_STATELESS_RESET_TOKEN)),
-                                   i, &opaque, NULL))
+                (QUIC_STATELESS_RESET_TOKEN *)(data + e->data_len
+                    - sizeof(QUIC_STATELESS_RESET_TOKEN)),
+                i, &opaque, NULL))
             break;
 
         assert(opaque != NULL);
@@ -845,8 +858,8 @@ static void cleanup_validation_token(QUIC_VALIDATION_TOKEN *token)
  * @return 1 if validation token is filled successfully, 0 otherwise.
  */
 static int generate_token(BIO_ADDR *peer, QUIC_CONN_ID odcid,
-                          QUIC_CONN_ID rscid, QUIC_VALIDATION_TOKEN *token,
-                          int is_retry)
+    QUIC_CONN_ID rscid, QUIC_VALIDATION_TOKEN *token,
+    int is_retry)
 {
     token->is_retry = is_retry;
     token->timestamp = ossl_time_now();
@@ -858,7 +871,7 @@ static int generate_token(BIO_ADDR *peer, QUIC_CONN_ID odcid,
         || token->remote_addr_len == 0
         || (token->remote_addr = OPENSSL_malloc(token->remote_addr_len)) == NULL
         || !BIO_ADDR_rawaddress(peer, token->remote_addr,
-                                &token->remote_addr_len)) {
+            &token->remote_addr_len)) {
         cleanup_validation_token(token);
         return 0;
     }
@@ -877,9 +890,9 @@ static int generate_token(BIO_ADDR *peer, QUIC_CONN_ID odcid,
  * @param buffer_len Size of data stored in |buffer|.
  */
 static int marshal_validation_token(QUIC_VALIDATION_TOKEN *token,
-                                    unsigned char *buffer, size_t *buffer_len)
+    unsigned char *buffer, size_t *buffer_len)
 {
-    WPACKET wpkt = {0};
+    WPACKET wpkt = { 0 };
     BUF_MEM *buf_mem = BUF_MEM_new();
 
     if (buffer == NULL || buf_mem == NULL
@@ -891,12 +904,12 @@ static int marshal_validation_token(QUIC_VALIDATION_TOKEN *token,
     if (!WPACKET_init(&wpkt, buf_mem)
         || !WPACKET_memset(&wpkt, token->is_retry, 1)
         || !WPACKET_memcpy(&wpkt, &token->timestamp,
-                           sizeof(token->timestamp))
+            sizeof(token->timestamp))
         || (token->is_retry
             && (!WPACKET_sub_memcpy_u8(&wpkt, &token->odcid.id,
-                                       token->odcid.id_len)
+                    token->odcid.id_len)
                 || !WPACKET_sub_memcpy_u8(&wpkt, &token->rscid.id,
-                                          token->rscid.id_len)))
+                    token->rscid.id_len)))
         || !WPACKET_sub_memcpy_u8(&wpkt, token->remote_addr, token->remote_addr_len)
         || !WPACKET_get_total_written(&wpkt, buffer_len)
         || *buffer_len > MARSHALLED_TOKEN_MAX_LEN
@@ -929,10 +942,10 @@ static int marshal_validation_token(QUIC_VALIDATION_TOKEN *token,
  * [EVP_GCM_IV_LEN bytes IV][encrypted data][EVP_GCM_TAG_LEN bytes tag]
  */
 static int encrypt_validation_token(const QUIC_PORT *port,
-                                    const unsigned char *plaintext,
-                                    size_t pt_len,
-                                    unsigned char *ciphertext,
-                                    size_t *ct_len)
+    const unsigned char *plaintext,
+    size_t pt_len,
+    unsigned char *ciphertext,
+    size_t *ct_len)
 {
     int iv_len, len, ret = 0;
     size_t tag_len;
@@ -979,10 +992,10 @@ err:
  * [EVP_GCM_IV_LEN bytes IV][encrypted data][EVP_GCM_TAG_LEN bytes tag]
  */
 static int decrypt_validation_token(const QUIC_PORT *port,
-                                    const unsigned char *ciphertext,
-                                    size_t ct_len,
-                                    unsigned char *plaintext,
-                                    size_t *pt_len)
+    const unsigned char *ciphertext,
+    size_t ct_len,
+    unsigned char *plaintext,
+    size_t *pt_len)
 {
     int iv_len, len = 0, ret = 0;
     size_t tag_len;
@@ -1007,9 +1020,9 @@ static int decrypt_validation_token(const QUIC_PORT *port,
 
     if (!EVP_DecryptInit_ex(port->token_ctx, NULL, NULL, NULL, iv)
         || !EVP_DecryptUpdate(port->token_ctx, plaintext, &len, data,
-                              ct_len - iv_len - tag_len)
+            ct_len - iv_len - tag_len)
         || !EVP_CIPHER_CTX_ctrl(port->token_ctx, EVP_CTRL_GCM_SET_TAG, tag_len,
-                                (void *)tag)
+            (void *)tag)
         || !EVP_DecryptFinal_ex(port->token_ctx, plaintext + len, &len))
         goto err;
 
@@ -1022,14 +1035,14 @@ err:
 /**
  * @brief Parses contents of a buffer into a validation token.
  *
- * VALIDATION_TOKEN should already be initalized. Does some basic sanity checks.
+ * VALIDATION_TOKEN should already be initialized. Does some basic sanity checks.
  *
  * @param token   Validation token to fill data in.
  * @param buf     Buffer of previously marshaled validation token.
  * @param buf_len Length of |buf|.
  */
 static int parse_validation_token(QUIC_VALIDATION_TOKEN *token,
-                                  const unsigned char *buf, size_t buf_len)
+    const unsigned char *buf, size_t buf_len)
 {
     PACKET pkt, subpkt;
 
@@ -1042,19 +1055,19 @@ static int parse_validation_token(QUIC_VALIDATION_TOKEN *token,
         || !PACKET_copy_bytes(&pkt, &token->is_retry, sizeof(token->is_retry))
         || !(token->is_retry == 0 || token->is_retry == 1)
         || !PACKET_copy_bytes(&pkt, (unsigned char *)&token->timestamp,
-                              sizeof(token->timestamp))
+            sizeof(token->timestamp))
         || (token->is_retry
             && (!PACKET_get_length_prefixed_1(&pkt, &subpkt)
                 || (token->odcid.id_len = (unsigned char)PACKET_remaining(&subpkt))
                     > QUIC_MAX_CONN_ID_LEN
                 || !PACKET_copy_bytes(&subpkt,
-                                      (unsigned char *)&token->odcid.id,
-                                      token->odcid.id_len)
+                    (unsigned char *)&token->odcid.id,
+                    token->odcid.id_len)
                 || !PACKET_get_length_prefixed_1(&pkt, &subpkt)
                 || (token->rscid.id_len = (unsigned char)PACKET_remaining(&subpkt))
                     > QUIC_MAX_CONN_ID_LEN
                 || !PACKET_copy_bytes(&subpkt, (unsigned char *)&token->rscid.id,
-                                      token->rscid.id_len)))
+                    token->rscid.id_len)))
         || !PACKET_get_length_prefixed_1(&pkt, &subpkt)
         || (token->remote_addr_len = PACKET_remaining(&subpkt)) == 0
         || (token->remote_addr = OPENSSL_malloc(token->remote_addr_len)) == NULL
@@ -1090,8 +1103,8 @@ static int parse_validation_token(QUIC_VALIDATION_TOKEN *token,
  * network transmiss
  */
 static void port_send_retry(QUIC_PORT *port,
-                            BIO_ADDR *peer,
-                            QUIC_PKT_HDR *client_hdr)
+    BIO_ADDR *peer,
+    QUIC_PKT_HDR *client_hdr)
 {
     BIO_MSG msg[1];
     /*
@@ -1103,8 +1116,8 @@ static void port_send_retry(QUIC_PORT *port,
     unsigned char ct_buf[ENCRYPTED_TOKEN_MAX_LEN];
     WPACKET wpkt;
     size_t written, token_buf_len, ct_len;
-    QUIC_PKT_HDR hdr = {0};
-    QUIC_VALIDATION_TOKEN token = {0};
+    QUIC_PKT_HDR hdr = { 0 };
+    QUIC_VALIDATION_TOKEN token = { 0 };
     int ok;
 
     if (!ossl_assert(sizeof(buffer) >= MARSHALLED_TOKEN_MAX_LEN))
@@ -1129,13 +1142,13 @@ static void port_send_retry(QUIC_PORT *port,
 
     /* Generate retry validation token */
     if (!generate_token(peer, client_hdr->dst_conn_id,
-                        hdr.src_conn_id, &token, 1)
+            hdr.src_conn_id, &token, 1)
         || !marshal_validation_token(&token, buffer, &token_buf_len)
         || !encrypt_validation_token(port, buffer, token_buf_len, NULL,
-                                     &ct_len)
+            &ct_len)
         || ct_len > ENCRYPTED_TOKEN_MAX_LEN
         || !encrypt_validation_token(port, buffer, token_buf_len, ct_buf,
-                                     &ct_len)
+            &ct_len)
         || !ossl_assert(ct_len >= QUIC_RETRY_INTEGRITY_TAG_LEN))
         goto err;
 
@@ -1146,10 +1159,10 @@ static void port_send_retry(QUIC_PORT *port,
     hdr.len = ct_len;
     hdr.data = ct_buf;
     ok = ossl_quic_calculate_retry_integrity_tag(port->engine->libctx,
-                                                 port->engine->propq, &hdr,
-                                                 &client_hdr->dst_conn_id,
-                                                 ct_buf + ct_len
-                                                 - QUIC_RETRY_INTEGRITY_TAG_LEN);
+        port->engine->propq, &hdr,
+        &client_hdr->dst_conn_id,
+        ct_buf + ct_len
+            - QUIC_RETRY_INTEGRITY_TAG_LEN);
     if (ok == 0)
         goto err;
 
@@ -1166,7 +1179,7 @@ static void port_send_retry(QUIC_PORT *port,
         goto err;
 
     ok = ossl_quic_wire_encode_pkt_hdr(&wpkt, client_hdr->dst_conn_id.id_len,
-                                       &hdr, NULL);
+        &hdr, NULL);
     if (ok == 0)
         goto err;
 
@@ -1184,7 +1197,7 @@ static void port_send_retry(QUIC_PORT *port,
      */
     if (!BIO_sendmmsg(port->net_wbio, msg, sizeof(BIO_MSG), 1, 0, &written))
         ERR_raise_data(ERR_LIB_SSL, SSL_R_QUIC_NETWORK_ERROR,
-                       "port retry send failed due to network BIO I/O error");
+            "port retry send failed due to network BIO I/O error");
 
 err:
     cleanup_validation_token(&token);
@@ -1208,7 +1221,7 @@ err:
  * @note The function will raise an error if sending the message fails.
  */
 static void port_send_version_negotiation(QUIC_PORT *port, BIO_ADDR *peer,
-                                          QUIC_PKT_HDR *client_hdr)
+    QUIC_PKT_HDR *client_hdr)
 {
     BIO_MSG msg[1];
     unsigned char buffer[1024];
@@ -1252,14 +1265,14 @@ static void port_send_version_negotiation(QUIC_PORT *port, BIO_ADDR *peer,
         return;
 
     if (!ossl_quic_wire_encode_pkt_hdr(&wpkt, client_hdr->dst_conn_id.id_len,
-                                       &hdr, NULL))
+            &hdr, NULL))
         return;
 
     /*
      * Add the array of supported versions to the end of the packet
      */
     for (i = 0; i < OSSL_NELEM(supported_versions); i++) {
-        if (!WPACKET_put_bytes_u32(&wpkt, htonl(supported_versions[i])))
+        if (!WPACKET_put_bytes_u32(&wpkt, supported_versions[i]))
             return;
     }
 
@@ -1276,11 +1289,11 @@ static void port_send_version_negotiation(QUIC_PORT *port, BIO_ADDR *peer,
      */
     if (!BIO_sendmmsg(port->net_wbio, msg, sizeof(BIO_MSG), 1, 0, &written))
         ERR_raise_data(ERR_LIB_SSL, SSL_R_QUIC_NETWORK_ERROR,
-                       "port version negotiation send failed");
+            "port version negotiation send failed");
 }
 
 /**
- * @brief defintions of token lifetimes
+ * @brief definitions of token lifetimes
  *
  * RETRY tokens are only valid for 10 seconds
  * NEW_TOKEN tokens have a lifetime of 3600 sec (1 hour)
@@ -1319,8 +1332,8 @@ static void port_send_version_negotiation(QUIC_PORT *port, BIO_ADDR *peer,
  *   configurable in the future.
  */
 static int port_validate_token(QUIC_PKT_HDR *hdr, QUIC_PORT *port,
-                               BIO_ADDR *peer, QUIC_CONN_ID *odcid,
-                               QUIC_CONN_ID *scid, uint8_t *gen_new_token)
+    BIO_ADDR *peer, QUIC_CONN_ID *odcid,
+    QUIC_CONN_ID *scid, uint8_t *gen_new_token)
 {
     int ret = 0;
     QUIC_VALIDATION_TOKEN token = { 0 };
@@ -1332,10 +1345,10 @@ static int port_validate_token(QUIC_PKT_HDR *hdr, QUIC_PORT *port,
     *gen_new_token = 0;
 
     if (!decrypt_validation_token(port, hdr->token, hdr->token_len, NULL,
-                                  &dec_token_len)
+            &dec_token_len)
         || dec_token_len > MARSHALLED_TOKEN_MAX_LEN
         || !decrypt_validation_token(port, hdr->token, hdr->token_len,
-                                     dec_token, &dec_token_len)
+            dec_token, &dec_token_len)
         || !parse_validation_token(&token, dec_token, dec_token_len))
         goto err;
 
@@ -1346,7 +1359,7 @@ static int port_validate_token(QUIC_PKT_HDR *hdr, QUIC_PORT *port,
     if (ossl_time_compare(now, token.timestamp) < 0)
         goto err;
     time_diff = ossl_time2seconds(ossl_time_abs_difference(token.timestamp,
-                                                           now));
+        now));
     if ((token.is_retry && time_diff > RETRY_LIFETIME)
         || (!token.is_retry && time_diff > NEW_TOKEN_LIFETIME))
         goto err;
@@ -1376,7 +1389,8 @@ static int port_validate_token(QUIC_PKT_HDR *hdr, QUIC_PORT *port,
          */
         if (token.rscid.id_len != hdr->dst_conn_id.id_len
             || memcmp(&token.rscid.id, &hdr->dst_conn_id.id,
-                      token.rscid.id_len) != 0)
+                   token.rscid.id_len)
+                != 0)
             goto err;
         *odcid = token.odcid;
         *scid = token.rscid;
@@ -1445,10 +1459,10 @@ static void generate_new_token(QUIC_CHANNEL *ch, BIO_ADDR *peer)
     if (!generate_token(peer, ch->init_dcid, rscid, &token, 0)
         || !marshal_validation_token(&token, buffer, &token_buf_len)
         || !encrypt_validation_token(ch->port, buffer, token_buf_len, NULL,
-                                     &ct_len)
+            &ct_len)
         || ct_len > ENCRYPTED_TOKEN_MAX_LEN
         || !encrypt_validation_token(ch->port, buffer, token_buf_len, ct_buf,
-                                     &ct_len)
+            &ct_len)
         || !ossl_assert(ct_len >= QUIC_RETRY_INTEGRITY_TAG_LEN)) {
         OPENSSL_free(ct_buf);
         cleanup_validation_token(&token);
@@ -1466,7 +1480,7 @@ static void generate_new_token(QUIC_CHANNEL *ch, BIO_ADDR *peer)
  * DCID.
  */
 static void port_default_packet_handler(QUIC_URXE *e, void *arg,
-                                        const QUIC_CONN_ID *dcid)
+    const QUIC_CONN_ID *dcid)
 {
     QUIC_PORT *port = arg;
     PACKET pkt;
@@ -1476,7 +1490,7 @@ static void port_default_packet_handler(QUIC_URXE *e, void *arg,
     uint8_t gen_new_token = 0;
     OSSL_QRX *qrx = NULL;
     OSSL_QRX *qrx_src = NULL;
-    OSSL_QRX_ARGS qrx_args = {0};
+    OSSL_QRX_ARGS qrx_args = { 0 };
     uint64_t cause_flags = 0;
     OSSL_QRX_PKT *qrx_pkt = NULL;
 
@@ -1489,7 +1503,7 @@ static void port_default_packet_handler(QUIC_URXE *e, void *arg,
 
     if (dcid != NULL
         && ossl_quic_lcidm_lookup(port->lcidm, dcid, NULL,
-                                  (void **)&ch)) {
+            (void **)&ch)) {
         assert(ch != NULL);
         ossl_quic_channel_inject(ch, e);
         return;
@@ -1518,7 +1532,7 @@ static void port_default_packet_handler(QUIC_URXE *e, void *arg,
      * care about Initial packets.
      */
     if (!ossl_quic_wire_decode_pkt_hdr(&pkt, SIZE_MAX, 1, 0, &hdr, NULL,
-                                       &cause_flags)) {
+            &cause_flags)) {
         /*
          * If we fail due to a bad version, we know the packet up to the version
          * number was decoded, and we use it below to send a version
@@ -1566,10 +1580,10 @@ static void port_default_packet_handler(QUIC_URXE *e, void *arg,
      * Create qrx now so we can check integrity of packet
      * which does not belong to any channel.
      */
-    qrx_args.libctx             = port->engine->libctx;
-    qrx_args.demux              = port->demux;
-    qrx_args.short_conn_id_len  = dcid->id_len;
-    qrx_args.max_deferred       = 32;
+    qrx_args.libctx = port->engine->libctx;
+    qrx_args.demux = port->demux;
+    qrx_args.short_conn_id_len = dcid->id_len;
+    qrx_args.max_deferred = 32;
     qrx = ossl_qrx_new(&qrx_args);
     if (qrx == NULL)
         goto undesirable;
@@ -1578,10 +1592,10 @@ static void port_default_packet_handler(QUIC_URXE *e, void *arg,
      * Derive secrets for qrx only.
      */
     if (!ossl_quic_provide_initial_secret(port->engine->libctx,
-                                          port->engine->propq,
-                                          &hdr.dst_conn_id,
-                                          /* is_server */ 1,
-                                          qrx, NULL))
+            port->engine->propq,
+            &hdr.dst_conn_id,
+            /* is_server */ 1,
+            qrx, NULL))
         goto undesirable;
 
     if (ossl_qrx_validate_initial_packet(qrx, e, (const QUIC_CONN_ID *)dcid) == 0)
@@ -1601,8 +1615,8 @@ static void port_default_packet_handler(QUIC_URXE *e, void *arg,
          * going to create. We use qrx_src alias so we can read packets from
          * qrx and inject them to channel.
          */
-         qrx_src = qrx;
-         qrx = NULL;
+        qrx_src = qrx;
+        qrx = NULL;
     }
     /*
      * TODO(QUIC FUTURE): there should be some logic similar to accounting half-open
@@ -1622,8 +1636,9 @@ static void port_default_packet_handler(QUIC_URXE *e, void *arg,
      */
     if (hdr.token != NULL
         && port_validate_token(&hdr, port, &e->peer,
-                               &odcid, &scid,
-                               &gen_new_token) == 0) {
+               &odcid, &scid,
+               &gen_new_token)
+            == 0) {
         /*
          * RFC 9000 s 8.1.3
          * When a server receives an Initial packet with an address
@@ -1656,7 +1671,7 @@ static void port_default_packet_handler(QUIC_URXE *e, void *arg,
     }
 
     port_bind_channel(port, &e->peer, &scid, &hdr.dst_conn_id,
-                      &odcid, qrx, &new_ch);
+        &odcid, qrx, &new_ch);
 
     /*
      * if packet validates it gets moved to channel, we've just bound
@@ -1683,6 +1698,7 @@ static void port_default_packet_handler(QUIC_URXE *e, void *arg,
          */
         while (ossl_qrx_read_pkt(qrx_src, &qrx_pkt) == 1)
             ossl_quic_channel_inject_pkt(new_ch, qrx_pkt);
+        ossl_qrx_update_pn_space(qrx_src, new_ch->qrx);
     }
 
     /*
@@ -1705,7 +1721,7 @@ undesirable:
 }
 
 void ossl_quic_port_raise_net_error(QUIC_PORT *port,
-                                    QUIC_CHANNEL *triggering_ch)
+    QUIC_CHANNEL *triggering_ch)
 {
     QUIC_CHANNEL *ch;
 
@@ -1717,7 +1733,7 @@ void ossl_quic_port_raise_net_error(QUIC_PORT *port,
      * cover error.
      */
     ERR_raise_data(ERR_LIB_SSL, SSL_R_QUIC_NETWORK_ERROR,
-                   "port failed due to network BIO I/O error");
+        "port failed due to network BIO I/O error");
     OSSL_ERR_STATE_save(port->err_state);
 
     port_transition_failed(port);
@@ -1727,8 +1743,8 @@ void ossl_quic_port_raise_net_error(QUIC_PORT *port,
         ossl_quic_channel_raise_net_error(triggering_ch);
 
     OSSL_LIST_FOREACH(ch, ch, &port->channel_list)
-        if (ch != triggering_ch)
-            ossl_quic_channel_raise_net_error(ch);
+    if (ch != triggering_ch)
+        ossl_quic_channel_raise_net_error(ch);
 }
 
 void ossl_quic_port_restore_err_state(const QUIC_PORT *port)
