@@ -25,13 +25,13 @@ typedef struct txe_st TXE;
 
 struct txe_st {
     OSSL_LIST_MEMBER(txe, TXE);
-    size_t              data_len, alloc_len;
+    size_t data_len, alloc_len;
 
     /*
      * Destination and local addresses, as applicable. Both of these are only
      * used if the family is not AF_UNSPEC.
      */
-    BIO_ADDR            peer, local;
+    BIO_ADDR peer, local;
 
     /*
      * alloc_len allocated bytes (of which data_len bytes are valid) follow this
@@ -52,52 +52,52 @@ static ossl_inline unsigned char *txe_data(const TXE *e)
  * ===
  */
 struct ossl_qtx_st {
-    OSSL_LIB_CTX               *libctx;
-    const char                 *propq;
+    OSSL_LIB_CTX *libctx;
+    const char *propq;
 
     /* Per encryption-level state. */
-    OSSL_QRL_ENC_LEVEL_SET      el_set;
+    OSSL_QRL_ENC_LEVEL_SET el_set;
 
     /* TX BIO. */
-    BIO                        *bio;
+    BIO *bio;
 
     /* QLOG instance retrieval callback if in use, or NULL. */
-    QLOG                     *(*get_qlog_cb)(void *arg);
-    void                       *get_qlog_cb_arg;
+    QLOG *(*get_qlog_cb)(void *arg);
+    void *get_qlog_cb_arg;
 
     /* TX maximum datagram payload length. */
-    size_t                      mdpl;
+    size_t mdpl;
 
     /*
      * List of TXEs which are not currently in use. These are moved to the
      * pending list (possibly via tx_cons first) as they are filled.
      */
-    TXE_LIST                    free;
+    TXE_LIST free;
 
     /*
      * List of TXEs which are filled with completed datagrams ready to be
      * transmitted.
      */
-    TXE_LIST                    pending;
-    size_t                      pending_count; /* items in list */
-    size_t                      pending_bytes; /* sum(txe->data_len) in pending */
+    TXE_LIST pending;
+    size_t pending_count; /* items in list */
+    size_t pending_bytes; /* sum(txe->data_len) in pending */
 
     /*
      * TXE which is under construction for coalescing purposes, if any.
      * This TXE is neither on the free nor pending list. Once the datagram
      * is completed, it is moved to the pending list.
      */
-    TXE                        *cons;
-    size_t                      cons_count; /* num packets */
+    TXE *cons;
+    size_t cons_count; /* num packets */
 
     /*
      * Number of packets transmitted in this key epoch. Used to enforce AEAD
      * confidentiality limit.
      */
-    uint64_t                    epoch_pkt_count;
+    uint64_t epoch_pkt_count;
 
     /* Datagram counter. Increases monotonically per datagram (not per packet). */
-    uint64_t                    datagram_count;
+    uint64_t datagram_count;
 
     ossl_mutate_packet_cb mutatecb;
     ossl_finish_mutate_cb finishmutatecb;
@@ -121,12 +121,12 @@ OSSL_QTX *ossl_qtx_new(const OSSL_QTX_ARGS *args)
     if (qtx == NULL)
         return 0;
 
-    qtx->libctx             = args->libctx;
-    qtx->propq              = args->propq;
-    qtx->bio                = args->bio;
-    qtx->mdpl               = args->mdpl;
-    qtx->get_qlog_cb        = args->get_qlog_cb;
-    qtx->get_qlog_cb_arg    = args->get_qlog_cb_arg;
+    qtx->libctx = args->libctx;
+    qtx->propq = args->propq;
+    qtx->bio = args->bio;
+    qtx->mdpl = args->mdpl;
+    qtx->get_qlog_cb = args->get_qlog_cb;
+    qtx->get_qlog_cb_arg = args->get_qlog_cb_arg;
 
     return qtx;
 }
@@ -163,40 +163,40 @@ void ossl_qtx_free(OSSL_QTX *qtx)
 
 /* Set mutator callbacks for test framework support */
 void ossl_qtx_set_mutator(OSSL_QTX *qtx, ossl_mutate_packet_cb mutatecb,
-                          ossl_finish_mutate_cb finishmutatecb, void *mutatearg)
+    ossl_finish_mutate_cb finishmutatecb, void *mutatearg)
 {
-    qtx->mutatecb       = mutatecb;
+    qtx->mutatecb = mutatecb;
     qtx->finishmutatecb = finishmutatecb;
-    qtx->mutatearg      = mutatearg;
+    qtx->mutatearg = mutatearg;
 }
 
 void ossl_qtx_set_qlog_cb(OSSL_QTX *qtx, QLOG *(*get_qlog_cb)(void *arg),
-                          void *get_qlog_cb_arg)
+    void *get_qlog_cb_arg)
 {
-    qtx->get_qlog_cb        = get_qlog_cb;
-    qtx->get_qlog_cb_arg    = get_qlog_cb_arg;
+    qtx->get_qlog_cb = get_qlog_cb;
+    qtx->get_qlog_cb_arg = get_qlog_cb_arg;
 }
 
-int ossl_qtx_provide_secret(OSSL_QTX              *qtx,
-                            uint32_t               enc_level,
-                            uint32_t               suite_id,
-                            EVP_MD                *md,
-                            const unsigned char   *secret,
-                            size_t                 secret_len)
+int ossl_qtx_provide_secret(OSSL_QTX *qtx,
+    uint32_t enc_level,
+    uint32_t suite_id,
+    EVP_MD *md,
+    const unsigned char *secret,
+    size_t secret_len)
 {
     if (enc_level >= QUIC_ENC_LEVEL_NUM)
         return 0;
 
     return ossl_qrl_enc_level_set_provide_secret(&qtx->el_set,
-                                                 qtx->libctx,
-                                                 qtx->propq,
-                                                 enc_level,
-                                                 suite_id,
-                                                 md,
-                                                 secret,
-                                                 secret_len,
-                                                 0,
-                                                 /*is_tx=*/1);
+        qtx->libctx,
+        qtx->propq,
+        enc_level,
+        suite_id,
+        md,
+        secret,
+        secret_len,
+        0,
+        /*is_tx=*/1);
 }
 
 int ossl_qtx_discard_enc_level(OSSL_QTX *qtx, uint32_t enc_level)
@@ -279,12 +279,12 @@ static TXE *qtx_resize_txe(OSSL_QTX *qtx, TXE_LIST *txl, TXE *txe, size_t n)
      * data.
      */
     txe2 = OPENSSL_realloc(txe, sizeof(TXE) + n);
-    if (txe2 == NULL || txe == txe2) {
+    if (txe2 == NULL) {
         if (p == NULL)
             ossl_list_txe_insert_head(txl, txe);
         else
             ossl_list_txe_insert_after(txl, p, txe);
-        return txe2;
+        return NULL;
     }
 
     if (p == NULL)
@@ -304,7 +304,7 @@ static TXE *qtx_resize_txe(OSSL_QTX *qtx, TXE_LIST *txl, TXE *txe, size_t n)
  * Returns NULL on failure.
  */
 static TXE *qtx_reserve_txe(OSSL_QTX *qtx, TXE_LIST *txl,
-                            TXE *txe, size_t n)
+    TXE *txe, size_t n)
 {
     if (txe->alloc_len >= n)
         return txe;
@@ -334,11 +334,11 @@ static void qtx_add_to_pending(OSSL_QTX *qtx, TXE *txe)
 
 struct iovec_cur {
     const OSSL_QTX_IOVEC *iovec;
-    size_t                num_iovec, idx, byte_off, bytes_remaining;
+    size_t num_iovec, idx, byte_off, bytes_remaining;
 };
 
 static size_t iovec_total_bytes(const OSSL_QTX_IOVEC *iovec,
-                                size_t num_iovec)
+    size_t num_iovec)
 {
     size_t i, l = 0;
 
@@ -349,14 +349,14 @@ static size_t iovec_total_bytes(const OSSL_QTX_IOVEC *iovec,
 }
 
 static void iovec_cur_init(struct iovec_cur *cur,
-                           const OSSL_QTX_IOVEC *iovec,
-                           size_t num_iovec)
+    const OSSL_QTX_IOVEC *iovec,
+    size_t num_iovec)
 {
-    cur->iovec              = iovec;
-    cur->num_iovec          = num_iovec;
-    cur->idx                = 0;
-    cur->byte_off           = 0;
-    cur->bytes_remaining    = iovec_total_bytes(iovec, num_iovec);
+    cur->iovec = iovec;
+    cur->num_iovec = num_iovec;
+    cur->idx = 0;
+    cur->byte_off = 0;
+    cur->bytes_remaining = iovec_total_bytes(iovec, num_iovec);
 }
 
 /*
@@ -366,8 +366,8 @@ static void iovec_cur_init(struct iovec_cur *cur,
  * available, returns 0.
  */
 static size_t iovec_cur_get_buffer(struct iovec_cur *cur,
-                                   const unsigned char **buf,
-                                   size_t max_buf_len)
+    const unsigned char **buf,
+    size_t max_buf_len)
 {
     size_t l;
 
@@ -402,8 +402,8 @@ static size_t iovec_cur_get_buffer(struct iovec_cur *cur,
 
 /* Determines the size of the AEAD output given the input size. */
 int ossl_qtx_calculate_ciphertext_payload_len(OSSL_QTX *qtx, uint32_t enc_level,
-                                              size_t plaintext_len,
-                                              size_t *ciphertext_len)
+    size_t plaintext_len,
+    size_t *ciphertext_len)
 {
     OSSL_QRL_ENC_LEVEL *el
         = ossl_qrl_enc_level_set_get(&qtx->el_set, enc_level, 1);
@@ -426,8 +426,8 @@ int ossl_qtx_calculate_ciphertext_payload_len(OSSL_QTX *qtx, uint32_t enc_level,
 
 /* Determines the size of the AEAD input given the output size. */
 int ossl_qtx_calculate_plaintext_payload_len(OSSL_QTX *qtx, uint32_t enc_level,
-                                             size_t ciphertext_len,
-                                             size_t *plaintext_len)
+    size_t ciphertext_len,
+    size_t *plaintext_len)
 {
     OSSL_QRL_ENC_LEVEL *el
         = ossl_qrl_enc_level_set_get(&qtx->el_set, enc_level, 1);
@@ -450,16 +450,16 @@ int ossl_qtx_calculate_plaintext_payload_len(OSSL_QTX *qtx, uint32_t enc_level,
 }
 
 /* Any other error (including packet being too big for MDPL). */
-#define QTX_FAIL_GENERIC            (-1)
+#define QTX_FAIL_GENERIC (-1)
 
 /*
  * Returned where there is insufficient room in the datagram to write the
  * packet.
  */
-#define QTX_FAIL_INSUFFICIENT_LEN   (-2)
+#define QTX_FAIL_INSUFFICIENT_LEN (-2)
 
 static int qtx_write_hdr(OSSL_QTX *qtx, const QUIC_PKT_HDR *hdr, TXE *txe,
-                         QUIC_PKT_HDR_PTRS *ptrs)
+    QUIC_PKT_HDR_PTRS *ptrs)
 {
     WPACKET wpkt;
     size_t l = 0;
@@ -469,7 +469,7 @@ static int qtx_write_hdr(OSSL_QTX *qtx, const QUIC_PKT_HDR *hdr, TXE *txe,
         return 0;
 
     if (!ossl_quic_wire_encode_pkt_hdr(&wpkt, hdr->dst_conn_id.id_len,
-                                       hdr, ptrs)
+            hdr, ptrs)
         || !WPACKET_get_total_written(&wpkt, &l)) {
         WPACKET_finish(&wpkt);
         return 0;
@@ -478,7 +478,7 @@ static int qtx_write_hdr(OSSL_QTX *qtx, const QUIC_PKT_HDR *hdr, TXE *txe,
 
     if (qtx->msg_callback != NULL)
         qtx->msg_callback(1, OSSL_QUIC1_VERSION, SSL3_RT_QUIC_PACKET, data, l,
-                          qtx->msg_callback_ssl, qtx->msg_callback_arg);
+            qtx->msg_callback_ssl, qtx->msg_callback_arg);
 
     txe->data_len += l;
 
@@ -486,9 +486,9 @@ static int qtx_write_hdr(OSSL_QTX *qtx, const QUIC_PKT_HDR *hdr, TXE *txe,
 }
 
 static int qtx_encrypt_into_txe(OSSL_QTX *qtx, struct iovec_cur *cur, TXE *txe,
-                                uint32_t enc_level, QUIC_PN pn,
-                                const unsigned char *hdr, size_t hdr_len,
-                                QUIC_PKT_HDR_PTRS *ptrs)
+    uint32_t enc_level, QUIC_PN pn,
+    const unsigned char *hdr, size_t hdr_len,
+    QUIC_PKT_HDR_PTRS *ptrs)
 {
     int l = 0, l2 = 0, nonce_len;
     OSSL_QRL_ENC_LEVEL *el
@@ -556,7 +556,8 @@ static int qtx_encrypt_into_txe(OSSL_QTX *qtx, struct iovec_cur *cur, TXE *txe,
             break;
 
         if (EVP_CipherUpdate(cctx, txe_data(txe) + txe->data_len,
-                             &l, src, src_len) != 1) {
+                &l, src, src_len)
+            != 1) {
             ERR_raise(ERR_LIB_SSL, ERR_R_EVP_LIB);
             return 0;
         }
@@ -577,7 +578,8 @@ static int qtx_encrypt_into_txe(OSSL_QTX *qtx, struct iovec_cur *cur, TXE *txe,
     }
 
     if (EVP_CIPHER_CTX_ctrl(cctx, EVP_CTRL_AEAD_GET_TAG,
-                            el->tag_len, txe_data(txe) + txe->data_len) != 1) {
+            el->tag_len, txe_data(txe) + txe->data_len)
+        != 1) {
         ERR_raise(ERR_LIB_SSL, ERR_R_EVP_LIB);
         return 0;
     }
@@ -597,8 +599,8 @@ static int qtx_encrypt_into_txe(OSSL_QTX *qtx, struct iovec_cur *cur, TXE *txe,
  * process.
  */
 static int qtx_write(OSSL_QTX *qtx, const OSSL_QTX_PKT *pkt, TXE *txe,
-                     uint32_t enc_level, QUIC_PKT_HDR *hdr,
-                     const OSSL_QTX_IOVEC *iovec, size_t num_iovec)
+    uint32_t enc_level, QUIC_PKT_HDR *hdr,
+    const OSSL_QTX_IOVEC *iovec, size_t num_iovec)
 {
     int ret, needs_encrypt;
     size_t hdr_len, pred_hdr_len, payload_len, pkt_len, space_left;
@@ -647,16 +649,16 @@ static int qtx_write(OSSL_QTX *qtx, const OSSL_QTX_PKT *pkt, TXE *txe,
     /* Determine encrypted payload length. */
     if (needs_encrypt)
         ossl_qtx_calculate_ciphertext_payload_len(qtx, enc_level,
-                                                  cur.bytes_remaining,
-                                                  &payload_len);
+            cur.bytes_remaining,
+            &payload_len);
     else
         payload_len = cur.bytes_remaining;
 
     /* Determine header length. */
-    hdr->data  = NULL;
-    hdr->len   = payload_len;
+    hdr->data = NULL;
+    hdr->len = payload_len;
     pred_hdr_len = ossl_quic_wire_get_encoded_pkt_hdr_len(hdr->dst_conn_id.id_len,
-                                                          hdr);
+        hdr);
     if (pred_hdr_len == 0) {
         ret = QTX_FAIL_GENERIC;
         goto err;
@@ -672,8 +674,8 @@ static int qtx_write(OSSL_QTX *qtx, const OSSL_QTX_PKT *pkt, TXE *txe,
 
     if (ossl_quic_pkt_type_has_pn(hdr->type)) {
         if (!ossl_quic_wire_encode_pkt_hdr_pn(pkt->pn,
-                                              hdr->pn,
-                                              hdr->pn_len)) {
+                hdr->pn,
+                hdr->pn_len)) {
             ret = QTX_FAIL_GENERIC;
             goto err;
         }
@@ -706,7 +708,7 @@ static int qtx_write(OSSL_QTX *qtx, const OSSL_QTX_PKT *pkt, TXE *txe,
     } else {
         /* Encrypt into TXE. */
         if (!qtx_encrypt_into_txe(qtx, &cur, txe, enc_level, pkt->pn,
-                                  hdr_start, hdr_len, &ptrs)) {
+                hdr_start, hdr_len, &ptrs)) {
             ret = QTX_FAIL_GENERIC;
             goto err;
         }
@@ -752,7 +754,7 @@ static QLOG *qtx_get_qlog(OSSL_QTX *qtx)
 }
 
 static int qtx_mutate_write(OSSL_QTX *qtx, const OSSL_QTX_PKT *pkt, TXE *txe,
-                            uint32_t enc_level)
+    uint32_t enc_level)
 {
     int ret;
     QUIC_PKT_HDR *hdr;
@@ -762,20 +764,20 @@ static int qtx_mutate_write(OSSL_QTX *qtx, const OSSL_QTX_PKT *pkt, TXE *txe,
     /* If we are running tests then mutate_packet may be non NULL */
     if (qtx->mutatecb != NULL) {
         if (!qtx->mutatecb(pkt->hdr, pkt->iovec, pkt->num_iovec, &hdr,
-                           &iovec, &num_iovec, qtx->mutatearg))
+                &iovec, &num_iovec, qtx->mutatearg))
             return QTX_FAIL_GENERIC;
     } else {
-        hdr         = pkt->hdr;
-        iovec       = pkt->iovec;
-        num_iovec   = pkt->num_iovec;
+        hdr = pkt->hdr;
+        iovec = pkt->iovec;
+        num_iovec = pkt->num_iovec;
     }
 
     ret = qtx_write(qtx, pkt, txe, enc_level,
-                    hdr, iovec, num_iovec);
+        hdr, iovec, num_iovec);
     if (ret == 1)
         ossl_qlog_event_transport_packet_sent(qtx_get_qlog(qtx), hdr, pkt->pn,
-                                              iovec, num_iovec,
-                                              qtx->datagram_count);
+            iovec, num_iovec,
+            qtx->datagram_count);
 
     if (qtx->finishmutatecb != NULL)
         qtx->finishmutatecb(qtx->mutatearg);
@@ -786,7 +788,7 @@ static int qtx_mutate_write(OSSL_QTX *qtx, const OSSL_QTX_PKT *pkt, TXE *txe,
 static int addr_eq(const BIO_ADDR *a, const BIO_ADDR *b)
 {
     return ((a == NULL || BIO_ADDR_family(a) == AF_UNSPEC)
-            && (b == NULL || BIO_ADDR_family(b) == AF_UNSPEC))
+               && (b == NULL || BIO_ADDR_family(b) == AF_UNSPEC))
         || (a != NULL && b != NULL && memcmp(a, b, sizeof(*a)) == 0);
 }
 
@@ -808,7 +810,7 @@ int ossl_qtx_write_pkt(OSSL_QTX *qtx, const OSSL_QTX_PKT *pkt)
     if (!ossl_quic_pkt_type_can_share_dgram(pkt->hdr->type))
         ossl_qtx_finish_dgram(qtx);
     else if (enc_level >= QUIC_ENC_LEVEL_NUM
-               || ossl_qrl_enc_level_set_have_el(&qtx->el_set, enc_level) != 1) {
+        || ossl_qrl_enc_level_set_have_el(&qtx->el_set, enc_level) != 1) {
         /* All other packet types are encrypted. */
         return 0;
     }
@@ -915,23 +917,23 @@ void ossl_qtx_finish_dgram(OSSL_QTX *qtx)
     else
         qtx_add_to_pending(qtx, txe);
 
-    qtx->cons       = NULL;
+    qtx->cons = NULL;
     qtx->cons_count = 0;
     ++qtx->datagram_count;
 }
 
 static void txe_to_msg(TXE *txe, BIO_MSG *msg)
 {
-    msg->data       = txe_data(txe);
-    msg->data_len   = txe->data_len;
-    msg->flags      = 0;
+    msg->data = txe_data(txe);
+    msg->data_len = txe->data_len;
+    msg->flags = 0;
     msg->peer
         = BIO_ADDR_family(&txe->peer) != AF_UNSPEC ? &txe->peer : NULL;
     msg->local
         = BIO_ADDR_family(&txe->local) != AF_UNSPEC ? &txe->local : NULL;
 }
 
-#define MAX_MSGS_PER_SEND   32
+#define MAX_MSGS_PER_SEND 32
 
 int ossl_qtx_flush_net(OSSL_QTX *qtx)
 {
@@ -948,8 +950,8 @@ int ossl_qtx_flush_net(OSSL_QTX *qtx)
 
     for (;;) {
         for (txe = ossl_list_txe_head(&qtx->pending), i = 0;
-             txe != NULL && i < OSSL_NELEM(msg);
-             txe = ossl_list_txe_next(txe), ++i)
+            txe != NULL && i < OSSL_NELEM(msg);
+            txe = ossl_list_txe_next(txe), ++i)
             txe_to_msg(txe, &msg[i]);
 
         if (!i)
@@ -988,9 +990,9 @@ int ossl_qtx_flush_net(OSSL_QTX *qtx)
         for (i = 0; i < wr; ++i) {
             if (qtx->msg_callback != NULL)
                 qtx->msg_callback(1, OSSL_QUIC1_VERSION, SSL3_RT_QUIC_DATAGRAM,
-                                msg[i].data, msg[i].data_len,
-                                qtx->msg_callback_ssl,
-                                qtx->msg_callback_arg);
+                    msg[i].data, msg[i].data_len,
+                    qtx->msg_callback_ssl,
+                    qtx->msg_callback_arg);
             qtx_pending_to_free(qtx);
         }
 
@@ -1056,7 +1058,7 @@ size_t ossl_qtx_get_unflushed_pkt_count(OSSL_QTX *qtx)
 int ossl_qtx_trigger_key_update(OSSL_QTX *qtx)
 {
     return ossl_qrl_enc_level_set_key_update(&qtx->el_set,
-                                             QUIC_ENC_LEVEL_1RTT);
+        QUIC_ENC_LEVEL_1RTT);
 }
 
 uint64_t ossl_qtx_get_cur_epoch_pkt_count(OSSL_QTX *qtx, uint32_t enc_level)
@@ -1082,7 +1084,7 @@ uint64_t ossl_qtx_get_max_epoch_pkt_count(OSSL_QTX *qtx, uint32_t enc_level)
 }
 
 void ossl_qtx_set_msg_callback(OSSL_QTX *qtx, ossl_msg_cb msg_callback,
-                               SSL *msg_callback_ssl)
+    SSL *msg_callback_ssl)
 {
     qtx->msg_callback = msg_callback;
     qtx->msg_callback_ssl = msg_callback_ssl;
