@@ -1,5 +1,5 @@
 /*
- * Copyright 2022-2023 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2022-2024 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -17,14 +17,14 @@
 #include "recmethod_local.h"
 
 static int tls1_set_crypto_state(OSSL_RECORD_LAYER *rl, int level,
-                                 unsigned char *key, size_t keylen,
-                                 unsigned char *iv, size_t ivlen,
-                                 unsigned char *mackey, size_t mackeylen,
-                                 const EVP_CIPHER *ciph,
-                                 size_t taglen,
-                                 int mactype,
-                                 const EVP_MD *md,
-                                 COMP_METHOD *comp)
+    unsigned char *key, size_t keylen,
+    unsigned char *iv, size_t ivlen,
+    unsigned char *mackey, size_t mackeylen,
+    const EVP_CIPHER *ciph,
+    size_t taglen,
+    int mactype,
+    const EVP_MD *md,
+    COMP_METHOD *comp)
 {
     EVP_CIPHER_CTX *ciph_ctx;
     EVP_PKEY *mac_key;
@@ -62,8 +62,8 @@ static int tls1_set_crypto_state(OSSL_RECORD_LAYER *rl, int level,
     if ((EVP_CIPHER_get_flags(ciph) & EVP_CIPH_FLAG_AEAD_CIPHER) == 0) {
         if (mactype == EVP_PKEY_HMAC) {
             mac_key = EVP_PKEY_new_raw_private_key_ex(rl->libctx, "HMAC",
-                                                      rl->propq, mackey,
-                                                      mackeylen);
+                rl->propq, mackey,
+                mackeylen);
         } else {
             /*
              * If its not HMAC then the only other types of MAC we support are
@@ -71,12 +71,13 @@ static int tls1_set_crypto_state(OSSL_RECORD_LAYER *rl, int level,
              * a MAC key.
              */
             mac_key = EVP_PKEY_new_mac_key(mactype, NULL, mackey,
-                                           (int)mackeylen);
+                (int)mackeylen);
         }
         if (mac_key == NULL
             || EVP_DigestSignInit_ex(rl->md_ctx, NULL, EVP_MD_get0_name(md),
-                                     rl->libctx, rl->propq, mac_key,
-                                     NULL) <= 0) {
+                   rl->libctx, rl->propq, mac_key,
+                   NULL)
+                <= 0) {
             EVP_PKEY_free(mac_key);
             ERR_raise(ERR_LIB_SSL, ERR_R_INTERNAL_ERROR);
             return OSSL_RECORD_RETURN_FATAL;
@@ -86,20 +87,24 @@ static int tls1_set_crypto_state(OSSL_RECORD_LAYER *rl, int level,
 
     if (EVP_CIPHER_get_mode(ciph) == EVP_CIPH_GCM_MODE) {
         if (!EVP_CipherInit_ex(ciph_ctx, ciph, NULL, key, NULL, enc)
-                || EVP_CIPHER_CTX_ctrl(ciph_ctx, EVP_CTRL_GCM_SET_IV_FIXED,
-                                       (int)ivlen, iv) <= 0) {
+            || EVP_CIPHER_CTX_ctrl(ciph_ctx, EVP_CTRL_GCM_SET_IV_FIXED,
+                   (int)ivlen, iv)
+                <= 0) {
             ERR_raise(ERR_LIB_SSL, ERR_R_INTERNAL_ERROR);
             return OSSL_RECORD_RETURN_FATAL;
         }
     } else if (EVP_CIPHER_get_mode(ciph) == EVP_CIPH_CCM_MODE) {
         if (!EVP_CipherInit_ex(ciph_ctx, ciph, NULL, NULL, NULL, enc)
-                || EVP_CIPHER_CTX_ctrl(ciph_ctx, EVP_CTRL_AEAD_SET_IVLEN, 12,
-                                       NULL) <= 0
-                || EVP_CIPHER_CTX_ctrl(ciph_ctx, EVP_CTRL_AEAD_SET_TAG,
-                                       (int)taglen, NULL) <= 0
-                || EVP_CIPHER_CTX_ctrl(ciph_ctx, EVP_CTRL_CCM_SET_IV_FIXED,
-                                       (int)ivlen, iv) <= 0
-                || !EVP_CipherInit_ex(ciph_ctx, NULL, NULL, key, NULL, enc)) {
+            || EVP_CIPHER_CTX_ctrl(ciph_ctx, EVP_CTRL_AEAD_SET_IVLEN, 12,
+                   NULL)
+                <= 0
+            || EVP_CIPHER_CTX_ctrl(ciph_ctx, EVP_CTRL_AEAD_SET_TAG,
+                   (int)taglen, NULL)
+                <= 0
+            || EVP_CIPHER_CTX_ctrl(ciph_ctx, EVP_CTRL_CCM_SET_IV_FIXED,
+                   (int)ivlen, iv)
+                <= 0
+            || !EVP_CipherInit_ex(ciph_ctx, NULL, NULL, key, NULL, enc)) {
             ERR_raise(ERR_LIB_SSL, ERR_R_INTERNAL_ERROR);
             return OSSL_RECORD_RETURN_FATAL;
         }
@@ -113,7 +118,8 @@ static int tls1_set_crypto_state(OSSL_RECORD_LAYER *rl, int level,
     if ((EVP_CIPHER_get_flags(ciph) & EVP_CIPH_FLAG_AEAD_CIPHER) != 0
         && mackeylen != 0
         && EVP_CIPHER_CTX_ctrl(ciph_ctx, EVP_CTRL_AEAD_SET_MAC_KEY,
-                               (int)mackeylen, mackey) <= 0) {
+               (int)mackeylen, mackey)
+            <= 0) {
         ERR_raise(ERR_LIB_SSL, ERR_R_INTERNAL_ERROR);
         return OSSL_RECORD_RETURN_FATAL;
     }
@@ -123,7 +129,7 @@ static int tls1_set_crypto_state(OSSL_RECORD_LAYER *rl, int level,
      * different to that in ciph if we have an ENGINE in use
      */
     if (EVP_CIPHER_get0_provider(EVP_CIPHER_CTX_get0_cipher(ciph_ctx)) != NULL
-            && !ossl_set_tls_provider_parameters(rl, ciph_ctx, ciph, md)) {
+        && !ossl_set_tls_provider_parameters(rl, ciph_ctx, ciph, md)) {
         /* ERR_raise already called */
         return OSSL_RECORD_RETURN_FATAL;
     }
@@ -165,8 +171,8 @@ static int tls1_set_crypto_state(OSSL_RECORD_LAYER *rl, int level,
  *    1: Success or Mac-then-encrypt decryption failed (MAC will be randomised)
  */
 static int tls1_cipher(OSSL_RECORD_LAYER *rl, TLS_RL_RECORD *recs,
-                       size_t n_recs, int sending, SSL_MAC_BUF *macs,
-                       size_t macsize)
+    size_t n_recs, int sending, SSL_MAC_BUF *macs,
+    size_t macsize)
 {
     EVP_CIPHER_CTX *ds;
     size_t reclen[SSL_MAX_PIPELINES];
@@ -213,7 +219,8 @@ static int tls1_cipher(OSSL_RECORD_LAYER *rl, TLS_RL_RECORD *recs,
                     RLAYERfatal(rl, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
                     return 0;
                 } else if (RAND_bytes_ex(rl->libctx, recs[ctr].input,
-                                         ivlen, 0) <= 0) {
+                               ivlen, 0)
+                    <= 0) {
                     RLAYERfatal(rl, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
                     return 0;
                 }
@@ -229,9 +236,15 @@ static int tls1_cipher(OSSL_RECORD_LAYER *rl, TLS_RL_RECORD *recs,
 
     bs = EVP_CIPHER_get_block_size(EVP_CIPHER_CTX_get0_cipher(ds));
 
+    if (bs == 0) {
+        RLAYERfatal(rl, SSL_AD_INTERNAL_ERROR, SSL_R_BAD_CIPHER);
+        return 0;
+    }
+
     if (n_recs > 1) {
         if ((EVP_CIPHER_get_flags(EVP_CIPHER_CTX_get0_cipher(ds))
-                 & EVP_CIPH_FLAG_PIPELINE) == 0) {
+                & EVP_CIPH_FLAG_PIPELINE)
+            == 0) {
             /*
              * We shouldn't have been called with pipeline data if the
              * cipher doesn't support pipelining
@@ -244,7 +257,8 @@ static int tls1_cipher(OSSL_RECORD_LAYER *rl, TLS_RL_RECORD *recs,
         reclen[ctr] = recs[ctr].length;
 
         if ((EVP_CIPHER_get_flags(EVP_CIPHER_CTX_get0_cipher(ds))
-                 & EVP_CIPH_FLAG_AEAD_CIPHER) != 0) {
+                & EVP_CIPH_FLAG_AEAD_CIPHER)
+            != 0) {
             unsigned char *seq;
 
             seq = rl->sequence;
@@ -269,7 +283,7 @@ static int tls1_cipher(OSSL_RECORD_LAYER *rl, TLS_RL_RECORD *recs,
             buf[ctr][11] = (unsigned char)(recs[ctr].length >> 8);
             buf[ctr][12] = (unsigned char)(recs[ctr].length & 0xff);
             pad = EVP_CIPHER_CTX_ctrl(ds, EVP_CTRL_AEAD_TLS1_AAD,
-                                      EVP_AEAD_TLS1_AAD_LEN, buf[ctr]);
+                EVP_AEAD_TLS1_AAD_LEN, buf[ctr]);
             if (pad <= 0) {
                 RLAYERfatal(rl, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
                 return 0;
@@ -313,7 +327,8 @@ static int tls1_cipher(OSSL_RECORD_LAYER *rl, TLS_RL_RECORD *recs,
             data[ctr] = recs[ctr].data;
 
         if (EVP_CIPHER_CTX_ctrl(ds, EVP_CTRL_SET_PIPELINE_OUTPUT_BUFS,
-                                (int)n_recs, data) <= 0) {
+                (int)n_recs, data)
+            <= 0) {
             RLAYERfatal(rl, SSL_AD_INTERNAL_ERROR, SSL_R_PIPELINE_FAILURE);
             return 0;
         }
@@ -322,9 +337,11 @@ static int tls1_cipher(OSSL_RECORD_LAYER *rl, TLS_RL_RECORD *recs,
             data[ctr] = recs[ctr].input;
 
         if (EVP_CIPHER_CTX_ctrl(ds, EVP_CTRL_SET_PIPELINE_INPUT_BUFS,
-                                (int)n_recs, data) <= 0
+                (int)n_recs, data)
+                <= 0
             || EVP_CIPHER_CTX_ctrl(ds, EVP_CTRL_SET_PIPELINE_INPUT_LENS,
-                                   (int)n_recs, reclen) <= 0) {
+                   (int)n_recs, reclen)
+                <= 0) {
             RLAYERfatal(rl, SSL_AD_INTERNAL_ERROR, SSL_R_PIPELINE_FAILURE);
             return 0;
         }
@@ -342,7 +359,8 @@ static int tls1_cipher(OSSL_RECORD_LAYER *rl, TLS_RL_RECORD *recs,
             decrement_seq = 1;
 
         if (EVP_CIPHER_CTX_ctrl(ds, EVP_CTRL_TLSTREE, decrement_seq,
-                                rl->sequence) <= 0) {
+                rl->sequence)
+            <= 0) {
 
             RLAYERfatal(rl, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
             return 0;
@@ -359,7 +377,7 @@ static int tls1_cipher(OSSL_RECORD_LAYER *rl, TLS_RL_RECORD *recs,
         }
 
         if (!EVP_CipherUpdate(ds, recs[0].data, &outlen, recs[0].input,
-                              (unsigned int)reclen[0]))
+                (unsigned int)reclen[0]))
             return 0;
         recs[0].length = outlen;
 
@@ -389,14 +407,14 @@ static int tls1_cipher(OSSL_RECORD_LAYER *rl, TLS_RL_RECORD *recs,
                 macs[0].alloced = 0;
 
                 *p++ = OSSL_PARAM_construct_octet_ptr(OSSL_CIPHER_PARAM_TLS_MAC,
-                                                      (void **)&macs[0].mac,
-                                                      macsize);
+                    (void **)&macs[0].mac,
+                    macsize);
                 *p = OSSL_PARAM_construct_end();
 
                 if (!EVP_CIPHER_CTX_get_params(ds, params)) {
                     /* Shouldn't normally happen */
                     RLAYERfatal(rl, SSL_AD_INTERNAL_ERROR,
-                                ERR_R_INTERNAL_ERROR);
+                        ERR_R_INTERNAL_ERROR);
                     return 0;
                 }
             }
@@ -405,11 +423,12 @@ static int tls1_cipher(OSSL_RECORD_LAYER *rl, TLS_RL_RECORD *recs,
         /* Legacy cipher */
 
         tmpr = EVP_Cipher(ds, recs[0].data, recs[0].input,
-                          (unsigned int)reclen[0]);
+            (unsigned int)reclen[0]);
         if ((EVP_CIPHER_get_flags(EVP_CIPHER_CTX_get0_cipher(ds))
-                 & EVP_CIPH_FLAG_CUSTOM_CIPHER) != 0
-            ? (tmpr < 0)
-            : (tmpr == 0)) {
+                & EVP_CIPH_FLAG_CUSTOM_CIPHER)
+                    != 0
+                ? (tmpr < 0)
+                : (tmpr == 0)) {
             /* AEAD can fail to verify MAC */
             return 0;
         }
@@ -439,16 +458,17 @@ static int tls1_cipher(OSSL_RECORD_LAYER *rl, TLS_RL_RECORD *recs,
                  * with a random MAC if padding is invalid
                  */
                 if (!tls1_cbc_remove_padding_and_mac(&recs[ctr].length,
-                                        recs[ctr].orig_len,
-                                        recs[ctr].data,
-                                        (macs != NULL) ? &macs[ctr].mac : NULL,
-                                        (macs != NULL) ? &macs[ctr].alloced
-                                                       : NULL,
-                                        bs,
-                                        pad ? (size_t)pad : macsize,
-                                        (EVP_CIPHER_get_flags(enc)
-                                        & EVP_CIPH_FLAG_AEAD_CIPHER) != 0,
-                                        rl->libctx))
+                        recs[ctr].orig_len,
+                        recs[ctr].data,
+                        (macs != NULL) ? &macs[ctr].mac : NULL,
+                        (macs != NULL) ? &macs[ctr].alloced
+                                       : NULL,
+                        bs,
+                        pad ? (size_t)pad : macsize,
+                        (EVP_CIPHER_get_flags(enc)
+                            & EVP_CIPH_FLAG_AEAD_CIPHER)
+                            != 0,
+                        rl->libctx))
                     return 0;
             }
         }
@@ -457,7 +477,7 @@ static int tls1_cipher(OSSL_RECORD_LAYER *rl, TLS_RL_RECORD *recs,
 }
 
 static int tls1_mac(OSSL_RECORD_LAYER *rl, TLS_RL_RECORD *rec, unsigned char *md,
-                    int sending)
+    int sending)
 {
     unsigned char *seq = rl->sequence;
     EVP_MD_CTX *hash;
@@ -485,8 +505,8 @@ static int tls1_mac(OSSL_RECORD_LAYER *rl, TLS_RL_RECORD *rec, unsigned char *md
     }
 
     if (!rl->isdtls
-            && rl->tlstree
-            && EVP_MD_CTX_ctrl(mac_ctx, EVP_MD_CTRL_TLSTREE, 0, seq) <= 0)
+        && rl->tlstree
+        && EVP_MD_CTX_ctrl(mac_ctx, EVP_MD_CTRL_TLSTREE, 0, seq) <= 0)
         goto end;
 
     if (rl->isdtls) {
@@ -512,11 +532,11 @@ static int tls1_mac(OSSL_RECORD_LAYER *rl, TLS_RL_RECORD *rec, unsigned char *md
         OSSL_PARAM tls_hmac_params[2], *p = tls_hmac_params;
 
         *p++ = OSSL_PARAM_construct_size_t(OSSL_MAC_PARAM_TLS_DATA_SIZE,
-                                           &rec->orig_len);
+            &rec->orig_len);
         *p++ = OSSL_PARAM_construct_end();
 
         if (!EVP_PKEY_CTX_set_params(EVP_MD_CTX_get_pkey_ctx(mac_ctx),
-                                     tls_hmac_params))
+                tls_hmac_params))
             goto end;
     }
 
@@ -525,65 +545,69 @@ static int tls1_mac(OSSL_RECORD_LAYER *rl, TLS_RL_RECORD *rec, unsigned char *md
         || EVP_DigestSignFinal(mac_ctx, md, &md_size) <= 0)
         goto end;
 
-    OSSL_TRACE_BEGIN(TLS) {
+    OSSL_TRACE_BEGIN(TLS)
+    {
         BIO_printf(trc_out, "seq:\n");
         BIO_dump_indent(trc_out, seq, 8, 4);
         BIO_printf(trc_out, "rec:\n");
         BIO_dump_indent(trc_out, rec->data, rec->length, 4);
-    } OSSL_TRACE_END(TLS);
+    }
+    OSSL_TRACE_END(TLS);
 
     if (!rl->isdtls && !tls_increment_sequence_ctr(rl)) {
         /* RLAYERfatal already called */
         goto end;
     }
 
-    OSSL_TRACE_BEGIN(TLS) {
+    OSSL_TRACE_BEGIN(TLS)
+    {
         BIO_printf(trc_out, "md:\n");
         BIO_dump_indent(trc_out, md, md_size, 4);
-    } OSSL_TRACE_END(TLS);
+    }
+    OSSL_TRACE_END(TLS);
     ret = 1;
- end:
+end:
     EVP_MD_CTX_free(hmac);
     return ret;
 }
 
 #if defined(SSL3_ALIGN_PAYLOAD) && SSL3_ALIGN_PAYLOAD != 0
-# ifndef OPENSSL_NO_COMP
-#  define MAX_PREFIX_LEN ((SSL3_ALIGN_PAYLOAD - 1) \
-                           + SSL3_RT_SEND_MAX_ENCRYPTED_OVERHEAD \
-                           + SSL3_RT_HEADER_LENGTH \
-                           + SSL3_RT_MAX_COMPRESSED_OVERHEAD)
-# else
-#  define MAX_PREFIX_LEN ((SSL3_ALIGN_PAYLOAD - 1) \
-                           + SSL3_RT_SEND_MAX_ENCRYPTED_OVERHEAD \
-                           + SSL3_RT_HEADER_LENGTH)
-# endif /* OPENSSL_NO_COMP */
+#ifndef OPENSSL_NO_COMP
+#define MAX_PREFIX_LEN ((SSL3_ALIGN_PAYLOAD - 1) \
+    + SSL3_RT_SEND_MAX_ENCRYPTED_OVERHEAD        \
+    + SSL3_RT_HEADER_LENGTH                      \
+    + SSL3_RT_MAX_COMPRESSED_OVERHEAD)
 #else
-# ifndef OPENSSL_NO_COMP
-#  define MAX_PREFIX_LEN (SSL3_RT_SEND_MAX_ENCRYPTED_OVERHEAD \
-                           + SSL3_RT_HEADER_LENGTH \
-                           + SSL3_RT_MAX_COMPRESSED_OVERHEAD)
-# else
-#  define MAX_PREFIX_LEN (SSL3_RT_SEND_MAX_ENCRYPTED_OVERHEAD \
-                           + SSL3_RT_HEADER_LENGTH)
-# endif /* OPENSSL_NO_COMP */
+#define MAX_PREFIX_LEN ((SSL3_ALIGN_PAYLOAD - 1) \
+    + SSL3_RT_SEND_MAX_ENCRYPTED_OVERHEAD        \
+    + SSL3_RT_HEADER_LENGTH)
+#endif /* OPENSSL_NO_COMP */
+#else
+#ifndef OPENSSL_NO_COMP
+#define MAX_PREFIX_LEN (SSL3_RT_SEND_MAX_ENCRYPTED_OVERHEAD \
+    + SSL3_RT_HEADER_LENGTH                                 \
+    + SSL3_RT_MAX_COMPRESSED_OVERHEAD)
+#else
+#define MAX_PREFIX_LEN (SSL3_RT_SEND_MAX_ENCRYPTED_OVERHEAD \
+    + SSL3_RT_HEADER_LENGTH)
+#endif /* OPENSSL_NO_COMP */
 #endif
 
 /* This function is also used by the SSLv3 implementation */
 int tls1_allocate_write_buffers(OSSL_RECORD_LAYER *rl,
-                                OSSL_RECORD_TEMPLATE *templates,
-                                size_t numtempl, size_t *prefix)
+    OSSL_RECORD_TEMPLATE *templates,
+    size_t numtempl, size_t *prefix)
 {
     /* Do we need to add an empty record prefix? */
     *prefix = rl->need_empty_fragments
-              && templates[0].type == SSL3_RT_APPLICATION_DATA;
+        && templates[0].type == SSL3_RT_APPLICATION_DATA;
 
     /*
      * In the prefix case we can allocate a much smaller buffer. Otherwise we
      * just allocate the default buffer size
      */
     if (!tls_setup_write_buffer(rl, numtempl + *prefix,
-                                *prefix ? MAX_PREFIX_LEN : 0, 0)) {
+            *prefix ? MAX_PREFIX_LEN : 0, 0)) {
         /* RLAYERfatal() already called */
         return 0;
     }
@@ -593,12 +617,12 @@ int tls1_allocate_write_buffers(OSSL_RECORD_LAYER *rl,
 
 /* This function is also used by the SSLv3 implementation */
 int tls1_initialise_write_packets(OSSL_RECORD_LAYER *rl,
-                                  OSSL_RECORD_TEMPLATE *templates,
-                                  size_t numtempl,
-                                  OSSL_RECORD_TEMPLATE *prefixtempl,
-                                  WPACKET *pkt,
-                                  TLS_BUFFER *bufs,
-                                  size_t *wpinited)
+    OSSL_RECORD_TEMPLATE *templates,
+    size_t numtempl,
+    OSSL_RECORD_TEMPLATE *prefixtempl,
+    WPACKET *pkt,
+    TLS_BUFFER *bufs,
+    size_t *wpinited)
 {
     size_t align = 0;
     TLS_BUFFER *wb;
@@ -606,7 +630,7 @@ int tls1_initialise_write_packets(OSSL_RECORD_LAYER *rl,
 
     /* Do we need to add an empty record prefix? */
     prefix = rl->need_empty_fragments
-             && templates[0].type == SSL3_RT_APPLICATION_DATA;
+        && templates[0].type == SSL3_RT_APPLICATION_DATA;
 
     if (prefix) {
         /*
@@ -623,12 +647,12 @@ int tls1_initialise_write_packets(OSSL_RECORD_LAYER *rl,
 #if defined(SSL3_ALIGN_PAYLOAD) && SSL3_ALIGN_PAYLOAD != 0
         align = (size_t)TLS_BUFFER_get_buf(wb) + SSL3_RT_HEADER_LENGTH;
         align = SSL3_ALIGN_PAYLOAD - 1
-                - ((align - 1) % SSL3_ALIGN_PAYLOAD);
+            - ((align - 1) % SSL3_ALIGN_PAYLOAD);
 #endif
         TLS_BUFFER_set_offset(wb, align);
 
         if (!WPACKET_init_static_len(&pkt[0], TLS_BUFFER_get_buf(wb),
-                                     TLS_BUFFER_get_len(wb), 0)) {
+                TLS_BUFFER_get_len(wb), 0)) {
             RLAYERfatal(rl, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
             return 0;
         }
@@ -640,13 +664,13 @@ int tls1_initialise_write_packets(OSSL_RECORD_LAYER *rl,
     }
 
     return tls_initialise_write_packets_default(rl, templates, numtempl,
-                                                NULL,
-                                                pkt + prefix, bufs + prefix,
-                                                wpinited);
+        NULL,
+        pkt + prefix, bufs + prefix,
+        wpinited);
 }
 
 /* TLSv1.0, TLSv1.1 and TLSv1.2 all use the same funcs */
-struct record_functions_st tls_1_funcs = {
+const struct record_functions_st tls_1_funcs = {
     tls1_set_crypto_state,
     tls1_cipher,
     tls1_mac,
@@ -667,7 +691,7 @@ struct record_functions_st tls_1_funcs = {
     NULL
 };
 
-struct record_functions_st dtls_1_funcs = {
+const struct record_functions_st dtls_1_funcs = {
     tls1_set_crypto_state,
     tls1_cipher,
     tls1_mac,
