@@ -30,10 +30,10 @@ typedef struct {
  * Provide thin wrapper callbacks which convert new style arguments to old style
  */
 static int custom_ext_add_old_cb_wrap(SSL *s, unsigned int ext_type,
-                                      unsigned int context,
-                                      const unsigned char **out,
-                                      size_t *outlen, X509 *x, size_t chainidx,
-                                      int *al, void *add_arg)
+    unsigned int context,
+    const unsigned char **out,
+    size_t *outlen, X509 *x, size_t chainidx,
+    int *al, void *add_arg)
 {
     custom_ext_add_cb_wrap *add_cb_wrap = (custom_ext_add_cb_wrap *)add_arg;
 
@@ -41,12 +41,12 @@ static int custom_ext_add_old_cb_wrap(SSL *s, unsigned int ext_type,
         return 1;
 
     return add_cb_wrap->add_cb(s, ext_type, out, outlen, al,
-                               add_cb_wrap->add_arg);
+        add_cb_wrap->add_arg);
 }
 
 static void custom_ext_free_old_cb_wrap(SSL *s, unsigned int ext_type,
-                                        unsigned int context,
-                                        const unsigned char *out, void *add_arg)
+    unsigned int context,
+    const unsigned char *out, void *add_arg)
 {
     custom_ext_add_cb_wrap *add_cb_wrap = (custom_ext_add_cb_wrap *)add_arg;
 
@@ -57,19 +57,18 @@ static void custom_ext_free_old_cb_wrap(SSL *s, unsigned int ext_type,
 }
 
 static int custom_ext_parse_old_cb_wrap(SSL *s, unsigned int ext_type,
-                                        unsigned int context,
-                                        const unsigned char *in,
-                                        size_t inlen, X509 *x, size_t chainidx,
-                                        int *al, void *parse_arg)
+    unsigned int context,
+    const unsigned char *in,
+    size_t inlen, X509 *x, size_t chainidx,
+    int *al, void *parse_arg)
 {
-    custom_ext_parse_cb_wrap *parse_cb_wrap =
-        (custom_ext_parse_cb_wrap *)parse_arg;
+    custom_ext_parse_cb_wrap *parse_cb_wrap = (custom_ext_parse_cb_wrap *)parse_arg;
 
     if (parse_cb_wrap->parse_cb == NULL)
         return 1;
 
     return parse_cb_wrap->parse_cb(s, ext_type, in, inlen, al,
-                                   parse_cb_wrap->parse_arg);
+        parse_cb_wrap->parse_arg);
 }
 
 /*
@@ -80,16 +79,16 @@ static int custom_ext_parse_old_cb_wrap(SSL *s, unsigned int ext_type,
  * client, or ENDPOINT_BOTH for either
  */
 custom_ext_method *custom_ext_find(const custom_ext_methods *exts,
-                                   ENDPOINT role, unsigned int ext_type,
-                                   size_t *idx)
+    ENDPOINT role, unsigned int ext_type,
+    size_t *idx)
 {
     size_t i;
     custom_ext_method *meth = exts->meths;
 
     for (i = 0; i < exts->meths_count; i++, meth++) {
         if (ext_type == meth->ext_type
-                && (role == ENDPOINT_BOTH || role == meth->role
-                    || meth->role == ENDPOINT_BOTH)) {
+            && (role == ENDPOINT_BOTH || role == meth->role
+                || meth->role == ENDPOINT_BOTH)) {
             if (idx != NULL)
                 *idx = i;
             return meth;
@@ -112,9 +111,9 @@ void custom_ext_init(custom_ext_methods *exts)
 
 /* Pass received custom extension data to the application for parsing. */
 int custom_ext_parse(SSL_CONNECTION *s, unsigned int context,
-                     unsigned int ext_type,
-                     const unsigned char *ext_data, size_t ext_size, X509 *x,
-                     size_t chainidx)
+    unsigned int ext_type,
+    const unsigned char *ext_data, size_t ext_size, X509 *x,
+    size_t chainidx)
 {
     int al = 0;
     custom_ext_methods *exts = &s->cert->custext;
@@ -133,9 +132,7 @@ int custom_ext_parse(SSL_CONNECTION *s, unsigned int context,
     if (!extension_is_relevant(s, meth->context, context))
         return 1;
 
-    if ((context & (SSL_EXT_TLS1_2_SERVER_HELLO
-                    | SSL_EXT_TLS1_3_SERVER_HELLO
-                    | SSL_EXT_TLS1_3_ENCRYPTED_EXTENSIONS)) != 0) {
+    if ((context & (SSL_EXT_TLS1_2_SERVER_HELLO | SSL_EXT_TLS1_3_SERVER_HELLO | SSL_EXT_TLS1_3_ENCRYPTED_EXTENSIONS)) != 0) {
         /*
          * If it's ServerHello or EncryptedExtensions we can't have any
          * extensions not sent in ClientHello.
@@ -152,7 +149,7 @@ int custom_ext_parse(SSL_CONNECTION *s, unsigned int context,
      * extensions in the response messages
      */
     if ((context & (SSL_EXT_CLIENT_HELLO | SSL_EXT_TLS1_3_CERTIFICATE_REQUEST))
-            != 0)
+        != 0)
         meth->ext_flags |= SSL_EXT_FLAG_RECEIVED;
 
     /* If no parse function set return success */
@@ -160,7 +157,8 @@ int custom_ext_parse(SSL_CONNECTION *s, unsigned int context,
         return 1;
 
     if (meth->parse_cb(SSL_CONNECTION_GET_USER_SSL(s), ext_type, context, ext_data,
-                       ext_size, x, chainidx, &al, meth->parse_arg) <= 0) {
+            ext_size, x, chainidx, &al, meth->parse_arg)
+        <= 0) {
         SSLfatal(s, al, SSL_R_BAD_EXTENSION);
         return 0;
     }
@@ -173,7 +171,7 @@ int custom_ext_parse(SSL_CONNECTION *s, unsigned int context,
  * buffer.
  */
 int custom_ext_add(SSL_CONNECTION *s, int context, WPACKET *pkt, X509 *x,
-                   size_t chainidx, int maxversion)
+    size_t chainidx, int maxversion)
 {
     custom_ext_methods *exts = &s->cert->custext;
     custom_ext_method *meth;
@@ -190,12 +188,7 @@ int custom_ext_add(SSL_CONNECTION *s, int context, WPACKET *pkt, X509 *x,
         if (!should_add_extension(s, meth->context, context, maxversion))
             continue;
 
-        if ((context & (SSL_EXT_TLS1_2_SERVER_HELLO
-                        | SSL_EXT_TLS1_3_SERVER_HELLO
-                        | SSL_EXT_TLS1_3_ENCRYPTED_EXTENSIONS
-                        | SSL_EXT_TLS1_3_CERTIFICATE
-                        | SSL_EXT_TLS1_3_RAW_PUBLIC_KEY
-                        | SSL_EXT_TLS1_3_HELLO_RETRY_REQUEST)) != 0) {
+        if ((context & (SSL_EXT_TLS1_2_SERVER_HELLO | SSL_EXT_TLS1_3_SERVER_HELLO | SSL_EXT_TLS1_3_ENCRYPTED_EXTENSIONS | SSL_EXT_TLS1_3_CERTIFICATE | SSL_EXT_TLS1_3_RAW_PUBLIC_KEY | SSL_EXT_TLS1_3_HELLO_RETRY_REQUEST)) != 0) {
             /* Only send extensions present in ClientHello/CertificateRequest */
             if (!(meth->ext_flags & SSL_EXT_FLAG_RECEIVED))
                 continue;
@@ -209,26 +202,26 @@ int custom_ext_add(SSL_CONNECTION *s, int context, WPACKET *pkt, X509 *x,
 
         if (meth->add_cb != NULL) {
             int cb_retval = meth->add_cb(SSL_CONNECTION_GET_USER_SSL(s),
-                                         meth->ext_type, context, &out,
-                                         &outlen, x, chainidx, &al,
-                                         meth->add_arg);
+                meth->ext_type, context, &out,
+                &outlen, x, chainidx, &al,
+                meth->add_arg);
 
             if (cb_retval < 0) {
                 if (!for_comp)
                     SSLfatal(s, al, SSL_R_CALLBACK_FAILED);
-                return 0;       /* error */
+                return 0; /* error */
             }
             if (cb_retval == 0)
-                continue;       /* skip this extension */
+                continue; /* skip this extension */
         }
 
         if (!WPACKET_put_bytes_u16(pkt, meth->ext_type)
-                || !WPACKET_start_sub_packet_u16(pkt)
-                || (outlen > 0 && !WPACKET_memcpy(pkt, out, outlen))
-                || !WPACKET_close(pkt)) {
+            || !WPACKET_start_sub_packet_u16(pkt)
+            || (outlen > 0 && !WPACKET_memcpy(pkt, out, outlen))
+            || !WPACKET_close(pkt)) {
             if (meth->free_cb != NULL)
                 meth->free_cb(SSL_CONNECTION_GET_USER_SSL(s), meth->ext_type,
-                              context, out, meth->add_arg);
+                    context, out, meth->add_arg);
             if (!for_comp)
                 SSLfatal(s, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
             return 0;
@@ -240,7 +233,7 @@ int custom_ext_add(SSL_CONNECTION *s, int context, WPACKET *pkt, X509 *x,
             if (!ossl_assert((meth->ext_flags & SSL_EXT_FLAG_SENT) == 0)) {
                 if (meth->free_cb != NULL)
                     meth->free_cb(SSL_CONNECTION_GET_USER_SSL(s), meth->ext_type,
-                                  context, out, meth->add_arg);
+                        context, out, meth->add_arg);
                 if (!for_comp)
                     SSLfatal(s, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
                 return 0;
@@ -254,21 +247,21 @@ int custom_ext_add(SSL_CONNECTION *s, int context, WPACKET *pkt, X509 *x,
         }
         if (meth->free_cb != NULL)
             meth->free_cb(SSL_CONNECTION_GET_USER_SSL(s), meth->ext_type,
-                          context, out, meth->add_arg);
+                context, out, meth->add_arg);
     }
     return 1;
 }
 
 /* Copy the flags from src to dst for any extensions that exist in both */
 int custom_exts_copy_flags(custom_ext_methods *dst,
-                           const custom_ext_methods *src)
+    const custom_ext_methods *src)
 {
     size_t i;
     custom_ext_method *methsrc = src->meths;
 
     for (i = 0; i < src->meths_count; i++, methsrc++) {
         custom_ext_method *methdst = custom_ext_find(dst, methsrc->role,
-                                                     methsrc->ext_type, NULL);
+            methsrc->ext_type, NULL);
 
         if (methdst == NULL)
             continue;
@@ -281,8 +274,8 @@ int custom_exts_copy_flags(custom_ext_methods *dst,
 
 /* Copy old style API wrapper arguments */
 static void custom_ext_copy_old_cb(custom_ext_method *methdst,
-                                   const custom_ext_method *methsrc,
-                                   int *err)
+    const custom_ext_method *methsrc,
+    int *err)
 {
     if (methsrc->add_cb != custom_ext_add_old_cb_wrap)
         return;
@@ -294,9 +287,9 @@ static void custom_ext_copy_old_cb(custom_ext_method *methdst,
     }
 
     methdst->add_arg = OPENSSL_memdup(methsrc->add_arg,
-                                      sizeof(custom_ext_add_cb_wrap));
+        sizeof(custom_ext_add_cb_wrap));
     methdst->parse_arg = OPENSSL_memdup(methsrc->parse_arg,
-                                        sizeof(custom_ext_parse_cb_wrap));
+        sizeof(custom_ext_parse_cb_wrap));
 
     if (methdst->add_arg == NULL || methdst->parse_arg == NULL)
         *err = 1;
@@ -311,9 +304,8 @@ int custom_exts_copy(custom_ext_methods *dst, const custom_ext_methods *src)
     int err = 0;
 
     if (src->meths_count > 0) {
-        dst->meths =
-            OPENSSL_memdup(src->meths,
-                           sizeof(*src->meths) * src->meths_count);
+        dst->meths = OPENSSL_memdup(src->meths,
+            sizeof(*src->meths) * src->meths_count);
         if (dst->meths == NULL)
             return 0;
         dst->meths_count = src->meths_count;
@@ -332,7 +324,7 @@ int custom_exts_copy(custom_ext_methods *dst, const custom_ext_methods *src)
 
 /* Copy custom extensions that were set on connection */
 int custom_exts_copy_conn(custom_ext_methods *dst,
-                          const custom_ext_methods *src)
+    const custom_ext_methods *src)
 {
     size_t i;
     int err = 0;
@@ -345,10 +337,8 @@ int custom_exts_copy_conn(custom_ext_methods *dst,
                 meths_count++;
 
         if (meths_count > 0) {
-            custom_ext_method *methdst =
-                OPENSSL_realloc(dst->meths,
-                                (dst->meths_count + meths_count) *
-                                sizeof(custom_ext_method));
+            custom_ext_method *methdst = OPENSSL_realloc(dst->meths,
+                (dst->meths_count + meths_count) * sizeof(custom_ext_method));
 
             if (methdst == NULL)
                 return 0;
@@ -404,17 +394,18 @@ void custom_exts_free(custom_ext_methods *exts)
 int SSL_CTX_has_client_custom_ext(const SSL_CTX *ctx, unsigned int ext_type)
 {
     return custom_ext_find(&ctx->cert->custext, ENDPOINT_CLIENT, ext_type,
-                           NULL) != NULL;
+               NULL)
+        != NULL;
 }
 
 int ossl_tls_add_custom_ext_intern(SSL_CTX *ctx, custom_ext_methods *exts,
-                                   ENDPOINT role, unsigned int ext_type,
-                                   unsigned int context,
-                                   SSL_custom_ext_add_cb_ex add_cb,
-                                   SSL_custom_ext_free_cb_ex free_cb,
-                                   void *add_arg,
-                                   SSL_custom_ext_parse_cb_ex parse_cb,
-                                   void *parse_arg)
+    ENDPOINT role, unsigned int ext_type,
+    unsigned int context,
+    SSL_custom_ext_add_cb_ex add_cb,
+    SSL_custom_ext_free_cb_ex free_cb,
+    void *add_arg,
+    SSL_custom_ext_parse_cb_ex parse_cb,
+    void *parse_arg)
 {
     custom_ext_method *meth, *tmp;
 
@@ -435,9 +426,9 @@ int ossl_tls_add_custom_ext_intern(SSL_CTX *ctx, custom_ext_methods *exts,
      * these two things may not play well together.
      */
     if (ext_type == TLSEXT_TYPE_signed_certificate_timestamp
-            && (context & SSL_EXT_CLIENT_HELLO) != 0
-            && ctx != NULL
-            && SSL_CTX_ct_is_enabled(ctx))
+        && (context & SSL_EXT_CLIENT_HELLO) != 0
+        && ctx != NULL
+        && SSL_CTX_ct_is_enabled(ctx))
         return 0;
 #endif
 
@@ -446,7 +437,7 @@ int ossl_tls_add_custom_ext_intern(SSL_CTX *ctx, custom_ext_methods *exts,
      * for extension types that previously were not supported, but now are.
      */
     if (SSL_extension_supported(ext_type)
-            && ext_type != TLSEXT_TYPE_signed_certificate_timestamp)
+        && ext_type != TLSEXT_TYPE_signed_certificate_timestamp)
         return 0;
 
     /* Extension type must fit in 16 bits */
@@ -456,7 +447,7 @@ int ossl_tls_add_custom_ext_intern(SSL_CTX *ctx, custom_ext_methods *exts,
     if (custom_ext_find(exts, role, ext_type, NULL))
         return 0;
     tmp = OPENSSL_realloc(exts->meths,
-                          (exts->meths_count + 1) * sizeof(custom_ext_method));
+        (exts->meths_count + 1) * sizeof(custom_ext_method));
     if (tmp == NULL)
         return 0;
 
@@ -477,12 +468,12 @@ int ossl_tls_add_custom_ext_intern(SSL_CTX *ctx, custom_ext_methods *exts,
 }
 
 static int add_old_custom_ext(SSL_CTX *ctx, ENDPOINT role,
-                              unsigned int ext_type,
-                              unsigned int context,
-                              custom_ext_add_cb add_cb,
-                              custom_ext_free_cb free_cb,
-                              void *add_arg,
-                              custom_ext_parse_cb parse_cb, void *parse_arg)
+    unsigned int ext_type,
+    unsigned int context,
+    custom_ext_add_cb add_cb,
+    custom_ext_free_cb free_cb,
+    void *add_arg,
+    custom_ext_parse_cb parse_cb, void *parse_arg)
 {
     custom_ext_add_cb_wrap *add_cb_wrap
         = OPENSSL_malloc(sizeof(*add_cb_wrap));
@@ -503,12 +494,12 @@ static int add_old_custom_ext(SSL_CTX *ctx, ENDPOINT role,
     parse_cb_wrap->parse_cb = parse_cb;
 
     ret = ossl_tls_add_custom_ext_intern(ctx, NULL, role, ext_type,
-                                         context,
-                                         custom_ext_add_old_cb_wrap,
-                                         custom_ext_free_old_cb_wrap,
-                                         add_cb_wrap,
-                                         custom_ext_parse_old_cb_wrap,
-                                         parse_cb_wrap);
+        context,
+        custom_ext_add_old_cb_wrap,
+        custom_ext_free_old_cb_wrap,
+        add_cb_wrap,
+        custom_ext_parse_old_cb_wrap,
+        parse_cb_wrap);
 
     if (!ret) {
         OPENSSL_free(add_cb_wrap);
@@ -520,43 +511,43 @@ static int add_old_custom_ext(SSL_CTX *ctx, ENDPOINT role,
 
 /* Application level functions to add the old custom extension callbacks */
 int SSL_CTX_add_client_custom_ext(SSL_CTX *ctx, unsigned int ext_type,
-                                  custom_ext_add_cb add_cb,
-                                  custom_ext_free_cb free_cb,
-                                  void *add_arg,
-                                  custom_ext_parse_cb parse_cb, void *parse_arg)
+    custom_ext_add_cb add_cb,
+    custom_ext_free_cb free_cb,
+    void *add_arg,
+    custom_ext_parse_cb parse_cb, void *parse_arg)
 {
     return add_old_custom_ext(ctx, ENDPOINT_CLIENT, ext_type,
-                              SSL_EXT_TLS1_2_AND_BELOW_ONLY
-                              | SSL_EXT_CLIENT_HELLO
-                              | SSL_EXT_TLS1_2_SERVER_HELLO
-                              | SSL_EXT_IGNORE_ON_RESUMPTION,
-                              add_cb, free_cb, add_arg, parse_cb, parse_arg);
+        SSL_EXT_TLS1_2_AND_BELOW_ONLY
+            | SSL_EXT_CLIENT_HELLO
+            | SSL_EXT_TLS1_2_SERVER_HELLO
+            | SSL_EXT_IGNORE_ON_RESUMPTION,
+        add_cb, free_cb, add_arg, parse_cb, parse_arg);
 }
 
 int SSL_CTX_add_server_custom_ext(SSL_CTX *ctx, unsigned int ext_type,
-                                  custom_ext_add_cb add_cb,
-                                  custom_ext_free_cb free_cb,
-                                  void *add_arg,
-                                  custom_ext_parse_cb parse_cb, void *parse_arg)
+    custom_ext_add_cb add_cb,
+    custom_ext_free_cb free_cb,
+    void *add_arg,
+    custom_ext_parse_cb parse_cb, void *parse_arg)
 {
     return add_old_custom_ext(ctx, ENDPOINT_SERVER, ext_type,
-                              SSL_EXT_TLS1_2_AND_BELOW_ONLY
-                              | SSL_EXT_CLIENT_HELLO
-                              | SSL_EXT_TLS1_2_SERVER_HELLO
-                              | SSL_EXT_IGNORE_ON_RESUMPTION,
-                              add_cb, free_cb, add_arg, parse_cb, parse_arg);
+        SSL_EXT_TLS1_2_AND_BELOW_ONLY
+            | SSL_EXT_CLIENT_HELLO
+            | SSL_EXT_TLS1_2_SERVER_HELLO
+            | SSL_EXT_IGNORE_ON_RESUMPTION,
+        add_cb, free_cb, add_arg, parse_cb, parse_arg);
 }
 
 int SSL_CTX_add_custom_ext(SSL_CTX *ctx, unsigned int ext_type,
-                           unsigned int context,
-                           SSL_custom_ext_add_cb_ex add_cb,
-                           SSL_custom_ext_free_cb_ex free_cb,
-                           void *add_arg,
-                           SSL_custom_ext_parse_cb_ex parse_cb, void *parse_arg)
+    unsigned int context,
+    SSL_custom_ext_add_cb_ex add_cb,
+    SSL_custom_ext_free_cb_ex free_cb,
+    void *add_arg,
+    SSL_custom_ext_parse_cb_ex parse_cb, void *parse_arg)
 {
     return ossl_tls_add_custom_ext_intern(ctx, NULL, ENDPOINT_BOTH, ext_type,
-                                          context, add_cb, free_cb, add_arg,
-                                          parse_cb, parse_arg);
+        context, add_cb, free_cb, add_arg,
+        parse_cb, parse_arg);
 }
 
 int SSL_extension_supported(unsigned int ext_type)
