@@ -17,7 +17,7 @@
 #include <openssl/kdf.h>
 #include <openssl/core_names.h>
 
-#define TLS13_MAX_LABEL_LEN     249
+#define TLS13_MAX_LABEL_LEN 249
 
 /* ASCII: "tls13 ", in hex for EBCDIC compatibility */
 static const unsigned char label_prefix[] = "\x74\x6C\x73\x31\x33\x20";
@@ -31,11 +31,11 @@ static const unsigned char label_prefix[] = "\x74\x6C\x73\x31\x33\x20";
  * If |raise_error| is set, ERR_raise is called on failure.
  */
 int tls13_hkdf_expand_ex(OSSL_LIB_CTX *libctx, const char *propq,
-                         const EVP_MD *md,
-                         const unsigned char *secret,
-                         const unsigned char *label, size_t labellen,
-                         const unsigned char *data, size_t datalen,
-                         unsigned char *out, size_t outlen, int raise_error)
+    const EVP_MD *md,
+    const unsigned char *secret,
+    const unsigned char *label, size_t labellen,
+    const unsigned char *data, size_t datalen,
+    unsigned char *out, size_t outlen, int raise_error)
 {
     EVP_KDF *kdf = EVP_KDF_fetch(libctx, OSSL_KDF_NAME_TLS1_3_KDF, propq);
     EVP_KDF_CTX *kctx;
@@ -72,18 +72,18 @@ int tls13_hkdf_expand_ex(OSSL_LIB_CTX *libctx, const char *propq,
 
     *p++ = OSSL_PARAM_construct_int(OSSL_KDF_PARAM_MODE, &mode);
     *p++ = OSSL_PARAM_construct_utf8_string(OSSL_KDF_PARAM_DIGEST,
-                                            (char *)mdname, 0);
+        (char *)mdname, 0);
     *p++ = OSSL_PARAM_construct_octet_string(OSSL_KDF_PARAM_KEY,
-                                             (unsigned char *)secret, hashlen);
+        (unsigned char *)secret, hashlen);
     *p++ = OSSL_PARAM_construct_octet_string(OSSL_KDF_PARAM_PREFIX,
-                                             (unsigned char *)label_prefix,
-                                             sizeof(label_prefix) - 1);
+        (unsigned char *)label_prefix,
+        sizeof(label_prefix) - 1);
     *p++ = OSSL_PARAM_construct_octet_string(OSSL_KDF_PARAM_LABEL,
-                                             (unsigned char *)label, labellen);
+        (unsigned char *)label, labellen);
     if (data != NULL)
         *p++ = OSSL_PARAM_construct_octet_string(OSSL_KDF_PARAM_DATA,
-                                                 (unsigned char *)data,
-                                                 datalen);
+            (unsigned char *)data,
+            datalen);
     *p++ = OSSL_PARAM_construct_end();
 
     ret = EVP_KDF_derive(kctx, out, outlen, params) <= 0;
@@ -98,17 +98,17 @@ int tls13_hkdf_expand_ex(OSSL_LIB_CTX *libctx, const char *propq,
 }
 
 int tls13_hkdf_expand(SSL_CONNECTION *s, const EVP_MD *md,
-                      const unsigned char *secret,
-                      const unsigned char *label, size_t labellen,
-                      const unsigned char *data, size_t datalen,
-                      unsigned char *out, size_t outlen, int fatal)
+    const unsigned char *secret,
+    const unsigned char *label, size_t labellen,
+    const unsigned char *data, size_t datalen,
+    unsigned char *out, size_t outlen, int fatal)
 {
     int ret;
     SSL_CTX *sctx = SSL_CONNECTION_GET_CTX(s);
 
     ret = tls13_hkdf_expand_ex(sctx->libctx, sctx->propq, md,
-                               secret, label, labellen, data, datalen,
-                               out, outlen, !fatal);
+        secret, label, labellen, data, datalen,
+        out, outlen, !fatal);
     if (ret == 0 && fatal)
         SSLfatal(s, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
 
@@ -120,14 +120,14 @@ int tls13_hkdf_expand(SSL_CONNECTION *s, const EVP_MD *md,
  * success  0 on failure.
  */
 int tls13_derive_key(SSL_CONNECTION *s, const EVP_MD *md,
-                     const unsigned char *secret,
-                     unsigned char *key, size_t keylen)
+    const unsigned char *secret,
+    unsigned char *key, size_t keylen)
 {
     /* ASCII: "key", in hex for EBCDIC compatibility */
     static const unsigned char keylabel[] = "\x6B\x65\x79";
 
     return tls13_hkdf_expand(s, md, secret, keylabel, sizeof(keylabel) - 1,
-                             NULL, 0, key, keylen, 1);
+        NULL, 0, key, keylen, 1);
 }
 
 /*
@@ -135,25 +135,25 @@ int tls13_derive_key(SSL_CONNECTION *s, const EVP_MD *md,
  * success  0 on failure.
  */
 int tls13_derive_iv(SSL_CONNECTION *s, const EVP_MD *md,
-                    const unsigned char *secret,
-                    unsigned char *iv, size_t ivlen)
+    const unsigned char *secret,
+    unsigned char *iv, size_t ivlen)
 {
     /* ASCII: "iv", in hex for EBCDIC compatibility */
     static const unsigned char ivlabel[] = "\x69\x76";
 
     return tls13_hkdf_expand(s, md, secret, ivlabel, sizeof(ivlabel) - 1,
-                             NULL, 0, iv, ivlen, 1);
+        NULL, 0, iv, ivlen, 1);
 }
 
 int tls13_derive_finishedkey(SSL_CONNECTION *s, const EVP_MD *md,
-                             const unsigned char *secret,
-                             unsigned char *fin, size_t finlen)
+    const unsigned char *secret,
+    unsigned char *fin, size_t finlen)
 {
     /* ASCII: "finished", in hex for EBCDIC compatibility */
     static const unsigned char finishedlabel[] = "\x66\x69\x6E\x69\x73\x68\x65\x64";
 
     return tls13_hkdf_expand(s, md, secret, finishedlabel,
-                             sizeof(finishedlabel) - 1, NULL, 0, fin, finlen, 1);
+        sizeof(finishedlabel) - 1, NULL, 0, fin, finlen, 1);
 }
 
 /*
@@ -162,10 +162,10 @@ int tls13_derive_finishedkey(SSL_CONNECTION *s, const EVP_MD *md,
  * pointed to by |outsecret|. Returns 1 on success  0 on failure.
  */
 int tls13_generate_secret(SSL_CONNECTION *s, const EVP_MD *md,
-                          const unsigned char *prevsecret,
-                          const unsigned char *insecret,
-                          size_t insecretlen,
-                          unsigned char *outsecret)
+    const unsigned char *prevsecret,
+    const unsigned char *insecret,
+    size_t insecretlen,
+    unsigned char *outsecret)
 {
     size_t mdlen;
     int mdleni;
@@ -198,20 +198,20 @@ int tls13_generate_secret(SSL_CONNECTION *s, const EVP_MD *md,
 
     *p++ = OSSL_PARAM_construct_int(OSSL_KDF_PARAM_MODE, &mode);
     *p++ = OSSL_PARAM_construct_utf8_string(OSSL_KDF_PARAM_DIGEST,
-                                            (char *)mdname, 0);
+        (char *)mdname, 0);
     if (insecret != NULL)
         *p++ = OSSL_PARAM_construct_octet_string(OSSL_KDF_PARAM_KEY,
-                                                 (unsigned char *)insecret,
-                                                 insecretlen);
+            (unsigned char *)insecret,
+            insecretlen);
     if (prevsecret != NULL)
         *p++ = OSSL_PARAM_construct_octet_string(OSSL_KDF_PARAM_SALT,
-                                                 (unsigned char *)prevsecret, mdlen);
+            (unsigned char *)prevsecret, mdlen);
     *p++ = OSSL_PARAM_construct_octet_string(OSSL_KDF_PARAM_PREFIX,
-                                             (unsigned char *)label_prefix,
-                                             sizeof(label_prefix) - 1);
+        (unsigned char *)label_prefix,
+        sizeof(label_prefix) - 1);
     *p++ = OSSL_PARAM_construct_octet_string(OSSL_KDF_PARAM_LABEL,
-                                             (unsigned char *)derived_secret_label,
-                                             sizeof(derived_secret_label) - 1);
+        (unsigned char *)derived_secret_label,
+        sizeof(derived_secret_label) - 1);
     *p++ = OSSL_PARAM_construct_end();
 
     ret = EVP_KDF_derive(kctx, outsecret, mdlen, params) <= 0;
@@ -229,13 +229,13 @@ int tls13_generate_secret(SSL_CONNECTION *s, const EVP_MD *md,
  * generated. Returns 1 on success  0 on failure.
  */
 int tls13_generate_handshake_secret(SSL_CONNECTION *s,
-                                    const unsigned char *insecret,
-                                    size_t insecretlen)
+    const unsigned char *insecret,
+    size_t insecretlen)
 {
     /* Calls SSLfatal() if required */
     return tls13_generate_secret(s, ssl_handshake_md(s), s->early_secret,
-                                 insecret, insecretlen,
-                                 (unsigned char *)&s->handshake_secret);
+        insecret, insecretlen,
+        (unsigned char *)&s->handshake_secret);
 }
 
 /*
@@ -244,8 +244,8 @@ int tls13_generate_handshake_secret(SSL_CONNECTION *s,
  * failure.
  */
 int tls13_generate_master_secret(SSL_CONNECTION *s, unsigned char *out,
-                                 unsigned char *prev, size_t prevlen,
-                                 size_t *secret_size)
+    unsigned char *prev, size_t prevlen,
+    size_t *secret_size)
 {
     const EVP_MD *md = ssl_handshake_md(s);
     int md_size;
@@ -265,7 +265,7 @@ int tls13_generate_master_secret(SSL_CONNECTION *s, unsigned char *out,
  * 0 on error.
  */
 size_t tls13_final_finish_mac(SSL_CONNECTION *s, const char *str, size_t slen,
-                             unsigned char *out)
+    unsigned char *out)
 {
     const EVP_MD *md = ssl_handshake_md(s);
     const char *mdname = EVP_MD_get0_name(md);
@@ -282,8 +282,8 @@ size_t tls13_final_finish_mac(SSL_CONNECTION *s, const char *str, size_t slen,
     /* Safe to cast away const here since we're not "getting" any data */
     if (sctx->propq != NULL)
         *p++ = OSSL_PARAM_construct_utf8_string(OSSL_ALG_PARAM_PROPERTIES,
-                                                (char *)sctx->propq,
-                                                0);
+            (char *)sctx->propq,
+            0);
     *p = OSSL_PARAM_construct_end();
 
     if (!ssl_handshake_hash(s, hash, sizeof(hash), &hashlen)) {
@@ -297,21 +297,21 @@ size_t tls13_final_finish_mac(SSL_CONNECTION *s, const char *str, size_t slen,
         key = s->client_finished_secret;
     } else {
         if (!tls13_derive_finishedkey(s, md,
-                                      s->client_app_traffic_secret,
-                                      finsecret, hashlen))
+                s->client_app_traffic_secret,
+                finsecret, hashlen))
             goto err;
         key = finsecret;
     }
 
     if (!EVP_Q_mac(sctx->libctx, "HMAC", sctx->propq, mdname,
-                   params, key, hashlen, hash, hashlen,
-                   /* outsize as per sizeof(peer_finish_md) */
-                   out, EVP_MAX_MD_SIZE * 2, &len)) {
+            params, key, hashlen, hash, hashlen,
+            /* outsize as per sizeof(peer_finish_md) */
+            out, EVP_MAX_MD_SIZE * 2, &len)) {
         SSLfatal(s, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
         goto err;
     }
 
- err:
+err:
     OPENSSL_cleanse(finsecret, sizeof(finsecret));
     return len;
 }
@@ -329,7 +329,7 @@ int tls13_setup_key_block(SSL_CONNECTION *s)
 
     s->session->cipher = s->s3.tmp.new_cipher;
     if (!ssl_cipher_get_evp(SSL_CONNECTION_GET_CTX(s), s->session, &c, &hash,
-                            &mac_type, &mac_secret_size, NULL, 0)) {
+            &mac_type, &mac_secret_size, NULL, 0)) {
         /* Error is already recorded */
         SSLfatal_alert(s, SSL_AD_INTERNAL_ERROR);
         return 0;
@@ -346,16 +346,16 @@ int tls13_setup_key_block(SSL_CONNECTION *s)
 }
 
 static int derive_secret_key_and_iv(SSL_CONNECTION *s, const EVP_MD *md,
-                                    const EVP_CIPHER *ciph,
-                                    int mac_type,
-                                    const EVP_MD *mac_md,
-                                    const unsigned char *insecret,
-                                    const unsigned char *hash,
-                                    const unsigned char *label,
-                                    size_t labellen, unsigned char *secret,
-                                    unsigned char *key, size_t *keylen,
-                                    unsigned char **iv, size_t *ivlen,
-                                    size_t *taglen)
+    const EVP_CIPHER *ciph,
+    int mac_type,
+    const EVP_MD *mac_md,
+    const unsigned char *insecret,
+    const unsigned char *hash,
+    const unsigned char *label,
+    size_t labellen, unsigned char *secret,
+    unsigned char *key, size_t *keylen,
+    unsigned char **iv, size_t *ivlen,
+    size_t *taglen)
 {
     int hashleni = EVP_MD_get_size(md);
     size_t hashlen;
@@ -369,7 +369,7 @@ static int derive_secret_key_and_iv(SSL_CONNECTION *s, const EVP_MD *md,
     hashlen = (size_t)hashleni;
 
     if (!tls13_hkdf_expand(s, md, insecret, label, labellen, hash, hashlen,
-                           secret, hashlen, 1)) {
+            secret, hashlen, 1)) {
         /* SSLfatal() already called */
         return 0;
     }
@@ -438,7 +438,7 @@ static int derive_secret_key_and_iv(SSL_CONNECTION *s, const EVP_MD *md,
     }
 
     if (!tls13_derive_key(s, md, secret, key, *keylen)
-            || !tls13_derive_iv(s, md, secret, *iv, *ivlen)) {
+        || !tls13_derive_iv(s, md, secret, *iv, *ivlen)) {
         /* SSLfatal() already called */
         return 0;
     }
@@ -446,6 +446,31 @@ static int derive_secret_key_and_iv(SSL_CONNECTION *s, const EVP_MD *md,
     return 1;
 }
 
+static int tls13_store_hash(SSL_CONNECTION *s, unsigned char *hash, size_t len)
+{
+    size_t hashlen;
+
+    if (!ssl3_digest_cached_records(s, 1)
+        || !ssl_handshake_hash(s, hash, len, &hashlen)) {
+        /* SSLfatal() already called */;
+        return 0;
+    }
+
+    return 1;
+}
+
+int tls13_store_handshake_traffic_hash(SSL_CONNECTION *s)
+{
+    return tls13_store_hash(s, s->handshake_traffic_hash,
+        sizeof(s->handshake_traffic_hash));
+}
+
+int tls13_store_server_finished_hash(SSL_CONNECTION *s)
+{
+    return tls13_store_hash(s, s->server_finished_hash,
+        sizeof(s->server_finished_hash));
+}
+
 int tls13_change_cipher_state(SSL_CONNECTION *s, int which)
 {
     /* ASCII: "c e traffic", in hex for EBCDIC compatibility */
@@ -487,7 +512,7 @@ int tls13_change_cipher_state(SSL_CONNECTION *s, int which)
                                                 : OSSL_RECORD_DIRECTION_WRITE;
 
     if (((which & SSL3_CC_CLIENT) && (which & SSL3_CC_WRITE))
-            || ((which & SSL3_CC_SERVER) && (which & SSL3_CC_READ))) {
+        || ((which & SSL3_CC_SERVER) && (which & SSL3_CC_READ))) {
         if ((which & SSL3_CC_EARLY) != 0) {
             EVP_MD_CTX *mdctx = NULL;
             long handlen;
@@ -507,16 +532,15 @@ int tls13_change_cipher_state(SSL_CONNECTION *s, int which)
             }
 
             if (s->early_data_state == SSL_EARLY_DATA_CONNECTING
-                    && s->max_early_data > 0
-                    && s->session->ext.max_early_data == 0) {
+                && s->max_early_data > 0
+                && s->session->ext.max_early_data == 0) {
                 /*
                  * If we are attempting to send early data, and we've decided to
                  * actually do it but max_early_data in s->session is 0 then we
                  * must be using an external PSK.
                  */
                 if (!ossl_assert(s->psksession != NULL
-                        && s->max_early_data ==
-                           s->psksession->ext.max_early_data)) {
+                        && s->max_early_data == s->psksession->ext.max_early_data)) {
                     SSLfatal(s, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
                     goto err;
                 }
@@ -539,7 +563,7 @@ int tls13_change_cipher_state(SSL_CONNECTION *s, int which)
 
             if (((EVP_CIPHER_flags(cipher) & EVP_CIPH_FLAG_AEAD_CIPHER) == 0)
                 && (!ssl_cipher_get_evp_md_mac(sctx, sslcipher, &mac_md,
-                                               &mac_pkey_type, NULL))) {
+                    &mac_pkey_type, NULL))) {
                 SSLfatal_alert(s, SSL_AD_INTERNAL_ERROR);
                 goto err;
             }
@@ -557,8 +581,8 @@ int tls13_change_cipher_state(SSL_CONNECTION *s, int which)
 
             md = ssl_md(sctx, sslcipher->algorithm2);
             if (md == NULL || !EVP_DigestInit_ex(mdctx, md, NULL)
-                    || !EVP_DigestUpdate(mdctx, hdata, handlen)
-                    || !EVP_DigestFinal_ex(mdctx, hashval, &hashlenui)) {
+                || !EVP_DigestUpdate(mdctx, hdata, handlen)
+                || !EVP_DigestFinal_ex(mdctx, hashval, &hashlenui)) {
                 SSLfatal(s, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
                 EVP_MD_CTX_free(mdctx);
                 goto err;
@@ -567,17 +591,17 @@ int tls13_change_cipher_state(SSL_CONNECTION *s, int which)
             EVP_MD_CTX_free(mdctx);
 
             if (!tls13_hkdf_expand(s, md, insecret,
-                                   early_exporter_master_secret,
-                                   sizeof(early_exporter_master_secret) - 1,
-                                   hashval, hashlen,
-                                   s->early_exporter_master_secret, hashlen,
-                                   1)) {
+                    early_exporter_master_secret,
+                    sizeof(early_exporter_master_secret) - 1,
+                    hashval, hashlen,
+                    s->early_exporter_master_secret, hashlen,
+                    1)) {
                 SSLfatal(s, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
                 goto err;
             }
 
             if (!ssl_log_secret(s, EARLY_EXPORTER_SECRET_LABEL,
-                                s->early_exporter_master_secret, hashlen)) {
+                    s->early_exporter_master_secret, hashlen)) {
                 /* SSLfatal() already called */
                 goto err;
             }
@@ -633,6 +657,7 @@ int tls13_change_cipher_state(SSL_CONNECTION *s, int which)
             label = server_application_traffic;
             labellen = sizeof(server_application_traffic) - 1;
             log_label = SERVER_APPLICATION_LABEL;
+            hash = s->server_finished_hash;
         }
     }
 
@@ -642,32 +667,22 @@ int tls13_change_cipher_state(SSL_CONNECTION *s, int which)
         mac_md = s->s3.tmp.new_hash;
         mac_pkey_type = s->s3.tmp.new_mac_pkey_type;
         if (!ssl3_digest_cached_records(s, 1)
-                || !ssl_handshake_hash(s, hashval, sizeof(hashval), &hashlen)) {
+            || !ssl_handshake_hash(s, hashval, sizeof(hashval), &hashlen)) {
             /* SSLfatal() already called */;
             goto err;
         }
     }
 
-    /*
-     * Save the hash of handshakes up to now for use when we calculate the
-     * client application traffic secret
-     */
-    if (label == server_application_traffic)
-        memcpy(s->server_finished_hash, hashval, hashlen);
-
-    if (label == server_handshake_traffic)
-        memcpy(s->handshake_traffic_hash, hashval, hashlen);
-
     if (label == client_application_traffic) {
         /*
          * We also create the resumption master secret, but this time use the
          * hash for the whole handshake including the Client Finished
          */
         if (!tls13_hkdf_expand(s, ssl_handshake_md(s), insecret,
-                               resumption_master_secret,
-                               sizeof(resumption_master_secret) - 1,
-                               hashval, hashlen, s->resumption_master_secret,
-                               hashlen, 1)) {
+                resumption_master_secret,
+                sizeof(resumption_master_secret) - 1,
+                hashval, hashlen, s->resumption_master_secret,
+                hashlen, 1)) {
             /* SSLfatal() already called */
             goto err;
         }
@@ -678,8 +693,8 @@ int tls13_change_cipher_state(SSL_CONNECTION *s, int which)
         goto err;
 
     if (!derive_secret_key_and_iv(s, md, cipher, mac_pkey_type, mac_md,
-                                  insecret, hash, label, labellen, secret, key,
-                                  &keylen, &iv, &ivlen, &taglen)) {
+            insecret, hash, label, labellen, secret, key,
+            &keylen, &iv, &ivlen, &taglen)) {
         /* SSLfatal() already called */
         goto err;
     }
@@ -688,16 +703,16 @@ int tls13_change_cipher_state(SSL_CONNECTION *s, int which)
         memcpy(s->server_app_traffic_secret, secret, hashlen);
         /* Now we create the exporter master secret */
         if (!tls13_hkdf_expand(s, ssl_handshake_md(s), insecret,
-                               exporter_master_secret,
-                               sizeof(exporter_master_secret) - 1,
-                               hash, hashlen, s->exporter_master_secret,
-                               hashlen, 1)) {
+                exporter_master_secret,
+                sizeof(exporter_master_secret) - 1,
+                hash, hashlen, s->exporter_master_secret,
+                hashlen, 1)) {
             /* SSLfatal() already called */
             goto err;
         }
 
         if (!ssl_log_secret(s, EXPORTER_SECRET_LABEL, s->exporter_master_secret,
-                            hashlen)) {
+                hashlen)) {
             /* SSLfatal() already called */
             goto err;
         }
@@ -710,8 +725,8 @@ int tls13_change_cipher_state(SSL_CONNECTION *s, int which)
     }
 
     if (finsecret != NULL
-            && !tls13_derive_finishedkey(s, ssl_handshake_md(s), secret,
-                                         finsecret, (size_t)finsecretlen)) {
+        && !tls13_derive_finishedkey(s, ssl_handshake_md(s), secret,
+            finsecret, (size_t)finsecretlen)) {
         /* SSLfatal() already called */
         goto err;
     }
@@ -724,22 +739,22 @@ int tls13_change_cipher_state(SSL_CONNECTION *s, int which)
     }
 
     level = (which & SSL3_CC_EARLY) != 0
-            ? OSSL_RECORD_PROTECTION_LEVEL_EARLY
-            : ((which &SSL3_CC_HANDSHAKE) != 0
-               ? OSSL_RECORD_PROTECTION_LEVEL_HANDSHAKE
-               : OSSL_RECORD_PROTECTION_LEVEL_APPLICATION);
+        ? OSSL_RECORD_PROTECTION_LEVEL_EARLY
+        : ((which & SSL3_CC_HANDSHAKE) != 0
+                  ? OSSL_RECORD_PROTECTION_LEVEL_HANDSHAKE
+                  : OSSL_RECORD_PROTECTION_LEVEL_APPLICATION);
 
     if (!ssl_set_new_record_layer(s, s->version,
-                                  direction,
-                                  level, secret, hashlen, key, keylen, iv,
-                                  ivlen, NULL, 0, cipher, taglen,
-                                  mac_pkey_type, mac_md, NULL, md)) {
+            direction,
+            level, secret, hashlen, key, keylen, iv,
+            ivlen, NULL, 0, cipher, taglen,
+            mac_pkey_type, mac_md, NULL, md)) {
         /* SSLfatal already called */
         goto err;
     }
 
     ret = 1;
- err:
+err:
     if ((which & SSL3_CC_EARLY) != 0) {
         /* We up-refed this so now we need to down ref */
         if ((EVP_CIPHER_flags(cipher) & EVP_CIPH_FLAG_AEAD_CIPHER) == 0)
@@ -782,12 +797,12 @@ int tls13_update_key(SSL_CONNECTION *s, int sending)
         insecret = s->client_app_traffic_secret;
 
     if (!derive_secret_key_and_iv(s, md,
-                                  s->s3.tmp.new_sym_enc,
-                                  s->s3.tmp.new_mac_pkey_type, s->s3.tmp.new_hash,
-                                  insecret, NULL,
-                                  application_traffic,
-                                  sizeof(application_traffic) - 1, secret, key,
-                                  &keylen, &iv, &ivlen, &taglen)) {
+            s->s3.tmp.new_sym_enc,
+            s->s3.tmp.new_mac_pkey_type, s->s3.tmp.new_hash,
+            insecret, NULL,
+            application_traffic,
+            sizeof(application_traffic) - 1, secret, key,
+            &keylen, &iv, &ivlen, &taglen)) {
         /* SSLfatal() already called */
         goto err;
     }
@@ -795,11 +810,11 @@ int tls13_update_key(SSL_CONNECTION *s, int sending)
     memcpy(insecret, secret, hashlen);
 
     if (!ssl_set_new_record_layer(s, s->version,
-                            direction,
-                            OSSL_RECORD_PROTECTION_LEVEL_APPLICATION,
-                            insecret, hashlen, key, keylen, iv, ivlen, NULL, 0,
-                            s->s3.tmp.new_sym_enc, taglen, NID_undef, NULL,
-                            NULL, md)) {
+            direction,
+            OSSL_RECORD_PROTECTION_LEVEL_APPLICATION,
+            insecret, hashlen, key, keylen, iv, ivlen, NULL, 0,
+            s->s3.tmp.new_sym_enc, taglen, NID_undef, NULL,
+            NULL, md)) {
         /* SSLfatal already called */
         goto err;
     }
@@ -811,7 +826,7 @@ int tls13_update_key(SSL_CONNECTION *s, int sending)
         goto err;
     }
     ret = 1;
- err:
+err:
     OPENSSL_cleanse(key, sizeof(key));
     OPENSSL_cleanse(secret, sizeof(secret));
     if (iv != iv_intern)
@@ -829,10 +844,10 @@ int tls13_alert_code(int code)
 }
 
 int tls13_export_keying_material(SSL_CONNECTION *s,
-                                 unsigned char *out, size_t olen,
-                                 const char *label, size_t llen,
-                                 const unsigned char *context,
-                                 size_t contextlen, int use_context)
+    unsigned char *out, size_t olen,
+    const char *label, size_t llen,
+    const unsigned char *context,
+    size_t contextlen, int use_context)
 {
     unsigned char exportsecret[EVP_MAX_MD_SIZE];
     /* ASCII: "exporter", in hex for EBCDIC compatibility */
@@ -850,29 +865,29 @@ int tls13_export_keying_material(SSL_CONNECTION *s,
         contextlen = 0;
 
     if (EVP_DigestInit_ex(ctx, md, NULL) <= 0
-            || EVP_DigestUpdate(ctx, context, contextlen) <= 0
-            || EVP_DigestFinal_ex(ctx, hash, &hashsize) <= 0
-            || EVP_DigestInit_ex(ctx, md, NULL) <= 0
-            || EVP_DigestFinal_ex(ctx, data, &datalen) <= 0
-            || !tls13_hkdf_expand(s, md, s->exporter_master_secret,
-                                  (const unsigned char *)label, llen,
-                                  data, datalen, exportsecret, hashsize, 0)
-            || !tls13_hkdf_expand(s, md, exportsecret, exporterlabel,
-                                  sizeof(exporterlabel) - 1, hash, hashsize,
-                                  out, olen, 0))
+        || EVP_DigestUpdate(ctx, context, contextlen) <= 0
+        || EVP_DigestFinal_ex(ctx, hash, &hashsize) <= 0
+        || EVP_DigestInit_ex(ctx, md, NULL) <= 0
+        || EVP_DigestFinal_ex(ctx, data, &datalen) <= 0
+        || !tls13_hkdf_expand(s, md, s->exporter_master_secret,
+            (const unsigned char *)label, llen,
+            data, datalen, exportsecret, hashsize, 0)
+        || !tls13_hkdf_expand(s, md, exportsecret, exporterlabel,
+            sizeof(exporterlabel) - 1, hash, hashsize,
+            out, olen, 0))
         goto err;
 
     ret = 1;
- err:
+err:
     EVP_MD_CTX_free(ctx);
     return ret;
 }
 
 int tls13_export_keying_material_early(SSL_CONNECTION *s,
-                                       unsigned char *out, size_t olen,
-                                       const char *label, size_t llen,
-                                       const unsigned char *context,
-                                       size_t contextlen)
+    unsigned char *out, size_t olen,
+    const char *label, size_t llen,
+    const unsigned char *context,
+    size_t contextlen)
 {
     /* ASCII: "exporter", in hex for EBCDIC compatibility */
     static const unsigned char exporterlabel[] = "\x65\x78\x70\x6F\x72\x74\x65\x72";
@@ -888,7 +903,7 @@ int tls13_export_keying_material_early(SSL_CONNECTION *s,
         goto err;
 
     if (!s->server && s->max_early_data > 0
-            && s->session->ext.max_early_data == 0)
+        && s->session->ext.max_early_data == 0)
         sslcipher = SSL_SESSION_get0_cipher(s->psksession);
     else
         sslcipher = SSL_SESSION_get0_cipher(s->session);
@@ -911,21 +926,21 @@ int tls13_export_keying_material_early(SSL_CONNECTION *s,
      * Here Transcript-Hash is the cipher suite hash algorithm.
      */
     if (md == NULL
-            || EVP_DigestInit_ex(ctx, md, NULL) <= 0
-            || EVP_DigestUpdate(ctx, context, contextlen) <= 0
-            || EVP_DigestFinal_ex(ctx, hash, &hashsize) <= 0
-            || EVP_DigestInit_ex(ctx, md, NULL) <= 0
-            || EVP_DigestFinal_ex(ctx, data, &datalen) <= 0
-            || !tls13_hkdf_expand(s, md, s->early_exporter_master_secret,
-                                  (const unsigned char *)label, llen,
-                                  data, datalen, exportsecret, hashsize, 0)
-            || !tls13_hkdf_expand(s, md, exportsecret, exporterlabel,
-                                  sizeof(exporterlabel) - 1, hash, hashsize,
-                                  out, olen, 0))
+        || EVP_DigestInit_ex(ctx, md, NULL) <= 0
+        || EVP_DigestUpdate(ctx, context, contextlen) <= 0
+        || EVP_DigestFinal_ex(ctx, hash, &hashsize) <= 0
+        || EVP_DigestInit_ex(ctx, md, NULL) <= 0
+        || EVP_DigestFinal_ex(ctx, data, &datalen) <= 0
+        || !tls13_hkdf_expand(s, md, s->early_exporter_master_secret,
+            (const unsigned char *)label, llen,
+            data, datalen, exportsecret, hashsize, 0)
+        || !tls13_hkdf_expand(s, md, exportsecret, exporterlabel,
+            sizeof(exporterlabel) - 1, hash, hashsize,
+            out, olen, 0))
         goto err;
 
     ret = 1;
- err:
+err:
     EVP_MD_CTX_free(ctx);
     return ret;
 }
