@@ -54,7 +54,7 @@ static int test_tbl_standard(void)
     TEST_info("asn1 tbl_standard: out of order");
     for (tmp = tbl_standard, i = 0; i < OSSL_NELEM(tbl_standard); i++, tmp++)
         TEST_note("asn1 tbl_standard: Index %zu, NID %d, Name=%s",
-                  i, tmp->nid, OBJ_nid2ln(tmp->nid));
+            i, tmp->nid, OBJ_nid2ln(tmp->nid));
 
     return 0;
 }
@@ -76,7 +76,7 @@ static int test_standard_methods(void)
     int ok = 1;
 
     for (tmp = standard_methods, i = 0; i < OSSL_NELEM(standard_methods);
-         i++, tmp++) {
+        i++, tmp++) {
         if ((*tmp)->pkey_id < last_pkey_id) {
             last_pkey_id = 0;
             break;
@@ -92,9 +92,9 @@ static int test_standard_methods(void)
          * Anything else is an error and may lead to a corrupt ASN1 method table
          */
         if (!TEST_true(((*tmp)->pem_str == NULL && ((*tmp)->pkey_flags & ASN1_PKEY_ALIAS) != 0)
-                       || ((*tmp)->pem_str != NULL && ((*tmp)->pkey_flags & ASN1_PKEY_ALIAS) == 0))) {
+                || ((*tmp)->pem_str != NULL && ((*tmp)->pkey_flags & ASN1_PKEY_ALIAS) == 0))) {
             TEST_note("asn1 standard methods: Index %zu, pkey ID %d, Name=%s",
-                      i, (*tmp)->pkey_id, OBJ_nid2sn((*tmp)->pkey_id));
+                i, (*tmp)->pkey_id, OBJ_nid2sn((*tmp)->pkey_id));
             ok = 0;
         }
     }
@@ -106,9 +106,9 @@ static int test_standard_methods(void)
 
     TEST_note("asn1 standard methods: out of order");
     for (tmp = standard_methods, i = 0; i < OSSL_NELEM(standard_methods);
-         i++, tmp++)
+        i++, tmp++)
         TEST_note("asn1 standard methods: Index %zu, pkey ID %d, Name=%s",
-                  i, (*tmp)->pkey_id, OBJ_nid2sn((*tmp)->pkey_id));
+            i, (*tmp)->pkey_id, OBJ_nid2sn((*tmp)->pkey_id));
 
     return 0;
 }
@@ -134,7 +134,7 @@ static int test_empty_nonoptional_content(void)
         || !TEST_true(RSA_set0_key(rsa, n, e, NULL)))
         goto end;
 
-    n = e = NULL;                /* They are now "owned" by |rsa| */
+    n = e = NULL; /* They are now "owned" by |rsa| */
 
     /*
      * This SHOULD fail, as we're trying to encode a public key as a private
@@ -143,7 +143,7 @@ static int test_empty_nonoptional_content(void)
     if (TEST_int_le(i2d_RSAPrivateKey(rsa, NULL), 0))
         ok = 1;
 
- end:
+end:
     RSA_free(rsa);
     BN_free(n);
     BN_free(e);
@@ -163,8 +163,8 @@ static int test_unicode(const unsigned char *univ, size_t len, int expected)
 
     for (; univ < end; univ += 4) {
         if (!TEST_int_eq(ASN1_mbstring_copy(NULL, univ, 4, MBSTRING_UNIV,
-                                            B_ASN1_UTF8STRING),
-                         expected))
+                             B_ASN1_UTF8STRING),
+                expected))
             ok = 0;
     }
     return ok;
@@ -190,6 +190,80 @@ static int test_unicode_range(void)
     return ok;
 }
 
+static int test_invalid_utf8(void)
+{
+    const unsigned char inv_utf8[] = "\xF4\x90\x80\x80";
+    unsigned long val;
+
+    if (!TEST_int_lt(UTF8_getc(inv_utf8, sizeof(inv_utf8), &val), 0))
+        return 0;
+    return 1;
+}
+
+/**********************************************************************
+ *
+ * Tests of object creation
+ *
+ ***/
+
+static int test_obj_create_once(const char *oid, const char *sn, const char *ln)
+{
+    int nid;
+
+    ERR_set_mark();
+
+    nid = OBJ_create(oid, sn, ln);
+
+    if (nid == NID_undef) {
+        unsigned long err = ERR_peek_last_error();
+        int l = ERR_GET_LIB(err);
+        int r = ERR_GET_REASON(err);
+
+        /* If it exists, that's fine, otherwise not */
+        if (l != ERR_LIB_OBJ || r != OBJ_R_OID_EXISTS) {
+            ERR_clear_last_mark();
+            return 0;
+        }
+    }
+    ERR_pop_to_mark();
+    return 1;
+}
+
+static int test_obj_create(void)
+{
+/* Stolen from evp_extra_test.c */
+#define arc "1.3.6.1.4.1.16604.998866."
+#define broken_arc "25."
+#define sn_prefix "custom"
+#define ln_prefix "custom"
+
+    /* Try different combinations of correct object creation */
+    if (!TEST_true(test_obj_create_once(NULL, sn_prefix "1", NULL))
+        || !TEST_int_ne(OBJ_sn2nid(sn_prefix "1"), NID_undef)
+        || !TEST_true(test_obj_create_once(NULL, NULL, ln_prefix "2"))
+        || !TEST_int_ne(OBJ_ln2nid(ln_prefix "2"), NID_undef)
+        || !TEST_true(test_obj_create_once(NULL, sn_prefix "3", ln_prefix "3"))
+        || !TEST_int_ne(OBJ_sn2nid(sn_prefix "3"), NID_undef)
+        || !TEST_int_ne(OBJ_ln2nid(ln_prefix "3"), NID_undef)
+        || !TEST_true(test_obj_create_once(arc "4", NULL, NULL))
+        || !TEST_true(test_obj_create_once(arc "5", sn_prefix "5", NULL))
+        || !TEST_int_ne(OBJ_sn2nid(sn_prefix "5"), NID_undef)
+        || !TEST_true(test_obj_create_once(arc "6", NULL, ln_prefix "6"))
+        || !TEST_int_ne(OBJ_ln2nid(ln_prefix "6"), NID_undef)
+        || !TEST_true(test_obj_create_once(arc "7",
+            sn_prefix "7", ln_prefix "7"))
+        || !TEST_int_ne(OBJ_sn2nid(sn_prefix "7"), NID_undef)
+        || !TEST_int_ne(OBJ_ln2nid(ln_prefix "7"), NID_undef))
+        return 0;
+
+    if (!TEST_false(test_obj_create_once(NULL, NULL, NULL))
+        || !TEST_false(test_obj_create_once(broken_arc "8",
+            sn_prefix "8", ln_prefix "8")))
+        return 0;
+
+    return 1;
+}
+
 static int test_obj_nid_undef(void)
 {
     if (!TEST_ptr(OBJ_nid2obj(NID_undef))
@@ -200,12 +274,31 @@ static int test_obj_nid_undef(void)
     return 1;
 }
 
+static int test_mbstring_ncopy(void)
+{
+    ASN1_STRING *str = NULL;
+    const unsigned char in[] = { 0xFF, 0xFE, 0xFF, 0xFE };
+    int inlen = 4;
+    int inform = MBSTRING_UNIV;
+
+    if (!TEST_int_eq(ASN1_mbstring_ncopy(&str, in, inlen, inform, B_ASN1_GENERALSTRING, 0, 0), -1)
+        || !TEST_int_eq(ASN1_mbstring_ncopy(&str, in, inlen, inform, B_ASN1_VISIBLESTRING, 0, 0), -1)
+        || !TEST_int_eq(ASN1_mbstring_ncopy(&str, in, inlen, inform, B_ASN1_VIDEOTEXSTRING, 0, 0), -1)
+        || !TEST_int_eq(ASN1_mbstring_ncopy(&str, in, inlen, inform, B_ASN1_GENERALIZEDTIME, 0, 0), -1))
+        return 0;
+
+    return 1;
+}
+
 int setup_tests(void)
 {
     ADD_TEST(test_tbl_standard);
     ADD_TEST(test_standard_methods);
     ADD_TEST(test_empty_nonoptional_content);
     ADD_TEST(test_unicode_range);
+    ADD_TEST(test_invalid_utf8);
+    ADD_TEST(test_obj_create);
     ADD_TEST(test_obj_nid_undef);
+    ADD_TEST(test_mbstring_ncopy);
     return 1;
 }
