@@ -54,9 +54,9 @@ static CMP_MSG_TEST_FIXTURE *set_up(const char *const test_case_name)
     fixture->test_case_name = test_case_name;
 
     if (!TEST_ptr(fixture->cmp_ctx = OSSL_CMP_CTX_new(libctx, NULL))
-            || !TEST_true(SET_OPT_UNPROTECTED_SEND(fixture->cmp_ctx, 1))
-            || !TEST_true(OSSL_CMP_CTX_set1_referenceValue(fixture->cmp_ctx,
-                                                           ref, sizeof(ref)))) {
+        || !TEST_true(SET_OPT_UNPROTECTED_SEND(fixture->cmp_ctx, 1))
+        || !TEST_true(OSSL_CMP_CTX_set1_referenceValue(fixture->cmp_ctx,
+            ref, sizeof(ref)))) {
         tear_down(fixture);
         return NULL;
     }
@@ -66,16 +66,14 @@ static CMP_MSG_TEST_FIXTURE *set_up(const char *const test_case_name)
 static EVP_PKEY *newkey = NULL;
 static X509 *cert = NULL;
 
-#define EXECUTE_MSG_CREATION_TEST(expr) \
-    do { \
-        OSSL_CMP_MSG *msg = NULL; \
-        int good = fixture->expected != 0 ? \
-            TEST_ptr(msg = (expr)) && TEST_true(valid_asn1_encoding(msg)) : \
-            TEST_ptr_null(msg = (expr)); \
- \
-        OSSL_CMP_MSG_free(msg); \
-        ERR_print_errors_fp(stderr); \
-        return good; \
+#define EXECUTE_MSG_CREATION_TEST(expr)                                                                                                  \
+    do {                                                                                                                                 \
+        OSSL_CMP_MSG *msg = NULL;                                                                                                        \
+        int good = fixture->expected != 0 ? TEST_ptr(msg = (expr)) && TEST_true(valid_asn1_encoding(msg)) : TEST_ptr_null(msg = (expr)); \
+                                                                                                                                         \
+        OSSL_CMP_MSG_free(msg);                                                                                                          \
+        ERR_print_errors_fp(stderr);                                                                                                     \
+        return good;                                                                                                                     \
     } while (0)
 
 /*-
@@ -88,15 +86,15 @@ static X509 *cert = NULL;
 static int execute_certreq_create_test(CMP_MSG_TEST_FIXTURE *fixture)
 {
     EXECUTE_MSG_CREATION_TEST(ossl_cmp_certreq_new(fixture->cmp_ctx,
-                                                   fixture->bodytype,
-                                                   NULL));
+        fixture->bodytype,
+        NULL));
 }
 
 static int execute_errormsg_create_test(CMP_MSG_TEST_FIXTURE *fixture)
 {
     EXECUTE_MSG_CREATION_TEST(ossl_cmp_error_new(fixture->cmp_ctx, fixture->si,
-                                                 fixture->err_code,
-                                                 "details", 0));
+        fixture->err_code,
+        "details", 0));
 }
 
 static int execute_rr_create_test(CMP_MSG_TEST_FIXTURE *fixture)
@@ -106,9 +104,8 @@ static int execute_rr_create_test(CMP_MSG_TEST_FIXTURE *fixture)
 
 static int execute_certconf_create_test(CMP_MSG_TEST_FIXTURE *fixture)
 {
-    EXECUTE_MSG_CREATION_TEST(ossl_cmp_certConf_new
-                              (fixture->cmp_ctx, OSSL_CMP_CERTREQID,
-                               fixture->fail_info, NULL));
+    EXECUTE_MSG_CREATION_TEST(ossl_cmp_certConf_new(fixture->cmp_ctx, OSSL_CMP_CERTREQID,
+        fixture->fail_info, NULL));
 }
 
 static int execute_genm_create_test(CMP_MSG_TEST_FIXTURE *fixture)
@@ -123,8 +120,7 @@ static int execute_pollreq_create_test(CMP_MSG_TEST_FIXTURE *fixture)
 
 static int execute_pkimessage_create_test(CMP_MSG_TEST_FIXTURE *fixture)
 {
-    EXECUTE_MSG_CREATION_TEST(ossl_cmp_msg_create
-                              (fixture->cmp_ctx, fixture->bodytype));
+    EXECUTE_MSG_CREATION_TEST(ossl_cmp_msg_create(fixture->cmp_ctx, fixture->bodytype));
 }
 
 static int set1_newPkey(OSSL_CMP_CTX *ctx, EVP_PKEY *pkey)
@@ -151,10 +147,10 @@ static int test_cmp_create_ir_protection_set(void)
     fixture->err_code = -1;
     fixture->expected = 1;
     if (!TEST_int_eq(1, RAND_bytes_ex(libctx, secret, sizeof(secret), 0))
-            || !TEST_true(SET_OPT_UNPROTECTED_SEND(ctx, 0))
-            || !TEST_true(set1_newPkey(ctx, newkey))
-            || !TEST_true(OSSL_CMP_CTX_set1_secretValue(ctx, secret,
-                                                        sizeof(secret)))) {
+        || !TEST_true(SET_OPT_UNPROTECTED_SEND(ctx, 0))
+        || !TEST_true(set1_newPkey(ctx, newkey))
+        || !TEST_true(OSSL_CMP_CTX_set1_secretValue(ctx, secret,
+            sizeof(secret)))) {
         tear_down(fixture);
         fixture = NULL;
     }
@@ -169,9 +165,9 @@ static int test_cmp_create_ir_protection_fails(void)
     fixture->err_code = -1;
     fixture->expected = 0;
     if (!TEST_true(OSSL_CMP_CTX_set1_pkey(fixture->cmp_ctx, newkey))
-            || !TEST_true(SET_OPT_UNPROTECTED_SEND(fixture->cmp_ctx, 0))
-            /* newkey used by default for signing does not match cert: */
-            || !TEST_true(OSSL_CMP_CTX_set1_cert(fixture->cmp_ctx, cert))) {
+        || !TEST_true(SET_OPT_UNPROTECTED_SEND(fixture->cmp_ctx, 0))
+        /* newkey used by default for signing does not match cert: */
+        || !TEST_true(OSSL_CMP_CTX_set1_cert(fixture->cmp_ctx, cert))) {
         tear_down(fixture);
         fixture = NULL;
     }
@@ -228,8 +224,8 @@ static int test_cmp_create_p10cr(void)
     fixture->err_code = CMP_R_ERROR_CREATING_CERTREQ;
     fixture->expected = 1;
     if (!TEST_ptr(p10cr = load_csr_der(pkcs10_f, libctx))
-            || !TEST_true(set1_newPkey(ctx, newkey))
-            || !TEST_true(OSSL_CMP_CTX_set1_p10CSR(ctx, p10cr))) {
+        || !TEST_true(set1_newPkey(ctx, newkey))
+        || !TEST_true(OSSL_CMP_CTX_set1_p10CSR(ctx, p10cr))) {
         tear_down(fixture);
         fixture = NULL;
     }
@@ -259,7 +255,7 @@ static int test_cmp_create_kur(void)
     fixture->err_code = -1;
     fixture->expected = 1;
     if (!TEST_true(set1_newPkey(fixture->cmp_ctx, newkey))
-            || !TEST_true(OSSL_CMP_CTX_set1_oldCert(fixture->cmp_ctx, cert))) {
+        || !TEST_true(OSSL_CMP_CTX_set1_oldCert(fixture->cmp_ctx, cert))) {
         tear_down(fixture);
         fixture = NULL;
     }
@@ -287,7 +283,7 @@ static int test_cmp_create_certconf(void)
     fixture->fail_info = 0;
     fixture->expected = 1;
     if (!TEST_true(ossl_cmp_ctx_set0_newCert(fixture->cmp_ctx,
-                                             X509_dup(cert)))) {
+            X509_dup(cert)))) {
         tear_down(fixture);
         fixture = NULL;
     }
@@ -301,7 +297,7 @@ static int test_cmp_create_certconf_badAlg(void)
     fixture->fail_info = 1 << OSSL_CMP_PKIFAILUREINFO_badAlg;
     fixture->expected = 1;
     if (!TEST_true(ossl_cmp_ctx_set0_newCert(fixture->cmp_ctx,
-                                             X509_dup(cert)))) {
+            X509_dup(cert)))) {
         tear_down(fixture);
         fixture = NULL;
     }
@@ -315,7 +311,7 @@ static int test_cmp_create_certconf_fail_info_max(void)
     fixture->fail_info = 1 << OSSL_CMP_PKIFAILUREINFO_MAX;
     fixture->expected = 1;
     if (!TEST_true(ossl_cmp_ctx_set0_newCert(fixture->cmp_ctx,
-                                             X509_dup(cert)))) {
+            X509_dup(cert)))) {
         tear_down(fixture);
         fixture = NULL;
     }
@@ -327,8 +323,8 @@ static int test_cmp_create_error_msg(void)
 {
     SETUP_TEST_FIXTURE(CMP_MSG_TEST_FIXTURE, set_up);
     fixture->si = OSSL_CMP_STATUSINFO_new(OSSL_CMP_PKISTATUS_rejection,
-                                          OSSL_CMP_PKIFAILUREINFO_systemFailure,
-                                          NULL);
+        OSSL_CMP_PKIFAILUREINFO_systemFailure,
+        NULL);
     fixture->err_code = -1;
     fixture->expected = 1; /* expected: message creation is successful */
     if (!TEST_true(set1_newPkey(fixture->cmp_ctx, newkey))) {
@@ -367,7 +363,7 @@ static int test_cmp_create_genm(void)
     fixture->expected = 1;
     iv = OSSL_CMP_ITAV_create(OBJ_nid2obj(NID_id_it_implicitConfirm), NULL);
     if (!TEST_ptr(iv)
-            || !TEST_true(OSSL_CMP_CTX_push0_genm_ITAV(fixture->cmp_ctx, iv))) {
+        || !TEST_true(OSSL_CMP_CTX_push0_genm_ITAV(fixture->cmp_ctx, iv))) {
         OSSL_CMP_ITAV_free(iv);
         tear_down(fixture);
         fixture = NULL;
@@ -391,11 +387,9 @@ static int execute_certrep_create(CMP_MSG_TEST_FIXTURE *fixture)
         goto err;
     if ((cresp->certifiedKeyPair = OSSL_CMP_CERTIFIEDKEYPAIR_new()) == NULL)
         goto err;
-    cresp->certifiedKeyPair->certOrEncCert->type =
-        OSSL_CMP_CERTORENCCERT_CERTIFICATE;
-    if ((cresp->certifiedKeyPair->certOrEncCert->value.certificate =
-         X509_dup(cert)) == NULL
-            || !sk_OSSL_CMP_CERTRESPONSE_push(crepmsg->response, cresp))
+    cresp->certifiedKeyPair->certOrEncCert->type = OSSL_CMP_CERTORENCCERT_CERTIFICATE;
+    if ((cresp->certifiedKeyPair->certOrEncCert->value.certificate = X509_dup(cert)) == NULL
+        || !sk_OSSL_CMP_CERTRESPONSE_push(crepmsg->response, cresp))
         goto err;
     cresp = NULL;
     read_cresp = ossl_cmp_certrepmessage_get0_certresponse(crepmsg, 99);
@@ -408,7 +402,7 @@ static int execute_certrep_create(CMP_MSG_TEST_FIXTURE *fixture)
         goto err;
 
     res = 1;
- err:
+err:
     X509_free(certfromresp);
     OSSL_CMP_CERTRESPONSE_free(cresp);
     OSSL_CMP_CERTREPMESSAGE_free(crepmsg);
@@ -435,10 +429,10 @@ static int execute_rp_create(CMP_MSG_TEST_FIXTURE *fixture)
         goto err;
 
     if (!X509_NAME_add_entry_by_txt(issuer, "CN", MBSTRING_ASC,
-                                    (unsigned char *)"The Issuer", -1, -1, 0)
-            || !ASN1_INTEGER_set(serial, 99)
-            || (cid = OSSL_CRMF_CERTID_gen(issuer, serial)) == NULL
-            || (rpmsg = ossl_cmp_rp_new(fixture->cmp_ctx, si, cid, 1)) == NULL)
+            (unsigned char *)"The Issuer", -1, -1, 0)
+        || !ASN1_INTEGER_set(serial, 99)
+        || (cid = OSSL_CRMF_CERTID_gen(issuer, serial)) == NULL
+        || (rpmsg = ossl_cmp_rp_new(fixture->cmp_ctx, si, cid, 1)) == NULL)
         goto err;
 
     if (!TEST_ptr(ossl_cmp_revrepcontent_get_CertId(rpmsg->body->value.rp, 0)))
@@ -448,7 +442,7 @@ static int execute_rp_create(CMP_MSG_TEST_FIXTURE *fixture)
         goto err;
 
     res = 1;
- err:
+err:
     ASN1_INTEGER_free(serial);
     X509_NAME_free(issuer);
     OSSL_CRMF_CERTID_free(cid);
@@ -472,15 +466,13 @@ static int execute_pollrep_create(CMP_MSG_TEST_FIXTURE *fixture)
     pollrep = ossl_cmp_pollRep_new(fixture->cmp_ctx, 77, 2000);
     if (!TEST_ptr(pollrep))
         return 0;
-    if (!TEST_ptr(ossl_cmp_pollrepcontent_get0_pollrep(pollrep->body->
-                                                       value.pollRep, 77)))
+    if (!TEST_ptr(ossl_cmp_pollrepcontent_get0_pollrep(pollrep->body->value.pollRep, 77)))
         goto err;
-    if (!TEST_ptr_null(ossl_cmp_pollrepcontent_get0_pollrep(pollrep->body->
-                                                            value.pollRep, 88)))
+    if (!TEST_ptr_null(ossl_cmp_pollrepcontent_get0_pollrep(pollrep->body->value.pollRep, 88)))
         goto err;
 
     res = 1;
- err:
+err:
     OSSL_CMP_MSG_free(pollrep);
     return res;
 }
@@ -554,8 +546,8 @@ int setup_tests(void)
     }
 
     if (!TEST_ptr(newkey_f = test_get_argument(0))
-            || !TEST_ptr(server_cert_f = test_get_argument(1))
-            || !TEST_ptr(pkcs10_f = test_get_argument(2))) {
+        || !TEST_ptr(server_cert_f = test_get_argument(1))
+        || !TEST_ptr(pkcs10_f = test_get_argument(2))) {
         TEST_error("usage: cmp_msg_test %s", USAGE);
         return 0;
     }
@@ -564,8 +556,8 @@ int setup_tests(void)
         return 0;
 
     if (!TEST_ptr(newkey = load_pkey_pem(newkey_f, libctx))
-            || !TEST_ptr(cert = load_cert_pem(server_cert_f, libctx))
-            || !TEST_int_eq(1, RAND_bytes_ex(libctx, ref, sizeof(ref), 0))) {
+        || !TEST_ptr(cert = load_cert_pem(server_cert_f, libctx))
+        || !TEST_int_eq(1, RAND_bytes_ex(libctx, ref, sizeof(ref), 0))) {
         cleanup_tests();
         return 0;
     }
@@ -591,6 +583,6 @@ int setup_tests(void)
     ADD_TEST(test_cmp_create_certrep);
     ADD_TEST(test_cmp_create_pollrep);
     ADD_ALL_TESTS_NOSUBTEST(test_cmp_pkimessage_create,
-                            OSSL_CMP_PKIBODY_POLLREP + 1);
+        OSSL_CMP_PKIBODY_POLLREP + 1);
     return 1;
 }
