@@ -76,25 +76,21 @@ static const uint8_t in_u3[56] = {
 };
 
 static const uint8_t out_u3[3][56] = {
-    {
-        0x3f, 0x48, 0x2c, 0x8a, 0x9f, 0x19, 0xb0, 0x1e, 0x6c, 0x46, 0xee, 0x97,
+    { 0x3f, 0x48, 0x2c, 0x8a, 0x9f, 0x19, 0xb0, 0x1e, 0x6c, 0x46, 0xee, 0x97,
         0x11, 0xd9, 0xdc, 0x14, 0xfd, 0x4b, 0xf6, 0x7a, 0xf3, 0x07, 0x65, 0xc2,
         0xae, 0x2b, 0x84, 0x6a, 0x4d, 0x23, 0xa8, 0xcd, 0x0d, 0xb8, 0x97, 0x08,
         0x62, 0x39, 0x49, 0x2c, 0xaf, 0x35, 0x0b, 0x51, 0xf8, 0x33, 0x86, 0x8b,
-        0x9b, 0xc2, 0xb3, 0xbc, 0xa9, 0xcf, 0x41, 0x13
-    }, {
-        0xaa, 0x3b, 0x47, 0x49, 0xd5, 0x5b, 0x9d, 0xaf, 0x1e, 0x5b, 0x00, 0x28,
+        0x9b, 0xc2, 0xb3, 0xbc, 0xa9, 0xcf, 0x41, 0x13 },
+    { 0xaa, 0x3b, 0x47, 0x49, 0xd5, 0x5b, 0x9d, 0xaf, 0x1e, 0x5b, 0x00, 0x28,
         0x88, 0x26, 0xc4, 0x67, 0x27, 0x4c, 0xe3, 0xeb, 0xbd, 0xd5, 0xc1, 0x7b,
         0x97, 0x5e, 0x09, 0xd4, 0xaf, 0x6c, 0x67, 0xcf, 0x10, 0xd0, 0x87, 0x20,
         0x2d, 0xb8, 0x82, 0x86, 0xe2, 0xb7, 0x9f, 0xce, 0xea, 0x3e, 0xc3, 0x53,
-        0xef, 0x54, 0xfa, 0xa2, 0x6e, 0x21, 0x9f, 0x38
-    }, {
-        0x07, 0x7f, 0x45, 0x36, 0x81, 0xca, 0xca, 0x36, 0x93, 0x19, 0x84, 0x20,
+        0xef, 0x54, 0xfa, 0xa2, 0x6e, 0x21, 0x9f, 0x38 },
+    { 0x07, 0x7f, 0x45, 0x36, 0x81, 0xca, 0xca, 0x36, 0x93, 0x19, 0x84, 0x20,
         0xbb, 0xe5, 0x15, 0xca, 0xe0, 0x00, 0x24, 0x72, 0x51, 0x9b, 0x3e, 0x67,
         0x66, 0x1a, 0x7e, 0x89, 0xca, 0xb9, 0x46, 0x95, 0xc8, 0xf4, 0xbc, 0xd6,
         0x6e, 0x61, 0xb9, 0xb9, 0xc9, 0x46, 0xda, 0x8d, 0x52, 0x4d, 0xe3, 0xd6,
-        0x9b, 0xd9, 0xd9, 0xd6, 0x6b, 0x99, 0x7e, 0x37
-    }
+        0x9b, 0xd9, 0xd9, 0xd6, 0x6b, 0x99, 0x7e, 0x37 }
 };
 
 /* Test vectors from RFC8032 for Ed448 */
@@ -583,13 +579,13 @@ static const uint8_t phsig2[114] = {
 };
 
 static const uint8_t *dohash(EVP_MD_CTX *hashctx, const uint8_t *msg,
-                             size_t msglen)
+    size_t msglen)
 {
     static uint8_t hashout[64];
 
     if (!EVP_DigestInit_ex(hashctx, EVP_shake256(), NULL)
-            || !EVP_DigestUpdate(hashctx, msg, msglen)
-            || !EVP_DigestFinalXOF(hashctx, hashout, sizeof(hashout)))
+        || !EVP_DigestUpdate(hashctx, msg, msglen)
+        || !EVP_DigestFinalXOF(hashctx, hashout, sizeof(hashout)))
         return NULL;
 
     return hashout;
@@ -601,45 +597,47 @@ static int test_ed448(void)
     EVP_MD_CTX *hashctx = EVP_MD_CTX_new();
 
     if (!TEST_ptr(hashctx)
-            || !TEST_true(ossl_ed448_sign(NULL, outsig, NULL, 0, pubkey1,
-                                          privkey1, NULL, 0, 0, NULL))
-            || !TEST_int_eq(memcmp(sig1, outsig, sizeof(sig1)), 0)
-            || !TEST_true(ossl_ed448_sign(NULL, outsig, msg2, sizeof(msg2),
-                                          pubkey2, privkey2, NULL, 0, 0, NULL))
-            || !TEST_int_eq(memcmp(sig2, outsig, sizeof(sig2)), 0)
-            || !TEST_true(ossl_ed448_sign(NULL, outsig, msg3, sizeof(msg3),
-                                          pubkey3, privkey3, context3,
-                                          sizeof(context3), 0, NULL))
-            || !TEST_int_eq(memcmp(sig3, outsig, sizeof(sig3)), 0)
-            || !TEST_true(ossl_ed448_sign(NULL, outsig, msg4, sizeof(msg4),
-                                          pubkey4, privkey4, NULL, 0, 0, NULL))
-            || !TEST_int_eq(memcmp(sig4, outsig, sizeof(sig4)), 0)
-            || !TEST_true(ossl_ed448_sign(NULL, outsig, msg5, sizeof(msg5),
-                                          pubkey5, privkey5, NULL, 0, 0, NULL))
-            || !TEST_int_eq(memcmp(sig5, outsig, sizeof(sig5)), 0)
-            || !TEST_true(ossl_ed448_sign(NULL, outsig, msg6, sizeof(msg6),
-                                          pubkey6, privkey6, NULL, 0, 0, NULL))
-            || !TEST_int_eq(memcmp(sig6, outsig, sizeof(sig6)), 0)
-            || !TEST_true(ossl_ed448_sign(NULL, outsig, msg7, sizeof(msg7),
-                                          pubkey7, privkey7, NULL, 0, 0, NULL))
-            || !TEST_int_eq(memcmp(sig7, outsig, sizeof(sig7)), 0)
-            || !TEST_true(ossl_ed448_sign(NULL, outsig, msg8, sizeof(msg8),
-                                          pubkey8, privkey8, NULL, 0, 0, NULL))
-            || !TEST_int_eq(memcmp(sig8, outsig, sizeof(sig8)), 0)
-            || !TEST_true(ossl_ed448_sign(NULL, outsig, msg9, sizeof(msg9),
-                                          pubkey9, privkey9, NULL, 0, 0, NULL))
-            || !TEST_int_eq(memcmp(sig9, outsig, sizeof(sig9)), 0)
-            || !TEST_true(ossl_ed448_sign(NULL, outsig,
-                                          dohash(hashctx, phmsg1,
-                                                 sizeof(phmsg1)), 64, phpubkey1,
-                                                 phprivkey1, NULL, 0, 1, NULL))
-            || !TEST_int_eq(memcmp(phsig1, outsig, sizeof(phsig1)), 0)
-            || !TEST_true(ossl_ed448_sign(NULL, outsig,
-                                          dohash(hashctx, phmsg2,
-                                                 sizeof(phmsg2)), 64, phpubkey2,
-                                                 phprivkey2, phcontext2,
-                                                 sizeof(phcontext2), 1, NULL))
-            || !TEST_int_eq(memcmp(phsig2, outsig, sizeof(phsig2)), 0)) {
+        || !TEST_true(ossl_ed448_sign(NULL, outsig, NULL, 0, pubkey1,
+            privkey1, NULL, 0, 0, NULL))
+        || !TEST_int_eq(memcmp(sig1, outsig, sizeof(sig1)), 0)
+        || !TEST_true(ossl_ed448_sign(NULL, outsig, msg2, sizeof(msg2),
+            pubkey2, privkey2, NULL, 0, 0, NULL))
+        || !TEST_int_eq(memcmp(sig2, outsig, sizeof(sig2)), 0)
+        || !TEST_true(ossl_ed448_sign(NULL, outsig, msg3, sizeof(msg3),
+            pubkey3, privkey3, context3,
+            sizeof(context3), 0, NULL))
+        || !TEST_int_eq(memcmp(sig3, outsig, sizeof(sig3)), 0)
+        || !TEST_true(ossl_ed448_sign(NULL, outsig, msg4, sizeof(msg4),
+            pubkey4, privkey4, NULL, 0, 0, NULL))
+        || !TEST_int_eq(memcmp(sig4, outsig, sizeof(sig4)), 0)
+        || !TEST_true(ossl_ed448_sign(NULL, outsig, msg5, sizeof(msg5),
+            pubkey5, privkey5, NULL, 0, 0, NULL))
+        || !TEST_int_eq(memcmp(sig5, outsig, sizeof(sig5)), 0)
+        || !TEST_true(ossl_ed448_sign(NULL, outsig, msg6, sizeof(msg6),
+            pubkey6, privkey6, NULL, 0, 0, NULL))
+        || !TEST_int_eq(memcmp(sig6, outsig, sizeof(sig6)), 0)
+        || !TEST_true(ossl_ed448_sign(NULL, outsig, msg7, sizeof(msg7),
+            pubkey7, privkey7, NULL, 0, 0, NULL))
+        || !TEST_int_eq(memcmp(sig7, outsig, sizeof(sig7)), 0)
+        || !TEST_true(ossl_ed448_sign(NULL, outsig, msg8, sizeof(msg8),
+            pubkey8, privkey8, NULL, 0, 0, NULL))
+        || !TEST_int_eq(memcmp(sig8, outsig, sizeof(sig8)), 0)
+        || !TEST_true(ossl_ed448_sign(NULL, outsig, msg9, sizeof(msg9),
+            pubkey9, privkey9, NULL, 0, 0, NULL))
+        || !TEST_int_eq(memcmp(sig9, outsig, sizeof(sig9)), 0)
+        || !TEST_true(ossl_ed448_sign(NULL, outsig,
+            dohash(hashctx, phmsg1,
+                sizeof(phmsg1)),
+            64, phpubkey1,
+            phprivkey1, NULL, 0, 1, NULL))
+        || !TEST_int_eq(memcmp(phsig1, outsig, sizeof(phsig1)), 0)
+        || !TEST_true(ossl_ed448_sign(NULL, outsig,
+            dohash(hashctx, phmsg2,
+                sizeof(phmsg2)),
+            64, phpubkey2,
+            phprivkey2, phcontext2,
+            sizeof(phcontext2), 1, NULL))
+        || !TEST_int_eq(memcmp(phsig2, outsig, sizeof(phsig2)), 0)) {
         EVP_MD_CTX_free(hashctx);
         return 0;
     }
@@ -657,9 +655,9 @@ static int test_x448(void)
     /* Curve448 tests */
 
     if (!TEST_true(ossl_x448(out, in_scalar1, in_u1))
-          || !TEST_int_eq(memcmp(out, out_u1, sizeof(out)), 0)
-          || !TEST_true(ossl_x448(out, in_scalar2, in_u2))
-          || !TEST_int_eq(memcmp(out, out_u2, sizeof(out)), 0))
+        || !TEST_int_eq(memcmp(out, out_u1, sizeof(out)), 0)
+        || !TEST_true(ossl_x448(out, in_scalar2, in_u2))
+        || !TEST_int_eq(memcmp(out, out_u2, sizeof(out)), 0))
         return 0;
 
     memcpy(u, in_u3, sizeof(u));
@@ -701,7 +699,7 @@ const OPTIONS *test_get_options(void)
         OPT_TEST_OPTIONS_WITH_EXTRA_USAGE("conf_file\n"),
         { "f", OPT_SLOW, '-', "Enables a slow test" },
         { "v", OPT_PROGRESS, '-',
-              "Enables verbose mode (prints progress dots)" },
+            "Enables verbose mode (prints progress dots)" },
         { NULL }
     };
     return test_options;
