@@ -81,8 +81,7 @@ static int ex_data_idx;
 static void info_cb(const SSL *s, int where, int ret)
 {
     if (where & SSL_CB_ALERT) {
-        HANDSHAKE_EX_DATA *ex_data =
-            (HANDSHAKE_EX_DATA*)(SSL_get_ex_data(s, ex_data_idx));
+        HANDSHAKE_EX_DATA *ex_data = (HANDSHAKE_EX_DATA *)(SSL_get_ex_data(s, ex_data_idx));
         if (where & SSL_CB_WRITE) {
             ex_data->alert_sent = ret;
             if (strcmp(SSL_alert_type_string(ret), "F") == 0
@@ -103,8 +102,7 @@ static void info_cb(const SSL *s, int where, int ret)
 static int select_server_ctx(SSL *s, void *arg, int ignore)
 {
     const char *servername = SSL_get_servername(s, TLSEXT_NAMETYPE_host_name);
-    HANDSHAKE_EX_DATA *ex_data =
-        (HANDSHAKE_EX_DATA*)(SSL_get_ex_data(s, ex_data_idx));
+    HANDSHAKE_EX_DATA *ex_data = (HANDSHAKE_EX_DATA *)(SSL_get_ex_data(s, ex_data_idx));
 
     if (servername == NULL) {
         ex_data->servername = SSL_TEST_SERVERNAME_SERVER1;
@@ -112,7 +110,7 @@ static int select_server_ctx(SSL *s, void *arg, int ignore)
     }
 
     if (strcmp(servername, "server2") == 0) {
-        SSL_CTX *new_ctx = (SSL_CTX*)arg;
+        SSL_CTX *new_ctx = (SSL_CTX *)arg;
         SSL_set_SSL_CTX(s, new_ctx);
         /*
          * Copy over all the SSL_CTX options - reasonable behavior
@@ -141,16 +139,15 @@ static int client_hello_select_server_ctx(SSL *s, void *arg, int ignore)
     const char *servername;
     const unsigned char *p;
     size_t len, remaining;
-    HANDSHAKE_EX_DATA *ex_data =
-        (HANDSHAKE_EX_DATA*)(SSL_get_ex_data(s, ex_data_idx));
+    HANDSHAKE_EX_DATA *ex_data = (HANDSHAKE_EX_DATA *)(SSL_get_ex_data(s, ex_data_idx));
 
     /*
      * The server_name extension was given too much extensibility when it
      * was written, so parsing the normal case is a bit complex.
      */
     if (!SSL_client_hello_get0_ext(s, TLSEXT_TYPE_server_name, &p,
-                                   &remaining) ||
-        remaining <= 2)
+            &remaining)
+        || remaining <= 2)
         return 0;
     /* Extract the length of the supplied list of names. */
     len = (*(p++) << 8);
@@ -188,8 +185,7 @@ static int client_hello_select_server_ctx(SSL *s, void *arg, int ignore)
 
         ex_data->servername = SSL_TEST_SERVERNAME_SERVER2;
         return 1;
-    } else if (len == strlen("server1") &&
-               HAS_PREFIX(servername, "server1")) {
+    } else if (len == strlen("server1") && HAS_PREFIX(servername, "server1")) {
         ex_data->servername = SSL_TEST_SERVERNAME_SERVER1;
         return 1;
     } else if (ignore) {
@@ -249,10 +245,7 @@ static int client_hello_nov12_cb(SSL *s, int *al, void *arg)
         return SSL_CLIENT_HELLO_ERROR;
     }
     (void)SSL_client_hello_get0_session_id(s, &p);
-    if (p == NULL ||
-        SSL_client_hello_get0_random(s, &p) == 0 ||
-        SSL_client_hello_get0_ciphers(s, &p) == 0 ||
-        SSL_client_hello_get0_compression_methods(s, &p) == 0) {
+    if (p == NULL || SSL_client_hello_get0_random(s, &p) == 0 || SSL_client_hello_get0_ciphers(s, &p) == 0 || SSL_client_hello_get0_compression_methods(s, &p) == 0) {
         *al = SSL_AD_INTERNAL_ERROR;
         return SSL_CLIENT_HELLO_ERROR;
     }
@@ -299,13 +292,15 @@ static int client_ocsp_cb(SSL *s, void *arg)
     return 1;
 }
 
-static int verify_reject_cb(X509_STORE_CTX *ctx, void *arg) {
+static int verify_reject_cb(X509_STORE_CTX *ctx, void *arg)
+{
     X509_STORE_CTX_set_error(ctx, X509_V_ERR_APPLICATION_VERIFICATION);
     return 0;
 }
 
 static int n_retries = 0;
-static int verify_retry_cb(X509_STORE_CTX *ctx, void *arg) {
+static int verify_retry_cb(X509_STORE_CTX *ctx, void *arg)
+{
     int idx = SSL_get_ex_data_X509_STORE_CTX_idx();
     SSL *ssl;
 
@@ -320,24 +315,24 @@ static int verify_retry_cb(X509_STORE_CTX *ctx, void *arg) {
     return SSL_set_retry_verify(ssl);
 }
 
-static int verify_accept_cb(X509_STORE_CTX *ctx, void *arg) {
+static int verify_accept_cb(X509_STORE_CTX *ctx, void *arg)
+{
     return 1;
 }
 
 static int broken_session_ticket_cb(SSL *s, unsigned char *key_name,
-                                    unsigned char *iv, EVP_CIPHER_CTX *ctx,
-                                    EVP_MAC_CTX *hctx, int enc)
+    unsigned char *iv, EVP_CIPHER_CTX *ctx,
+    EVP_MAC_CTX *hctx, int enc)
 {
     return 0;
 }
 
 static int do_not_call_session_ticket_cb(SSL *s, unsigned char *key_name,
-                                         unsigned char *iv,
-                                         EVP_CIPHER_CTX *ctx,
-                                         EVP_MAC_CTX *hctx, int enc)
+    unsigned char *iv,
+    EVP_CIPHER_CTX *ctx,
+    EVP_MAC_CTX *hctx, int enc)
 {
-    HANDSHAKE_EX_DATA *ex_data =
-        (HANDSHAKE_EX_DATA*)(SSL_get_ex_data(s, ex_data_idx));
+    HANDSHAKE_EX_DATA *ex_data = (HANDSHAKE_EX_DATA *)(SSL_get_ex_data(s, ex_data_idx));
     ex_data->session_ticket_do_not_call = 1;
     return 0;
 }
@@ -357,8 +352,8 @@ static int parse_protos(const char *protos, unsigned char **out, size_t *outlen)
 
     /* Should never have reuse. */
     if (!TEST_ptr_null(*out)
-            /* Test values are small, so we omit length limit checks. */
-            || !TEST_ptr(*out = OPENSSL_malloc(len + 1)))
+        /* Test values are small, so we omit length limit checks. */
+        || !TEST_ptr(*out = OPENSSL_malloc(len + 1)))
         return 0;
     *outlen = len + 1;
 
@@ -398,24 +393,25 @@ err:
  * protocol that it supports.
  */
 static int client_npn_cb(SSL *s, unsigned char **out, unsigned char *outlen,
-                         const unsigned char *in, unsigned int inlen,
-                         void *arg)
+    const unsigned char *in, unsigned int inlen,
+    void *arg)
 {
-    CTX_DATA *ctx_data = (CTX_DATA*)(arg);
+    CTX_DATA *ctx_data = (CTX_DATA *)(arg);
     int ret;
 
     ret = SSL_select_next_proto(out, outlen, in, inlen,
-                                ctx_data->npn_protocols,
-                                ctx_data->npn_protocols_len);
+        ctx_data->npn_protocols,
+        ctx_data->npn_protocols_len);
     /* Accept both OPENSSL_NPN_NEGOTIATED and OPENSSL_NPN_NO_OVERLAP. */
     return TEST_true(ret == OPENSSL_NPN_NEGOTIATED || ret == OPENSSL_NPN_NO_OVERLAP)
-        ? SSL_TLSEXT_ERR_OK : SSL_TLSEXT_ERR_ALERT_FATAL;
+        ? SSL_TLSEXT_ERR_OK
+        : SSL_TLSEXT_ERR_ALERT_FATAL;
 }
 
 static int server_npn_cb(SSL *s, const unsigned char **data,
-                         unsigned int *len, void *arg)
+    unsigned int *len, void *arg)
 {
-    CTX_DATA *ctx_data = (CTX_DATA*)(arg);
+    CTX_DATA *ctx_data = (CTX_DATA *)(arg);
     *data = ctx_data->npn_protocols;
     *len = ctx_data->npn_protocols_len;
     return SSL_TLSEXT_ERR_OK;
@@ -429,10 +425,10 @@ static int server_npn_cb(SSL *s, const unsigned char **data,
  * respond with a fatal "no_application_protocol" alert.
  */
 static int server_alpn_cb(SSL *s, const unsigned char **out,
-                          unsigned char *outlen, const unsigned char *in,
-                          unsigned int inlen, void *arg)
+    unsigned char *outlen, const unsigned char *in,
+    unsigned int inlen, void *arg)
 {
-    CTX_DATA *ctx_data = (CTX_DATA*)(arg);
+    CTX_DATA *ctx_data = (CTX_DATA *)(arg);
     int ret;
 
     /* SSL_select_next_proto isn't const-correct... */
@@ -444,13 +440,13 @@ static int server_alpn_cb(SSL *s, const unsigned char **out,
      * so we can return directly without storing a copy.
      */
     ret = SSL_select_next_proto(&tmp_out, outlen,
-                                ctx_data->alpn_protocols,
-                                ctx_data->alpn_protocols_len, in, inlen);
+        ctx_data->alpn_protocols,
+        ctx_data->alpn_protocols_len, in, inlen);
 
     *out = tmp_out;
     /* Unlike NPN, we don't tolerate a mismatch. */
     return ret == OPENSSL_NPN_NEGOTIATED ? SSL_TLSEXT_ERR_OK
-        : SSL_TLSEXT_ERR_ALERT_FATAL;
+                                         : SSL_TLSEXT_ERR_ALERT_FATAL;
 }
 
 static int generate_session_ticket_cb(SSL *s, void *arg)
@@ -466,10 +462,10 @@ static int generate_session_ticket_cb(SSL *s, void *arg)
 }
 
 static int decrypt_session_ticket_cb(SSL *s, SSL_SESSION *ss,
-                                     const unsigned char *keyname,
-                                     size_t keyname_len,
-                                     SSL_TICKET_STATUS status,
-                                     void *arg)
+    const unsigned char *keyname,
+    size_t keyname_len,
+    SSL_TICKET_STATUS status,
+    void *arg)
 {
     switch (status) {
     case SSL_TICKET_EMPTY:
@@ -490,27 +486,29 @@ static int decrypt_session_ticket_cb(SSL *s, SSL_SESSION *ss,
  * in the server/client CONF.
  */
 static int configure_handshake_ctx(SSL_CTX *server_ctx, SSL_CTX *server2_ctx,
-                                   SSL_CTX *client_ctx,
-                                   const SSL_TEST_CTX *test,
-                                   const SSL_TEST_EXTRA_CONF *extra,
-                                   CTX_DATA *server_ctx_data,
-                                   CTX_DATA *server2_ctx_data,
-                                   CTX_DATA *client_ctx_data)
+    SSL_CTX *client_ctx,
+    const SSL_TEST_CTX *test,
+    const SSL_TEST_EXTRA_CONF *extra,
+    CTX_DATA *server_ctx_data,
+    CTX_DATA *server2_ctx_data,
+    CTX_DATA *client_ctx_data)
 {
     unsigned char *ticket_keys;
     size_t ticket_key_len;
 
     if (!TEST_int_eq(SSL_CTX_set_max_send_fragment(server_ctx,
-                                                   test->max_fragment_size), 1))
+                         test->max_fragment_size),
+            1))
         goto err;
     if (server2_ctx != NULL) {
         if (!TEST_int_eq(SSL_CTX_set_max_send_fragment(server2_ctx,
-                                                       test->max_fragment_size),
-                         1))
+                             test->max_fragment_size),
+                1))
             goto err;
     }
     if (!TEST_int_eq(SSL_CTX_set_max_send_fragment(client_ctx,
-                                                   test->max_fragment_size), 1))
+                         test->max_fragment_size),
+            1))
         goto err;
 
     switch (extra->client.verify_callback) {
@@ -535,7 +533,7 @@ static int configure_handshake_ctx(SSL_CTX *server_ctx, SSL_CTX *server2_ctx,
     case TLSEXT_max_fragment_length_4096:
     case TLSEXT_max_fragment_length_DISABLED:
         SSL_CTX_set_tlsext_max_fragment_length(
-              client_ctx, extra->client.max_fragment_len_mode);
+            client_ctx, extra->client.max_fragment_len_mode);
         break;
     }
 
@@ -572,7 +570,8 @@ static int configure_handshake_ctx(SSL_CTX *server_ctx, SSL_CTX *server2_ctx,
         SSL_CTX_set_tlsext_status_cb(server_ctx, server_ocsp_cb);
         SSL_CTX_set_tlsext_status_arg(server_ctx,
             ((extra->server.cert_status == SSL_TEST_CERT_STATUS_GOOD_RESPONSE)
-            ? &dummy_ocsp_resp_good_val : &dummy_ocsp_resp_bad_val));
+                    ? &dummy_ocsp_resp_good_val
+                    : &dummy_ocsp_resp_bad_val));
     }
 
     /*
@@ -582,86 +581,84 @@ static int configure_handshake_ctx(SSL_CTX *server_ctx, SSL_CTX *server2_ctx,
      */
     if (server2_ctx != NULL)
         SSL_CTX_set_tlsext_ticket_key_evp_cb(server2_ctx,
-                                             do_not_call_session_ticket_cb);
+            do_not_call_session_ticket_cb);
 
     if (extra->server.broken_session_ticket) {
         SSL_CTX_set_tlsext_ticket_key_evp_cb(server_ctx,
-                                             broken_session_ticket_cb);
+            broken_session_ticket_cb);
     }
 #ifndef OPENSSL_NO_NEXTPROTONEG
     if (extra->server.npn_protocols != NULL) {
         if (!TEST_true(parse_protos(extra->server.npn_protocols,
-                                    &server_ctx_data->npn_protocols,
-                                    &server_ctx_data->npn_protocols_len)))
+                &server_ctx_data->npn_protocols,
+                &server_ctx_data->npn_protocols_len)))
             goto err;
         SSL_CTX_set_npn_advertised_cb(server_ctx, server_npn_cb,
-                                      server_ctx_data);
+            server_ctx_data);
     }
     if (extra->server2.npn_protocols != NULL) {
         if (!TEST_true(parse_protos(extra->server2.npn_protocols,
-                                    &server2_ctx_data->npn_protocols,
-                                    &server2_ctx_data->npn_protocols_len))
-                || !TEST_ptr(server2_ctx))
+                &server2_ctx_data->npn_protocols,
+                &server2_ctx_data->npn_protocols_len))
+            || !TEST_ptr(server2_ctx))
             goto err;
         SSL_CTX_set_npn_advertised_cb(server2_ctx, server_npn_cb,
-                                      server2_ctx_data);
+            server2_ctx_data);
     }
     if (extra->client.npn_protocols != NULL) {
         if (!TEST_true(parse_protos(extra->client.npn_protocols,
-                                    &client_ctx_data->npn_protocols,
-                                    &client_ctx_data->npn_protocols_len)))
+                &client_ctx_data->npn_protocols,
+                &client_ctx_data->npn_protocols_len)))
             goto err;
         SSL_CTX_set_next_proto_select_cb(client_ctx, client_npn_cb,
-                                         client_ctx_data);
+            client_ctx_data);
     }
 #endif
     if (extra->server.alpn_protocols != NULL) {
         if (!TEST_true(parse_protos(extra->server.alpn_protocols,
-                                    &server_ctx_data->alpn_protocols,
-                                    &server_ctx_data->alpn_protocols_len)))
+                &server_ctx_data->alpn_protocols,
+                &server_ctx_data->alpn_protocols_len)))
             goto err;
         SSL_CTX_set_alpn_select_cb(server_ctx, server_alpn_cb, server_ctx_data);
     }
     if (extra->server2.alpn_protocols != NULL) {
         if (!TEST_ptr(server2_ctx)
-                || !TEST_true(parse_protos(extra->server2.alpn_protocols,
-                                           &server2_ctx_data->alpn_protocols,
-                                           &server2_ctx_data->alpn_protocols_len
-            )))
+            || !TEST_true(parse_protos(extra->server2.alpn_protocols,
+                &server2_ctx_data->alpn_protocols,
+                &server2_ctx_data->alpn_protocols_len)))
             goto err;
         SSL_CTX_set_alpn_select_cb(server2_ctx, server_alpn_cb,
-                                   server2_ctx_data);
+            server2_ctx_data);
     }
     if (extra->client.alpn_protocols != NULL) {
         unsigned char *alpn_protos = NULL;
         size_t alpn_protos_len = 0;
 
         if (!TEST_true(parse_protos(extra->client.alpn_protocols,
-                                    &alpn_protos, &alpn_protos_len))
-                /* Reversed return value convention... */
-                || !TEST_int_eq(SSL_CTX_set_alpn_protos(client_ctx, alpn_protos,
-                                                        alpn_protos_len), 0))
+                &alpn_protos, &alpn_protos_len))
+            /* Reversed return value convention... */
+            || !TEST_int_eq(SSL_CTX_set_alpn_protos(client_ctx, alpn_protos,
+                                alpn_protos_len),
+                0))
             goto err;
         OPENSSL_free(alpn_protos);
     }
 
     if (extra->server.session_ticket_app_data != NULL) {
-        server_ctx_data->session_ticket_app_data =
-            OPENSSL_strdup(extra->server.session_ticket_app_data);
+        server_ctx_data->session_ticket_app_data = OPENSSL_strdup(extra->server.session_ticket_app_data);
         if (!TEST_ptr(server_ctx_data->session_ticket_app_data))
             goto err;
         SSL_CTX_set_session_ticket_cb(server_ctx, generate_session_ticket_cb,
-                                      decrypt_session_ticket_cb, server_ctx_data);
+            decrypt_session_ticket_cb, server_ctx_data);
     }
     if (extra->server2.session_ticket_app_data != NULL) {
         if (!TEST_ptr(server2_ctx))
             goto err;
-        server2_ctx_data->session_ticket_app_data =
-            OPENSSL_strdup(extra->server2.session_ticket_app_data);
+        server2_ctx_data->session_ticket_app_data = OPENSSL_strdup(extra->server2.session_ticket_app_data);
         if (!TEST_ptr(server2_ctx_data->session_ticket_app_data))
             goto err;
         SSL_CTX_set_session_ticket_cb(server2_ctx, NULL,
-                                      decrypt_session_ticket_cb, server2_ctx_data);
+            decrypt_session_ticket_cb, server2_ctx_data);
     }
 
     /*
@@ -670,9 +667,10 @@ static int configure_handshake_ctx(SSL_CTX *server_ctx, SSL_CTX *server2_ctx,
      */
     ticket_key_len = SSL_CTX_set_tlsext_ticket_keys(server_ctx, NULL, 0);
     if (!TEST_ptr(ticket_keys = OPENSSL_zalloc(ticket_key_len))
-            || !TEST_int_eq(SSL_CTX_set_tlsext_ticket_keys(server_ctx,
-                                                           ticket_keys,
-                                                           ticket_key_len), 1)) {
+        || !TEST_int_eq(SSL_CTX_set_tlsext_ticket_keys(server_ctx,
+                            ticket_keys,
+                            ticket_key_len),
+            1)) {
         OPENSSL_free(ticket_keys);
         goto err;
     }
@@ -685,7 +683,7 @@ static int configure_handshake_ctx(SSL_CTX *server_ctx, SSL_CTX *server2_ctx,
     switch (extra->client.ct_validation) {
     case SSL_TEST_CT_VALIDATION_PERMISSIVE:
         if (!TEST_true(SSL_CTX_enable_ct(client_ctx,
-                                         SSL_CT_VALIDATION_PERMISSIVE)))
+                SSL_CT_VALIDATION_PERMISSIVE)))
             goto err;
         break;
     case SSL_TEST_CT_VALIDATION_STRICT:
@@ -698,10 +696,10 @@ static int configure_handshake_ctx(SSL_CTX *server_ctx, SSL_CTX *server2_ctx,
 #endif
 #ifndef OPENSSL_NO_SRP
     if (!configure_handshake_ctx_for_srp(server_ctx, server2_ctx, client_ctx,
-                                         extra, server_ctx_data,
-                                         server2_ctx_data, client_ctx_data))
+            extra, server_ctx_data,
+            server2_ctx_data, client_ctx_data))
         goto err;
-#endif  /* !OPENSSL_NO_SRP */
+#endif /* !OPENSSL_NO_SRP */
 #ifndef OPENSSL_NO_COMP_ALG
     if (test->compress_certificates) {
         if (!TEST_true(SSL_CTX_compress_certs(server_ctx, 0)))
@@ -717,11 +715,11 @@ err:
 
 /* Configure per-SSL callbacks and other properties. */
 static void configure_handshake_ssl(SSL *server, SSL *client,
-                                    const SSL_TEST_EXTRA_CONF *extra)
+    const SSL_TEST_EXTRA_CONF *extra)
 {
     if (extra->client.servername != SSL_TEST_SERVERNAME_NONE)
         SSL_set_tlsext_host_name(client,
-                                 ssl_servername_name(extra->client.servername));
+            ssl_servername_name(extra->client.servername));
     if (extra->client.enable_pha)
         SSL_set_post_handshake_auth(client, 1);
 }
@@ -755,8 +753,8 @@ static int create_peer(PEER *peer, SSL_CTX *ctx)
     unsigned char *read_buf = NULL, *write_buf = NULL;
 
     if (!TEST_ptr(ssl = SSL_new(ctx))
-            || !TEST_ptr(write_buf = OPENSSL_zalloc(peer_buffer_size))
-            || !TEST_ptr(read_buf = OPENSSL_zalloc(peer_buffer_size)))
+        || !TEST_ptr(write_buf = OPENSSL_zalloc(peer_buffer_size))
+        || !TEST_ptr(read_buf = OPENSSL_zalloc(peer_buffer_size)))
         goto err;
 
     peer->ssl = ssl;
@@ -798,7 +796,7 @@ static void do_handshake_step(PEER *peer)
 
             /* Memory bios should never block with SSL_ERROR_WANT_WRITE. */
             if (error != SSL_ERROR_WANT_READ
-                    && error != SSL_ERROR_WANT_RETRY_VERIFY)
+                && error != SSL_ERROR_WANT_RETRY_VERIFY)
                 peer->status = PEER_ERROR;
         }
     }
@@ -844,8 +842,7 @@ static void do_app_data_step(PEER *peer)
     }
 
     /* ... but we only write one write-buffer-full of data. */
-    write_bytes = peer->bytes_to_write < peer->write_buf_len ? peer->bytes_to_write :
-        peer->write_buf_len;
+    write_bytes = peer->bytes_to_write < peer->write_buf_len ? peer->bytes_to_write : peer->write_buf_len;
     if (write_bytes) {
         ret = SSL_write(peer->ssl, peer->write_buf, write_bytes);
         if (ret > 0) {
@@ -893,16 +890,16 @@ static void do_reneg_setup_step(const SSL_TEST_CTX *test_ctx, PEER *peer)
     }
 
     if (!TEST_int_eq(peer->status, PEER_RETRY)
-            || !TEST_true(test_ctx->handshake_mode
-                              == SSL_TEST_HANDSHAKE_RENEG_SERVER
-                          || test_ctx->handshake_mode
-                              == SSL_TEST_HANDSHAKE_RENEG_CLIENT
-                          || test_ctx->handshake_mode
-                              == SSL_TEST_HANDSHAKE_KEY_UPDATE_SERVER
-                          || test_ctx->handshake_mode
-                              == SSL_TEST_HANDSHAKE_KEY_UPDATE_CLIENT
-                          || test_ctx->handshake_mode
-                              == SSL_TEST_HANDSHAKE_POST_HANDSHAKE_AUTH)) {
+        || !TEST_true(test_ctx->handshake_mode
+                == SSL_TEST_HANDSHAKE_RENEG_SERVER
+            || test_ctx->handshake_mode
+                == SSL_TEST_HANDSHAKE_RENEG_CLIENT
+            || test_ctx->handshake_mode
+                == SSL_TEST_HANDSHAKE_KEY_UPDATE_SERVER
+            || test_ctx->handshake_mode
+                == SSL_TEST_HANDSHAKE_KEY_UPDATE_CLIENT
+            || test_ctx->handshake_mode
+                == SSL_TEST_HANDSHAKE_POST_HANDSHAKE_AUTH)) {
         peer->status = PEER_TEST_FAILURE;
         return;
     }
@@ -912,9 +909,9 @@ static void do_reneg_setup_step(const SSL_TEST_CTX *test_ctx, PEER *peer)
 
     /* Check if we are the peer that is going to initiate */
     if ((test_ctx->handshake_mode == SSL_TEST_HANDSHAKE_RENEG_SERVER
-                && SSL_is_server(peer->ssl))
-            || (test_ctx->handshake_mode == SSL_TEST_HANDSHAKE_RENEG_CLIENT
-                && !SSL_is_server(peer->ssl))) {
+            && SSL_is_server(peer->ssl))
+        || (test_ctx->handshake_mode == SSL_TEST_HANDSHAKE_RENEG_CLIENT
+            && !SSL_is_server(peer->ssl))) {
         /*
          * If we already asked for a renegotiation then fall through to the
          * SSL_read() below.
@@ -936,7 +933,7 @@ static void do_reneg_setup_step(const SSL_TEST_CTX *test_ctx, PEER *peer)
                 }
                 if (test_ctx->extra.client.reneg_ciphers != NULL) {
                     if (!SSL_set_cipher_list(peer->ssl,
-                                test_ctx->extra.client.reneg_ciphers)) {
+                            test_ctx->extra.client.reneg_ciphers)) {
                         peer->status = PEER_ERROR;
                         return;
                     }
@@ -969,11 +966,11 @@ static void do_reneg_setup_step(const SSL_TEST_CTX *test_ctx, PEER *peer)
             return;
         }
     } else if (test_ctx->handshake_mode == SSL_TEST_HANDSHAKE_KEY_UPDATE_SERVER
-               || test_ctx->handshake_mode
-                  == SSL_TEST_HANDSHAKE_KEY_UPDATE_CLIENT) {
+        || test_ctx->handshake_mode
+            == SSL_TEST_HANDSHAKE_KEY_UPDATE_CLIENT) {
         if (SSL_is_server(peer->ssl)
-                != (test_ctx->handshake_mode
-                    == SSL_TEST_HANDSHAKE_KEY_UPDATE_SERVER)) {
+            != (test_ctx->handshake_mode
+                == SSL_TEST_HANDSHAKE_KEY_UPDATE_SERVER)) {
             peer->status = PEER_SUCCESS;
             return;
         }
@@ -1045,7 +1042,6 @@ static void do_reneg_setup_step(const SSL_TEST_CTX *test_ctx, PEER *peer)
     peer->status = PEER_SUCCESS;
 }
 
-
 /*
  * RFC 5246 says:
  *
@@ -1091,7 +1087,6 @@ typedef enum {
     CONNECTION_DONE
 } connect_phase_t;
 
-
 static int renegotiate_op(const SSL_TEST_CTX *test_ctx)
 {
     switch (test_ctx->handshake_mode) {
@@ -1115,7 +1110,7 @@ static int post_handshake_op(const SSL_TEST_CTX *test_ctx)
 }
 
 static connect_phase_t next_phase(const SSL_TEST_CTX *test_ctx,
-                                  connect_phase_t phase)
+    connect_phase_t phase)
 {
     switch (phase) {
     case HANDSHAKE:
@@ -1142,7 +1137,7 @@ static connect_phase_t next_phase(const SSL_TEST_CTX *test_ctx,
 }
 
 static void do_connect_step(const SSL_TEST_CTX *test_ctx, PEER *peer,
-                            connect_phase_t phase)
+    connect_phase_t phase)
 {
     switch (phase) {
     case HANDSHAKE:
@@ -1189,8 +1184,8 @@ typedef enum {
  * client_spoke_last: 1 if the client went last.
  */
 static handshake_status_t handshake_status(peer_status_t last_status,
-                                           peer_status_t previous_status,
-                                           int client_spoke_last)
+    peer_status_t previous_status,
+    int client_spoke_last)
 {
     switch (last_status) {
     case PEER_TEST_FAILURE:
@@ -1254,8 +1249,8 @@ static char *dup_str(const unsigned char *in, size_t len)
         return NULL;
 
     /* Assert that the string does not contain NUL-bytes. */
-    if (TEST_size_t_eq(OPENSSL_strnlen((const char*)(in), len), len))
-        TEST_ptr(ret = OPENSSL_strndup((const char*)(in), len));
+    if (TEST_size_t_eq(OPENSSL_strnlen((const char *)(in), len), len))
+        TEST_ptr(ret = OPENSSL_strndup((const char *)(in), len));
     return ret;
 }
 
@@ -1297,12 +1292,12 @@ static int set_sock_as_sctp(int sock)
     rto_info.srto_max = 200;
     rto_info.srto_min = 50;
     (void)setsockopt(sock, IPPROTO_SCTP, SCTP_RTOINFO,
-                     (const void *)&rto_info, sizeof(struct sctp_rtoinfo));
+        (const void *)&rto_info, sizeof(struct sctp_rtoinfo));
     memset(&assocparams, 0, sizeof(struct sctp_assocparams));
     assocparams.sasoc_asocmaxrxt = 2;
     (void)setsockopt(sock, IPPROTO_SCTP, SCTP_ASSOCINFO,
-                     (const void *)&assocparams,
-                     sizeof(struct sctp_assocparams));
+        (const void *)&assocparams,
+        sizeof(struct sctp_assocparams));
 
     /*
      * For SCTP we have to set various options on the socket prior to
@@ -1337,7 +1332,7 @@ static int create_sctp_socks(int *ssock, int *csock)
      * worry about it here.
      */
     if (!BIO_lookup_ex(NULL, "4463", BIO_LOOKUP_SERVER, family, SOCK_STREAM,
-                       IPPROTO_SCTP, &res))
+            IPPROTO_SCTP, &res))
         return 0;
 
     for (ai = res; ai != NULL; ai = BIO_ADDRINFO_next(ai)) {
@@ -1351,8 +1346,8 @@ static int create_sctp_socks(int *ssock, int *csock)
         }
 
         if (!set_sock_as_sctp(lsock)
-                || !BIO_listen(lsock, BIO_ADDRINFO_address(ai),
-                               BIO_SOCK_REUSEADDR)) {
+            || !BIO_listen(lsock, BIO_ADDRINFO_address(ai),
+                BIO_SOCK_REUSEADDR)) {
             BIO_closesocket(lsock);
             lsock = INVALID_SOCKET;
             continue;
@@ -1369,7 +1364,7 @@ static int create_sctp_socks(int *ssock, int *csock)
     res = NULL;
 
     if (!BIO_lookup_ex(NULL, "4463", BIO_LOOKUP_CLIENT, family, SOCK_STREAM,
-                        IPPROTO_SCTP, &res))
+            IPPROTO_SCTP, &res))
         goto err;
 
     consock = BIO_socket(family, SOCK_STREAM, IPPROTO_SCTP, 0);
@@ -1377,8 +1372,8 @@ static int create_sctp_socks(int *ssock, int *csock)
         goto err;
 
     if (!set_sock_as_sctp(consock)
-            || !BIO_connect(consock, BIO_ADDRINFO_address(res), 0)
-            || !BIO_socket_nbio(consock, 1))
+        || !BIO_connect(consock, BIO_ADDRINFO_address(res), 0)
+        || !BIO_socket_nbio(consock, 1))
         goto err;
 
     asock = BIO_accept_ex(lsock, NULL, BIO_SOCK_NONBLOCK);
@@ -1390,7 +1385,7 @@ static int create_sctp_socks(int *ssock, int *csock)
     consock = asock = INVALID_SOCKET;
     ret = 1;
 
- err:
+err:
     BIO_ADDRINFO_free(res);
     if (consock != INVALID_SOCKET)
         BIO_closesocket(consock);
@@ -1429,18 +1424,18 @@ static HANDSHAKE_RESULT *do_handshake_internal(
     int client_turn = 1, client_turn_count = 0, client_wait_count = 0;
     connect_phase_t phase = HANDSHAKE;
     handshake_status_t status = HANDSHAKE_RETRY;
-    const unsigned char* tick = NULL;
+    const unsigned char *tick = NULL;
     size_t tick_len = 0;
-    const unsigned char* sess_id = NULL;
+    const unsigned char *sess_id = NULL;
     unsigned int sess_id_len = 0;
-    SSL_SESSION* sess = NULL;
+    SSL_SESSION *sess = NULL;
     const unsigned char *proto = NULL;
     /* API dictates unsigned int rather than size_t. */
     unsigned int proto_len = 0;
     EVP_PKEY *tmp_key;
     const STACK_OF(X509_NAME) *names;
     time_t start;
-    const char* cipher;
+    const char *cipher;
 
     if (ret == NULL)
         return NULL;
@@ -1454,8 +1449,8 @@ static HANDSHAKE_RESULT *do_handshake_internal(
     memset(&client_ex_data, 0, sizeof(client_ex_data));
 
     if (!configure_handshake_ctx(server_ctx, server2_ctx, client_ctx,
-                                 test_ctx, extra, &server_ctx_data,
-                                 &server2_ctx_data, &client_ctx_data)) {
+            test_ctx, extra, &server_ctx_data,
+            &server2_ctx_data, &client_ctx_data)) {
         TEST_note("configure_handshake_ctx");
         HANDSHAKE_RESULT_free(ret);
         return NULL;
@@ -1486,9 +1481,9 @@ static HANDSHAKE_RESULT *do_handshake_internal(
         SSL_SESSION_get_id(serv_sess_in, &sess_id_len);
         /* In case we're testing resumption without tickets. */
         if ((sess_id_len > 0
-                    && !TEST_true(SSL_CTX_add_session(server_ctx,
-                                                      serv_sess_in)))
-                || !TEST_true(SSL_set_session(client.ssl, session_in)))
+                && !TEST_true(SSL_CTX_add_session(server_ctx,
+                    serv_sess_in)))
+            || !TEST_true(SSL_set_session(client.ssl, session_in)))
             goto err;
         sess_id_len = 0;
     }
@@ -1510,7 +1505,7 @@ static HANDSHAKE_RESULT *do_handshake_internal(
     }
 
     if (!TEST_ptr(client_to_server)
-            || !TEST_ptr(server_to_client))
+        || !TEST_ptr(server_to_client))
         goto err;
 
     /* Non-blocking bio. */
@@ -1527,15 +1522,15 @@ static HANDSHAKE_RESULT *do_handshake_internal(
     } else {
         SSL_set_bio(client.ssl, server_to_client, client_to_server);
         if (!TEST_int_gt(BIO_up_ref(server_to_client), 0)
-                || !TEST_int_gt(BIO_up_ref(client_to_server), 0))
+            || !TEST_int_gt(BIO_up_ref(client_to_server), 0))
             goto err;
         SSL_set_bio(server.ssl, client_to_server, server_to_client);
     }
 
     ex_data_idx = SSL_get_ex_new_index(0, "ex data", NULL, NULL, NULL);
     if (!TEST_int_ge(ex_data_idx, 0)
-            || !TEST_int_eq(SSL_set_ex_data(server.ssl, ex_data_idx, &server_ex_data), 1)
-            || !TEST_int_eq(SSL_set_ex_data(client.ssl, ex_data_idx, &client_ex_data), 1))
+        || !TEST_int_eq(SSL_set_ex_data(server.ssl, ex_data_idx, &server_ex_data), 1)
+        || !TEST_int_eq(SSL_set_ex_data(client.ssl, ex_data_idx, &client_ex_data), 1))
         goto err;
 
     SSL_set_info_callback(server.ssl, &info_cb);
@@ -1558,13 +1553,13 @@ static HANDSHAKE_RESULT *do_handshake_internal(
         if (client_turn) {
             do_connect_step(test_ctx, &client, phase);
             status = handshake_status(client.status, server.status,
-                                      1 /* client went last */);
+                1 /* client went last */);
             if (server.status == PEER_WAITING)
                 server.status = PEER_RETRY;
         } else {
             do_connect_step(test_ctx, &server, phase);
             status = handshake_status(server.status, client.status,
-                                      0 /* server went last */);
+                0 /* server went last */);
         }
 
         switch (status) {
@@ -1609,7 +1604,7 @@ static HANDSHAKE_RESULT *do_handshake_internal(
                  * same endpoint again.
                  */
                 if ((client_turn && server.status == PEER_RETRY)
-                        || (!client_turn && client.status == PEER_RETRY))
+                    || (!client_turn && client.status == PEER_RETRY))
                     client_turn ^= 1;
             } else {
                 if (client_turn_count++ >= 2000) {
@@ -1638,7 +1633,7 @@ static HANDSHAKE_RESULT *do_handshake_internal(
             break;
         }
     }
- err:
+err:
     ret->server_alert_sent = server_ex_data.alert_sent;
     ret->server_num_fatal_alerts_sent = server_ex_data.num_fatal_alerts_sent;
     ret->server_alert_received = client_ex_data.alert_received;
@@ -1657,8 +1652,8 @@ static HANDSHAKE_RESULT *do_handshake_internal(
     else
         ret->session_ticket = SSL_TEST_SESSION_TICKET_YES;
     ret->compression = (SSL_get_current_compression(client.ssl) == NULL)
-                       ? SSL_TEST_COMPRESSION_NO
-                       : SSL_TEST_COMPRESSION_YES;
+        ? SSL_TEST_COMPRESSION_NO
+        : SSL_TEST_COMPRESSION_YES;
     if (sess_id == NULL || sess_id_len == 0)
         ret->session_id = SSL_TEST_SESSION_ID_NO;
     else
@@ -1666,7 +1661,7 @@ static HANDSHAKE_RESULT *do_handshake_internal(
     ret->session_ticket_do_not_call = server_ex_data.session_ticket_do_not_call;
 
     if (extra->client.verify_callback == SSL_TEST_VERIFY_RETRY_ONCE
-            && n_retries != -1)
+        && n_retries != -1)
         ret->result = SSL_TEST_SERVER_FAIL;
 
 #ifndef OPENSSL_NO_NEXTPROTONEG
@@ -1684,15 +1679,15 @@ static HANDSHAKE_RESULT *do_handshake_internal(
     ret->server_alpn_negotiated = dup_str(proto, proto_len);
 
     if ((sess = SSL_get0_session(server.ssl)) != NULL) {
-        SSL_SESSION_get0_ticket_appdata(sess, (void**)&tick, &tick_len);
-        ret->result_session_ticket_app_data = OPENSSL_strndup((const char*)tick, tick_len);
+        SSL_SESSION_get0_ticket_appdata(sess, (void **)&tick, &tick_len);
+        ret->result_session_ticket_app_data = OPENSSL_strndup((const char *)tick, tick_len);
     }
 
     ret->client_resumed = SSL_session_reused(client.ssl);
     ret->server_resumed = SSL_session_reused(server.ssl);
 
     cipher = SSL_CIPHER_get_name(SSL_get_current_cipher(client.ssl));
-    ret->cipher = dup_str((const unsigned char*)cipher, strlen(cipher));
+    ret->cipher = dup_str((const unsigned char *)cipher, strlen(cipher));
 
     if (session_out != NULL)
         *session_out = SSL_get1_session(client.ssl);
@@ -1743,19 +1738,19 @@ static HANDSHAKE_RESULT *do_handshake_internal(
 }
 
 HANDSHAKE_RESULT *do_handshake(SSL_CTX *server_ctx, SSL_CTX *server2_ctx,
-                               SSL_CTX *client_ctx, SSL_CTX *resume_server_ctx,
-                               SSL_CTX *resume_client_ctx,
-                               const SSL_TEST_CTX *test_ctx)
+    SSL_CTX *client_ctx, SSL_CTX *resume_server_ctx,
+    SSL_CTX *resume_client_ctx,
+    const SSL_TEST_CTX *test_ctx)
 {
     HANDSHAKE_RESULT *result;
     SSL_SESSION *session = NULL, *serv_sess = NULL;
 
     result = do_handshake_internal(server_ctx, server2_ctx, client_ctx,
-                                   test_ctx, &test_ctx->extra,
-                                   NULL, NULL, &session, &serv_sess);
+        test_ctx, &test_ctx->extra,
+        NULL, NULL, &session, &serv_sess);
     if (result == NULL
-            || test_ctx->handshake_mode != SSL_TEST_HANDSHAKE_RESUME
-            || result->result == SSL_TEST_INTERNAL_ERROR)
+        || test_ctx->handshake_mode != SSL_TEST_HANDSHAKE_RESUME
+        || result->result == SSL_TEST_INTERNAL_ERROR)
         goto end;
 
     if (result->result != SSL_TEST_SUCCESS) {
@@ -1766,9 +1761,9 @@ HANDSHAKE_RESULT *do_handshake(SSL_CTX *server_ctx, SSL_CTX *server2_ctx,
     HANDSHAKE_RESULT_free(result);
     /* We don't support SNI on second handshake yet, so server2_ctx is NULL. */
     result = do_handshake_internal(resume_server_ctx, NULL, resume_client_ctx,
-                                   test_ctx, &test_ctx->resume_extra,
-                                   session, serv_sess, NULL, NULL);
- end:
+        test_ctx, &test_ctx->resume_extra,
+        session, serv_sess, NULL, NULL);
+end:
     SSL_SESSION_free(session);
     SSL_SESSION_free(serv_sess);
     return result;
