@@ -15,7 +15,7 @@
 #include "ssltestlib.h"
 #include "../testutil.h"
 #if defined(OPENSSL_THREADS) && !defined(CRYPTO_TDEBUG)
-# include "../threadstest.h"
+#include "../threadstest.h"
 #endif
 #include "internal/quic_ssl.h"
 #include "internal/quic_wire_pkt.h"
@@ -94,8 +94,8 @@ static OSSL_TIME fake_now_cb(void *arg)
 }
 
 static void noise_msg_callback(int write_p, int version, int content_type,
-                               const void *buf, size_t len, SSL *ssl,
-                               void *arg)
+    const void *buf, size_t len, SSL *ssl,
+    void *arg)
 {
     struct noise_args_data_st *noiseargs = (struct noise_args_data_st *)arg;
 
@@ -122,23 +122,23 @@ static void noise_msg_callback(int write_p, int version, int content_type,
 
 #ifndef OPENSSL_NO_SSL_TRACE
     if ((noiseargs->flags & QTEST_FLAG_CLIENT_TRACE) != 0
-            && !SSL_is_server(ssl))
+        && !SSL_is_server(ssl))
         SSL_trace(write_p, version, content_type, buf, len, ssl,
-                  noiseargs->tracebio);
+            noiseargs->tracebio);
 #endif
 }
 
 int qtest_create_quic_objects(OSSL_LIB_CTX *libctx, SSL_CTX *clientctx,
-                              SSL_CTX *serverctx, char *certfile, char *keyfile,
-                              int flags, QUIC_TSERVER **qtserv, SSL **cssl,
-                              QTEST_FAULT **fault, BIO **tracebio)
+    SSL_CTX *serverctx, char *certfile, char *keyfile,
+    int flags, QUIC_TSERVER **qtserv, SSL **cssl,
+    QTEST_FAULT **fault, BIO **tracebio)
 {
     /* ALPN value as recognised by QUIC_TSERVER */
     unsigned char alpn[] = { 8, 'o', 's', 's', 'l', 't', 'e', 's', 't' };
-    QUIC_TSERVER_ARGS tserver_args = {0};
+    QUIC_TSERVER_ARGS tserver_args = { 0 };
     BIO *cbio = NULL, *sbio = NULL, *fisbio = NULL;
     BIO_ADDR *peeraddr = NULL;
-    struct in_addr ina = {0};
+    struct in_addr ina = { 0 };
     BIO *tmpbio = NULL;
     QTEST_DATA *bdata = NULL;
 
@@ -229,14 +229,14 @@ int qtest_create_quic_objects(OSSL_LIB_CTX *libctx, SSL_CTX *clientctx,
             goto err;
 
         if (!TEST_true(BIO_dgram_set_caps(cbio, BIO_DGRAM_CAP_HANDLES_DST_ADDR))
-                || !TEST_true(BIO_dgram_set_caps(sbio, BIO_DGRAM_CAP_HANDLES_DST_ADDR)))
+            || !TEST_true(BIO_dgram_set_caps(sbio, BIO_DGRAM_CAP_HANDLES_DST_ADDR)))
             goto err;
 
         if (!TEST_ptr(localaddr = BIO_ADDR_new()))
             goto err;
         /* Dummy client local addresses */
         if (!TEST_true(BIO_ADDR_rawmake(localaddr, AF_INET, &ina, sizeof(ina),
-                                        htons(0)))) {
+                htons(0)))) {
             BIO_ADDR_free(localaddr);
             goto err;
         }
@@ -246,7 +246,7 @@ int qtest_create_quic_objects(OSSL_LIB_CTX *libctx, SSL_CTX *clientctx,
         }
         /* Dummy server address */
         if (!TEST_true(BIO_ADDR_rawmake(peeraddr, AF_INET, &ina, sizeof(ina),
-                                        htons(0))))
+                htons(0))))
             goto err;
     }
 
@@ -282,7 +282,8 @@ int qtest_create_quic_objects(OSSL_LIB_CTX *libctx, SSL_CTX *clientctx,
         cbio = BIO_push(noisebio, cbio);
         if ((flags & QTEST_FLAG_FAKE_TIME) != 0) {
             if (!TEST_int_eq(BIO_ctrl(cbio, BIO_CTRL_NOISE_SET_NOW_CB,
-                                      0, &now_cb), 1))
+                                 0, &now_cb),
+                    1))
                 goto err;
         }
 
@@ -293,7 +294,8 @@ int qtest_create_quic_objects(OSSL_LIB_CTX *libctx, SSL_CTX *clientctx,
         sbio = BIO_push(noisebio, sbio);
         if ((flags & QTEST_FLAG_FAKE_TIME) != 0) {
             if (!TEST_int_eq(BIO_ctrl(sbio, BIO_CTRL_NOISE_SET_NOW_CB,
-                                      0, &now_cb), 1))
+                                 0, &now_cb),
+                    1))
                 goto err;
         }
 
@@ -311,7 +313,7 @@ int qtest_create_quic_objects(OSSL_LIB_CTX *libctx, SSL_CTX *clientctx,
     SSL_set_bio(*cssl, cbio, cbio);
 
     if (!TEST_true(SSL_set_blocking_mode(*cssl,
-                                         (flags & QTEST_FLAG_BLOCK) != 0 ? 1 : 0)))
+            (flags & QTEST_FLAG_BLOCK) != 0 ? 1 : 0)))
         goto err;
 
     if (!TEST_true(SSL_set1_initial_peer_addr(*cssl, peeraddr)))
@@ -352,7 +354,7 @@ int qtest_create_quic_objects(OSSL_LIB_CTX *libctx, SSL_CTX *clientctx,
     }
 
     if (!TEST_ptr(*qtserv = ossl_quic_tserver_new(&tserver_args, certfile,
-                                                  keyfile)))
+                      keyfile)))
         goto err;
 
     bdata->short_conn_id_len = ossl_quic_tserver_get_short_header_conn_id_len(*qtserv);
@@ -362,7 +364,7 @@ int qtest_create_quic_objects(OSSL_LIB_CTX *libctx, SSL_CTX *clientctx,
 
     if ((flags & QTEST_FLAG_NOISE) != 0)
         ossl_quic_tserver_set_msg_callback(*qtserv, noise_msg_callback,
-                                           &(*fault)->noiseargs);
+            &(*fault)->noiseargs);
 
     if (fault != NULL)
         (*fault)->qtserv = *qtserv;
@@ -370,7 +372,7 @@ int qtest_create_quic_objects(OSSL_LIB_CTX *libctx, SSL_CTX *clientctx,
     BIO_ADDR_free(peeraddr);
 
     return 1;
- err:
+err:
     SSL_CTX_free(tserver_args.ctx);
     BIO_ADDR_free(peeraddr);
     BIO_free_all(cbio);
@@ -438,7 +440,6 @@ QTEST_FAULT *qtest_create_injector(QUIC_TSERVER *ts)
 
     f->qtserv = ts;
     return f;
-
 }
 
 int qtest_supports_blocking(void)
@@ -450,7 +451,7 @@ int qtest_supports_blocking(void)
 #endif
 }
 
-#define MAXLOOPS    1000
+#define MAXLOOPS 1000
 
 #if defined(OPENSSL_THREADS) && !defined(CRYPTO_TDEBUG)
 static int globserverret = 0;
@@ -480,7 +481,7 @@ int qtest_wait_for_timeout(SSL *s, QUIC_TSERVER *qtserv)
 
     /* Don't wait if either BIO has data waiting */
     if (BIO_pending(SSL_get_rbio(s)) > 0
-            || BIO_pending(ossl_quic_tserver_get0_rbio(qtserv)) > 0)
+        || BIO_pending(ossl_quic_tserver_get0_rbio(qtserv)) > 0)
         return 1;
 
     /*
@@ -513,7 +514,7 @@ int qtest_wait_for_timeout(SSL *s, QUIC_TSERVER *qtserv)
 }
 
 int qtest_create_quic_connection_ex(QUIC_TSERVER *qtserv, SSL *clientssl,
-                                    int wanterr)
+    int wanterr)
 {
     int retc = -1, rets = 0, abortctr = 0, ret = 0;
     int clienterr = 0, servererr = 0;
@@ -584,7 +585,7 @@ int qtest_create_quic_connection_ex(QUIC_TSERVER *qtserv, SSL *clientssl,
                         rets = 1;
                 } else {
                     if (err != SSL_ERROR_WANT_READ
-                            && err != SSL_ERROR_WANT_WRITE) {
+                        && err != SSL_ERROR_WANT_WRITE) {
                         TEST_info("SSL_connect() failed %d, %d", retc, err);
                         TEST_openssl_errors();
                         clienterr = 1;
@@ -628,9 +629,9 @@ int qtest_create_quic_connection_ex(QUIC_TSERVER *qtserv, SSL *clientssl,
                 goto err;
         }
     } while ((retc <= 0 && !clienterr)
-             || (rets <= 0 && !servererr
+        || (rets <= 0 && !servererr
 #if defined(OPENSSL_THREADS) && !defined(CRYPTO_TDEBUG)
-                 && !tsan_load(&abortserverthread)
+            && !tsan_load(&abortserverthread)
 #endif
                 ));
 
@@ -654,7 +655,7 @@ int qtest_create_quic_connection_ex(QUIC_TSERVER *qtserv, SSL *clientssl,
 
     if (!clienterr && !servererr)
         ret = 1;
- err:
+err:
     return ret;
 }
 
@@ -675,7 +676,7 @@ static void run_server_shutdown_thread(void)
      */
     do {
         ossl_quic_tserver_tick(globtserv);
-    } while(!tsan_load(&shutdowndone));
+    } while (!tsan_load(&shutdowndone));
 }
 #endif
 
@@ -754,10 +755,10 @@ int qtest_check_server_transport_err(QUIC_TSERVER *qtserv, uint64_t code)
         return 0;
 
     cause = ossl_quic_tserver_get_terminate_cause(qtserv);
-    if  (!TEST_ptr(cause)
-            || !TEST_true(cause->remote)
-            || !TEST_false(cause->app)
-            || !TEST_uint64_t_eq(cause->error_code, code))
+    if (!TEST_ptr(cause)
+        || !TEST_true(cause->remote)
+        || !TEST_false(cause->app)
+        || !TEST_uint64_t_eq(cause->error_code, code))
         return 0;
 
     return 1;
@@ -785,11 +786,11 @@ void qtest_fault_free(QTEST_FAULT *fault)
 }
 
 static int packet_plain_mutate(const QUIC_PKT_HDR *hdrin,
-                               const OSSL_QTX_IOVEC *iovecin, size_t numin,
-                               QUIC_PKT_HDR **hdrout,
-                               const OSSL_QTX_IOVEC **iovecout,
-                               size_t *numout,
-                               void *arg)
+    const OSSL_QTX_IOVEC *iovecin, size_t numin,
+    QUIC_PKT_HDR **hdrout,
+    const OSSL_QTX_IOVEC **iovecout,
+    size_t *numout,
+    void *arg)
 {
     QTEST_FAULT *fault = arg;
     size_t i, bufsz = 0;
@@ -841,8 +842,8 @@ static int packet_plain_mutate(const QUIC_PKT_HDR *hdrin,
      */
     if (fault->pplaincb != NULL)
         fault->pplaincb(fault, &fault->pplainhdr,
-                        (unsigned char *)fault->pplainio.buf,
-                        fault->pplainio.buf_len, fault->pplaincbarg);
+            (unsigned char *)fault->pplainio.buf,
+            fault->pplainio.buf_len, fault->pplaincbarg);
 
     *hdrout = &fault->pplainhdr;
     *iovecout = &fault->pplainio;
@@ -863,16 +864,16 @@ static void packet_plain_finish(void *arg)
 }
 
 int qtest_fault_set_packet_plain_listener(QTEST_FAULT *fault,
-                                          qtest_fault_on_packet_plain_cb pplaincb,
-                                          void *pplaincbarg)
+    qtest_fault_on_packet_plain_cb pplaincb,
+    void *pplaincbarg)
 {
     fault->pplaincb = pplaincb;
     fault->pplaincbarg = pplaincbarg;
 
     return ossl_quic_tserver_set_plain_packet_mutator(fault->qtserv,
-                                                      packet_plain_mutate,
-                                                      packet_plain_finish,
-                                                      fault);
+        packet_plain_mutate,
+        packet_plain_finish,
+        fault);
 }
 
 /* To be called from a packet_plain_listener callback */
@@ -912,7 +913,7 @@ int qtest_fault_resize_plain_packet(QTEST_FAULT *fault, size_t newlen)
  * callback
  */
 int qtest_fault_prepend_frame(QTEST_FAULT *fault, const unsigned char *frame,
-                              size_t frame_len)
+    size_t frame_len)
 {
     unsigned char *buf;
     size_t old_len;
@@ -930,7 +931,7 @@ int qtest_fault_prepend_frame(QTEST_FAULT *fault, const unsigned char *frame,
 
     /* Extend the size of the packet by the size of the new frame */
     if (!TEST_true(qtest_fault_resize_plain_packet(fault,
-                                                   old_len + frame_len)))
+            old_len + frame_len)))
         return 0;
 
     memmove(buf + frame_len, buf, old_len);
@@ -940,8 +941,8 @@ int qtest_fault_prepend_frame(QTEST_FAULT *fault, const unsigned char *frame,
 }
 
 static int handshake_mutate(const unsigned char *msgin, size_t msginlen,
-                            unsigned char **msgout, size_t *msgoutlen,
-                            void *arg)
+    unsigned char **msgout, size_t *msgoutlen,
+    void *arg)
 {
     QTEST_FAULT *fault = arg;
     unsigned char *buf;
@@ -959,15 +960,14 @@ static int handshake_mutate(const unsigned char *msgin, size_t msginlen,
     memcpy(buf, msgin, msginlen);
 
     if (!PACKET_buf_init(&pkt, buf, msginlen)
-            || !PACKET_get_1(&pkt, &msgtype)
-            || !PACKET_get_net_3(&pkt, &payloadlen)
-            || PACKET_remaining(&pkt) != payloadlen)
+        || !PACKET_get_1(&pkt, &msgtype)
+        || !PACKET_get_net_3(&pkt, &payloadlen)
+        || PACKET_remaining(&pkt) != payloadlen)
         return 0;
 
     /* Parse specific message types */
     switch (msgtype) {
-    case SSL3_MT_ENCRYPTED_EXTENSIONS:
-    {
+    case SSL3_MT_ENCRYPTED_EXTENSIONS: {
         QTEST_ENCRYPTED_EXTENSIONS ee;
 
         if (fault->encextcb == NULL)
@@ -989,8 +989,8 @@ static int handshake_mutate(const unsigned char *msgin, size_t msginlen,
     }
 
     if (fault->handshakecb != NULL
-            && !fault->handshakecb(fault, buf, fault->handbuflen,
-                                   fault->handshakecbarg))
+        && !fault->handshakecb(fault, buf, fault->handbuflen,
+            fault->handshakecbarg))
         return 0;
 
     *msgout = buf;
@@ -1008,29 +1008,29 @@ static void handshake_finish(void *arg)
 }
 
 int qtest_fault_set_handshake_listener(QTEST_FAULT *fault,
-                                       qtest_fault_on_handshake_cb handshakecb,
-                                       void *handshakecbarg)
+    qtest_fault_on_handshake_cb handshakecb,
+    void *handshakecbarg)
 {
     fault->handshakecb = handshakecb;
     fault->handshakecbarg = handshakecbarg;
 
     return ossl_quic_tserver_set_handshake_mutator(fault->qtserv,
-                                                   handshake_mutate,
-                                                   handshake_finish,
-                                                   fault);
+        handshake_mutate,
+        handshake_finish,
+        fault);
 }
 
 int qtest_fault_set_hand_enc_ext_listener(QTEST_FAULT *fault,
-                                          qtest_fault_on_enc_ext_cb encextcb,
-                                          void *encextcbarg)
+    qtest_fault_on_enc_ext_cb encextcb,
+    void *encextcbarg)
 {
     fault->encextcb = encextcb;
     fault->encextcbarg = encextcbarg;
 
     return ossl_quic_tserver_set_handshake_mutator(fault->qtserv,
-                                                   handshake_mutate,
-                                                   handshake_finish,
-                                                   fault);
+        handshake_mutate,
+        handshake_finish,
+        fault);
 }
 
 /* To be called from a handshake_listener callback */
@@ -1071,16 +1071,16 @@ int qtest_fault_resize_message(QTEST_FAULT *fault, size_t newlen)
 
     /* Fixup the handshake message header */
     fault->handbuf[1] = (unsigned char)((newlen >> 16) & 0xff);
-    fault->handbuf[2] = (unsigned char)((newlen >>  8) & 0xff);
-    fault->handbuf[3] = (unsigned char)((newlen      ) & 0xff);
+    fault->handbuf[2] = (unsigned char)((newlen >> 8) & 0xff);
+    fault->handbuf[3] = (unsigned char)((newlen) & 0xff);
 
     return 1;
 }
 
 int qtest_fault_delete_extension(QTEST_FAULT *fault,
-                                 unsigned int exttype, unsigned char *ext,
-                                 size_t *extlen,
-                                 BUF_MEM *old_ext)
+    unsigned int exttype, unsigned char *ext,
+    size_t *extlen,
+    BUF_MEM *old_ext)
 {
     PACKET pkt, sub, subext;
     WPACKET old_ext_wpkt;
@@ -1099,7 +1099,7 @@ int qtest_fault_delete_extension(QTEST_FAULT *fault,
     do {
         start = PACKET_data(&sub);
         if (!PACKET_get_net_2(&sub, &type)
-                || !PACKET_get_length_prefixed_2(&sub, &subext))
+            || !PACKET_get_length_prefixed_2(&sub, &subext))
             return 0;
     } while (type != exttype);
 
@@ -1111,7 +1111,7 @@ int qtest_fault_delete_extension(QTEST_FAULT *fault,
             return 0;
 
         if (!WPACKET_memcpy(&old_ext_wpkt, PACKET_data(&subext),
-                            PACKET_remaining(&subext))
+                PACKET_remaining(&subext))
             || !WPACKET_get_total_written(&old_ext_wpkt, &w)) {
             WPACKET_cleanup(&old_ext_wpkt);
             return 0;
@@ -1139,7 +1139,7 @@ int qtest_fault_delete_extension(QTEST_FAULT *fault,
 
     /* Fixup the length bytes for the extension block */
     ext[0] = (unsigned char)((newlen >> 8) & 0xff);
-    ext[1] = (unsigned char)((newlen     ) & 0xff);
+    ext[1] = (unsigned char)((newlen) & 0xff);
 
     /*
      * Length of the whole extension block is the new payload length plus the
@@ -1157,15 +1157,15 @@ int qtest_fault_delete_extension(QTEST_FAULT *fault,
     return 1;
 }
 
-#define BIO_TYPE_CIPHER_PACKET_FILTER  (0x80 | BIO_TYPE_FILTER)
+#define BIO_TYPE_CIPHER_PACKET_FILTER (0x80 | BIO_TYPE_FILTER)
 
 static BIO_METHOD *pcipherbiometh = NULL;
 
-# define BIO_MSG_N(array, stride, n) (*(BIO_MSG *)((char *)(array) + (n)*(stride)))
+#define BIO_MSG_N(array, stride, n) (*(BIO_MSG *)((char *)(array) + (n) * (stride)))
 
 static int pcipher_sendmmsg(BIO *b, BIO_MSG *msg, size_t stride,
-                            size_t num_msg, uint64_t flags,
-                            size_t *num_processed)
+    size_t num_msg, uint64_t flags,
+    size_t *num_processed)
 {
     BIO *next = BIO_next(b);
     ossl_ssize_t ret = 0;
@@ -1180,7 +1180,7 @@ static int pcipher_sendmmsg(BIO *b, BIO_MSG *msg, size_t stride,
 
     bdata = BIO_get_data(b);
     if (bdata == NULL || bdata->fault == NULL
-            || (bdata->fault->pciphercb == NULL && bdata->fault->datagramcb == NULL))
+        || (bdata->fault->pciphercb == NULL && bdata->fault->datagramcb == NULL))
         return BIO_sendmmsg(next, msg, stride, num_msg, flags, num_processed);
 
     if (num_msg == 0) {
@@ -1205,8 +1205,8 @@ static int pcipher_sendmmsg(BIO *b, BIO_MSG *msg, size_t stride,
 
             do {
                 if (!ossl_quic_wire_decode_pkt_hdr(&pkt,
-                                                   bdata->short_conn_id_len,
-                                                   1, 0, &hdr, NULL, NULL))
+                        bdata->short_conn_id_len,
+                        1, 0, &hdr, NULL, NULL))
                     goto out;
 
                 /*
@@ -1214,8 +1214,8 @@ static int pcipher_sendmmsg(BIO *b, BIO_MSG *msg, size_t stride,
                  * const is safe
                  */
                 if (!bdata->fault->pciphercb(bdata->fault, &hdr,
-                                             (unsigned char *)hdr.data, hdr.len,
-                                             bdata->fault->pciphercbarg))
+                        (unsigned char *)hdr.data, hdr.len,
+                        bdata->fault->pciphercbarg))
                     goto out;
 
                 /*
@@ -1229,8 +1229,8 @@ static int pcipher_sendmmsg(BIO *b, BIO_MSG *msg, size_t stride,
         }
 
         if (bdata->fault->datagramcb != NULL
-                && !bdata->fault->datagramcb(bdata->fault, &bdata->fault->msg, stride,
-                                             bdata->fault->datagramcbarg))
+            && !bdata->fault->datagramcb(bdata->fault, &bdata->fault->msg, stride,
+                bdata->fault->datagramcbarg))
             goto out;
 
         if (!BIO_sendmmsg(next, &bdata->fault->msg, stride, 1, flags, &tmpnump)) {
@@ -1280,20 +1280,20 @@ BIO_METHOD *qtest_get_bio_method(void)
         return NULL;
 
     if (!TEST_true(BIO_meth_set_sendmmsg(tmp, pcipher_sendmmsg))
-            || !TEST_true(BIO_meth_set_ctrl(tmp, pcipher_ctrl))
-            || !TEST_true(BIO_meth_set_destroy(tmp, pcipher_destroy)))
+        || !TEST_true(BIO_meth_set_ctrl(tmp, pcipher_ctrl))
+        || !TEST_true(BIO_meth_set_destroy(tmp, pcipher_destroy)))
         goto err;
 
     pcipherbiometh = tmp;
     tmp = NULL;
- err:
+err:
     BIO_meth_free(tmp);
     return pcipherbiometh;
 }
 
 int qtest_fault_set_packet_cipher_listener(QTEST_FAULT *fault,
-                                           qtest_fault_on_packet_cipher_cb pciphercb,
-                                           void *pciphercbarg)
+    qtest_fault_on_packet_cipher_cb pciphercb,
+    void *pciphercbarg)
 {
     fault->pciphercb = pciphercb;
     fault->pciphercbarg = pciphercbarg;
@@ -1302,8 +1302,8 @@ int qtest_fault_set_packet_cipher_listener(QTEST_FAULT *fault,
 }
 
 int qtest_fault_set_datagram_listener(QTEST_FAULT *fault,
-                                      qtest_fault_on_datagram_cb datagramcb,
-                                      void *datagramcbarg)
+    qtest_fault_on_datagram_cb datagramcb,
+    void *datagramcbarg)
 {
     fault->datagramcb = datagramcb;
     fault->datagramcbarg = datagramcbarg;
@@ -1315,11 +1315,11 @@ int qtest_fault_set_datagram_listener(QTEST_FAULT *fault,
 int qtest_fault_resize_datagram(QTEST_FAULT *fault, size_t newlen)
 {
     if (newlen > fault->msgalloc)
-            return 0;
+        return 0;
 
     if (newlen > fault->msg.data_len)
         memset((unsigned char *)fault->msg.data + fault->msg.data_len, 0,
-                newlen - fault->msg.data_len);
+            newlen - fault->msg.data_len);
 
     fault->msg.data_len = newlen;
 
@@ -1327,8 +1327,8 @@ int qtest_fault_resize_datagram(QTEST_FAULT *fault, size_t newlen)
 }
 
 int qtest_fault_set_bw_limit(QTEST_FAULT *fault,
-                             size_t ctos_bw, size_t stoc_bw,
-                             int noise_rate)
+    size_t ctos_bw, size_t stoc_bw,
+    int noise_rate)
 {
     BIO *sbio = fault->noiseargs.sbio;
     BIO *cbio = fault->noiseargs.cbio;
@@ -1341,15 +1341,16 @@ int qtest_fault_set_bw_limit(QTEST_FAULT *fault,
         return 0;
     /* We set the bandwidth limit on the sending side */
     if (!TEST_int_eq(BIO_ctrl(cbio, BIO_CTRL_NOISE_SEND_BANDWIDTH,
-                              (long)ctos_bw, NULL), 1))
+                         (long)ctos_bw, NULL),
+            1))
         return 0;
     if (!TEST_int_eq(BIO_ctrl(sbio, BIO_CTRL_NOISE_SEND_BANDWIDTH,
-                              (long)stoc_bw, NULL), 1))
+                         (long)stoc_bw, NULL),
+            1))
         return 0;
     return 1;
 }
 
-
 int bio_msg_copy(BIO_MSG *dst, BIO_MSG *src)
 {
     /*
