@@ -25,8 +25,7 @@ static int parse_boolean(const char *value, int *result)
     if (OPENSSL_strcasecmp(value, "Yes") == 0) {
         *result = 1;
         return 1;
-    }
-    else if (OPENSSL_strcasecmp(value, "No") == 0) {
+    } else if (OPENSSL_strcasecmp(value, "No") == 0) {
         *result = 0;
         return 1;
     }
@@ -34,25 +33,25 @@ static int parse_boolean(const char *value, int *result)
     return 0;
 }
 
-#define IMPLEMENT_SSL_TEST_BOOL_OPTION(struct_type, name, field)        \
+#define IMPLEMENT_SSL_TEST_BOOL_OPTION(struct_type, name, field)           \
     static int parse_##name##_##field(struct_type *ctx, const char *value) \
-    {                                                                   \
-        return parse_boolean(value, &ctx->field);                       \
+    {                                                                      \
+        return parse_boolean(value, &ctx->field);                          \
     }
 
-#define IMPLEMENT_SSL_TEST_STRING_OPTION(struct_type, name, field)      \
+#define IMPLEMENT_SSL_TEST_STRING_OPTION(struct_type, name, field)         \
     static int parse_##name##_##field(struct_type *ctx, const char *value) \
-    {                                                                   \
-        OPENSSL_free(ctx->field);                                       \
-        ctx->field = OPENSSL_strdup(value);                             \
-        return TEST_ptr(ctx->field);                                    \
+    {                                                                      \
+        OPENSSL_free(ctx->field);                                          \
+        ctx->field = OPENSSL_strdup(value);                                \
+        return TEST_ptr(ctx->field);                                       \
     }
 
-#define IMPLEMENT_SSL_TEST_INT_OPTION(struct_type, name, field)        \
+#define IMPLEMENT_SSL_TEST_INT_OPTION(struct_type, name, field)            \
     static int parse_##name##_##field(struct_type *ctx, const char *value) \
-    {                                                                   \
-        ctx->field = atoi(value);                                       \
-        return 1;                                                       \
+    {                                                                      \
+        ctx->field = atoi(value);                                          \
+        return 1;                                                          \
     }
 
 /* True enums and other test configuration values that map to an int. */
@@ -61,9 +60,8 @@ typedef struct {
     int value;
 } test_enum;
 
-
 __owur static int parse_enum(const test_enum *enums, size_t num_enums,
-                             int *value, const char *name)
+    int *value, const char *name)
 {
     size_t i;
     for (i = 0; i < num_enums; i++) {
@@ -76,7 +74,7 @@ __owur static int parse_enum(const test_enum *enums, size_t num_enums,
 }
 
 static const char *enum_name(const test_enum *enums, size_t num_enums,
-                             int value)
+    int value)
 {
     size_t i;
     for (i = 0; i < num_enums; i++) {
@@ -87,22 +85,21 @@ static const char *enum_name(const test_enum *enums, size_t num_enums,
     return "InvalidValue";
 }
 
-
 /* ExpectedResult */
 
 static const test_enum ssl_test_results[] = {
-    {"Success", SSL_TEST_SUCCESS},
-    {"ServerFail", SSL_TEST_SERVER_FAIL},
-    {"ClientFail", SSL_TEST_CLIENT_FAIL},
-    {"InternalError", SSL_TEST_INTERNAL_ERROR},
-    {"FirstHandshakeFailed", SSL_TEST_FIRST_HANDSHAKE_FAILED},
+    { "Success", SSL_TEST_SUCCESS },
+    { "ServerFail", SSL_TEST_SERVER_FAIL },
+    { "ClientFail", SSL_TEST_CLIENT_FAIL },
+    { "InternalError", SSL_TEST_INTERNAL_ERROR },
+    { "FirstHandshakeFailed", SSL_TEST_FIRST_HANDSHAKE_FAILED },
 };
 
 __owur static int parse_expected_result(SSL_TEST_CTX *test_ctx, const char *value)
 {
     int ret_value;
     if (!parse_enum(ssl_test_results, OSSL_NELEM(ssl_test_results),
-                    &ret_value, value)) {
+            &ret_value, value)) {
         return 0;
     }
     test_ctx->expected_result = ret_value;
@@ -117,13 +114,13 @@ const char *ssl_test_result_name(ssl_test_result_t result)
 /* ExpectedClientAlert / ExpectedServerAlert */
 
 static const test_enum ssl_alerts[] = {
-    {"UnknownCA", SSL_AD_UNKNOWN_CA},
-    {"HandshakeFailure", SSL_AD_HANDSHAKE_FAILURE},
-    {"UnrecognizedName", SSL_AD_UNRECOGNIZED_NAME},
-    {"NoRenegotiation", SSL_AD_NO_RENEGOTIATION},
-    {"BadCertificate", SSL_AD_BAD_CERTIFICATE},
-    {"NoApplicationProtocol", SSL_AD_NO_APPLICATION_PROTOCOL},
-    {"CertificateRequired", SSL_AD_CERTIFICATE_REQUIRED},
+    { "UnknownCA", SSL_AD_UNKNOWN_CA },
+    { "HandshakeFailure", SSL_AD_HANDSHAKE_FAILURE },
+    { "UnrecognizedName", SSL_AD_UNRECOGNIZED_NAME },
+    { "NoRenegotiation", SSL_AD_NO_RENEGOTIATION },
+    { "BadCertificate", SSL_AD_BAD_CERTIFICATE },
+    { "NoApplicationProtocol", SSL_AD_NO_APPLICATION_PROTOCOL },
+    { "CertificateRequired", SSL_AD_CERTIFICATE_REQUIRED },
 };
 
 __owur static int parse_alert(int *alert, const char *value)
@@ -149,19 +146,19 @@ const char *ssl_alert_name(int alert)
 /* ExpectedProtocol */
 
 static const test_enum ssl_protocols[] = {
-     {"TLSv1.3", TLS1_3_VERSION},
-     {"TLSv1.2", TLS1_2_VERSION},
-     {"TLSv1.1", TLS1_1_VERSION},
-     {"TLSv1", TLS1_VERSION},
-     {"SSLv3", SSL3_VERSION},
-     {"DTLSv1", DTLS1_VERSION},
-     {"DTLSv1.2", DTLS1_2_VERSION},
+    { "TLSv1.3", TLS1_3_VERSION },
+    { "TLSv1.2", TLS1_2_VERSION },
+    { "TLSv1.1", TLS1_1_VERSION },
+    { "TLSv1", TLS1_VERSION },
+    { "SSLv3", SSL3_VERSION },
+    { "DTLSv1", DTLS1_VERSION },
+    { "DTLSv1.2", DTLS1_2_VERSION },
 };
 
 __owur static int parse_protocol(SSL_TEST_CTX *test_ctx, const char *value)
 {
     return parse_enum(ssl_protocols, OSSL_NELEM(ssl_protocols),
-                      &test_ctx->expected_protocol, value);
+        &test_ctx->expected_protocol, value);
 }
 
 const char *ssl_protocol_name(int protocol)
@@ -172,19 +169,19 @@ const char *ssl_protocol_name(int protocol)
 /* VerifyCallback */
 
 static const test_enum ssl_verify_callbacks[] = {
-    {"None", SSL_TEST_VERIFY_NONE},
-    {"AcceptAll", SSL_TEST_VERIFY_ACCEPT_ALL},
-    {"RetryOnce", SSL_TEST_VERIFY_RETRY_ONCE},
-    {"RejectAll", SSL_TEST_VERIFY_REJECT_ALL},
+    { "None", SSL_TEST_VERIFY_NONE },
+    { "AcceptAll", SSL_TEST_VERIFY_ACCEPT_ALL },
+    { "RetryOnce", SSL_TEST_VERIFY_RETRY_ONCE },
+    { "RejectAll", SSL_TEST_VERIFY_REJECT_ALL },
 };
 
 __owur static int parse_client_verify_callback(SSL_TEST_CLIENT_CONF *client_conf,
-                                               const char *value)
+    const char *value)
 {
     int ret_value;
 
     if (!parse_enum(ssl_verify_callbacks, OSSL_NELEM(ssl_verify_callbacks),
-                    &ret_value, value)) {
+            &ret_value, value)) {
         return 0;
     }
     client_conf->verify_callback = ret_value;
@@ -194,24 +191,24 @@ __owur static int parse_client_verify_callback(SSL_TEST_CLIENT_CONF *client_conf
 const char *ssl_verify_callback_name(ssl_verify_callback_t callback)
 {
     return enum_name(ssl_verify_callbacks, OSSL_NELEM(ssl_verify_callbacks),
-                     callback);
+        callback);
 }
 
 /* ServerName */
 
 static const test_enum ssl_servername[] = {
-    {"None", SSL_TEST_SERVERNAME_NONE},
-    {"server1", SSL_TEST_SERVERNAME_SERVER1},
-    {"server2", SSL_TEST_SERVERNAME_SERVER2},
-    {"invalid", SSL_TEST_SERVERNAME_INVALID},
+    { "None", SSL_TEST_SERVERNAME_NONE },
+    { "server1", SSL_TEST_SERVERNAME_SERVER1 },
+    { "server2", SSL_TEST_SERVERNAME_SERVER2 },
+    { "invalid", SSL_TEST_SERVERNAME_INVALID },
 };
 
 __owur static int parse_servername(SSL_TEST_CLIENT_CONF *client_conf,
-                                   const char *value)
+    const char *value)
 {
     int ret_value;
     if (!parse_enum(ssl_servername, OSSL_NELEM(ssl_servername),
-                    &ret_value, value)) {
+            &ret_value, value)) {
         return 0;
     }
     client_conf->servername = ret_value;
@@ -219,11 +216,11 @@ __owur static int parse_servername(SSL_TEST_CLIENT_CONF *client_conf,
 }
 
 __owur static int parse_expected_servername(SSL_TEST_CTX *test_ctx,
-                                            const char *value)
+    const char *value)
 {
     int ret_value;
     if (!parse_enum(ssl_servername, OSSL_NELEM(ssl_servername),
-                    &ret_value, value)) {
+            &ret_value, value)) {
         return 0;
     }
     test_ctx->expected_servername = ret_value;
@@ -233,28 +230,28 @@ __owur static int parse_expected_servername(SSL_TEST_CTX *test_ctx,
 const char *ssl_servername_name(ssl_servername_t server)
 {
     return enum_name(ssl_servername, OSSL_NELEM(ssl_servername),
-                     server);
+        server);
 }
 
 /* ServerNameCallback */
 
 static const test_enum ssl_servername_callbacks[] = {
-    {"None", SSL_TEST_SERVERNAME_CB_NONE},
-    {"IgnoreMismatch", SSL_TEST_SERVERNAME_IGNORE_MISMATCH},
-    {"RejectMismatch", SSL_TEST_SERVERNAME_REJECT_MISMATCH},
-    {"ClientHelloIgnoreMismatch",
-     SSL_TEST_SERVERNAME_CLIENT_HELLO_IGNORE_MISMATCH},
-    {"ClientHelloRejectMismatch",
-     SSL_TEST_SERVERNAME_CLIENT_HELLO_REJECT_MISMATCH},
-    {"ClientHelloNoV12", SSL_TEST_SERVERNAME_CLIENT_HELLO_NO_V12},
+    { "None", SSL_TEST_SERVERNAME_CB_NONE },
+    { "IgnoreMismatch", SSL_TEST_SERVERNAME_IGNORE_MISMATCH },
+    { "RejectMismatch", SSL_TEST_SERVERNAME_REJECT_MISMATCH },
+    { "ClientHelloIgnoreMismatch",
+        SSL_TEST_SERVERNAME_CLIENT_HELLO_IGNORE_MISMATCH },
+    { "ClientHelloRejectMismatch",
+        SSL_TEST_SERVERNAME_CLIENT_HELLO_REJECT_MISMATCH },
+    { "ClientHelloNoV12", SSL_TEST_SERVERNAME_CLIENT_HELLO_NO_V12 },
 };
 
 __owur static int parse_servername_callback(SSL_TEST_SERVER_CONF *server_conf,
-                                            const char *value)
+    const char *value)
 {
     int ret_value;
     if (!parse_enum(ssl_servername_callbacks,
-                    OSSL_NELEM(ssl_servername_callbacks), &ret_value, value)) {
+            OSSL_NELEM(ssl_servername_callbacks), &ret_value, value)) {
         return 0;
     }
     server_conf->servername_callback = ret_value;
@@ -264,22 +261,22 @@ __owur static int parse_servername_callback(SSL_TEST_SERVER_CONF *server_conf,
 const char *ssl_servername_callback_name(ssl_servername_callback_t callback)
 {
     return enum_name(ssl_servername_callbacks,
-                     OSSL_NELEM(ssl_servername_callbacks), callback);
+        OSSL_NELEM(ssl_servername_callbacks), callback);
 }
 
 /* SessionTicketExpected */
 
 static const test_enum ssl_session_ticket[] = {
-    {"Ignore", SSL_TEST_SESSION_TICKET_IGNORE},
-    {"Yes", SSL_TEST_SESSION_TICKET_YES},
-    {"No", SSL_TEST_SESSION_TICKET_NO},
+    { "Ignore", SSL_TEST_SESSION_TICKET_IGNORE },
+    { "Yes", SSL_TEST_SESSION_TICKET_YES },
+    { "No", SSL_TEST_SESSION_TICKET_NO },
 };
 
 __owur static int parse_session_ticket(SSL_TEST_CTX *test_ctx, const char *value)
 {
     int ret_value;
     if (!parse_enum(ssl_session_ticket, OSSL_NELEM(ssl_session_ticket),
-                    &ret_value, value)) {
+            &ret_value, value)) {
         return 0;
     }
     test_ctx->session_ticket_expected = ret_value;
@@ -289,8 +286,8 @@ __owur static int parse_session_ticket(SSL_TEST_CTX *test_ctx, const char *value
 const char *ssl_session_ticket_name(ssl_session_ticket_t server)
 {
     return enum_name(ssl_session_ticket,
-                     OSSL_NELEM(ssl_session_ticket),
-                     server);
+        OSSL_NELEM(ssl_session_ticket),
+        server);
 }
 
 /* CompressionExpected */
@@ -300,16 +297,16 @@ IMPLEMENT_SSL_TEST_BOOL_OPTION(SSL_TEST_CTX, test, compression_expected)
 /* SessionIdExpected */
 
 static const test_enum ssl_session_id[] = {
-    {"Ignore", SSL_TEST_SESSION_ID_IGNORE},
-    {"Yes", SSL_TEST_SESSION_ID_YES},
-    {"No", SSL_TEST_SESSION_ID_NO},
+    { "Ignore", SSL_TEST_SESSION_ID_IGNORE },
+    { "Yes", SSL_TEST_SESSION_ID_YES },
+    { "No", SSL_TEST_SESSION_ID_NO },
 };
 
 __owur static int parse_session_id(SSL_TEST_CTX *test_ctx, const char *value)
 {
     int ret_value;
     if (!parse_enum(ssl_session_id, OSSL_NELEM(ssl_session_id),
-                    &ret_value, value)) {
+            &ret_value, value)) {
         return 0;
     }
     test_ctx->session_id_expected = ret_value;
@@ -319,23 +316,23 @@ __owur static int parse_session_id(SSL_TEST_CTX *test_ctx, const char *value)
 const char *ssl_session_id_name(ssl_session_id_t server)
 {
     return enum_name(ssl_session_id,
-                     OSSL_NELEM(ssl_session_id),
-                     server);
+        OSSL_NELEM(ssl_session_id),
+        server);
 }
 
 /* Method */
 
 static const test_enum ssl_test_methods[] = {
-    {"TLS", SSL_TEST_METHOD_TLS},
-    {"DTLS", SSL_TEST_METHOD_DTLS},
-    {"QUIC", SSL_TEST_METHOD_QUIC}
+    { "TLS", SSL_TEST_METHOD_TLS },
+    { "DTLS", SSL_TEST_METHOD_DTLS },
+    { "QUIC", SSL_TEST_METHOD_QUIC }
 };
 
 __owur static int parse_test_method(SSL_TEST_CTX *test_ctx, const char *value)
 {
     int ret_value;
     if (!parse_enum(ssl_test_methods, OSSL_NELEM(ssl_test_methods),
-                    &ret_value, value)) {
+            &ret_value, value)) {
         return 0;
     }
     test_ctx->method = ret_value;
@@ -369,20 +366,20 @@ IMPLEMENT_SSL_TEST_STRING_OPTION(SSL_TEST_SERVER_CONF, server, session_ticket_ap
 /* Handshake mode */
 
 static const test_enum ssl_handshake_modes[] = {
-    {"Simple", SSL_TEST_HANDSHAKE_SIMPLE},
-    {"Resume", SSL_TEST_HANDSHAKE_RESUME},
-    {"RenegotiateServer", SSL_TEST_HANDSHAKE_RENEG_SERVER},
-    {"RenegotiateClient", SSL_TEST_HANDSHAKE_RENEG_CLIENT},
-    {"KeyUpdateServer", SSL_TEST_HANDSHAKE_KEY_UPDATE_SERVER},
-    {"KeyUpdateClient", SSL_TEST_HANDSHAKE_KEY_UPDATE_CLIENT},
-    {"PostHandshakeAuth", SSL_TEST_HANDSHAKE_POST_HANDSHAKE_AUTH},
+    { "Simple", SSL_TEST_HANDSHAKE_SIMPLE },
+    { "Resume", SSL_TEST_HANDSHAKE_RESUME },
+    { "RenegotiateServer", SSL_TEST_HANDSHAKE_RENEG_SERVER },
+    { "RenegotiateClient", SSL_TEST_HANDSHAKE_RENEG_CLIENT },
+    { "KeyUpdateServer", SSL_TEST_HANDSHAKE_KEY_UPDATE_SERVER },
+    { "KeyUpdateClient", SSL_TEST_HANDSHAKE_KEY_UPDATE_CLIENT },
+    { "PostHandshakeAuth", SSL_TEST_HANDSHAKE_POST_HANDSHAKE_AUTH },
 };
 
 __owur static int parse_handshake_mode(SSL_TEST_CTX *test_ctx, const char *value)
 {
     int ret_value;
     if (!parse_enum(ssl_handshake_modes, OSSL_NELEM(ssl_handshake_modes),
-                    &ret_value, value)) {
+            &ret_value, value)) {
         return 0;
     }
     test_ctx->handshake_mode = ret_value;
@@ -392,7 +389,7 @@ __owur static int parse_handshake_mode(SSL_TEST_CTX *test_ctx, const char *value
 const char *ssl_handshake_mode_name(ssl_handshake_mode_t mode)
 {
     return enum_name(ssl_handshake_modes, OSSL_NELEM(ssl_handshake_modes),
-                     mode);
+        mode);
 }
 
 /* Renegotiation Ciphersuites */
@@ -402,15 +399,15 @@ IMPLEMENT_SSL_TEST_STRING_OPTION(SSL_TEST_CLIENT_CONF, client, reneg_ciphers)
 /* KeyUpdateType */
 
 static const test_enum ssl_key_update_types[] = {
-    {"KeyUpdateRequested", SSL_KEY_UPDATE_REQUESTED},
-    {"KeyUpdateNotRequested", SSL_KEY_UPDATE_NOT_REQUESTED},
+    { "KeyUpdateRequested", SSL_KEY_UPDATE_REQUESTED },
+    { "KeyUpdateNotRequested", SSL_KEY_UPDATE_NOT_REQUESTED },
 };
 
 __owur static int parse_key_update_type(SSL_TEST_CTX *test_ctx, const char *value)
 {
     int ret_value;
     if (!parse_enum(ssl_key_update_types, OSSL_NELEM(ssl_key_update_types),
-                    &ret_value, value)) {
+            &ret_value, value)) {
         return 0;
     }
     test_ctx->key_update_type = ret_value;
@@ -420,17 +417,17 @@ __owur static int parse_key_update_type(SSL_TEST_CTX *test_ctx, const char *valu
 /* CT Validation */
 
 static const test_enum ssl_ct_validation_modes[] = {
-    {"None", SSL_TEST_CT_VALIDATION_NONE},
-    {"Permissive", SSL_TEST_CT_VALIDATION_PERMISSIVE},
-    {"Strict", SSL_TEST_CT_VALIDATION_STRICT},
+    { "None", SSL_TEST_CT_VALIDATION_NONE },
+    { "Permissive", SSL_TEST_CT_VALIDATION_PERMISSIVE },
+    { "Strict", SSL_TEST_CT_VALIDATION_STRICT },
 };
 
 __owur static int parse_ct_validation(SSL_TEST_CLIENT_CONF *client_conf,
-                                      const char *value)
+    const char *value)
 {
     int ret_value;
     if (!parse_enum(ssl_ct_validation_modes, OSSL_NELEM(ssl_ct_validation_modes),
-                    &ret_value, value)) {
+            &ret_value, value)) {
         return 0;
     }
     client_conf->ct_validation = ret_value;
@@ -440,7 +437,7 @@ __owur static int parse_ct_validation(SSL_TEST_CLIENT_CONF *client_conf,
 const char *ssl_ct_validation_name(ssl_ct_validation_t mode)
 {
     return enum_name(ssl_ct_validation_modes, OSSL_NELEM(ssl_ct_validation_modes),
-                     mode);
+        mode);
 }
 
 IMPLEMENT_SSL_TEST_BOOL_OPTION(SSL_TEST_CTX, test, resumption_expected)
@@ -453,17 +450,17 @@ IMPLEMENT_SSL_TEST_BOOL_OPTION(SSL_TEST_CTX, test, enable_server_sctp_label_bug)
 /* CertStatus */
 
 static const test_enum ssl_certstatus[] = {
-    {"None", SSL_TEST_CERT_STATUS_NONE},
-    {"GoodResponse", SSL_TEST_CERT_STATUS_GOOD_RESPONSE},
-    {"BadResponse", SSL_TEST_CERT_STATUS_BAD_RESPONSE}
+    { "None", SSL_TEST_CERT_STATUS_NONE },
+    { "GoodResponse", SSL_TEST_CERT_STATUS_GOOD_RESPONSE },
+    { "BadResponse", SSL_TEST_CERT_STATUS_BAD_RESPONSE }
 };
 
 __owur static int parse_certstatus(SSL_TEST_SERVER_CONF *server_conf,
-                                            const char *value)
+    const char *value)
 {
     int ret_value;
     if (!parse_enum(ssl_certstatus, OSSL_NELEM(ssl_certstatus), &ret_value,
-                    value)) {
+            value)) {
         return 0;
     }
     server_conf->cert_status = ret_value;
@@ -473,34 +470,33 @@ __owur static int parse_certstatus(SSL_TEST_SERVER_CONF *server_conf,
 const char *ssl_certstatus_name(ssl_cert_status_t cert_status)
 {
     return enum_name(ssl_certstatus,
-                     OSSL_NELEM(ssl_certstatus), cert_status);
+        OSSL_NELEM(ssl_certstatus), cert_status);
 }
 
 /* ApplicationData */
 
 IMPLEMENT_SSL_TEST_INT_OPTION(SSL_TEST_CTX, test, app_data_size)
 
-
 /* MaxFragmentSize */
 
 IMPLEMENT_SSL_TEST_INT_OPTION(SSL_TEST_CTX, test, max_fragment_size)
 
 /* Maximum-Fragment-Length TLS extension mode */
 static const test_enum ssl_max_fragment_len_mode[] = {
-    {"None", TLSEXT_max_fragment_length_DISABLED},
-    { "512", TLSEXT_max_fragment_length_512},
-    {"1024", TLSEXT_max_fragment_length_1024},
-    {"2048", TLSEXT_max_fragment_length_2048},
-    {"4096", TLSEXT_max_fragment_length_4096}
+    { "None", TLSEXT_max_fragment_length_DISABLED },
+    { "512", TLSEXT_max_fragment_length_512 },
+    { "1024", TLSEXT_max_fragment_length_1024 },
+    { "2048", TLSEXT_max_fragment_length_2048 },
+    { "4096", TLSEXT_max_fragment_length_4096 }
 };
 
 __owur static int parse_max_fragment_len_mode(SSL_TEST_CLIENT_CONF *client_conf,
-                                              const char *value)
+    const char *value)
 {
     int ret_value;
 
     if (!parse_enum(ssl_max_fragment_len_mode,
-                    OSSL_NELEM(ssl_max_fragment_len_mode), &ret_value, value)) {
+            OSSL_NELEM(ssl_max_fragment_len_mode), &ret_value, value)) {
         return 0;
     }
     client_conf->max_fragment_len_mode = ret_value;
@@ -510,10 +506,9 @@ __owur static int parse_max_fragment_len_mode(SSL_TEST_CLIENT_CONF *client_conf,
 const char *ssl_max_fragment_len_name(int MFL_mode)
 {
     return enum_name(ssl_max_fragment_len_mode,
-                     OSSL_NELEM(ssl_max_fragment_len_mode), MFL_mode);
+        OSSL_NELEM(ssl_max_fragment_len_mode), MFL_mode);
 }
 
-
 /* Expected key and signature types */
 
 __owur static int parse_expected_key_type(int *ptype, const char *value)
@@ -552,40 +547,39 @@ __owur static int parse_expected_key_type(int *ptype, const char *value)
 }
 
 __owur static int parse_expected_tmp_key_type(SSL_TEST_CTX *test_ctx,
-                                              const char *value)
+    const char *value)
 {
     return parse_expected_key_type(&test_ctx->expected_tmp_key_type, value);
 }
 
 __owur static int parse_expected_server_cert_type(SSL_TEST_CTX *test_ctx,
-                                                  const char *value)
+    const char *value)
 {
     return parse_expected_key_type(&test_ctx->expected_server_cert_type,
-                                   value);
+        value);
 }
 
 __owur static int parse_expected_server_sign_type(SSL_TEST_CTX *test_ctx,
-                                                 const char *value)
+    const char *value)
 {
     return parse_expected_key_type(&test_ctx->expected_server_sign_type,
-                                   value);
+        value);
 }
 
 __owur static int parse_expected_client_cert_type(SSL_TEST_CTX *test_ctx,
-                                                  const char *value)
+    const char *value)
 {
     return parse_expected_key_type(&test_ctx->expected_client_cert_type,
-                                   value);
+        value);
 }
 
 __owur static int parse_expected_client_sign_type(SSL_TEST_CTX *test_ctx,
-                                                 const char *value)
+    const char *value)
 {
     return parse_expected_key_type(&test_ctx->expected_client_sign_type,
-                                   value);
+        value);
 }
 
-
 /* Expected signing hash */
 
 __owur static int parse_expected_sign_hash(int *ptype, const char *value)
@@ -604,22 +598,22 @@ __owur static int parse_expected_sign_hash(int *ptype, const char *value)
 }
 
 __owur static int parse_expected_server_sign_hash(SSL_TEST_CTX *test_ctx,
-                                                  const char *value)
+    const char *value)
 {
     return parse_expected_sign_hash(&test_ctx->expected_server_sign_hash,
-                                    value);
+        value);
 }
 
 __owur static int parse_expected_client_sign_hash(SSL_TEST_CTX *test_ctx,
-                                                  const char *value)
+    const char *value)
 {
     return parse_expected_sign_hash(&test_ctx->expected_client_sign_hash,
-                                    value);
+        value);
 }
 
 __owur static int parse_expected_ca_names(STACK_OF(X509_NAME) **pnames,
-                                          const char *value,
-                                          OSSL_LIB_CTX *libctx)
+    const char *value,
+    OSSL_LIB_CTX *libctx)
 {
     if (value == NULL)
         return 0;
@@ -630,16 +624,16 @@ __owur static int parse_expected_ca_names(STACK_OF(X509_NAME) **pnames,
     return *pnames != NULL;
 }
 __owur static int parse_expected_server_ca_names(SSL_TEST_CTX *test_ctx,
-                                                 const char *value)
+    const char *value)
 {
     return parse_expected_ca_names(&test_ctx->expected_server_ca_names, value,
-                                   test_ctx->libctx);
+        test_ctx->libctx);
 }
 __owur static int parse_expected_client_ca_names(SSL_TEST_CTX *test_ctx,
-                                                 const char *value)
+    const char *value)
 {
     return parse_expected_ca_names(&test_ctx->expected_client_ca_names, value,
-                                   test_ctx->libctx);
+        test_ctx->libctx);
 }
 
 /* ExpectedCipher */
@@ -710,7 +704,7 @@ static const ssl_test_client_option ssl_test_client_options[] = {
     { "NPNProtocols", &parse_client_npn_protocols },
     { "ALPNProtocols", &parse_client_alpn_protocols },
     { "CTValidation", &parse_ct_validation },
-    { "RenegotiateCiphers", &parse_client_reneg_ciphers},
+    { "RenegotiateCiphers", &parse_client_reneg_ciphers },
     { "SRPUser", &parse_client_srp_user },
     { "SRPPassword", &parse_client_srp_password },
     { "MaxFragmentLenExt", &parse_max_fragment_len_mode },
@@ -790,7 +784,7 @@ void SSL_TEST_CTX_free(SSL_TEST_CTX *ctx)
 }
 
 static int parse_client_options(SSL_TEST_CLIENT_CONF *client, const CONF *conf,
-                                const char *client_section)
+    const char *client_section)
 {
     STACK_OF(CONF_VALUE) *sk_conf;
     int i;
@@ -806,7 +800,7 @@ static int parse_client_options(SSL_TEST_CLIENT_CONF *client, const CONF *conf,
             if (strcmp(option->name, ssl_test_client_options[j].name) == 0) {
                 if (!ssl_test_client_options[j].parse(client, option->value)) {
                     TEST_info("Bad value %s for option %s",
-                              option->value, option->name);
+                        option->value, option->name);
                     return 0;
                 }
                 found = 1;
@@ -823,7 +817,7 @@ static int parse_client_options(SSL_TEST_CLIENT_CONF *client, const CONF *conf,
 }
 
 static int parse_server_options(SSL_TEST_SERVER_CONF *server, const CONF *conf,
-                                const char *server_section)
+    const char *server_section)
 {
     STACK_OF(CONF_VALUE) *sk_conf;
     int i;
@@ -839,7 +833,7 @@ static int parse_server_options(SSL_TEST_SERVER_CONF *server, const CONF *conf,
             if (strcmp(option->name, ssl_test_server_options[j].name) == 0) {
                 if (!ssl_test_server_options[j].parse(server, option->value)) {
                     TEST_info("Bad value %s for option %s",
-                               option->value, option->name);
+                        option->value, option->name);
                     return 0;
                 }
                 found = 1;
@@ -856,7 +850,7 @@ static int parse_server_options(SSL_TEST_SERVER_CONF *server, const CONF *conf,
 }
 
 SSL_TEST_CTX *SSL_TEST_CTX_create(const CONF *conf, const char *test_section,
-                                  OSSL_LIB_CTX *libctx)
+    OSSL_LIB_CTX *libctx)
 {
     STACK_OF(CONF_VALUE) *sk_conf = NULL;
     SSL_TEST_CTX *ctx = NULL;
@@ -864,7 +858,7 @@ SSL_TEST_CTX *SSL_TEST_CTX_create(const CONF *conf, const char *test_section,
     size_t j;
 
     if (!TEST_ptr(sk_conf = NCONF_get_section(conf, test_section))
-            || !TEST_ptr(ctx = SSL_TEST_CTX_new(libctx)))
+        || !TEST_ptr(ctx = SSL_TEST_CTX_new(libctx)))
         goto err;
 
     for (i = 0; i < sk_CONF_VALUE_num(sk_conf); i++) {
@@ -883,22 +877,22 @@ SSL_TEST_CTX *SSL_TEST_CTX_create(const CONF *conf, const char *test_section,
                 goto err;
         } else if (strcmp(option->name, "resume-client") == 0) {
             if (!parse_client_options(&ctx->resume_extra.client, conf,
-                                      option->value))
+                    option->value))
                 goto err;
         } else if (strcmp(option->name, "resume-server") == 0) {
             if (!parse_server_options(&ctx->resume_extra.server, conf,
-                                      option->value))
+                    option->value))
                 goto err;
         } else if (strcmp(option->name, "resume-server2") == 0) {
             if (!parse_server_options(&ctx->resume_extra.server2, conf,
-                                      option->value))
+                    option->value))
                 goto err;
         } else {
             for (j = 0; j < OSSL_NELEM(ssl_test_ctx_options); j++) {
                 if (strcmp(option->name, ssl_test_ctx_options[j].name) == 0) {
                     if (!ssl_test_ctx_options[j].parse(ctx, option->value)) {
                         TEST_info("Bad value %s for option %s",
-                                   option->value, option->name);
+                            option->value, option->name);
                         goto err;
                     }
                     found = 1;
@@ -914,9 +908,9 @@ SSL_TEST_CTX *SSL_TEST_CTX_create(const CONF *conf, const char *test_section,
 
     goto done;
 
- err:
+err:
     SSL_TEST_CTX_free(ctx);
     ctx = NULL;
- done:
+done:
     return ctx;
 }
