@@ -15,9 +15,9 @@
 
 #include "testutil.h"
 
-#define HTTP_STATUS_CODE_OK                200
-#define HTTP_STATUS_CODES_FATAL_ERROR      399
-#define HTTP_STATUS_CODES_NONFATAL_ERROR   400
+#define HTTP_STATUS_CODE_OK 200
+#define HTTP_STATUS_CODES_FATAL_ERROR 399
+#define HTTP_STATUS_CODES_NONFATAL_ERROR 400
 
 static const ASN1_ITEM *x509_it = NULL;
 static X509 *x509 = NULL;
@@ -41,8 +41,8 @@ typedef struct {
  * Response hdr has HTTP version 1.|version| and |keep_alive| (unless implicit).
  */
 static int mock_http_server(BIO *in, BIO *out, char version, int keep_alive,
-                            const char *content_type, const char *txt,
-                            ASN1_VALUE *rsp, const ASN1_ITEM *it)
+    const char *content_type, const char *txt,
+    ASN1_VALUE *rsp, const ASN1_ITEM *it)
 {
     const char *req, *path;
     long count = BIO_get_mem_data(in, (unsigned char **)&req);
@@ -53,7 +53,7 @@ static int mock_http_server(BIO *in, BIO *out, char version, int keep_alive,
 
     /* first line should contain "(GET|POST) (/<suggested status>)?/<path> HTTP/1.x" */
     if (!is_get
-            && !(TEST_true(count >= 5 && CHECK_AND_SKIP_PREFIX(hdr, "POST "))))
+        && !(TEST_true(count >= 5 && CHECK_AND_SKIP_PREFIX(hdr, "POST "))))
         return 0;
 
     /* get any status code string to be returned suggested by test client */
@@ -89,17 +89,20 @@ static int mock_http_server(BIO *in, BIO *out, char version, int keep_alive,
         if (!is_get)
             return 0;
         return BIO_printf(out, "HTTP/1.%c 301 Moved Permanently\r\n"
-                          "Location: %s\r\n\r\n",
-                          version, RPATH) > 0; /* same server */
+                               "Location: %s\r\n\r\n",
+                   version, RPATH)
+            > 0; /* same server */
     }
     if (BIO_printf(out, "HTTP/1.%c %s %s\r\n", version, status,
-                   /* mock some reason string: */
-                   strcmp(status, "200") == 0 ? "OK" :
-                   strcmp(status, "400") >= 0 ? "error" : "fatal") <= 0)
+            /* mock some reason string: */
+            strcmp(status, "200") == 0 ? "OK" : strcmp(status, "400") >= 0 ? "error"
+                                                                           : "fatal")
+        <= 0)
         return 0;
     if ((version == '0') == keep_alive) /* otherwise, default */
         if (BIO_printf(out, "Connection: %s\r\n",
-                       version == '0' ? "keep-alive" : "close") <= 0)
+                version == '0' ? "keep-alive" : "close")
+            <= 0)
             return 0;
 
     if (strcmp(status, "399") == 0) /* HTTP_STATUS_CODES_FATAL_ERROR */
@@ -111,7 +114,9 @@ static int mock_http_server(BIO *in, BIO *out, char version, int keep_alive,
         else if ((len = ASN1_item_i2d(rsp, NULL, it)) <= 0)
             return 0;
         if (BIO_printf(out, "Content-Type: %s\r\n"
-                       "Content-Length: %d\r\n\r\n", content_type, len) <= 0)
+                            "Content-Length: %d\r\n\r\n",
+                content_type, len)
+            <= 0)
             return 0;
         if (txt != NULL)
             return BIO_puts(out, txt);
@@ -130,14 +135,14 @@ static int mock_http_server(BIO *in, BIO *out, char version, int keep_alive,
 }
 
 static long http_bio_cb_ex(BIO *bio, int oper, const char *argp, size_t len,
-                           int cmd, long argl, int ret, size_t *processed)
+    int cmd, long argl, int ret, size_t *processed)
 {
     server_args *args = (server_args *)BIO_get_callback_arg(bio);
 
     if (oper == (BIO_CB_CTRL | BIO_CB_RETURN) && cmd == BIO_CTRL_FLUSH)
         ret = mock_http_server(bio, args->out, args->version, args->keep_alive,
-                               args->content_type, args->txt,
-                               (ASN1_VALUE *)x509, x509_it);
+            args->content_type, args->txt,
+            (ASN1_VALUE *)x509, x509_it);
     return ret;
 }
 
@@ -160,13 +165,13 @@ static int test_http_method(int do_get, int do_txt, int suggested_status)
     int real_server = do_txt && 0; /* remove "&& 0" for using real server */
 
     BIO_snprintf(path, sizeof(path), "/%d%s", suggested_status,
-                 do_get > 1 ? "/will-be-redirected" : RPATH);
+        do_get > 1 ? "/will-be-redirected" : RPATH);
     if (do_txt) {
         content_type = "text/plain";
         req = BIO_new(BIO_s_mem());
         if (req == NULL
-                || BIO_puts(req, text1) != sizeof(text1) - 1
-                || BIO_puts(req, text2) != sizeof(text2) - 1) {
+            || BIO_puts(req, text1) != sizeof(text1) - 1
+            || BIO_puts(req, text2) != sizeof(text2) - 1) {
             BIO_free(req);
             req = NULL;
         }
@@ -184,23 +189,22 @@ static int test_http_method(int do_get, int do_txt, int suggested_status)
     BIO_set_callback_ex(wbio, http_bio_cb_ex);
     BIO_set_callback_arg(wbio, (char *)&mock_args);
 
-    rsp = do_get ?
-        OSSL_HTTP_get(real_server ? REAL_SERVER_URL : path,
-                      NULL /* proxy */, NULL /* no_proxy */,
-                      real_server ? NULL : wbio,
-                      real_server ? NULL : rbio,
-                      NULL /* bio_update_fn */, NULL /* arg */,
-                      0 /* buf_size */, headers,
-                      real_server ? "text/html; charset=utf-8":  content_type,
-                      !do_txt /* expect_asn1 */,
-                      OSSL_HTTP_DEFAULT_MAX_RESP_LEN, 0 /* timeout */)
-        : OSSL_HTTP_transfer(NULL, NULL /* host */, NULL /* port */, path,
-                             0 /* use_ssl */, NULL /* proxy */, NULL /* no_pr */,
-                             wbio, rbio, NULL /* bio_fn */, NULL /* arg */,
-                             0 /* buf_size */, headers, content_type,
-                             req, content_type, !do_txt /* expect_asn1 */,
-                             OSSL_HTTP_DEFAULT_MAX_RESP_LEN, 0 /* timeout */,
-                             0 /* keep_alive */);
+    rsp = do_get ? OSSL_HTTP_get(real_server ? REAL_SERVER_URL : path,
+                       NULL /* proxy */, NULL /* no_proxy */,
+                       real_server ? NULL : wbio,
+                       real_server ? NULL : rbio,
+                       NULL /* bio_update_fn */, NULL /* arg */,
+                       0 /* buf_size */, headers,
+                       real_server ? "text/html; charset=utf-8" : content_type,
+                       !do_txt /* expect_asn1 */,
+                       OSSL_HTTP_DEFAULT_MAX_RESP_LEN, 0 /* timeout */)
+                 : OSSL_HTTP_transfer(NULL, NULL /* host */, NULL /* port */, path,
+                       0 /* use_ssl */, NULL /* proxy */, NULL /* no_pr */,
+                       wbio, rbio, NULL /* bio_fn */, NULL /* arg */,
+                       0 /* buf_size */, headers, content_type,
+                       req, content_type, !do_txt /* expect_asn1 */,
+                       OSSL_HTTP_DEFAULT_MAX_RESP_LEN, 0 /* timeout */,
+                       0 /* keep_alive */);
     if (!TEST_int_eq(suggested_status == HTTP_STATUS_CODES_FATAL_ERROR, rsp == NULL))
         goto err;
     if (suggested_status == HTTP_STATUS_CODES_FATAL_ERROR)
@@ -210,13 +214,13 @@ static int test_http_method(int do_get, int do_txt, int suggested_status)
             char rtext[sizeof(DOCTYPE_HTML)];
 
             res = TEST_int_eq(BIO_gets(rsp, rtext, sizeof(rtext)),
-                              sizeof(DOCTYPE_HTML) - 1)
+                      sizeof(DOCTYPE_HTML) - 1)
                 && TEST_str_eq(rtext, DOCTYPE_HTML);
         } else if (do_txt) {
             char rtext[sizeof(text1) + 1 /* more space than needed */];
 
             res = TEST_int_eq(BIO_gets(rsp, rtext, sizeof(rtext)),
-                              sizeof(text1) - 1)
+                      sizeof(text1) - 1)
                 && TEST_str_eq(rtext, text1);
         } else {
             X509 *rcert = d2i_X509_bio(rsp, NULL);
@@ -227,7 +231,7 @@ static int test_http_method(int do_get, int do_txt, int suggested_status)
         BIO_free(rsp);
     }
 
- err:
+err:
     BIO_free(req);
     BIO_free(wbio);
     BIO_free(rbio);
@@ -256,14 +260,14 @@ static int test_http_keep_alive(char version, int keep_alive, int kept_alive)
 
     for (res = 1, i = 1; res && i <= 2; i++) {
         rsp = OSSL_HTTP_transfer(&rctx, NULL /* server */, NULL /* port */,
-                                 RPATH, 0 /* use_ssl */,
-                                 NULL /* proxy */, NULL /* no_proxy */,
-                                 wbio, rbio, NULL /* bio_update_fn */, NULL,
-                                 0 /* buf_size */, NULL /* headers */,
-                                 NULL /* content_type */, NULL /* req => GET */,
-                                 content_type, 0 /* ASN.1 not expected */,
-                                 0 /* max_resp_len */, 0 /* timeout */,
-                                 keep_alive);
+            RPATH, 0 /* use_ssl */,
+            NULL /* proxy */, NULL /* no_proxy */,
+            wbio, rbio, NULL /* bio_update_fn */, NULL,
+            0 /* buf_size */, NULL /* headers */,
+            NULL /* content_type */, NULL /* req => GET */,
+            content_type, 0 /* ASN.1 not expected */,
+            0 /* max_resp_len */, 0 /* timeout */,
+            keep_alive);
         if (keep_alive == 2 && kept_alive == 0)
             res = res && TEST_ptr_null(rsp)
                 && TEST_int_eq(OSSL_HTTP_is_alive(rctx), 0);
@@ -276,14 +280,14 @@ static int test_http_keep_alive(char version, int keep_alive, int kept_alive)
     }
     OSSL_HTTP_close(rctx, res);
 
- err:
+err:
     BIO_free(wbio);
     BIO_free(rbio);
     return res;
 }
 
 static int test_http_url_ok(const char *url, int exp_ssl, const char *exp_host,
-                            const char *exp_port, const char *exp_path)
+    const char *exp_port, const char *exp_path)
 {
     char *user, *host, *port, *path, *query, *frag;
     int exp_num, num, ssl;
@@ -292,7 +296,7 @@ static int test_http_url_ok(const char *url, int exp_ssl, const char *exp_host,
     if (!TEST_int_eq(sscanf(exp_port, "%d", &exp_num), 1))
         return 0;
     res = TEST_true(OSSL_HTTP_parse_url(url, &ssl, &user, &host, &port, &num,
-                                        &path, &query, &frag))
+              &path, &query, &frag))
         && TEST_str_eq(host, exp_host)
         && TEST_str_eq(port, exp_port)
         && TEST_int_eq(num, exp_num)
@@ -319,7 +323,7 @@ static int test_http_url_path_query_ok(const char *url, const char *exp_path_qu)
     int res;
 
     res = TEST_true(OSSL_HTTP_parse_url(url, NULL, NULL, &host, NULL, NULL,
-                                        &path, NULL, NULL))
+              &path, NULL, NULL))
         && TEST_str_eq(host, "host")
         && TEST_str_eq(path, exp_path_qu);
     OPENSSL_free(host);
@@ -335,11 +339,11 @@ static int test_http_url_dns(void)
 static int test_http_url_timestamp(void)
 {
     return test_http_url_ok("host/p/2017-01-03T00:00:00", 0, "host", "80",
-                            "/p/2017-01-03T00:00:00")
+               "/p/2017-01-03T00:00:00")
         && test_http_url_ok("http://host/p/2017-01-03T00:00:00", 0, "host",
-                            "80", "/p/2017-01-03T00:00:00")
+            "80", "/p/2017-01-03T00:00:00")
         && test_http_url_ok("https://host/p/2017-01-03T00:00:00", 1, "host",
-                            "443", "/p/2017-01-03T00:00:00");
+            "443", "/p/2017-01-03T00:00:00");
 }
 
 static int test_http_url_path_query(void)
@@ -371,7 +375,7 @@ static int test_http_url_invalid(const char *url)
     int res;
 
     res = TEST_false(OSSL_HTTP_parse_url(url, &ssl, NULL, &host, &port, &num,
-                                         &path, NULL, NULL))
+              &path, NULL, NULL))
         && TEST_ptr_null(host)
         && TEST_ptr_null(port)
         && TEST_ptr_null(path);
@@ -391,7 +395,7 @@ static int test_http_url_invalid_prefix(void)
 static int test_http_url_invalid_port(void)
 {
     return test_http_url_invalid("https://1.2.3.4:65536/pkix")
-           && test_http_url_invalid("https://1.2.3.4:");
+        && test_http_url_invalid("https://1.2.3.4:");
 }
 
 static int test_http_url_invalid_path(void)
@@ -514,7 +518,7 @@ static int test_http_resp_hdr_limit(size_t limit)
         goto err;
 
     if (!TEST_true(OSSL_HTTP_REQ_CTX_set_request_line(rctx, 0 /* GET */,
-                                                      NULL, NULL, RPATH)))
+            NULL, NULL, RPATH)))
         goto err;
 
     OSSL_HTTP_REQ_CTX_set_max_response_hdr_lines(rctx, limit);
@@ -529,7 +533,7 @@ static int test_http_resp_hdr_limit(size_t limit)
     else
         res = TEST_ptr(mem);
 
- err:
+err:
     BIO_free(wbio);
     BIO_free(rbio);
     OSSL_HTTP_REQ_CTX_free(rctx);
