@@ -26,7 +26,7 @@ static OSSL_PROVIDER *null_prov = NULL;
 static OSSL_PROVIDER *lib_prov = NULL;
 
 static EVP_PKEY *do_gen_key(const char *alg,
-                            const uint8_t *seed, size_t seed_len)
+    const uint8_t *seed, size_t seed_len)
 {
     EVP_PKEY *pkey = NULL;
     EVP_PKEY_CTX *ctx = NULL;
@@ -34,15 +34,15 @@ static EVP_PKEY *do_gen_key(const char *alg,
 
     if (seed_len != 0)
         *p++ = OSSL_PARAM_construct_octet_string(OSSL_PKEY_PARAM_ML_DSA_SEED,
-                                                 (char *)seed, seed_len);
+            (char *)seed, seed_len);
     *p++ = OSSL_PARAM_construct_utf8_string(OSSL_PKEY_PARAM_PROPERTIES,
-                                            "?fips=yes", 0);
+        "?fips=yes", 0);
     *p = OSSL_PARAM_construct_end();
 
     if (!TEST_ptr(ctx = EVP_PKEY_CTX_new_from_name(lib_ctx, alg, NULL))
-            || !TEST_int_eq(EVP_PKEY_keygen_init(ctx), 1)
-            || !TEST_int_eq(EVP_PKEY_CTX_set_params(ctx, params), 1)
-            || !TEST_int_eq(EVP_PKEY_generate(ctx, &pkey), 1))
+        || !TEST_int_eq(EVP_PKEY_keygen_init(ctx), 1)
+        || !TEST_int_eq(EVP_PKEY_CTX_set_params(ctx, params), 1)
+        || !TEST_int_eq(EVP_PKEY_generate(ctx, &pkey), 1))
         pkey = NULL;
 
     EVP_PKEY_CTX_free(ctx);
@@ -50,9 +50,9 @@ static EVP_PKEY *do_gen_key(const char *alg,
 }
 
 static int ml_dsa_create_keypair(EVP_PKEY **pkey, const char *name,
-                                 const uint8_t *priv, size_t priv_len,
-                                 const uint8_t *pub, size_t pub_len,
-                                 int expected)
+    const uint8_t *priv, size_t priv_len,
+    const uint8_t *pub, size_t pub_len,
+    int expected)
 {
     int ret = 0, selection = 0;
     EVP_PKEY_CTX *ctx = NULL;
@@ -60,20 +60,21 @@ static int ml_dsa_create_keypair(EVP_PKEY **pkey, const char *name,
 
     if (priv != NULL) {
         *p++ = OSSL_PARAM_construct_octet_string(OSSL_PKEY_PARAM_PRIV_KEY,
-                                                 (uint8_t *)priv, priv_len);
+            (uint8_t *)priv, priv_len);
         selection = OSSL_KEYMGMT_SELECT_PRIVATE_KEY;
     }
     if (pub != NULL) {
         *p++ = OSSL_PARAM_construct_octet_string(OSSL_PKEY_PARAM_PUB_KEY,
-                                                 (uint8_t *)pub, pub_len);
+            (uint8_t *)pub, pub_len);
         selection |= OSSL_KEYMGMT_SELECT_PUBLIC_KEY;
     }
     *p = OSSL_PARAM_construct_end();
 
     if (!TEST_ptr(ctx = EVP_PKEY_CTX_new_from_name(lib_ctx, name, NULL))
-            || !TEST_int_eq(EVP_PKEY_fromdata_init(ctx), 1)
-            || !TEST_int_eq(EVP_PKEY_fromdata(ctx, pkey, selection,
-                                              params), expected))
+        || !TEST_int_eq(EVP_PKEY_fromdata_init(ctx), 1)
+        || !TEST_int_eq(EVP_PKEY_fromdata(ctx, pkey, selection,
+                            params),
+            expected))
         goto err;
 
     ret = 1;
@@ -92,24 +93,24 @@ static int ml_dsa_keygen_test(int tst_id)
     int bits = 0, sec_bits = 0, sig_len = 0;
 
     if (!TEST_ptr(pkey = do_gen_key(tst->name, tst->seed, tst->seed_len))
-            || !TEST_true(EVP_PKEY_get_octet_string_param(pkey, OSSL_PKEY_PARAM_ML_DSA_SEED,
-                                                          seed, sizeof(seed), &seed_len))
-            || !TEST_true(EVP_PKEY_get_octet_string_param(pkey, OSSL_PKEY_PARAM_PRIV_KEY,
-                                                          priv, sizeof(priv), &priv_len))
-            || !TEST_true(EVP_PKEY_get_octet_string_param(pkey, OSSL_PKEY_PARAM_PUB_KEY,
-                                                          pub, sizeof(pub), &pub_len))
-            || !TEST_mem_eq(pub, pub_len, tst->pub, tst->pub_len)
-            || !TEST_mem_eq(priv, priv_len, tst->priv, tst->priv_len)
-            || !TEST_mem_eq(seed, seed_len, tst->seed, tst->seed_len)
-            /* The following checks assume that algorithm is ML-DSA-65 */
-            || !TEST_true(EVP_PKEY_get_int_param(pkey, OSSL_PKEY_PARAM_BITS, &bits))
-            || !TEST_int_eq(bits, 1952 * 8)
-            || !TEST_true(EVP_PKEY_get_int_param(pkey, OSSL_PKEY_PARAM_SECURITY_BITS,
-                                                 &sec_bits))
-            || !TEST_int_eq(sec_bits, 192)
-            || !TEST_true(EVP_PKEY_get_int_param(pkey, OSSL_PKEY_PARAM_MAX_SIZE,
-                                                 &sig_len))
-            || !TEST_int_ge(sig_len, 3309))
+        || !TEST_true(EVP_PKEY_get_octet_string_param(pkey, OSSL_PKEY_PARAM_ML_DSA_SEED,
+            seed, sizeof(seed), &seed_len))
+        || !TEST_true(EVP_PKEY_get_octet_string_param(pkey, OSSL_PKEY_PARAM_PRIV_KEY,
+            priv, sizeof(priv), &priv_len))
+        || !TEST_true(EVP_PKEY_get_octet_string_param(pkey, OSSL_PKEY_PARAM_PUB_KEY,
+            pub, sizeof(pub), &pub_len))
+        || !TEST_mem_eq(pub, pub_len, tst->pub, tst->pub_len)
+        || !TEST_mem_eq(priv, priv_len, tst->priv, tst->priv_len)
+        || !TEST_mem_eq(seed, seed_len, tst->seed, tst->seed_len)
+        /* The following checks assume that algorithm is ML-DSA-65 */
+        || !TEST_true(EVP_PKEY_get_int_param(pkey, OSSL_PKEY_PARAM_BITS, &bits))
+        || !TEST_int_eq(bits, 1952 * 8)
+        || !TEST_true(EVP_PKEY_get_int_param(pkey, OSSL_PKEY_PARAM_SECURITY_BITS,
+            &sec_bits))
+        || !TEST_int_eq(sec_bits, 192)
+        || !TEST_true(EVP_PKEY_get_int_param(pkey, OSSL_PKEY_PARAM_MAX_SIZE,
+            &sig_len))
+        || !TEST_int_ge(sig_len, 3309))
         goto err;
     ret = 1;
 err:
@@ -135,8 +136,8 @@ static int ml_dsa_siggen_test(int tst_id)
     *p++ = OSSL_PARAM_construct_int(OSSL_SIGNATURE_PARAM_MESSAGE_ENCODING, &encode);
     if (td->add_random != NULL)
         *p++ = OSSL_PARAM_construct_octet_string(OSSL_SIGNATURE_PARAM_TEST_ENTROPY,
-                                                 (char *)td->add_random,
-                                                 td->add_random_len);
+            (char *)td->add_random,
+            td->add_random_len);
     *p = OSSL_PARAM_construct_end();
 
     /*
@@ -144,21 +145,24 @@ static int ml_dsa_siggen_test(int tst_id)
      * The keygen path is tested via ml_dsa_keygen_test
      */
     if (!TEST_true(ml_dsa_create_keypair(&pkey, td->alg, td->priv, td->priv_len,
-                                         NULL, 0, 1))
-            || !TEST_ptr(sctx = EVP_PKEY_CTX_new_from_pkey(lib_ctx, pkey, NULL))
-            || !TEST_ptr(sig_alg = EVP_SIGNATURE_fetch(lib_ctx, td->alg, NULL))
-            || !TEST_int_eq(EVP_PKEY_sign_message_init(sctx, sig_alg, params), 1)
-            || !TEST_int_eq(EVP_PKEY_sign(sctx, NULL, &psig_len,
-                                          td->msg, td->msg_len), 1)
-            || !TEST_true(EVP_PKEY_get_size_t_param(pkey, OSSL_PKEY_PARAM_MAX_SIZE,
-                                                    &sig_len2))
-            || !TEST_int_eq(sig_len2, psig_len)
-            || !TEST_ptr(psig = OPENSSL_zalloc(psig_len))
-            || !TEST_int_eq(EVP_PKEY_sign(sctx, psig, &psig_len,
-                                          td->msg, td->msg_len), 1)
-            || !TEST_int_eq(EVP_Q_digest(lib_ctx, "SHA256", NULL, psig, psig_len,
-                                         digest, &digest_len), 1)
-            || !TEST_mem_eq(digest, digest_len, td->sig_digest, td->sig_digest_len))
+            NULL, 0, 1))
+        || !TEST_ptr(sctx = EVP_PKEY_CTX_new_from_pkey(lib_ctx, pkey, NULL))
+        || !TEST_ptr(sig_alg = EVP_SIGNATURE_fetch(lib_ctx, td->alg, NULL))
+        || !TEST_int_eq(EVP_PKEY_sign_message_init(sctx, sig_alg, params), 1)
+        || !TEST_int_eq(EVP_PKEY_sign(sctx, NULL, &psig_len,
+                            td->msg, td->msg_len),
+            1)
+        || !TEST_true(EVP_PKEY_get_size_t_param(pkey, OSSL_PKEY_PARAM_MAX_SIZE,
+            &sig_len2))
+        || !TEST_int_eq(sig_len2, psig_len)
+        || !TEST_ptr(psig = OPENSSL_zalloc(psig_len))
+        || !TEST_int_eq(EVP_PKEY_sign(sctx, psig, &psig_len,
+                            td->msg, td->msg_len),
+            1)
+        || !TEST_int_eq(EVP_Q_digest(lib_ctx, "SHA256", NULL, psig, psig_len,
+                            digest, &digest_len),
+            1)
+        || !TEST_mem_eq(digest, digest_len, td->sig_digest, td->sig_digest_len))
         goto err;
     ret = 1;
 err:
@@ -183,7 +187,7 @@ static int ml_dsa_sigver_test(int tst_id)
     *p = OSSL_PARAM_construct_end();
 
     if (!TEST_true(ml_dsa_create_keypair(&pkey, td->alg, NULL, 0,
-                                         td->pub, td->pub_len, 1)))
+            td->pub, td->pub_len, 1)))
         goto err;
 
     if (!TEST_ptr(vctx = EVP_PKEY_CTX_new_from_pkey(lib_ctx, pkey, NULL)))
@@ -191,8 +195,9 @@ static int ml_dsa_sigver_test(int tst_id)
     if (!TEST_ptr(sig_alg = EVP_SIGNATURE_fetch(lib_ctx, td->alg, NULL)))
         goto err;
     if (!TEST_int_eq(EVP_PKEY_verify_message_init(vctx, sig_alg, params), 1)
-            || !TEST_int_eq(EVP_PKEY_verify(vctx, td->sig, td->sig_len,
-                                            td->msg, td->msg_len), td->expected))
+        || !TEST_int_eq(EVP_PKEY_verify(vctx, td->sig, td->sig_len,
+                            td->msg, td->msg_len),
+            td->expected))
         goto err;
     ret = 1;
 err:
@@ -210,13 +215,13 @@ static int ml_dsa_key_dup_test(void)
     EVP_PKEY_CTX *ctx = NULL;
 
     if (!TEST_ptr(pkey = do_gen_key(tst->name, tst->seed, tst->seed_len))
-            || !TEST_ptr(pkey_copy = EVP_PKEY_dup(pkey))
-            || !TEST_int_eq(EVP_PKEY_eq(pkey, pkey_copy), 1)
-            || !TEST_ptr(ctx = EVP_PKEY_CTX_new_from_pkey(lib_ctx, pkey_copy, NULL))
-            || !TEST_int_eq(EVP_PKEY_check(ctx), 1))
+        || !TEST_ptr(pkey_copy = EVP_PKEY_dup(pkey))
+        || !TEST_int_eq(EVP_PKEY_eq(pkey, pkey_copy), 1)
+        || !TEST_ptr(ctx = EVP_PKEY_CTX_new_from_pkey(lib_ctx, pkey_copy, NULL))
+        || !TEST_int_eq(EVP_PKEY_check(ctx), 1))
         goto err;
     ret = 1;
- err:
+err:
     EVP_PKEY_free(pkey);
     EVP_PKEY_free(pkey_copy);
     EVP_PKEY_CTX_free(ctx);
@@ -233,21 +238,21 @@ static int ml_dsa_key_internal_test(void)
 
     /* We should fail to fetch and fail here if the libctx is not set */
     if (!TEST_ptr_null(key = ossl_ml_dsa_key_new(NULL, NULL, EVP_PKEY_ML_DSA_44))
-            /* fail if the algorithm is invalid */
-            || !TEST_ptr_null(key = ossl_ml_dsa_key_new(lib_ctx, "", NID_undef))
-            /* Dup should fail if the src is NULL */
-            || !TEST_ptr_null(key1 = ossl_ml_dsa_key_dup(NULL, OSSL_KEYMGMT_SELECT_KEYPAIR))
-            || !TEST_ptr(key = ossl_ml_dsa_key_new(lib_ctx, "?fips=yes",
-                                                   EVP_PKEY_ML_DSA_44))
-            || !TEST_ptr(key1 = ossl_ml_dsa_key_dup(key, OSSL_KEYMGMT_SELECT_KEYPAIR))
-            || !TEST_true(ossl_ml_dsa_key_pub_alloc(key1))
-            || !TEST_false(ossl_ml_dsa_key_pub_alloc(key1))
-            || !TEST_true(ossl_ml_dsa_key_priv_alloc(key))
-            || !TEST_false(ossl_ml_dsa_key_priv_alloc(key)))
+        /* fail if the algorithm is invalid */
+        || !TEST_ptr_null(key = ossl_ml_dsa_key_new(lib_ctx, "", NID_undef))
+        /* Dup should fail if the src is NULL */
+        || !TEST_ptr_null(key1 = ossl_ml_dsa_key_dup(NULL, OSSL_KEYMGMT_SELECT_KEYPAIR))
+        || !TEST_ptr(key = ossl_ml_dsa_key_new(lib_ctx, "?fips=yes",
+                         EVP_PKEY_ML_DSA_44))
+        || !TEST_ptr(key1 = ossl_ml_dsa_key_dup(key, OSSL_KEYMGMT_SELECT_KEYPAIR))
+        || !TEST_true(ossl_ml_dsa_key_pub_alloc(key1))
+        || !TEST_false(ossl_ml_dsa_key_pub_alloc(key1))
+        || !TEST_true(ossl_ml_dsa_key_priv_alloc(key))
+        || !TEST_false(ossl_ml_dsa_key_priv_alloc(key)))
         goto err;
 
     ret = 1;
- err:
+err:
     ossl_ml_dsa_key_free(key1);
     ossl_ml_dsa_key_free(key);
     return ret;
@@ -266,21 +271,21 @@ static int from_data_invalid_public_test(void)
     pub[0] ^= 1;
 
     if (!TEST_true(ml_dsa_create_keypair(&pkey, tst->name, tst->priv, tst->priv_len,
-                                         tst->pub, tst->pub_len, 1))
-            || !TEST_true(ml_dsa_create_keypair(&pkey, tst->name, tst->priv, tst->priv_len,
-                                                pub, tst->pub_len, 0))
-            || !TEST_true(ml_dsa_create_keypair(&pkey, tst->name, tst->priv, tst->priv_len,
-                                                tst->pub, tst->pub_len - 1, 0))
-            || !TEST_true(ml_dsa_create_keypair(&pkey, tst->name, tst->priv, tst->priv_len,
-                                                tst->pub, tst->pub_len + 1, 0))
-            || !TEST_true(ml_dsa_create_keypair(&pkey, tst->name, tst->priv, tst->priv_len - 1,
-                                                tst->pub, tst->pub_len, 0))
-            || !TEST_true(ml_dsa_create_keypair(&pkey, tst->name, tst->priv, tst->priv_len + 1,
-                                                tst->pub, tst->pub_len, 0)))
+            tst->pub, tst->pub_len, 1))
+        || !TEST_true(ml_dsa_create_keypair(&pkey, tst->name, tst->priv, tst->priv_len,
+            pub, tst->pub_len, 0))
+        || !TEST_true(ml_dsa_create_keypair(&pkey, tst->name, tst->priv, tst->priv_len,
+            tst->pub, tst->pub_len - 1, 0))
+        || !TEST_true(ml_dsa_create_keypair(&pkey, tst->name, tst->priv, tst->priv_len,
+            tst->pub, tst->pub_len + 1, 0))
+        || !TEST_true(ml_dsa_create_keypair(&pkey, tst->name, tst->priv, tst->priv_len - 1,
+            tst->pub, tst->pub_len, 0))
+        || !TEST_true(ml_dsa_create_keypair(&pkey, tst->name, tst->priv, tst->priv_len + 1,
+            tst->pub, tst->pub_len, 0)))
         goto err;
 
     ret = 1;
- err:
+err:
     OPENSSL_free(pub);
     EVP_PKEY_free(pkey);
     return ret;
@@ -295,23 +300,25 @@ static int from_data_bad_input_test(void)
     uint32_t i = 0;
 
     if (!TEST_ptr(ctx = EVP_PKEY_CTX_new_from_name(lib_ctx, "ML-DSA-44", NULL))
-            || !TEST_int_eq(EVP_PKEY_fromdata_init(ctx), 1)
-            || !TEST_ptr(EVP_PKEY_fromdata_settable(ctx, OSSL_KEYMGMT_SELECT_KEYPAIR))
-            || !TEST_ptr_null(EVP_PKEY_fromdata_settable(ctx, 0)))
+        || !TEST_int_eq(EVP_PKEY_fromdata_init(ctx), 1)
+        || !TEST_ptr(EVP_PKEY_fromdata_settable(ctx, OSSL_KEYMGMT_SELECT_KEYPAIR))
+        || !TEST_ptr_null(EVP_PKEY_fromdata_settable(ctx, 0)))
         goto err;
 
     params[0] = OSSL_PARAM_construct_uint32(OSSL_PKEY_PARAM_PRIV_KEY, &i);
     params[1] = OSSL_PARAM_construct_end();
     if (!TEST_int_ne(EVP_PKEY_fromdata(ctx, &pkey, OSSL_KEYMGMT_SELECT_PRIVATE_KEY,
-                                       params), 1))
+                         params),
+            1))
         goto err;
     params[0] = OSSL_PARAM_construct_uint32(OSSL_PKEY_PARAM_PUB_KEY, &i);
     params[1] = OSSL_PARAM_construct_end();
     if (!TEST_int_ne(EVP_PKEY_fromdata(ctx, &pkey, OSSL_KEYMGMT_SELECT_PUBLIC_KEY,
-                                       params), 1))
+                         params),
+            1))
         goto err;
     ret = 1;
- err:
+err:
     EVP_PKEY_free(pkey);
     EVP_PKEY_CTX_free(ctx);
     return ret;
@@ -325,26 +332,26 @@ static int ml_dsa_keygen_drbg_test(void)
     uint8_t *priv = NULL, *pub = NULL;
 
     if (!TEST_ptr(pkey = do_gen_key("ML-DSA-44", NULL, 0))
-            || !TEST_ptr(pkey2 = do_gen_key("ML-DSA-44", NULL, 0))
-            || !TEST_ptr(pkey3 = do_gen_key("ML-DSA-65", NULL, 0))
-            || !TEST_int_eq(EVP_PKEY_eq(pkey, pkey2), 0)
-            || !TEST_int_eq(EVP_PKEY_eq(pkey, pkey3), -1)
-            || !TEST_int_eq(EVP_PKEY_get_raw_private_key(pkey, NULL, &len), 1)
-            || !TEST_int_gt(len, 0)
-            || !TEST_ptr(priv = OPENSSL_malloc(len))
-            || !TEST_int_eq(EVP_PKEY_get_raw_private_key(pkey, priv, &len), 1)
-            || !TEST_int_eq(EVP_PKEY_get_raw_public_key(pkey, NULL, &len), 1)
-            || !TEST_int_gt(len, 0)
-            || !TEST_ptr(pub = OPENSSL_malloc(len))
-            || !TEST_int_eq(EVP_PKEY_get_raw_public_key(pkey, pub, &len), 1)
-            /* Load just the public part into a PKEY */
-            || !TEST_true(ml_dsa_create_keypair(&pkey_pub, "ML-DSA-44", NULL, 0,
-                                                pub, len, 1))
-            /* test that the KEY's are equal */
-            || !TEST_int_eq(EVP_PKEY_eq(pkey_pub, pkey), 1))
+        || !TEST_ptr(pkey2 = do_gen_key("ML-DSA-44", NULL, 0))
+        || !TEST_ptr(pkey3 = do_gen_key("ML-DSA-65", NULL, 0))
+        || !TEST_int_eq(EVP_PKEY_eq(pkey, pkey2), 0)
+        || !TEST_int_eq(EVP_PKEY_eq(pkey, pkey3), -1)
+        || !TEST_int_eq(EVP_PKEY_get_raw_private_key(pkey, NULL, &len), 1)
+        || !TEST_int_gt(len, 0)
+        || !TEST_ptr(priv = OPENSSL_malloc(len))
+        || !TEST_int_eq(EVP_PKEY_get_raw_private_key(pkey, priv, &len), 1)
+        || !TEST_int_eq(EVP_PKEY_get_raw_public_key(pkey, NULL, &len), 1)
+        || !TEST_int_gt(len, 0)
+        || !TEST_ptr(pub = OPENSSL_malloc(len))
+        || !TEST_int_eq(EVP_PKEY_get_raw_public_key(pkey, pub, &len), 1)
+        /* Load just the public part into a PKEY */
+        || !TEST_true(ml_dsa_create_keypair(&pkey_pub, "ML-DSA-44", NULL, 0,
+            pub, len, 1))
+        /* test that the KEY's are equal */
+        || !TEST_int_eq(EVP_PKEY_eq(pkey_pub, pkey), 1))
         goto err;
     ret = 1;
- err:
+err:
     OPENSSL_free(pub);
     OPENSSL_free(priv);
     EVP_PKEY_free(pkey);
@@ -357,9 +364,9 @@ static int ml_dsa_keygen_drbg_test(void)
 static uint8_t msg1[] = "Hello World";
 static uint8_t ctx1[] = "Context Test";
 /* This message size will not fit into the internal buffer - so an alloc occurs */
-static uint8_t msg2[2048] = {0};
+static uint8_t msg2[2048] = { 0 };
 /* This ctx is larger than 255 and will fail */
-static uint8_t ctx2[256] = {0};
+static uint8_t ctx2[256] = { 0 };
 
 static struct sig_params_st {
     uint8_t *msg;
@@ -398,31 +405,31 @@ static int do_ml_dsa_sign_verify(const char *alg, int tstid)
         goto err;
 
     *p++ = OSSL_PARAM_construct_int(OSSL_SIGNATURE_PARAM_MESSAGE_ENCODING,
-                                    (int *)&sp->encoded);
+        (int *)&sp->encoded);
     if (sp->ctx != NULL)
         *p++ = OSSL_PARAM_construct_octet_string(OSSL_SIGNATURE_PARAM_CONTEXT_STRING,
-                                                 sp->ctx, sp->ctx_len);
+            sp->ctx, sp->ctx_len);
     *p++ = OSSL_PARAM_construct_end();
 
     if (!TEST_ptr(sctx = EVP_PKEY_CTX_new_from_pkey(lib_ctx, key, NULL))
-            || !TEST_ptr(sig_alg = EVP_SIGNATURE_fetch(lib_ctx, alg, NULL))
-            || !TEST_int_eq(EVP_PKEY_sign_message_init(sctx, sig_alg, params), sp->expected))
+        || !TEST_ptr(sig_alg = EVP_SIGNATURE_fetch(lib_ctx, alg, NULL))
+        || !TEST_int_eq(EVP_PKEY_sign_message_init(sctx, sig_alg, params), sp->expected))
         goto err;
     if (sp->expected == 0) {
         ret = 1; /* return true as we expected to fail */
         goto err;
     }
     if (!TEST_int_eq(EVP_PKEY_sign(sctx, NULL, &sig_len, sp->msg, sp->msg_len), 1)
-            || !TEST_ptr(sig = OPENSSL_zalloc(sig_len)))
+        || !TEST_ptr(sig = OPENSSL_zalloc(sig_len)))
         goto err;
     sig_len--;
     if (!TEST_int_eq(EVP_PKEY_sign(sctx, sig, &sig_len, sp->msg, sp->msg_len), 0))
         goto err;
     sig_len++;
     if (!TEST_int_eq(EVP_PKEY_sign(sctx, sig, &sig_len, sp->msg, sp->msg_len), 1)
-            || !TEST_ptr(vctx = EVP_PKEY_CTX_new_from_pkey(lib_ctx, key, NULL))
-            || !TEST_int_eq(EVP_PKEY_verify_message_init(vctx, sig_alg, params), 1)
-            || !TEST_int_eq(EVP_PKEY_verify(vctx, sig, sig_len, sp->msg, sp->msg_len), 1))
+        || !TEST_ptr(vctx = EVP_PKEY_CTX_new_from_pkey(lib_ctx, key, NULL))
+        || !TEST_int_eq(EVP_PKEY_verify_message_init(vctx, sig_alg, params), 1)
+        || !TEST_int_eq(EVP_PKEY_verify(vctx, sig, sig_len, sp->msg, sp->msg_len), 1))
         goto err;
     ret = 1;
 err:
@@ -461,42 +468,49 @@ static int ml_dsa_digest_sign_verify_test(void)
         goto err;
 
     *p++ = OSSL_PARAM_construct_int(OSSL_SIGNATURE_PARAM_MESSAGE_ENCODING,
-                                    (int *)&sp->encoded);
+        (int *)&sp->encoded);
     if (sp->ctx != NULL)
         *p++ = OSSL_PARAM_construct_octet_string(OSSL_SIGNATURE_PARAM_CONTEXT_STRING,
-                                                 sp->ctx, sp->ctx_len);
+            sp->ctx, sp->ctx_len);
     *p++ = OSSL_PARAM_construct_end();
 
     if (!TEST_ptr(mctx = EVP_MD_CTX_new())
-            || !TEST_int_eq(EVP_DigestSignInit_ex(mctx, NULL, "SHA256",
-                                                  lib_ctx, "?fips=true",
-                                                  key, params), 0)
-            || !TEST_int_eq(EVP_DigestSignInit_ex(mctx, NULL, NULL, lib_ctx,
-                                                  "?fips=true", key, params), 1))
+        || !TEST_int_eq(EVP_DigestSignInit_ex(mctx, NULL, "SHA256",
+                            lib_ctx, "?fips=true",
+                            key, params),
+            0)
+        || !TEST_int_eq(EVP_DigestSignInit_ex(mctx, NULL, NULL, lib_ctx,
+                            "?fips=true", key, params),
+            1))
         goto err;
     if (sp->expected == 0) {
         ret = 1; /* return true as we expected to fail */
         goto err;
     }
     if (!TEST_int_eq(EVP_DigestSign(mctx, NULL, &sig_len, sp->msg, sp->msg_len), 1)
-            || !TEST_ptr(sig = OPENSSL_zalloc(sig_len)))
+        || !TEST_ptr(sig = OPENSSL_zalloc(sig_len)))
         goto err;
     sig_len--;
     if (!TEST_int_eq(EVP_DigestSign(mctx, sig, &sig_len, sp->msg, sp->msg_len), 0))
         goto err;
     sig_len++;
     if (!TEST_int_eq(EVP_DigestSignInit_ex(mctx, NULL, NULL, lib_ctx, "?fips=true",
-                                           key, params), 1)
-            || !TEST_int_eq(EVP_DigestSign(mctx, sig, &sig_len,
-                                           sp->msg, sp->msg_len), 1)
-            || !TEST_int_eq(EVP_DigestVerifyInit_ex(mctx, NULL, "SHA256",
-                                                    lib_ctx, "?fips=true",
-                                                    key, params), 0)
-            || !TEST_int_eq(EVP_DigestVerifyInit_ex(mctx, NULL, NULL,
-                                                    lib_ctx, "?fips=true",
-                                                    key, params), 1)
-            || !TEST_int_eq(EVP_DigestVerify(mctx, sig, sig_len,
-                                             sp->msg, sp->msg_len), 1))
+                         key, params),
+            1)
+        || !TEST_int_eq(EVP_DigestSign(mctx, sig, &sig_len,
+                            sp->msg, sp->msg_len),
+            1)
+        || !TEST_int_eq(EVP_DigestVerifyInit_ex(mctx, NULL, "SHA256",
+                            lib_ctx, "?fips=true",
+                            key, params),
+            0)
+        || !TEST_int_eq(EVP_DigestVerifyInit_ex(mctx, NULL, NULL,
+                            lib_ctx, "?fips=true",
+                            key, params),
+            1)
+        || !TEST_int_eq(EVP_DigestVerify(mctx, sig, sig_len,
+                            sp->msg, sp->msg_len),
+            1))
         goto err;
     ret = 1;
 err:
@@ -522,15 +536,15 @@ static int ml_dsa_priv_pub_bad_t0_test(void)
      */
     priv[td->priv_len - 6 * 416] ^= 1;
     if (!TEST_true(ml_dsa_create_keypair(&key, td->alg,
-                                         priv, td->priv_len, NULL, 0, 0)))
+            priv, td->priv_len, NULL, 0, 0)))
         goto err;
 
     priv[td->priv_len - 6 * 416] ^= 1;
     if (!TEST_true(ml_dsa_create_keypair(&key, td->alg,
-                                         priv, td->priv_len, NULL, 0, 1)))
+            priv, td->priv_len, NULL, 0, 1)))
         goto err;
     ret = 1;
- err:
+err:
     OPENSSL_free(priv);
     EVP_PKEY_free(key);
     return ret;
@@ -541,7 +555,7 @@ const OPTIONS *test_get_options(void)
     static const OPTIONS options[] = {
         OPT_TEST_OPTIONS_DEFAULT_USAGE,
         { "config", OPT_CONFIG_FILE, '<',
-          "The configuration file to use for the libctx" },
+            "The configuration file to use for the libctx" },
         { NULL }
     };
     return options;
