@@ -26,15 +26,13 @@ static int test_double_config(void)
     int testresult = 0;
     EVP_MD *sha256 = NULL;
 
-    if (!TEST_ptr(configfile))
-        return 0;
     if (!TEST_ptr(ctx))
         return 0;
 
     if (!TEST_true(OSSL_LIB_CTX_load_config(ctx, configfile)))
-        return 0;
+        goto err;
     if (!TEST_true(OSSL_LIB_CTX_load_config(ctx, configfile)))
-        return 0;
+        goto err;
 
     /* Check we can actually fetch something */
     sha256 = EVP_MD_fetch(ctx, "SHA2-256", NULL);
@@ -42,7 +40,7 @@ static int test_double_config(void)
         goto err;
 
     testresult = 1;
- err:
+err:
     EVP_MD_free(sha256);
     OSSL_LIB_CTX_free(ctx);
     return testresult;
@@ -54,9 +52,6 @@ static int test_recursive_config(void)
     int testresult = 0;
     unsigned long err;
 
-    if (!TEST_ptr(recurseconfigfile))
-        goto err;
-
     if (!TEST_ptr(ctx))
         goto err;
 
@@ -67,7 +62,7 @@ static int test_recursive_config(void)
     /* We expect to get a recursion error here */
     if (ERR_GET_REASON(err) == CONF_R_RECURSIVE_SECTION_REFERENCE)
         testresult = 1;
- err:
+err:
     OSSL_LIB_CTX_free(ctx);
     return testresult;
 }
@@ -115,7 +110,7 @@ static int test_path_config(void)
     OSSL_PROVIDER_unload(prov);
 
     testresult = 1;
- err:
+err:
     OSSL_LIB_CTX_free(ctx);
     return testresult;
 }
