@@ -12,7 +12,7 @@
 #include "internal/quic_ackm.h"
 #include "internal/quic_cc.h"
 
-static OSSL_TIME fake_time = {0};
+static OSSL_TIME fake_time = { 0 };
 
 #define TIME_BASE (ossl_ticks2time(123 * OSSL_TIME_SECOND))
 
@@ -104,8 +104,8 @@ static int helper_init(struct helper *h, size_t num_pkts)
 
     /* Initialise ACK manager. */
     h->ackm = ossl_ackm_new(fake_now, NULL, &h->statm,
-                            &ossl_cc_dummy_method, h->ccdata,
-                            /* is_server */0);
+        &ossl_cc_dummy_method, h->ccdata,
+        /* is_server */ 0);
     if (!TEST_ptr(h->ackm))
         goto err;
 
@@ -142,18 +142,18 @@ static const QUIC_PN high_linear_20[] = {
  * ******************************************************************
  */
 struct tx_ack_test_case {
-    const QUIC_PN              *pn_table;
-    size_t                      pn_table_len;
-    const OSSL_QUIC_ACK_RANGE  *ack_ranges;
-    size_t                      num_ack_ranges;
-    const char                 *expect_ack; /* 1=ack, 2=lost, 4=discarded */
+    const QUIC_PN *pn_table;
+    size_t pn_table_len;
+    const OSSL_QUIC_ACK_RANGE *ack_ranges;
+    size_t num_ack_ranges;
+    const char *expect_ack; /* 1=ack, 2=lost, 4=discarded */
 };
 
-#define DEFINE_TX_ACK_CASE(n, pntable)                          \
-    static const struct tx_ack_test_case tx_ack_case_##n = {    \
-        (pntable), OSSL_NELEM(pntable),                         \
-        tx_ack_range_##n, OSSL_NELEM(tx_ack_range_##n),         \
-        tx_ack_expect_##n                                       \
+#define DEFINE_TX_ACK_CASE(n, pntable)                       \
+    static const struct tx_ack_test_case tx_ack_case_##n = { \
+        (pntable), OSSL_NELEM(pntable),                      \
+        tx_ack_range_##n, OSSL_NELEM(tx_ack_range_##n),      \
+        tx_ack_expect_##n                                    \
     }
 
 /* One range, partial coverage of space */
@@ -306,15 +306,18 @@ static const struct tx_ack_test_case *const tx_ack_cases[] = {
 };
 
 enum {
-    MODE_ACK, MODE_DISCARD, MODE_PTO, MODE_NUM
+    MODE_ACK,
+    MODE_DISCARD,
+    MODE_PTO,
+    MODE_NUM
 };
 
 static int test_probe_counts(const OSSL_ACKM_PROBE_INFO *p,
-                             uint32_t anti_deadlock_handshake,
-                             uint32_t anti_deadlock_initial,
-                             uint32_t pto_initial,
-                             uint32_t pto_handshake,
-                             uint32_t pto_app)
+    uint32_t anti_deadlock_handshake,
+    uint32_t anti_deadlock_initial,
+    uint32_t pto_initial,
+    uint32_t pto_handshake,
+    uint32_t pto_app)
 {
     if (!TEST_uint_eq(p->anti_deadlock_handshake, anti_deadlock_handshake))
         return 0;
@@ -341,7 +344,7 @@ static int test_tx_ack_case_actual(int tidx, int space, int mode)
     size_t i;
     OSSL_ACKM_TX_PKT *tx;
     const struct tx_ack_test_case *c = tx_ack_cases[tidx];
-    OSSL_QUIC_FRAME_ACK ack = {0};
+    OSSL_QUIC_FRAME_ACK ack = { 0 };
     OSSL_TIME loss_detection_deadline = ossl_time_zero();
 
     /* Cannot discard app space, so skip this */
@@ -355,8 +358,8 @@ static int test_tx_ack_case_actual(int tidx, int space, int mode)
 
     /* Arm callback. */
     ossl_ackm_set_loss_detection_deadline_callback(h.ackm,
-                                                   on_loss_detection_deadline_callback,
-                                                   &loss_detection_deadline);
+        on_loss_detection_deadline_callback,
+        &loss_detection_deadline);
 
     /* Allocate TX packet structures. */
     for (i = 0; i < c->pn_table_len; ++i) {
@@ -364,18 +367,18 @@ static int test_tx_ack_case_actual(int tidx, int space, int mode)
         if (!TEST_ptr(tx))
             goto err;
 
-        tx->pkt_num             = c->pn_table[i];
-        tx->pkt_space           = space;
-        tx->is_inflight         = 1;
-        tx->is_ack_eliciting    = 1;
-        tx->num_bytes           = 123;
-        tx->largest_acked       = QUIC_PN_INVALID;
-        tx->on_lost             = on_lost;
-        tx->on_acked            = on_acked;
-        tx->on_discarded        = on_discarded;
-        tx->cb_arg              = &h.pkts[i];
+        tx->pkt_num = c->pn_table[i];
+        tx->pkt_space = space;
+        tx->is_inflight = 1;
+        tx->is_ack_eliciting = 1;
+        tx->num_bytes = 123;
+        tx->largest_acked = QUIC_PN_INVALID;
+        tx->on_lost = on_lost;
+        tx->on_acked = on_acked;
+        tx->on_discarded = on_discarded;
+        tx->cb_arg = &h.pkts[i];
 
-        tx->time  = fake_time;
+        tx->time = fake_time;
 
         if (!TEST_int_eq(ossl_ackm_on_tx_packet(h.ackm, tx), 1))
             goto err;
@@ -387,7 +390,7 @@ static int test_tx_ack_case_actual(int tidx, int space, int mode)
             goto err;
 
         /* Check all discard callbacks were called. */
-        for (i  = 0; i < c->pn_table_len; ++i) {
+        for (i = 0; i < c->pn_table_len; ++i) {
             if (!TEST_int_eq(h.pkts[i].acked, 0))
                 goto err;
             if (!TEST_int_eq(h.pkts[i].lost, 0))
@@ -397,21 +400,21 @@ static int test_tx_ack_case_actual(int tidx, int space, int mode)
         }
     } else if (mode == MODE_ACK) {
         /* Try acknowledging. */
-        ack.ack_ranges      = (OSSL_QUIC_ACK_RANGE *)c->ack_ranges;
-        ack.num_ack_ranges  = c->num_ack_ranges;
+        ack.ack_ranges = (OSSL_QUIC_ACK_RANGE *)c->ack_ranges;
+        ack.num_ack_ranges = c->num_ack_ranges;
         if (!TEST_int_eq(ossl_ackm_on_rx_ack_frame(h.ackm, &ack, space, fake_time), 1))
             goto err;
 
         /* Check correct ranges were acknowledged. */
         for (i = 0; i < c->pn_table_len; ++i) {
             if (!TEST_int_eq(h.pkts[i].acked,
-                             (c->expect_ack[i] & 1) != 0 ? 1 : 0))
+                    (c->expect_ack[i] & 1) != 0 ? 1 : 0))
                 goto err;
             if (!TEST_int_eq(h.pkts[i].lost,
-                             (c->expect_ack[i] & 2) != 0 ? 1 : 0))
+                    (c->expect_ack[i] & 2) != 0 ? 1 : 0))
                 goto err;
             if (!TEST_int_eq(h.pkts[i].discarded,
-                             (c->expect_ack[i] & 4) != 0 ? 1 : 0))
+                    (c->expect_ack[i] & 4) != 0 ? 1 : 0))
                 goto err;
         }
     } else if (mode == MODE_PTO) {
@@ -455,9 +458,10 @@ static int test_tx_ack_case_actual(int tidx, int space, int mode)
                     goto err;
             } else {
                 if (!TEST_int_eq(test_probe_counts(&probe, 0, 0,
-                                                   space == QUIC_PN_SPACE_INITIAL,
-                                                   space == QUIC_PN_SPACE_HANDSHAKE,
-                                                   space == QUIC_PN_SPACE_APP), 1))
+                                     space == QUIC_PN_SPACE_INITIAL,
+                                     space == QUIC_PN_SPACE_HANDSHAKE,
+                                     space == QUIC_PN_SPACE_APP),
+                        1))
                     goto err;
             }
         }
@@ -477,17 +481,17 @@ err:
  */
 enum {
     TX_ACK_TIME_OP_END,
-    TX_ACK_TIME_OP_PKT,     /* TX packets */
-    TX_ACK_TIME_OP_ACK,     /* Synthesise incoming ACK of single PN range */
-    TX_ACK_TIME_OP_EXPECT   /* Ack/loss assertion */
+    TX_ACK_TIME_OP_PKT, /* TX packets */
+    TX_ACK_TIME_OP_ACK, /* Synthesise incoming ACK of single PN range */
+    TX_ACK_TIME_OP_EXPECT /* Ack/loss assertion */
 };
 
 struct tx_ack_time_op {
-    int       kind;
-    uint64_t  time_advance; /* all ops */
-    QUIC_PN   pn;           /* PKT, ACK */
-    size_t    num_pn;       /* PKT, ACK */
-    const char *expect;     /* 1=ack, 2=lost, 4=discarded */
+    int kind;
+    uint64_t time_advance; /* all ops */
+    QUIC_PN pn; /* PKT, ACK */
+    size_t num_pn; /* PKT, ACK */
+    const char *expect; /* 1=ack, 2=lost, 4=discarded */
 };
 
 #define TX_OP_PKT(advance, pn, num_pn) \
@@ -503,11 +507,11 @@ static const char tx_ack_time_script_1_expect[] = {
 };
 
 static const struct tx_ack_time_op tx_ack_time_script_1[] = {
-    TX_OP_PKT   (      0, 0, 1)
-    TX_OP_PKT   (3600000, 1, 1)
-    TX_OP_ACK   (   1000, 1, 1)
-    TX_OP_EXPECT(tx_ack_time_script_1_expect)
-    TX_OP_END
+    TX_OP_PKT(0, 0, 1)
+        TX_OP_PKT(3600000, 1, 1)
+            TX_OP_ACK(1000, 1, 1)
+                TX_OP_EXPECT(tx_ack_time_script_1_expect)
+                    TX_OP_END
 };
 
 static const struct tx_ack_time_op *const tx_ack_time_scripts[] = {
@@ -519,8 +523,8 @@ static int test_tx_ack_time_script(int tidx)
     int testresult = 0;
     struct helper h;
     OSSL_ACKM_TX_PKT *tx = NULL;
-    OSSL_QUIC_FRAME_ACK ack = {0};
-    OSSL_QUIC_ACK_RANGE ack_range = {0};
+    OSSL_QUIC_FRAME_ACK ack = { 0 };
+    OSSL_QUIC_ACK_RANGE ack_range = { 0 };
     size_t i, num_pkts = 0, pkt_idx = 0;
     const struct tx_ack_time_op *script = tx_ack_time_scripts[tidx], *s;
 
@@ -542,63 +546,64 @@ static int test_tx_ack_time_script(int tidx)
     /* Run script. */
     for (s = script; s->kind != TX_ACK_TIME_OP_END; ++s)
         switch (s->kind) {
-            case TX_ACK_TIME_OP_PKT:
-                for (i = 0; i < s->num_pn; ++i) {
-                    tx = h.pkts[pkt_idx + i].pkt;
+        case TX_ACK_TIME_OP_PKT:
+            for (i = 0; i < s->num_pn; ++i) {
+                tx = h.pkts[pkt_idx + i].pkt;
 
-                    tx->pkt_num             = s->pn + i;
-                    tx->pkt_space           = QUIC_PN_SPACE_INITIAL;
-                    tx->num_bytes           = 123;
-                    tx->largest_acked       = QUIC_PN_INVALID;
-                    tx->is_inflight         = 1;
-                    tx->is_ack_eliciting    = 1;
-                    tx->on_lost             = on_lost;
-                    tx->on_acked            = on_acked;
-                    tx->on_discarded        = on_discarded;
-                    tx->cb_arg              = &h.pkts[pkt_idx + i];
-
-                    fake_time = ossl_time_add(fake_time,
-                                              ossl_ticks2time(s->time_advance));
-                    tx->time   = fake_time;
-
-                    if (!TEST_int_eq(ossl_ackm_on_tx_packet(h.ackm, tx), 1))
-                        goto err;
-                }
-
-                pkt_idx += s->num_pn;
-                break;
-
-            case TX_ACK_TIME_OP_ACK:
-                ack.ack_ranges      = &ack_range;
-                ack.num_ack_ranges  = 1;
-
-                ack_range.start     = s->pn;
-                ack_range.end       = s->pn + s->num_pn;
+                tx->pkt_num = s->pn + i;
+                tx->pkt_space = QUIC_PN_SPACE_INITIAL;
+                tx->num_bytes = 123;
+                tx->largest_acked = QUIC_PN_INVALID;
+                tx->is_inflight = 1;
+                tx->is_ack_eliciting = 1;
+                tx->on_lost = on_lost;
+                tx->on_acked = on_acked;
+                tx->on_discarded = on_discarded;
+                tx->cb_arg = &h.pkts[pkt_idx + i];
 
                 fake_time = ossl_time_add(fake_time,
-                                          ossl_ticks2time(s->time_advance));
+                    ossl_ticks2time(s->time_advance));
+                tx->time = fake_time;
 
-                if (!TEST_int_eq(ossl_ackm_on_rx_ack_frame(h.ackm, &ack,
-                                                           QUIC_PN_SPACE_INITIAL,
-                                                           fake_time), 1))
+                if (!TEST_int_eq(ossl_ackm_on_tx_packet(h.ackm, tx), 1))
                     goto err;
+            }
 
-                break;
+            pkt_idx += s->num_pn;
+            break;
 
-            case TX_ACK_TIME_OP_EXPECT:
-                for (i = 0; i < num_pkts; ++i) {
-                    if (!TEST_int_eq(h.pkts[i].acked,
-                                     (s->expect[i] & 1) != 0 ? 1 : 0))
-                        goto err;
-                    if (!TEST_int_eq(h.pkts[i].lost,
-                                     (s->expect[i] & 2) != 0 ? 1 : 0))
-                        goto err;
-                    if (!TEST_int_eq(h.pkts[i].discarded,
-                                     (s->expect[i] & 4) != 0 ? 1 : 0))
-                        goto err;
-                }
+        case TX_ACK_TIME_OP_ACK:
+            ack.ack_ranges = &ack_range;
+            ack.num_ack_ranges = 1;
 
-                break;
+            ack_range.start = s->pn;
+            ack_range.end = s->pn + s->num_pn;
+
+            fake_time = ossl_time_add(fake_time,
+                ossl_ticks2time(s->time_advance));
+
+            if (!TEST_int_eq(ossl_ackm_on_rx_ack_frame(h.ackm, &ack,
+                                 QUIC_PN_SPACE_INITIAL,
+                                 fake_time),
+                    1))
+                goto err;
+
+            break;
+
+        case TX_ACK_TIME_OP_EXPECT:
+            for (i = 0; i < num_pkts; ++i) {
+                if (!TEST_int_eq(h.pkts[i].acked,
+                        (s->expect[i] & 1) != 0 ? 1 : 0))
+                    goto err;
+                if (!TEST_int_eq(h.pkts[i].lost,
+                        (s->expect[i] & 2) != 0 ? 1 : 0))
+                    goto err;
+                if (!TEST_int_eq(h.pkts[i].discarded,
+                        (s->expect[i] & 4) != 0 ? 1 : 0))
+                    goto err;
+            }
+
+            break;
         }
 
     testresult = 1;
@@ -613,87 +618,87 @@ err:
  */
 enum {
     RX_OPK_END,
-    RX_OPK_PKT,              /* RX packet */
-    RX_OPK_CHECK_UNPROC,     /* check PNs unprocessable */
-    RX_OPK_CHECK_PROC,       /* check PNs processable */
-    RX_OPK_CHECK_STATE,      /* check is_desired/deadline */
-    RX_OPK_CHECK_ACKS,       /* check ACK ranges */
-    RX_OPK_TX,               /* TX packet */
-    RX_OPK_RX_ACK,           /* RX ACK frame */
-    RX_OPK_SKIP_IF_PN_SPACE  /* skip for a given PN space */
+    RX_OPK_PKT, /* RX packet */
+    RX_OPK_CHECK_UNPROC, /* check PNs unprocessable */
+    RX_OPK_CHECK_PROC, /* check PNs processable */
+    RX_OPK_CHECK_STATE, /* check is_desired/deadline */
+    RX_OPK_CHECK_ACKS, /* check ACK ranges */
+    RX_OPK_TX, /* TX packet */
+    RX_OPK_RX_ACK, /* RX ACK frame */
+    RX_OPK_SKIP_IF_PN_SPACE /* skip for a given PN space */
 };
 
 struct rx_test_op {
-    int                         kind;
-    uint64_t                    time_advance;
+    int kind;
+    uint64_t time_advance;
 
-    QUIC_PN                     pn;     /* PKT, CHECK_(UN)PROC, TX, RX_ACK */
-    size_t                      num_pn; /* PKT, CHECK_(UN)PROC, TX, RX_ACK */
+    QUIC_PN pn; /* PKT, CHECK_(UN)PROC, TX, RX_ACK */
+    size_t num_pn; /* PKT, CHECK_(UN)PROC, TX, RX_ACK */
 
-    char                        expect_desired;     /* CHECK_STATE */
-    char                        expect_deadline;    /* CHECK_STATE */
+    char expect_desired; /* CHECK_STATE */
+    char expect_deadline; /* CHECK_STATE */
 
-    const OSSL_QUIC_ACK_RANGE  *ack_ranges;         /* CHECK_ACKS */
-    size_t                      num_ack_ranges;     /* CHECK_ACKS */
+    const OSSL_QUIC_ACK_RANGE *ack_ranges; /* CHECK_ACKS */
+    size_t num_ack_ranges; /* CHECK_ACKS */
 
-    QUIC_PN                     largest_acked;      /* TX */
+    QUIC_PN largest_acked; /* TX */
 };
 
-#define RX_OP_PKT(advance, pn, num_pn)                              \
-    {                                                               \
-      RX_OPK_PKT, (advance) * OSSL_TIME_MS, (pn), (num_pn),         \
-      0, 0, NULL, 0, 0                                              \
+#define RX_OP_PKT(advance, pn, num_pn)                        \
+    {                                                         \
+        RX_OPK_PKT, (advance) * OSSL_TIME_MS, (pn), (num_pn), \
+        0, 0, NULL, 0, 0                                      \
     },
 
-#define RX_OP_CHECK_UNPROC(advance, pn, num_pn)                     \
-    {                                                               \
-      RX_OPK_CHECK_UNPROC, (advance) * OSSL_TIME_MS, (pn), (num_pn),\
-      0, 0, NULL, 0, 0                                              \
+#define RX_OP_CHECK_UNPROC(advance, pn, num_pn)                        \
+    {                                                                  \
+        RX_OPK_CHECK_UNPROC, (advance) * OSSL_TIME_MS, (pn), (num_pn), \
+        0, 0, NULL, 0, 0                                               \
     },
 
-#define RX_OP_CHECK_PROC(advance, pn, num_pn)                       \
-    {                                                               \
-      RX_OPK_CHECK_PROC, (advance) * OSSL_TIME_MS, (pn), (num_pn),  \
-      0, 0, NULL, 0, 0                                              \
+#define RX_OP_CHECK_PROC(advance, pn, num_pn)                        \
+    {                                                                \
+        RX_OPK_CHECK_PROC, (advance) * OSSL_TIME_MS, (pn), (num_pn), \
+        0, 0, NULL, 0, 0                                             \
     },
 
 #define RX_OP_CHECK_STATE(advance, expect_desired, expect_deadline) \
     {                                                               \
-      RX_OPK_CHECK_STATE, (advance) * OSSL_TIME_MS, 0, 0,           \
-      (expect_desired), (expect_deadline), NULL, 0, 0               \
+        RX_OPK_CHECK_STATE, (advance) * OSSL_TIME_MS, 0, 0,         \
+        (expect_desired), (expect_deadline), NULL, 0, 0             \
     },
 
-#define RX_OP_CHECK_ACKS(advance, ack_ranges)                       \
-    {                                                               \
-      RX_OPK_CHECK_ACKS, (advance) * OSSL_TIME_MS, 0, 0,            \
-      0, 0, (ack_ranges), OSSL_NELEM(ack_ranges), 0                 \
+#define RX_OP_CHECK_ACKS(advance, ack_ranges)              \
+    {                                                      \
+        RX_OPK_CHECK_ACKS, (advance) * OSSL_TIME_MS, 0, 0, \
+        0, 0, (ack_ranges), OSSL_NELEM(ack_ranges), 0      \
     },
 
-#define RX_OP_CHECK_NO_ACKS(advance)                                \
-    {                                                               \
-      RX_OPK_CHECK_ACKS, (advance) * OSSL_TIME_MS, 0, 0,            \
-      0, 0, NULL, 0, 0                                              \
+#define RX_OP_CHECK_NO_ACKS(advance)                       \
+    {                                                      \
+        RX_OPK_CHECK_ACKS, (advance) * OSSL_TIME_MS, 0, 0, \
+        0, 0, NULL, 0, 0                                   \
     },
 
-#define RX_OP_TX(advance, pn, largest_acked)                        \
-    {                                                               \
-      RX_OPK_TX, (advance) * OSSL_TIME_MS, (pn), 1,                 \
-      0, 0, NULL, 0, (largest_acked)                                \
+#define RX_OP_TX(advance, pn, largest_acked)          \
+    {                                                 \
+        RX_OPK_TX, (advance) * OSSL_TIME_MS, (pn), 1, \
+        0, 0, NULL, 0, (largest_acked)                \
     },
 
-#define RX_OP_RX_ACK(advance, pn, num_pn)                           \
-    {                                                               \
-      RX_OPK_RX_ACK, (advance) * OSSL_TIME_MS, (pn), (num_pn),      \
-      0, 0, NULL, 0, 0                                              \
+#define RX_OP_RX_ACK(advance, pn, num_pn)                        \
+    {                                                            \
+        RX_OPK_RX_ACK, (advance) * OSSL_TIME_MS, (pn), (num_pn), \
+        0, 0, NULL, 0, 0                                         \
     },
 
-#define RX_OP_SKIP_IF_PN_SPACE(pn_space)                            \
-    {                                                               \
-      RX_OPK_SKIP_IF_PN_SPACE, 0, (pn_space), 0,                    \
-      0, 0, NULL, 0, 0                                              \
+#define RX_OP_SKIP_IF_PN_SPACE(pn_space)           \
+    {                                              \
+        RX_OPK_SKIP_IF_PN_SPACE, 0, (pn_space), 0, \
+        0, 0, NULL, 0, 0                           \
     },
 
-#define RX_OP_END                                                   \
+#define RX_OP_END \
     { RX_OPK_END }
 
 /* RX 1. Simple Test with ACK Desired (Packet Threshold, Exactly) */
@@ -702,23 +707,23 @@ static const OSSL_QUIC_ACK_RANGE rx_ack_ranges_1a[] = {
 };
 
 static const struct rx_test_op rx_script_1[] = {
-    RX_OP_CHECK_STATE   (0, 0, 0)   /* no threshold yet */
-    RX_OP_CHECK_PROC    (0, 0, 3)
+    RX_OP_CHECK_STATE(0, 0, 0) /* no threshold yet */
+    RX_OP_CHECK_PROC(0, 0, 3)
 
-    RX_OP_PKT           (0, 0, 2)   /* two packets, threshold */
-    RX_OP_CHECK_UNPROC  (0, 0, 2)
-    RX_OP_CHECK_PROC    (0, 2, 1)
-    RX_OP_CHECK_STATE   (0, 1, 0)   /* threshold met, immediate */
-    RX_OP_CHECK_ACKS    (0, rx_ack_ranges_1a)
+        RX_OP_PKT(0, 0, 2) /* two packets, threshold */
+    RX_OP_CHECK_UNPROC(0, 0, 2)
+        RX_OP_CHECK_PROC(0, 2, 1)
+            RX_OP_CHECK_STATE(0, 1, 0) /* threshold met, immediate */
+    RX_OP_CHECK_ACKS(0, rx_ack_ranges_1a)
 
     /* At this point we would generate e.g. a packet with an ACK. */
-    RX_OP_TX            (0, 0, 1)   /* ACKs both */
-    RX_OP_CHECK_ACKS    (0, rx_ack_ranges_1a) /* not provably ACKed yet */
-    RX_OP_RX_ACK        (0, 0, 1)   /* TX'd packet is ACK'd */
+    RX_OP_TX(0, 0, 1) /* ACKs both */
+    RX_OP_CHECK_ACKS(0, rx_ack_ranges_1a) /* not provably ACKed yet */
+    RX_OP_RX_ACK(0, 0, 1) /* TX'd packet is ACK'd */
 
-    RX_OP_CHECK_NO_ACKS (0)         /* nothing more to ACK */
-    RX_OP_CHECK_UNPROC  (0, 0, 2)   /* still unprocessable */
-    RX_OP_CHECK_PROC    (0, 2, 1)   /* still processable */
+    RX_OP_CHECK_NO_ACKS(0) /* nothing more to ACK */
+    RX_OP_CHECK_UNPROC(0, 0, 2) /* still unprocessable */
+    RX_OP_CHECK_PROC(0, 2, 1) /* still processable */
 
     RX_OP_END
 };
@@ -739,41 +744,41 @@ static const struct rx_test_op rx_script_2[] = {
      * generation, so a different RX_OP_CHECK_STATE test is needed.
      */
     RX_OP_SKIP_IF_PN_SPACE(QUIC_PN_SPACE_INITIAL)
-    RX_OP_SKIP_IF_PN_SPACE(QUIC_PN_SPACE_HANDSHAKE)
+        RX_OP_SKIP_IF_PN_SPACE(QUIC_PN_SPACE_HANDSHAKE)
 
-    RX_OP_CHECK_STATE   (0, 0, 0)   /* no threshold yet */
-    RX_OP_CHECK_PROC    (0, 0, 3)
+            RX_OP_CHECK_STATE(0, 0, 0) /* no threshold yet */
+    RX_OP_CHECK_PROC(0, 0, 3)
 
     /* First packet always generates an ACK so get it out of the way. */
-    RX_OP_PKT           (0, 0, 1)
-    RX_OP_CHECK_UNPROC  (0, 0, 1)
-    RX_OP_CHECK_PROC    (0, 1, 1)
-    RX_OP_CHECK_STATE   (0, 1, 0)   /* first packet always causes ACK */
-    RX_OP_CHECK_ACKS    (0, rx_ack_ranges_2a) /* clears packet counter */
-    RX_OP_CHECK_STATE   (0, 0, 0)   /* desired state should have been cleared */
+    RX_OP_PKT(0, 0, 1)
+        RX_OP_CHECK_UNPROC(0, 0, 1)
+            RX_OP_CHECK_PROC(0, 1, 1)
+                RX_OP_CHECK_STATE(0, 1, 0) /* first packet always causes ACK */
+    RX_OP_CHECK_ACKS(0, rx_ack_ranges_2a) /* clears packet counter */
+    RX_OP_CHECK_STATE(0, 0, 0) /* desired state should have been cleared */
 
     /* Second packet should not cause ACK-desired state */
-    RX_OP_PKT           (0, 1, 1)   /* just one packet, threshold is 2 */
-    RX_OP_CHECK_UNPROC  (0, 0, 2)
-    RX_OP_CHECK_PROC    (0, 2, 1)
-    RX_OP_CHECK_STATE   (0, 0, 1)   /* threshold not yet met, so deadline */
+    RX_OP_PKT(0, 1, 1) /* just one packet, threshold is 2 */
+    RX_OP_CHECK_UNPROC(0, 0, 2)
+        RX_OP_CHECK_PROC(0, 2, 1)
+            RX_OP_CHECK_STATE(0, 0, 1) /* threshold not yet met, so deadline */
     /* Don't check ACKs here, as it would reset our threshold counter. */
 
     /* Now receive a second packet, triggering the threshold */
-    RX_OP_PKT           (0, 2, 1)   /* second packet meets threshold */
-    RX_OP_CHECK_UNPROC  (0, 0, 3)
-    RX_OP_CHECK_PROC    (0, 3, 1)
-    RX_OP_CHECK_STATE   (0, 1, 0)   /* desired immediately */
-    RX_OP_CHECK_ACKS    (0, rx_ack_ranges_2b)
+    RX_OP_PKT(0, 2, 1) /* second packet meets threshold */
+    RX_OP_CHECK_UNPROC(0, 0, 3)
+        RX_OP_CHECK_PROC(0, 3, 1)
+            RX_OP_CHECK_STATE(0, 1, 0) /* desired immediately */
+    RX_OP_CHECK_ACKS(0, rx_ack_ranges_2b)
 
     /* At this point we would generate e.g. a packet with an ACK. */
-    RX_OP_TX            (0, 0, 2)   /* ACKs all */
-    RX_OP_CHECK_ACKS    (0, rx_ack_ranges_2b) /* not provably ACKed yet */
-    RX_OP_RX_ACK        (0, 0, 1)   /* TX'd packet is ACK'd */
+    RX_OP_TX(0, 0, 2) /* ACKs all */
+    RX_OP_CHECK_ACKS(0, rx_ack_ranges_2b) /* not provably ACKed yet */
+    RX_OP_RX_ACK(0, 0, 1) /* TX'd packet is ACK'd */
 
-    RX_OP_CHECK_NO_ACKS (0)         /* nothing more to ACK */
-    RX_OP_CHECK_UNPROC  (0, 0, 3)   /* still unprocessable */
-    RX_OP_CHECK_PROC    (0, 3, 1)   /* still processable */
+    RX_OP_CHECK_NO_ACKS(0) /* nothing more to ACK */
+    RX_OP_CHECK_UNPROC(0, 0, 3) /* still unprocessable */
+    RX_OP_CHECK_PROC(0, 3, 1) /* still processable */
 
     RX_OP_END
 };
@@ -792,52 +797,52 @@ static const OSSL_QUIC_ACK_RANGE rx_ack_ranges_3c[] = {
 };
 
 static const struct rx_test_op rx_script_3[] = {
-    RX_OP_CHECK_STATE   (0, 0, 0)   /* no threshold yet */
-    RX_OP_CHECK_PROC    (0, 0, 11)
+    RX_OP_CHECK_STATE(0, 0, 0) /* no threshold yet */
+    RX_OP_CHECK_PROC(0, 0, 11)
 
     /* First packet always generates an ACK so get it out of the way. */
-    RX_OP_PKT           (0, 0, 1)
-    RX_OP_CHECK_UNPROC  (0, 0, 1)
-    RX_OP_CHECK_PROC    (0, 1, 1)
-    RX_OP_CHECK_STATE   (0, 1, 0)   /* first packet always causes ACK */
-    RX_OP_CHECK_ACKS    (0, rx_ack_ranges_3a) /* clears packet counter */
-    RX_OP_CHECK_STATE   (0, 0, 0)   /* desired state should have been cleared */
+    RX_OP_PKT(0, 0, 1)
+        RX_OP_CHECK_UNPROC(0, 0, 1)
+            RX_OP_CHECK_PROC(0, 1, 1)
+                RX_OP_CHECK_STATE(0, 1, 0) /* first packet always causes ACK */
+    RX_OP_CHECK_ACKS(0, rx_ack_ranges_3a) /* clears packet counter */
+    RX_OP_CHECK_STATE(0, 0, 0) /* desired state should have been cleared */
 
     /* Generate ten packets, exceeding the threshold. */
-    RX_OP_PKT           (0, 1, 10)  /* ten packets, threshold is 2 */
-    RX_OP_CHECK_UNPROC  (0, 0, 11)
-    RX_OP_CHECK_PROC    (0, 11, 1)
-    RX_OP_CHECK_STATE   (0, 1, 0)   /* threshold met, immediate */
-    RX_OP_CHECK_ACKS    (0, rx_ack_ranges_3b)
+    RX_OP_PKT(0, 1, 10) /* ten packets, threshold is 2 */
+    RX_OP_CHECK_UNPROC(0, 0, 11)
+        RX_OP_CHECK_PROC(0, 11, 1)
+            RX_OP_CHECK_STATE(0, 1, 0) /* threshold met, immediate */
+    RX_OP_CHECK_ACKS(0, rx_ack_ranges_3b)
 
     /*
      * Test TX'ing a packet which doesn't ACK anything.
      */
-    RX_OP_TX            (0, 0, QUIC_PN_INVALID)
-    RX_OP_RX_ACK        (0, 0, 1)
+    RX_OP_TX(0, 0, QUIC_PN_INVALID)
+        RX_OP_RX_ACK(0, 0, 1)
 
     /*
      * At this point we would generate a packet with an ACK immediately.
      * TX a packet which when ACKed makes [0,5] provably ACKed.
      */
-    RX_OP_TX            (0, 1, 5)
-    RX_OP_CHECK_ACKS    (0, rx_ack_ranges_3b) /* not provably ACKed yet */
-    RX_OP_RX_ACK        (0, 1, 1)
+    RX_OP_TX(0, 1, 5)
+        RX_OP_CHECK_ACKS(0, rx_ack_ranges_3b) /* not provably ACKed yet */
+    RX_OP_RX_ACK(0, 1, 1)
 
-    RX_OP_CHECK_ACKS    (0, rx_ack_ranges_3c) /* provably ACKed now gone */
-    RX_OP_CHECK_UNPROC  (0, 0, 11) /* still unprocessable */
-    RX_OP_CHECK_PROC    (0, 11, 1) /* still processable */
+        RX_OP_CHECK_ACKS(0, rx_ack_ranges_3c) /* provably ACKed now gone */
+    RX_OP_CHECK_UNPROC(0, 0, 11) /* still unprocessable */
+    RX_OP_CHECK_PROC(0, 11, 1) /* still processable */
 
     /*
      * Now TX another packet which provably ACKs the rest when ACKed.
      */
-    RX_OP_TX            (0, 2, 10)
-    RX_OP_CHECK_ACKS    (0, rx_ack_ranges_3c) /* not provably ACKed yet */
-    RX_OP_RX_ACK        (0, 2, 1)
+    RX_OP_TX(0, 2, 10)
+        RX_OP_CHECK_ACKS(0, rx_ack_ranges_3c) /* not provably ACKed yet */
+    RX_OP_RX_ACK(0, 2, 1)
 
-    RX_OP_CHECK_NO_ACKS (0)         /* provably ACKed now gone */
-    RX_OP_CHECK_UNPROC  (0, 0, 11)  /* still unprocessable */
-    RX_OP_CHECK_PROC    (0, 11, 1)  /* still processable */
+        RX_OP_CHECK_NO_ACKS(0) /* provably ACKed now gone */
+    RX_OP_CHECK_UNPROC(0, 0, 11) /* still unprocessable */
+    RX_OP_CHECK_PROC(0, 11, 1) /* still processable */
 
     RX_OP_END
 };
@@ -854,36 +859,36 @@ static const struct rx_test_op rx_script_4[] = {
     /* The application PN space is tested in rx_script_2. */
     RX_OP_SKIP_IF_PN_SPACE(QUIC_PN_SPACE_APP)
 
-    RX_OP_CHECK_STATE   (0, 0, 0)   /* no threshold yet */
-    RX_OP_CHECK_PROC    (0, 0, 3)
+        RX_OP_CHECK_STATE(0, 0, 0) /* no threshold yet */
+    RX_OP_CHECK_PROC(0, 0, 3)
 
     /* First packet always generates an ACK so get it out of the way. */
-    RX_OP_PKT           (0, 0, 1)
-    RX_OP_CHECK_UNPROC  (0, 0, 1)
-    RX_OP_CHECK_PROC    (0, 1, 1)
-    RX_OP_CHECK_STATE   (0, 1, 0)   /* first packet always causes ACK */
-    RX_OP_CHECK_ACKS    (0, rx_ack_ranges_2a) /* clears packet counter */
-    RX_OP_CHECK_STATE   (0, 0, 0)   /* desired state should have been cleared */
+    RX_OP_PKT(0, 0, 1)
+        RX_OP_CHECK_UNPROC(0, 0, 1)
+            RX_OP_CHECK_PROC(0, 1, 1)
+                RX_OP_CHECK_STATE(0, 1, 0) /* first packet always causes ACK */
+    RX_OP_CHECK_ACKS(0, rx_ack_ranges_2a) /* clears packet counter */
+    RX_OP_CHECK_STATE(0, 0, 0) /* desired state should have been cleared */
 
     /*
      * Second packet should cause ACK-desired state because we are
      * INITIAL/HANDSHAKE (RFC 9000 s. 13.2.1)
      */
-    RX_OP_PKT           (0, 1, 1)   /* just one packet, threshold is 2 */
-    RX_OP_CHECK_UNPROC  (0, 0, 2)
-    RX_OP_CHECK_PROC    (0, 2, 1)
-    RX_OP_CHECK_STATE   (0, 1, 1)
-    RX_OP_CHECK_ACKS    (0, rx_ack_ranges_4a)
-    RX_OP_CHECK_STATE   (0, 0, 0)   /* desired state should have been cleared */
+    RX_OP_PKT(0, 1, 1) /* just one packet, threshold is 2 */
+    RX_OP_CHECK_UNPROC(0, 0, 2)
+        RX_OP_CHECK_PROC(0, 2, 1)
+            RX_OP_CHECK_STATE(0, 1, 1)
+                RX_OP_CHECK_ACKS(0, rx_ack_ranges_4a)
+                    RX_OP_CHECK_STATE(0, 0, 0) /* desired state should have been cleared */
 
     /* At this point we would generate e.g. a packet with an ACK. */
-    RX_OP_TX            (0, 0, 1)   /* ACKs all */
-    RX_OP_CHECK_ACKS    (0, rx_ack_ranges_4a) /* not provably ACKed yet */
-    RX_OP_RX_ACK        (0, 0, 1)   /* TX'd packet is ACK'd */
+    RX_OP_TX(0, 0, 1) /* ACKs all */
+    RX_OP_CHECK_ACKS(0, rx_ack_ranges_4a) /* not provably ACKed yet */
+    RX_OP_RX_ACK(0, 0, 1) /* TX'd packet is ACK'd */
 
-    RX_OP_CHECK_NO_ACKS (0)         /* nothing more to ACK */
-    RX_OP_CHECK_UNPROC  (0, 0, 2)   /* still unprocessable */
-    RX_OP_CHECK_PROC    (0, 2, 1)   /* still processable */
+    RX_OP_CHECK_NO_ACKS(0) /* nothing more to ACK */
+    RX_OP_CHECK_UNPROC(0, 0, 2) /* still unprocessable */
+    RX_OP_CHECK_PROC(0, 2, 1) /* still processable */
 
     RX_OP_END
 };
@@ -896,7 +901,7 @@ static const struct rx_test_op *const rx_test_scripts[] = {
 };
 
 static void on_ack_deadline_callback(OSSL_TIME deadline,
-                                     int pkt_space, void *arg)
+    int pkt_space, void *arg)
 {
     ((OSSL_TIME *)arg)[pkt_space] = deadline;
 }
@@ -908,8 +913,8 @@ static int test_rx_ack_actual(int tidx, int space)
     const struct rx_test_op *script = rx_test_scripts[tidx], *s;
     size_t i, num_tx = 0, txi = 0;
     const OSSL_QUIC_FRAME_ACK *ack;
-    OSSL_QUIC_FRAME_ACK rx_ack = {0};
-    OSSL_QUIC_ACK_RANGE rx_ack_range = {0};
+    OSSL_QUIC_FRAME_ACK rx_ack = { 0 };
+    OSSL_QUIC_ACK_RANGE rx_ack_range = { 0 };
     struct pkt_info *pkts = NULL;
     OSSL_ACKM_TX_PKT *txs = NULL, *tx;
     OSSL_TIME ack_deadline[QUIC_PN_SPACE_NUM];
@@ -924,7 +929,7 @@ static int test_rx_ack_actual(int tidx, int space)
 
     /* Arm callback for testing. */
     ossl_ackm_set_ack_deadline_callback(h.ackm, on_ack_deadline_callback,
-                                        ack_deadline);
+        ack_deadline);
 
     /*
      * Determine how many packets we are TXing, and therefore how many packet
@@ -946,21 +951,22 @@ static int test_rx_ack_actual(int tidx, int space)
     /* Run script. */
     for (s = script; s->kind != RX_OPK_END; ++s, ++opn) {
         fake_time = ossl_time_add(fake_time,
-                                  ossl_ticks2time(s->time_advance));
+            ossl_ticks2time(s->time_advance));
         switch (s->kind) {
         case RX_OPK_PKT:
             for (i = 0; i < s->num_pn; ++i) {
-                OSSL_ACKM_RX_PKT pkt = {0};
+                OSSL_ACKM_RX_PKT pkt = { 0 };
 
-                pkt.pkt_num             = s->pn + i;
-                pkt.time                = fake_time;
-                pkt.pkt_space           = space;
-                pkt.is_ack_eliciting    = 1;
+                pkt.pkt_num = s->pn + i;
+                pkt.time = fake_time;
+                pkt.pkt_space = space;
+                pkt.is_ack_eliciting = 1;
 
                 /* The packet should be processable before we feed it. */
                 if (!TEST_int_eq(ossl_ackm_is_rx_pn_processable(h.ackm,
-                                                                pkt.pkt_num,
-                                                                pkt.pkt_space), 1))
+                                     pkt.pkt_num,
+                                     pkt.pkt_space),
+                        1))
                     goto err;
 
                 if (!TEST_int_eq(ossl_ackm_on_rx_packet(h.ackm, &pkt), 1))
@@ -973,29 +979,30 @@ static int test_rx_ack_actual(int tidx, int space)
         case RX_OPK_CHECK_PROC:
             for (i = 0; i < s->num_pn; ++i)
                 if (!TEST_int_eq(ossl_ackm_is_rx_pn_processable(h.ackm,
-                                                                s->pn + i, space),
-                                 (s->kind == RX_OPK_CHECK_PROC)))
+                                     s->pn + i, space),
+                        (s->kind == RX_OPK_CHECK_PROC)))
                     goto err;
 
             break;
 
         case RX_OPK_CHECK_STATE:
             if (!TEST_int_eq(ossl_ackm_is_ack_desired(h.ackm, space),
-                             s->expect_desired))
+                    s->expect_desired))
                 goto err;
 
             if (!TEST_int_eq(!ossl_time_is_infinite(ossl_ackm_get_ack_deadline(h.ackm, space))
-                             && !ossl_time_is_zero(ossl_ackm_get_ack_deadline(h.ackm, space)),
-                             s->expect_deadline))
+                        && !ossl_time_is_zero(ossl_ackm_get_ack_deadline(h.ackm, space)),
+                    s->expect_deadline))
                 goto err;
 
             for (i = 0; i < QUIC_PN_SPACE_NUM; ++i) {
                 if (i != (size_t)space
-                        && !TEST_true(ossl_time_is_infinite(ossl_ackm_get_ack_deadline(h.ackm, i))))
+                    && !TEST_true(ossl_time_is_infinite(ossl_ackm_get_ack_deadline(h.ackm, i))))
                     goto err;
 
                 if (!TEST_int_eq(ossl_time_compare(ossl_ackm_get_ack_deadline(h.ackm, i),
-                                                   ack_deadline[i]), 0))
+                                     ack_deadline[i]),
+                        0))
                     goto err;
             }
 
@@ -1013,10 +1020,10 @@ static int test_rx_ack_actual(int tidx, int space)
 
             for (i = 0; i < ack->num_ack_ranges; ++i) {
                 if (!TEST_uint64_t_eq(ack->ack_ranges[i].start,
-                                      s->ack_ranges[i].start))
+                        s->ack_ranges[i].start))
                     goto err;
                 if (!TEST_uint64_t_eq(ack->ack_ranges[i].end,
-                                      s->ack_ranges[i].end))
+                        s->ack_ranges[i].end))
                     goto err;
             }
 
@@ -1025,17 +1032,17 @@ static int test_rx_ack_actual(int tidx, int space)
         case RX_OPK_TX:
             pkts[txi].pkt = tx = &txs[txi];
 
-            tx->pkt_num             = s->pn;
-            tx->pkt_space           = space;
-            tx->num_bytes           = 123;
-            tx->largest_acked       = s->largest_acked;
-            tx->is_inflight         = 1;
-            tx->is_ack_eliciting    = 1;
-            tx->on_lost             = on_lost;
-            tx->on_acked            = on_acked;
-            tx->on_discarded        = on_discarded;
-            tx->cb_arg              = &pkts[txi];
-            tx->time                = fake_time;
+            tx->pkt_num = s->pn;
+            tx->pkt_space = space;
+            tx->num_bytes = 123;
+            tx->largest_acked = s->largest_acked;
+            tx->is_inflight = 1;
+            tx->is_ack_eliciting = 1;
+            tx->on_lost = on_lost;
+            tx->on_acked = on_acked;
+            tx->on_discarded = on_discarded;
+            tx->cb_arg = &pkts[txi];
+            tx->time = fake_time;
 
             if (!TEST_int_eq(ossl_ackm_on_tx_packet(h.ackm, tx), 1))
                 goto err;
@@ -1044,14 +1051,15 @@ static int test_rx_ack_actual(int tidx, int space)
             break;
 
         case RX_OPK_RX_ACK:
-            rx_ack.ack_ranges       = &rx_ack_range;
-            rx_ack.num_ack_ranges   = 1;
+            rx_ack.ack_ranges = &rx_ack_range;
+            rx_ack.num_ack_ranges = 1;
 
-            rx_ack_range.start      = s->pn;
-            rx_ack_range.end        = s->pn + s->num_pn - 1;
+            rx_ack_range.start = s->pn;
+            rx_ack_range.end = s->pn + s->num_pn - 1;
 
             if (!TEST_int_eq(ossl_ackm_on_rx_ack_frame(h.ackm, &rx_ack,
-                                                       space, fake_time), 1))
+                                 space, fake_time),
+                    1))
                 goto err;
 
             break;
@@ -1110,7 +1118,7 @@ static int test_rx_ack(int idx)
 int setup_tests(void)
 {
     ADD_ALL_TESTS(test_tx_ack_case,
-                  OSSL_NELEM(tx_ack_cases) * MODE_NUM * QUIC_PN_SPACE_NUM);
+        OSSL_NELEM(tx_ack_cases) * MODE_NUM * QUIC_PN_SPACE_NUM);
     ADD_ALL_TESTS(test_tx_ack_time_script, OSSL_NELEM(tx_ack_time_scripts));
     ADD_ALL_TESTS(test_rx_ack, OSSL_NELEM(rx_test_scripts) * QUIC_PN_SPACE_NUM);
     return 1;
