@@ -48,57 +48,57 @@
  * objects.
  */
 typedef struct radix_obj_st {
-    char                *name;  /* owned, zero-terminated */
-    SSL                 *ssl;   /* owns one reference */
-    unsigned int        registered      : 1; /* in LHASH? */
-    unsigned int        active          : 1; /* tick? */
+    char *name; /* owned, zero-terminated */
+    SSL *ssl; /* owns one reference */
+    unsigned int registered : 1; /* in LHASH? */
+    unsigned int active : 1; /* tick? */
 } RADIX_OBJ;
 
 DEFINE_LHASH_OF_EX(RADIX_OBJ);
 
 /* Process-level state (i.e. "globals" in the normal sense of the word) */
 typedef struct radix_process_st {
-    size_t                  node_idx;
-    size_t                  process_idx;
-    size_t                  next_thread_idx;
-    STACK_OF(RADIX_THREAD)  *threads;
+    size_t node_idx;
+    size_t process_idx;
+    size_t next_thread_idx;
+    STACK_OF(RADIX_THREAD) *threads;
 
     /* Process-global state. */
-    CRYPTO_MUTEX            *gm;            /* global mutex */
-    LHASH_OF(RADIX_OBJ)     *objs;          /* protected by gm */
-    OSSL_TIME               time_slip;      /* protected by gm */
-    BIO                     *keylog_out;    /* protected by gm */
+    CRYPTO_MUTEX *gm; /* global mutex */
+    LHASH_OF(RADIX_OBJ) *objs; /* protected by gm */
+    OSSL_TIME time_slip; /* protected by gm */
+    BIO *keylog_out; /* protected by gm */
 
-    int                     done_join_all_threads;
+    int done_join_all_threads;
 
     /*
      * Valid if done_join_all threads. Logical AND of all child worker results.
      */
-    int                     thread_composite_testresult;
+    int thread_composite_testresult;
 } RADIX_PROCESS;
 
-#define NUM_SLOTS       8
+#define NUM_SLOTS 8
 
 /* Thread-level state within a process */
 typedef struct radix_thread_st {
-    RADIX_PROCESS       *rp;
-    CRYPTO_THREAD       *t;
-    unsigned char       *tmp_buf;
-    size_t              tmp_buf_offset;
-    size_t              thread_idx; /* 0=main thread */
-    RADIX_OBJ           *slot[NUM_SLOTS];
-    SSL                 *ssl[NUM_SLOTS];
+    RADIX_PROCESS *rp;
+    CRYPTO_THREAD *t;
+    unsigned char *tmp_buf;
+    size_t tmp_buf_offset;
+    size_t thread_idx; /* 0=main thread */
+    RADIX_OBJ *slot[NUM_SLOTS];
+    SSL *ssl[NUM_SLOTS];
 
     /* child thread spawn arguments */
-    SCRIPT_INFO         *child_script_info;
-    BIO                 *debug_bio;
+    SCRIPT_INFO *child_script_info;
+    BIO *debug_bio;
 
     /* m protects all of the below values */
-    CRYPTO_MUTEX        *m;
-    int                 done;
-    int                 testresult; /* valid if done */
+    CRYPTO_MUTEX *m;
+    int done;
+    int testresult; /* valid if done */
 
-    uint64_t            scratch0;
+    uint64_t scratch0;
 } RADIX_THREAD;
 
 DEFINE_STACK_OF(RADIX_THREAD)
@@ -112,14 +112,14 @@ static RADIX_OBJ *RADIX_OBJ_new(const char *name, SSL *ssl)
         return NULL;
 
     if (!TEST_ptr(obj = OPENSSL_zalloc(sizeof(*obj))))
-       return NULL;
+        return NULL;
 
     if (!TEST_ptr(obj->name = OPENSSL_strdup(name))) {
         OPENSSL_free(obj);
         return NULL;
     }
 
-    obj->ssl  = ssl;
+    obj->ssl = ssl;
     return obj;
 }
 
@@ -166,10 +166,10 @@ static int RADIX_PROCESS_init(RADIX_PROCESS *rp, size_t node_idx, size_t process
         && !TEST_ptr(rp->keylog_out = BIO_new_file(keylog_path, "a")))
         goto err;
 
-    rp->node_idx                = node_idx;
-    rp->process_idx             = process_idx;
-    rp->done_join_all_threads   = 0;
-    rp->next_thread_idx         = 0;
+    rp->node_idx = node_idx;
+    rp->process_idx = process_idx;
+    rp->done_join_all_threads = 0;
+    rp->next_thread_idx = 0;
     return 1;
 
 err:
@@ -202,7 +202,7 @@ static const char *stream_state_to_str(int state)
 }
 
 static void report_ssl_state(BIO *bio, const char *pfx, int is_write,
-                             int state, uint64_t ec)
+    int state, uint64_t ec)
 {
     const char *state_s = stream_state_to_str(state);
 
@@ -217,7 +217,7 @@ static void report_ssl(SSL *ssl, BIO *bio, const char *pfx)
 {
     const char *type = "SSL";
     int is_quic = SSL_is_quic(ssl), is_conn = 0, is_listener = 0;
-    SSL_CONN_CLOSE_INFO cc_info = {0};
+    SSL_CONN_CLOSE_INFO cc_info = { 0 };
     const char *e_str, *f_str;
 
     if (is_quic) {
@@ -246,17 +246,19 @@ static void report_ssl(SSL *ssl, BIO *bio, const char *pfx)
             f_str = "?";
 
         BIO_printf(bio, "%sConnection is closed: %s(%llu)/%s(%llu), "
-                   "%s, %s, reason: \"%s\"\n",
-                   pfx,
-                   e_str,
-                   (unsigned long long)cc_info.error_code,
-                   f_str,
-                   (unsigned long long)cc_info.frame_type,
-                   (cc_info.flags & SSL_CONN_CLOSE_FLAG_LOCAL) != 0
-                     ? "local" : "remote",
-                   (cc_info.flags & SSL_CONN_CLOSE_FLAG_TRANSPORT) != 0
-                     ? "transport" : "app",
-                   cc_info.reason != NULL ? cc_info.reason : "-");
+                        "%s, %s, reason: \"%s\"\n",
+            pfx,
+            e_str,
+            (unsigned long long)cc_info.error_code,
+            f_str,
+            (unsigned long long)cc_info.frame_type,
+            (cc_info.flags & SSL_CONN_CLOSE_FLAG_LOCAL) != 0
+                ? "local"
+                : "remote",
+            (cc_info.flags & SSL_CONN_CLOSE_FLAG_TRANSPORT) != 0
+                ? "transport"
+                : "app",
+            cc_info.reason != NULL ? cc_info.reason : "-");
     }
 
     if (is_quic && !is_listener) {
@@ -265,7 +267,7 @@ static void report_ssl(SSL *ssl, BIO *bio, const char *pfx)
 
         if (stream_id != UINT64_MAX)
             BIO_printf(bio, "%sStream ID: %llu\n", pfx,
-                       (unsigned long long)stream_id);
+                (unsigned long long)stream_id);
 
         rstate = SSL_get_stream_read_state(ssl);
         wstate = SSL_get_stream_write_state(ssl);
@@ -302,30 +304,30 @@ static void RADIX_THREAD_report_state(RADIX_THREAD *rt, BIO *bio)
             BIO_printf(bio, "  %3zu) <NULL>\n", i);
         else
             BIO_printf(bio, "  %3zu) '%s' (SSL: %p)\n", i,
-                       rt->slot[i]->name,
-                       (void *)rt->ssl[i]);
+                rt->slot[i]->name,
+                (void *)rt->ssl[i]);
 }
 
 static void RADIX_PROCESS_report_state(RADIX_PROCESS *rp, BIO *bio,
-                                       int verbose)
+    int verbose)
 {
     BIO_printf(bio, "Final process state for node %zu, process %zu:\n",
-               rp->node_idx, rp->process_idx);
+        rp->node_idx, rp->process_idx);
 
     BIO_printf(bio, "  Threads (incl. main):        %zu\n",
-               rp->next_thread_idx);
+        rp->next_thread_idx);
     BIO_printf(bio, "  Time slip:                   %llu ms\n",
-               (unsigned long long)ossl_time2ms(rp->time_slip));
+        (unsigned long long)ossl_time2ms(rp->time_slip));
 
     BIO_printf(bio, "  Objects:\n");
     lh_RADIX_OBJ_doall_arg(rp->objs, report_obj, bio);
 
     if (verbose)
         RADIX_THREAD_report_state(sk_RADIX_THREAD_value(rp->threads, 0),
-                                  bio_err);
+            bio_err);
 
     BIO_printf(bio, "\n==========================================="
-               "===========================\n");
+                    "===========================\n");
 }
 
 static void RADIX_PROCESS_report_thread_results(RADIX_PROCESS *rp, BIO *bio)
@@ -346,9 +348,9 @@ static void RADIX_PROCESS_report_thread_results(RADIX_PROCESS *rp, BIO *bio)
         ossl_crypto_mutex_unlock(rt->m);
 
         BIO_printf(bio, "\n====(n%zu/p%zu/t%zu)============================"
-                   "===========================\n"
-                   "Result for child thread with index %zu:\n",
-                   rp->node_idx, rp->process_idx, rt->thread_idx, rt->thread_idx);
+                        "===========================\n"
+                        "Result for child thread with index %zu:\n",
+            rp->node_idx, rp->process_idx, rt->thread_idx, rt->thread_idx);
 
         BIO_snprintf(pfx_buf, sizeof(pfx_buf), "#  -T-%2zu:\t# ", rt->thread_idx);
         BIO_set_prefix(bio_err, pfx_buf);
@@ -358,13 +360,13 @@ static void RADIX_PROCESS_report_thread_results(RADIX_PROCESS *rp, BIO *bio)
         BIO_printf(bio, "\n");
         BIO_set_prefix(bio_err, "# ");
         BIO_printf(bio, "==> Child thread with index %zu exited with %d\n",
-                   rt->thread_idx, rt_testresult);
+            rt->thread_idx, rt_testresult);
         if (!rt_testresult)
             RADIX_THREAD_report_state(rt, bio);
     }
 
     BIO_printf(bio, "\n==========================================="
-               "===========================\n");
+                    "===========================\n");
 }
 
 static int RADIX_THREAD_join(RADIX_THREAD *rt);
@@ -394,8 +396,8 @@ static int RADIX_PROCESS_join_all_threads(RADIX_PROCESS *rp, int *testresult)
     }
 
     rp->thread_composite_testresult = composite_testresult;
-    *testresult                     = composite_testresult;
-    rp->done_join_all_threads       = 1;
+    *testresult = composite_testresult;
+    rp->done_join_all_threads = 1;
 
     RADIX_PROCESS_report_thread_results(rp, bio_err);
     return ok;
@@ -439,7 +441,7 @@ static RADIX_OBJ *RADIX_PROCESS_get_obj(RADIX_PROCESS *rp, const char *name)
 }
 
 static int RADIX_PROCESS_set_obj(RADIX_PROCESS *rp,
-                                 const char *name, RADIX_OBJ *obj)
+    const char *name, RADIX_OBJ *obj)
 {
     RADIX_OBJ *existing;
 
@@ -497,7 +499,7 @@ static RADIX_THREAD *RADIX_THREAD_new(RADIX_PROCESS *rp)
         || !TEST_ptr(rt = OPENSSL_zalloc(sizeof(*rt))))
         return 0;
 
-    rt->rp          = rp;
+    rt->rp = rp;
 
 #if defined(OPENSSL_THREADS)
     if (!TEST_ptr(rt->m = ossl_crypto_mutex_new())) {
@@ -511,7 +513,7 @@ static RADIX_THREAD *RADIX_THREAD_new(RADIX_PROCESS *rp)
         return 0;
     }
 
-    rt->thread_idx  = rp->next_thread_idx++;
+    rt->thread_idx = rp->next_thread_idx++;
     assert(rt->thread_idx + 1 == (size_t)sk_RADIX_THREAD_num(rp->threads));
     return rt;
 }
@@ -544,8 +546,8 @@ static int RADIX_THREAD_join(RADIX_THREAD *rt)
     return 1;
 }
 
-static RADIX_PROCESS        radix_process;
-static CRYPTO_THREAD_LOCAL  radix_thread;
+static RADIX_PROCESS radix_process;
+static CRYPTO_THREAD_LOCAL radix_thread;
 
 static void radix_thread_cleanup_tl(void *p)
 {
@@ -592,7 +594,7 @@ static int bindings_process_init(size_t node_idx, size_t process_idx)
         return 0;
 
     if (!TEST_true(CRYPTO_THREAD_init_local(&radix_thread,
-                                            radix_thread_cleanup_tl)))
+            radix_thread_cleanup_tl)))
         return 0;
 
     if (!TEST_ptr(rt = RADIX_THREAD_new(&radix_process)))
@@ -607,12 +609,12 @@ static int bindings_process_finish(int testresult_main)
     int testresult, testresult_child;
 
     if (!TEST_true(RADIX_PROCESS_join_all_threads(&radix_process,
-                                                  &testresult_child)))
+            &testresult_child)))
         return 0;
 
     testresult = testresult_main && testresult_child;
     RADIX_PROCESS_report_state(&radix_process, bio_err,
-                               /*verbose=*/!testresult);
+        /*verbose=*/!testresult);
     radix_thread_cleanup(); /* cleanup main thread */
     RADIX_PROCESS_cleanup(&radix_process);
 
@@ -620,13 +622,13 @@ static int bindings_process_finish(int testresult_main)
         BIO_printf(bio_err, "==> OK\n\n");
     else
         BIO_printf(bio_err, "==> ERROR (main=%d, children=%d)\n\n",
-                   testresult_main, testresult_child);
+            testresult_main, testresult_child);
 
     return testresult;
 }
 
-#define RP()    (&radix_process)
-#define RT()    (radix_get_thread())
+#define RP() (&radix_process)
+#define RT() (radix_get_thread())
 
 static OSSL_TIME get_time(void *arg)
 {
@@ -660,8 +662,8 @@ static int do_per_op(TERP *terp, void *arg)
 
 static int bindings_adjust_terp_config(TERP_CONFIG *cfg)
 {
-    cfg->now_cb     = get_time;
-    cfg->per_op_cb  = do_per_op;
+    cfg->now_cb = get_time;
+    cfg->per_op_cb = do_per_op;
     return 1;
 }
 
@@ -674,42 +676,42 @@ static int expect_slot_ssl(FUNC_CTX *fctx, size_t idx, SSL **p_ssl)
     return 1;
 }
 
-#define REQUIRE_SSL_N(idx, ssl)                                 \
-    do {                                                        \
-        (ssl) = NULL; /* quiet uninitialized warnings */        \
-        if (!TEST_true(expect_slot_ssl(fctx, (idx), &(ssl))))   \
-            goto err;                                           \
+#define REQUIRE_SSL_N(idx, ssl)                               \
+    do {                                                      \
+        (ssl) = NULL; /* quiet uninitialized warnings */      \
+        if (!TEST_true(expect_slot_ssl(fctx, (idx), &(ssl)))) \
+            goto err;                                         \
     } while (0)
-#define REQUIRE_SSL(ssl)    REQUIRE_SSL_N(0, (ssl))
+#define REQUIRE_SSL(ssl) REQUIRE_SSL_N(0, (ssl))
 
-#define REQUIRE_SSL_2(a, b)                                     \
-    do {                                                        \
-        REQUIRE_SSL_N(0, (a));                                  \
-        REQUIRE_SSL_N(1, (b));                                  \
+#define REQUIRE_SSL_2(a, b)    \
+    do {                       \
+        REQUIRE_SSL_N(0, (a)); \
+        REQUIRE_SSL_N(1, (b)); \
     } while (0)
 
-#define REQUIRE_SSL_3(a, b, c)                                  \
-    do {                                                        \
-        REQUIRE_SSL_N(0, (a));                                  \
-        REQUIRE_SSL_N(1, (b));                                  \
-        REQUIRE_SSL_N(2, (c));                                  \
+#define REQUIRE_SSL_3(a, b, c) \
+    do {                       \
+        REQUIRE_SSL_N(0, (a)); \
+        REQUIRE_SSL_N(1, (b)); \
+        REQUIRE_SSL_N(2, (c)); \
     } while (0)
 
-#define REQUIRE_SSL_4(a, b, c, d)                               \
-    do {                                                        \
-        REQUIRE_SSL_N(0, (a));                                  \
-        REQUIRE_SSL_N(1, (b));                                  \
-        REQUIRE_SSL_N(2, (c));                                  \
-        REQUIRE_SSL_N(3, (d));                                  \
+#define REQUIRE_SSL_4(a, b, c, d) \
+    do {                          \
+        REQUIRE_SSL_N(0, (a));    \
+        REQUIRE_SSL_N(1, (b));    \
+        REQUIRE_SSL_N(2, (c));    \
+        REQUIRE_SSL_N(3, (d));    \
     } while (0)
 
-#define REQUIRE_SSL_5(a, b, c, d, e)                            \
-    do {                                                        \
-        REQUIRE_SSL_N(0, (a));                                  \
-        REQUIRE_SSL_N(1, (b));                                  \
-        REQUIRE_SSL_N(2, (c));                                  \
-        REQUIRE_SSL_N(3, (d));                                  \
-        REQUIRE_SSL_N(4, (e));                                  \
+#define REQUIRE_SSL_5(a, b, c, d, e) \
+    do {                             \
+        REQUIRE_SSL_N(0, (a));       \
+        REQUIRE_SSL_N(1, (b));       \
+        REQUIRE_SSL_N(2, (c));       \
+        REQUIRE_SSL_N(3, (d));       \
+        REQUIRE_SSL_N(4, (e));       \
     } while (0)
 
 #define C_BIDI_ID(ordinal) \
@@ -726,7 +728,7 @@ static int expect_slot_ssl(FUNC_CTX *fctx, size_t idx, SSL **p_ssl)
 static int RADIX_THREAD_worker_run(RADIX_THREAD *rt)
 {
     int ok = 0;
-    TERP_CONFIG cfg = {0};
+    TERP_CONFIG cfg = { 0 };
 
     cfg.debug_bio = rt->debug_bio;
     if (!TEST_true(bindings_adjust_terp_config(&cfg)))
@@ -755,8 +757,8 @@ static unsigned int RADIX_THREAD_worker_main(void *p)
     testresult = RADIX_THREAD_worker_run(rt);
 
     ossl_crypto_mutex_lock(rt->m);
-    rt->testresult  = testresult;
-    rt->done        = 1;
+    rt->testresult = testresult;
+    rt->done = 1;
     ossl_crypto_mutex_unlock(rt->m);
 
     radix_thread_cleanup();
@@ -803,7 +805,7 @@ DEF_FUNC(hf_spawn_thread)
 
     ossl_crypto_mutex_lock(child_rt->m);
     if (!TEST_ptr(child_rt->t = ossl_crypto_thread_native_start(RADIX_THREAD_worker_main,
-                                                                child_rt, 1))) {
+                      child_rt, 1))) {
         ossl_crypto_mutex_unlock(child_rt->m);
         goto err;
     }
@@ -830,14 +832,14 @@ DEF_FUNC(hf_clear)
 
     for (i = 0; i < NUM_SLOTS; ++i) {
         rt->slot[i] = NULL;
-        rt->ssl[i]  = NULL;
+        rt->ssl[i] = NULL;
     }
 
     ossl_crypto_mutex_unlock(RP()->gm);
     return 1;
 }
 
-#define OP_SPAWN_THREAD(script_name)                            \
+#define OP_SPAWN_THREAD(script_name) \
     (OP_PUSH_P(SCRIPT(script_name)), OP_FUNC(hf_spawn_thread))
-#define OP_CLEAR()                                              \
+#define OP_CLEAR() \
     (OP_FUNC(hf_clear))
