@@ -11,13 +11,18 @@
  * Check to see if there is a conflict between complex.h and openssl/rsa.h.
  * The former defines "I" as a macro and earlier versions of the latter use
  * for function arguments.
+ *
+ * Will always succeed on djgpp, since its libc does not have complex.h.
  */
+
+#if !defined(__DJGPP__)
 #if defined(__STDC_VERSION__)
-# if __STDC_VERSION__ >= 199901L
-#  include <complex.h>
-# endif
+#if __STDC_VERSION__ >= 199901L
+#include <complex.h>
+#endif
 #endif
 #include <openssl/rsa.h>
+#endif
 #include <stdlib.h>
 
 int main(int argc, char *argv[])
