@@ -22,20 +22,21 @@
     do_test_cert_table(nid, amask, idx, #idx)
 
 static int do_test_cert_table(int nid, uint32_t amask, size_t idx,
-                              const char *idxname)
+    const char *idxname)
 {
     const SSL_CERT_LOOKUP *clu = &ssl_cert_info[idx];
 
-    if (clu->nid == nid && clu->amask == amask)
+    if (clu->pkey_nid == nid && clu->amask == amask)
         return 1;
 
     TEST_error("Invalid table entry for certificate type %s, index %zu",
-               idxname, idx);
-    if (clu->nid != nid)
+        idxname, idx);
+    if (clu->pkey_nid != nid)
         TEST_note("Expected %s, got %s\n", OBJ_nid2sn(nid),
-                  OBJ_nid2sn(clu->nid));
+            OBJ_nid2sn(clu->pkey_nid));
     if (clu->amask != amask)
-        TEST_note("Expected auth mask 0x%x, got 0x%x\n", amask, clu->amask);
+        TEST_note("Expected auth mask 0x%x, got 0x%x\n",
+            (unsigned int)amask, (unsigned int)clu->amask);
     return 0;
 }
 
@@ -44,17 +45,17 @@ static int do_test_cert_table(int nid, uint32_t amask, size_t idx,
 static int test_ssl_cert_table(void)
 {
     return TEST_size_t_eq(OSSL_NELEM(ssl_cert_info), SSL_PKEY_NUM)
-           && test_cert_table(EVP_PKEY_RSA, SSL_aRSA, SSL_PKEY_RSA)
-           && test_cert_table(EVP_PKEY_DSA, SSL_aDSS, SSL_PKEY_DSA_SIGN)
-           && test_cert_table(EVP_PKEY_EC, SSL_aECDSA, SSL_PKEY_ECC)
-           && test_cert_table(NID_id_GostR3410_2001, SSL_aGOST01,
-                              SSL_PKEY_GOST01)
-           && test_cert_table(NID_id_GostR3410_2012_256, SSL_aGOST12,
-                              SSL_PKEY_GOST12_256)
-           && test_cert_table(NID_id_GostR3410_2012_512, SSL_aGOST12,
-                              SSL_PKEY_GOST12_512)
-           && test_cert_table(EVP_PKEY_ED25519, SSL_aECDSA, SSL_PKEY_ED25519)
-           && test_cert_table(EVP_PKEY_ED448, SSL_aECDSA, SSL_PKEY_ED448);
+        && test_cert_table(EVP_PKEY_RSA, SSL_aRSA, SSL_PKEY_RSA)
+        && test_cert_table(EVP_PKEY_DSA, SSL_aDSS, SSL_PKEY_DSA_SIGN)
+        && test_cert_table(EVP_PKEY_EC, SSL_aECDSA, SSL_PKEY_ECC)
+        && test_cert_table(NID_id_GostR3410_2001, SSL_aGOST01,
+            SSL_PKEY_GOST01)
+        && test_cert_table(NID_id_GostR3410_2012_256, SSL_aGOST12,
+            SSL_PKEY_GOST12_256)
+        && test_cert_table(NID_id_GostR3410_2012_512, SSL_aGOST12,
+            SSL_PKEY_GOST12_512)
+        && test_cert_table(EVP_PKEY_ED25519, SSL_aECDSA, SSL_PKEY_ED25519)
+        && test_cert_table(EVP_PKEY_ED448, SSL_aECDSA, SSL_PKEY_ED448);
 }
 
 int setup_tests(void)
