@@ -1,5 +1,5 @@
 /*
- * Copyright 2018-2022 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2018-2023 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -14,8 +14,8 @@
 #include <string.h>
 
 int test_get_libctx(OSSL_LIB_CTX **libctx, OSSL_PROVIDER **default_null_prov,
-                    const char *config_file,
-                    OSSL_PROVIDER **provider, const char *module_name)
+    const char *config_file,
+    OSSL_PROVIDER **provider, const char *module_name)
 {
     OSSL_LIB_CTX *new_libctx = NULL;
 
@@ -33,25 +33,25 @@ int test_get_libctx(OSSL_LIB_CTX **libctx, OSSL_PROVIDER **default_null_prov,
     }
 
     if (config_file != NULL
-            && !OSSL_LIB_CTX_load_config(new_libctx, config_file)) {
+        && !OSSL_LIB_CTX_load_config(new_libctx, config_file)) {
         opt_printf_stderr("Error loading config from file %s\n", config_file);
         goto err;
     }
 
-    if (module_name != NULL
-            && (*provider = OSSL_PROVIDER_load(new_libctx, module_name)) == NULL) {
+    if (provider != NULL && module_name != NULL
+        && (*provider = OSSL_PROVIDER_load(new_libctx, module_name)) == NULL) {
         opt_printf_stderr("Failed to load provider %s\n", module_name);
         goto err;
     }
     return 1;
 
- err:
+err:
     ERR_print_errors_fp(stderr);
     return 0;
 }
 
 int test_arg_libctx(OSSL_LIB_CTX **libctx, OSSL_PROVIDER **default_null_prov,
-                    OSSL_PROVIDER **provider, int argn, const char *usage)
+    OSSL_PROVIDER **provider, int argn, const char *usage)
 {
     const char *module_name;
 
@@ -62,7 +62,7 @@ int test_arg_libctx(OSSL_LIB_CTX **libctx, OSSL_PROVIDER **default_null_prov,
     if (strcmp(module_name, "none") == 0)
         return 1;
     return test_get_libctx(libctx, default_null_prov,
-                           test_get_argument(argn + 1), provider, module_name);
+        test_get_argument(argn + 1), provider, module_name);
 }
 
 typedef struct {
@@ -86,12 +86,12 @@ static int fips_provider_version(OSSL_LIB_CTX *libctx, FIPS_VERSION *vers)
     if ((fips_prov = OSSL_PROVIDER_load(libctx, "fips")) == NULL)
         return -1;
     if (!OSSL_PROVIDER_get_params(fips_prov, params)
-            || sscanf(vs, "%d.%d.%d", &vers->major, &vers->minor, &vers->patch) != 3)
+        || sscanf(vs, "%d.%d.%d", &vers->major, &vers->minor, &vers->patch) != 3)
         goto err;
     if (!OSSL_PROVIDER_unload(fips_prov))
         return -1;
     return 1;
- err:
+err:
     OSSL_PROVIDER_unload(fips_prov);
     return -1;
 }
@@ -124,9 +124,9 @@ int fips_provider_version_le(OSSL_LIB_CTX *libctx, int major, int minor, int pat
     if ((res = fips_provider_version(libctx, &prov)) <= 0)
         return res == 0;
     return prov.major < major
-           || (prov.major == major
-               && (prov.minor < minor
-                   || (prov.minor == minor && prov.patch <= patch)));
+        || (prov.major == major
+            && (prov.minor < minor
+                || (prov.minor == minor && prov.patch <= patch)));
 }
 
 int fips_provider_version_lt(OSSL_LIB_CTX *libctx, int major, int minor, int patch)
@@ -137,9 +137,9 @@ int fips_provider_version_lt(OSSL_LIB_CTX *libctx, int major, int minor, int pat
     if ((res = fips_provider_version(libctx, &prov)) <= 0)
         return res == 0;
     return prov.major < major
-           || (prov.major == major
-               && (prov.minor < minor
-                   || (prov.minor == minor && prov.patch < patch)));
+        || (prov.major == major
+            && (prov.minor < minor
+                || (prov.minor == minor && prov.patch < patch)));
 }
 
 int fips_provider_version_gt(OSSL_LIB_CTX *libctx, int major, int minor, int patch)
@@ -150,9 +150,9 @@ int fips_provider_version_gt(OSSL_LIB_CTX *libctx, int major, int minor, int pat
     if ((res = fips_provider_version(libctx, &prov)) <= 0)
         return res == 0;
     return prov.major > major
-           || (prov.major == major
-               && (prov.minor > minor
-                   || (prov.minor == minor && prov.patch > patch)));
+        || (prov.major == major
+            && (prov.minor > minor
+                || (prov.minor == minor && prov.patch > patch)));
 }
 
 int fips_provider_version_ge(OSSL_LIB_CTX *libctx, int major, int minor, int patch)
@@ -163,9 +163,9 @@ int fips_provider_version_ge(OSSL_LIB_CTX *libctx, int major, int minor, int pat
     if ((res = fips_provider_version(libctx, &prov)) <= 0)
         return res == 0;
     return prov.major > major
-           || (prov.major == major
-               && (prov.minor > minor
-                   || (prov.minor == minor && prov.patch >= patch)));
+        || (prov.major == major
+            && (prov.minor > minor
+                || (prov.minor == minor && prov.patch >= patch)));
 }
 
 int fips_provider_version_match(OSSL_LIB_CTX *libctx, const char *versions)
@@ -173,15 +173,20 @@ int fips_provider_version_match(OSSL_LIB_CTX *libctx, const char *versions)
     const char *p;
     int major, minor, patch, r;
     enum {
-        MODE_EQ, MODE_NE, MODE_LE, MODE_LT, MODE_GT, MODE_GE
+        MODE_EQ,
+        MODE_NE,
+        MODE_LE,
+        MODE_LT,
+        MODE_GT,
+        MODE_GE
     } mode;
 
     while (*versions != '\0') {
-        for (; isspace(*versions); versions++)
+        for (; isspace((unsigned char)(*versions)); versions++)
             continue;
         if (*versions == '\0')
             break;
-        for (p = versions; *versions != '\0' && !isspace(*versions); versions++)
+        for (p = versions; *versions != '\0' && !isspace((unsigned char)(*versions)); versions++)
             continue;
         if (*p == '!') {
             mode = MODE_NE;
@@ -201,7 +206,7 @@ int fips_provider_version_match(OSSL_LIB_CTX *libctx, const char *versions)
         } else if (*p == '>') {
             mode = MODE_GT;
             p++;
-        } else if (isdigit(*p)) {
+        } else if (isdigit((unsigned char)*p)) {
             mode = MODE_EQ;
         } else {
             TEST_info("Error matching FIPS version: mode %s\n", p);
