@@ -27,8 +27,8 @@ static int test_pathlen(void)
     int ret = 0;
 
     if (!TEST_ptr(b = BIO_new_file(infile, "r"))
-            || !TEST_ptr(x = PEM_read_bio_X509(b, NULL, NULL, NULL))
-            || !TEST_int_eq(pathlen = X509_get_pathlen(x), 6))
+        || !TEST_ptr(x = PEM_read_bio_X509(b, NULL, NULL, NULL))
+        || !TEST_int_eq(pathlen = X509_get_pathlen(x), 6))
         goto end;
 
     ret = 1;
@@ -48,12 +48,12 @@ static int test_asid(void)
     int testresult = 0;
 
     if (!TEST_ptr(asid1)
-            || !TEST_ptr(asid2)
-            || !TEST_ptr(asid3))
+        || !TEST_ptr(asid2)
+        || !TEST_ptr(asid3))
         goto err;
 
     if (!TEST_ptr(val1 = ASN1_INTEGER_new())
-            || !TEST_true(ASN1_INTEGER_set_int64(val1, 64496)))
+        || !TEST_true(ASN1_INTEGER_set_int64(val1, 64496)))
         goto err;
 
     if (!TEST_true(X509v3_asid_add_id_or_range(asid1, V3_ASID_ASNUM, val1, NULL)))
@@ -61,7 +61,7 @@ static int test_asid(void)
 
     val1 = NULL;
     if (!TEST_ptr(val2 = ASN1_INTEGER_new())
-            || !TEST_true(ASN1_INTEGER_set_int64(val2, 64497)))
+        || !TEST_true(ASN1_INTEGER_set_int64(val2, 64497)))
         goto err;
 
     if (!TEST_true(X509v3_asid_add_id_or_range(asid2, V3_ASID_ASNUM, val2, NULL)))
@@ -69,9 +69,9 @@ static int test_asid(void)
 
     val2 = NULL;
     if (!TEST_ptr(val1 = ASN1_INTEGER_new())
-            || !TEST_true(ASN1_INTEGER_set_int64(val1, 64496))
-            || !TEST_ptr(val2 = ASN1_INTEGER_new())
-            || !TEST_true(ASN1_INTEGER_set_int64(val2, 64497)))
+        || !TEST_true(ASN1_INTEGER_set_int64(val1, 64496))
+        || !TEST_ptr(val2 = ASN1_INTEGER_new())
+        || !TEST_true(ASN1_INTEGER_set_int64(val2, 64497)))
         goto err;
 
     /*
@@ -84,30 +84,30 @@ static int test_asid(void)
 
     /* Actual subsets */
     if (!TEST_true(X509v3_asid_subset(NULL, NULL))
-            || !TEST_true(X509v3_asid_subset(NULL, asid1))
-            || !TEST_true(X509v3_asid_subset(asid1, asid1))
-            || !TEST_true(X509v3_asid_subset(asid2, asid2))
-            || !TEST_true(X509v3_asid_subset(asid1, asid3))
-            || !TEST_true(X509v3_asid_subset(asid2, asid3))
-            || !TEST_true(X509v3_asid_subset(asid3, asid3))
-            || !TEST_true(X509v3_asid_subset(asid4, asid1))
-            || !TEST_true(X509v3_asid_subset(asid4, asid2))
-            || !TEST_true(X509v3_asid_subset(asid4, asid3)))
+        || !TEST_true(X509v3_asid_subset(NULL, asid1))
+        || !TEST_true(X509v3_asid_subset(asid1, asid1))
+        || !TEST_true(X509v3_asid_subset(asid2, asid2))
+        || !TEST_true(X509v3_asid_subset(asid1, asid3))
+        || !TEST_true(X509v3_asid_subset(asid2, asid3))
+        || !TEST_true(X509v3_asid_subset(asid3, asid3))
+        || !TEST_true(X509v3_asid_subset(asid4, asid1))
+        || !TEST_true(X509v3_asid_subset(asid4, asid2))
+        || !TEST_true(X509v3_asid_subset(asid4, asid3)))
         goto err;
 
     /* Not subsets */
     if (!TEST_false(X509v3_asid_subset(asid1, NULL))
-            || !TEST_false(X509v3_asid_subset(asid1, asid2))
-            || !TEST_false(X509v3_asid_subset(asid2, asid1))
-            || !TEST_false(X509v3_asid_subset(asid3, asid1))
-            || !TEST_false(X509v3_asid_subset(asid3, asid2))
-            || !TEST_false(X509v3_asid_subset(asid1, asid4))
-            || !TEST_false(X509v3_asid_subset(asid2, asid4))
-            || !TEST_false(X509v3_asid_subset(asid3, asid4)))
+        || !TEST_false(X509v3_asid_subset(asid1, asid2))
+        || !TEST_false(X509v3_asid_subset(asid2, asid1))
+        || !TEST_false(X509v3_asid_subset(asid3, asid1))
+        || !TEST_false(X509v3_asid_subset(asid3, asid2))
+        || !TEST_false(X509v3_asid_subset(asid1, asid4))
+        || !TEST_false(X509v3_asid_subset(asid2, asid4))
+        || !TEST_false(X509v3_asid_subset(asid3, asid4)))
         goto err;
 
     testresult = 1;
- err:
+err:
     ASN1_INTEGER_free(val1);
     ASN1_INTEGER_free(val2);
     ASIdentifiers_free(asid1);
@@ -123,24 +123,24 @@ static struct ip_ranges_st {
     const char *ip2;
     int rorp;
 } ranges[] = {
-    { IANA_AFI_IPV4, "192.168.0.0", "192.168.0.1", IPAddressOrRange_addressPrefix},
-    { IANA_AFI_IPV4, "192.168.0.0", "192.168.0.2", IPAddressOrRange_addressRange},
-    { IANA_AFI_IPV4, "192.168.0.0", "192.168.0.3", IPAddressOrRange_addressPrefix},
-    { IANA_AFI_IPV4, "192.168.0.0", "192.168.0.254", IPAddressOrRange_addressRange},
-    { IANA_AFI_IPV4, "192.168.0.0", "192.168.0.255", IPAddressOrRange_addressPrefix},
-    { IANA_AFI_IPV4, "192.168.0.1", "192.168.0.255", IPAddressOrRange_addressRange},
-    { IANA_AFI_IPV4, "192.168.0.1", "192.168.0.1", IPAddressOrRange_addressPrefix},
-    { IANA_AFI_IPV4, "192.168.0.0", "192.168.255.255", IPAddressOrRange_addressPrefix},
-    { IANA_AFI_IPV4, "192.168.1.0", "192.168.255.255", IPAddressOrRange_addressRange},
-    { IANA_AFI_IPV6, "2001:0db8::0", "2001:0db8::1", IPAddressOrRange_addressPrefix},
-    { IANA_AFI_IPV6, "2001:0db8::0", "2001:0db8::2", IPAddressOrRange_addressRange},
-    { IANA_AFI_IPV6, "2001:0db8::0", "2001:0db8::3", IPAddressOrRange_addressPrefix},
-    { IANA_AFI_IPV6, "2001:0db8::0", "2001:0db8::fffe", IPAddressOrRange_addressRange},
-    { IANA_AFI_IPV6, "2001:0db8::0", "2001:0db8::ffff", IPAddressOrRange_addressPrefix},
-    { IANA_AFI_IPV6, "2001:0db8::1", "2001:0db8::ffff", IPAddressOrRange_addressRange},
-    { IANA_AFI_IPV6, "2001:0db8::1", "2001:0db8::1", IPAddressOrRange_addressPrefix},
-    { IANA_AFI_IPV6, "2001:0db8::0:0", "2001:0db8::ffff:ffff", IPAddressOrRange_addressPrefix},
-    { IANA_AFI_IPV6, "2001:0db8::1:0", "2001:0db8::ffff:ffff", IPAddressOrRange_addressRange}
+    { IANA_AFI_IPV4, "192.168.0.0", "192.168.0.1", IPAddressOrRange_addressPrefix },
+    { IANA_AFI_IPV4, "192.168.0.0", "192.168.0.2", IPAddressOrRange_addressRange },
+    { IANA_AFI_IPV4, "192.168.0.0", "192.168.0.3", IPAddressOrRange_addressPrefix },
+    { IANA_AFI_IPV4, "192.168.0.0", "192.168.0.254", IPAddressOrRange_addressRange },
+    { IANA_AFI_IPV4, "192.168.0.0", "192.168.0.255", IPAddressOrRange_addressPrefix },
+    { IANA_AFI_IPV4, "192.168.0.1", "192.168.0.255", IPAddressOrRange_addressRange },
+    { IANA_AFI_IPV4, "192.168.0.1", "192.168.0.1", IPAddressOrRange_addressPrefix },
+    { IANA_AFI_IPV4, "192.168.0.0", "192.168.255.255", IPAddressOrRange_addressPrefix },
+    { IANA_AFI_IPV4, "192.168.1.0", "192.168.255.255", IPAddressOrRange_addressRange },
+    { IANA_AFI_IPV6, "2001:0db8::0", "2001:0db8::1", IPAddressOrRange_addressPrefix },
+    { IANA_AFI_IPV6, "2001:0db8::0", "2001:0db8::2", IPAddressOrRange_addressRange },
+    { IANA_AFI_IPV6, "2001:0db8::0", "2001:0db8::3", IPAddressOrRange_addressPrefix },
+    { IANA_AFI_IPV6, "2001:0db8::0", "2001:0db8::fffe", IPAddressOrRange_addressRange },
+    { IANA_AFI_IPV6, "2001:0db8::0", "2001:0db8::ffff", IPAddressOrRange_addressPrefix },
+    { IANA_AFI_IPV6, "2001:0db8::1", "2001:0db8::ffff", IPAddressOrRange_addressRange },
+    { IANA_AFI_IPV6, "2001:0db8::1", "2001:0db8::1", IPAddressOrRange_addressPrefix },
+    { IANA_AFI_IPV6, "2001:0db8::0:0", "2001:0db8::ffff:ffff", IPAddressOrRange_addressPrefix },
+    { IANA_AFI_IPV6, "2001:0db8::1:0", "2001:0db8::ffff:ffff", IPAddressOrRange_addressRange }
 };
 
 static int check_addr(IPAddrBlocks *addr, int type)
@@ -219,7 +219,7 @@ static int test_addr_ranges(void)
     }
 
     testresult = 1;
- end:
+end:
     sk_IPAddressFamily_pop_free(addr, IPAddressFamily_free);
     ASN1_OCTET_STRING_free(ip1);
     ASN1_OCTET_STRING_free(ip2);
@@ -261,11 +261,9 @@ static int test_addr_fam_len(void)
     keylen = 6;
     if ((f1 = IPAddressFamily_new()) == NULL)
         goto end;
-    if (f1->ipAddressChoice == NULL &&
-        (f1->ipAddressChoice = IPAddressChoice_new()) == NULL)
+    if (f1->ipAddressChoice == NULL && (f1->ipAddressChoice = IPAddressChoice_new()) == NULL)
         goto end;
-    if (f1->addressFamily == NULL &&
-        (f1->addressFamily = ASN1_OCTET_STRING_new()) == NULL)
+    if (f1->addressFamily == NULL && (f1->addressFamily = ASN1_OCTET_STRING_new()) == NULL)
         goto end;
     if (!ASN1_OCTET_STRING_set(f1->addressFamily, key, keylen))
         goto end;
@@ -289,11 +287,9 @@ static int test_addr_fam_len(void)
     keylen = 3;
     if ((f1 = IPAddressFamily_new()) == NULL)
         goto end;
-    if (f1->ipAddressChoice == NULL &&
-        (f1->ipAddressChoice = IPAddressChoice_new()) == NULL)
+    if (f1->ipAddressChoice == NULL && (f1->ipAddressChoice = IPAddressChoice_new()) == NULL)
         goto end;
-    if (f1->addressFamily == NULL &&
-        (f1->addressFamily = ASN1_OCTET_STRING_new()) == NULL)
+    if (f1->addressFamily == NULL && (f1->addressFamily = ASN1_OCTET_STRING_new()) == NULL)
         goto end;
     if (!ASN1_OCTET_STRING_set(f1->addressFamily, key, keylen))
         goto end;
@@ -311,7 +307,7 @@ static int test_addr_fam_len(void)
         goto end;
 
     testresult = 1;
- end:
+end:
     /* Free stack and any memory owned by detached element */
     IPAddressFamily_free(f1);
     sk_IPAddressFamily_pop_free(addr, IPAddressFamily_free);
@@ -376,12 +372,12 @@ static int test_ext_syntax(void)
     for (i = 0; i < OSSL_NELEM(extvalues); i++) {
         X509V3_CTX ctx;
         BIO *extbio = BIO_new_mem_buf(extvalues[i].value,
-                                      strlen(extvalues[i].value));
+            strlen(extvalues[i].value));
         CONF *conf;
         long eline;
 
         if (!TEST_ptr(extbio))
-            return 0 ;
+            return 0;
 
         conf = NCONF_new_ex(NULL, NULL);
         if (!TEST_ptr(conf)) {
@@ -396,14 +392,14 @@ static int test_ext_syntax(void)
 
             if (extvalues[i].pass) {
                 if (!TEST_true(X509V3_EXT_add_nconf(conf, &ctx, "default",
-                                                    NULL))) {
+                        NULL))) {
                     TEST_info("Value: %s", extvalues[i].value);
                     testresult = 0;
                 }
             } else {
                 ERR_set_mark();
                 if (!TEST_false(X509V3_EXT_add_nconf(conf, &ctx, "default",
-                                                     NULL))) {
+                        NULL))) {
                     testresult = 0;
                     TEST_info("Value: %s", extvalues[i].value);
                     ERR_clear_last_mark();
@@ -435,22 +431,22 @@ static int test_addr_subset(void)
             || !TEST_ptr(ip1[i] = a2i_IPADDRESS(ranges[i].ip1))
             || !TEST_ptr(ip2[i] = a2i_IPADDRESS(ranges[i].ip2))
             || !TEST_true(X509v3_addr_add_range(addr[i], ranges[i].afi, NULL,
-                                                ip1[i]->data, ip2[i]->data)))
+                ip1[i]->data, ip2[i]->data)))
             goto end;
     }
 
     ret = TEST_ptr(addrEmpty = sk_IPAddressFamily_new_null())
-          && TEST_true(X509v3_addr_subset(NULL, NULL))
-          && TEST_true(X509v3_addr_subset(NULL, addr[0]))
-          && TEST_true(X509v3_addr_subset(addrEmpty, addr[0]))
-          && TEST_true(X509v3_addr_subset(addr[0], addr[0]))
-          && TEST_true(X509v3_addr_subset(addr[0], addr[1]))
-          && TEST_true(X509v3_addr_subset(addr[0], addr[2]))
-          && TEST_true(X509v3_addr_subset(addr[1], addr[2]))
-          && TEST_false(X509v3_addr_subset(addr[0], NULL))
-          && TEST_false(X509v3_addr_subset(addr[1], addr[0]))
-          && TEST_false(X509v3_addr_subset(addr[2], addr[1]))
-          && TEST_false(X509v3_addr_subset(addr[0], addrEmpty));
+        && TEST_true(X509v3_addr_subset(NULL, NULL))
+        && TEST_true(X509v3_addr_subset(NULL, addr[0]))
+        && TEST_true(X509v3_addr_subset(addrEmpty, addr[0]))
+        && TEST_true(X509v3_addr_subset(addr[0], addr[0]))
+        && TEST_true(X509v3_addr_subset(addr[0], addr[1]))
+        && TEST_true(X509v3_addr_subset(addr[0], addr[2]))
+        && TEST_true(X509v3_addr_subset(addr[1], addr[2]))
+        && TEST_false(X509v3_addr_subset(addr[0], NULL))
+        && TEST_false(X509v3_addr_subset(addr[1], addr[0]))
+        && TEST_false(X509v3_addr_subset(addr[2], addr[1]))
+        && TEST_false(X509v3_addr_subset(addr[0], addrEmpty));
 end:
     sk_IPAddressFamily_pop_free(addrEmpty, IPAddressFamily_free);
     for (i = 0; i < sz; ++i) {
